-- Update FSC_EXT_PARTY_ACCOUNT_DIM, add SCD2 columns
ALTER TABLE FCFCORE.FSC_EXT_PARTY_ACCOUNT_DIM
       ADD COLUMN change_begin_date    TIMESTAMP NOT NULL  DEFAULT CURRENT TIMESTAMP
       ADD COLUMN change_end_date      TIMESTAMP NOT NULL  DEFAULT TIMESTAMP('59990101000000')
       ADD COLUMN change_current_ind   CHAR(1) NOT NULL DEFAULT 'Y'
;

CREATE OR REPLACE VIEW FCFBU1.FSC_EXT_PARTY_ACCOUNT_DIM AS SELECT * FROM FCFCORE.FSC_EXT_PARTY_ACCOUNT_DIM;


-- Recreate the Alert Triage Datamart to contain entity numbers

---- Drop Datamart Views
DROP VIEW FCFBU1.FSK_ALERT_TX_AGG;
DROP VIEW FCFBU1.FSK_ENTITY_TX_AGG;
DROP VIEW FCFBU1.FSK_ALERTED_ENTITY;
DROP VIEW FCFBU1.FSK_ENTITY_TRANSACTION;
DROP VIEW FCFBU1.FSK_ALERT_TRANSACTION;

---- Drop Datamart Tables
DROP TABLE FCFKC.FSK_ENTITY_TX_AGG;
DROP TABLE FCFKC.FSK_ALERT_TX_AGG;
DROP TABLE FCFKC.FSK_ENTITY_TRANSACTION;
---- DROP TABLE FCFKC.FSK_ALERTED_ENTITY;
DROP TABLE FCFKC.FSK_ALERT_TRANSACTION;

---- Drop indexes, constraint and column
DROP INDEX FCFKC.XAK1FSK_ALERTED_ENTITY;
ALTER TABLE FCFKC.FSK_ALERTED_ENTITY DROP CONSTRAINT XPKFSK_ALERTED_ENTITY;
ALTER TABLE FCFKC.FSK_ALERTED_ENTITY DROP COLUMN alerted_entity_key;
ALTER TABLE FCFKC.FSK_ALERTED_ENTITY ALTER COLUMN alerted_entity_number SET NOT NULL;
REORG TABLE FCFKC.FSK_ALERTED_ENTITY;

CREATE UNIQUE INDEX FCFKC.XAK1FSK_ALERTED_ENTITY ON FCFKC.FSK_ALERTED_ENTITY
(alerted_entity_number   ASC,alerted_entity_level_code   ASC);

CREATE TABLE FCFKC.FSK_ALERT_TRANSACTION
(
	fsk_alert_transaction_pk NUMERIC(22) NOT NULL ,
	alerted_entity_level_code CHAR(3)  ,
	alerted_entity_number VARCHAR(50)  ,
	alert_id             NUMERIC(12)  ,
	transaction_id       VARCHAR(50)  ,
	transaction_amt      NUMERIC(15,3)  ,
	transaction_cdi_desc VARCHAR(30)  ,
	primary_medium_desc  VARCHAR(30)  ,
	secondary_medium_desc VARCHAR(30)  ,
	transaction_date     TIMESTAMP  ,
	transaction_mechanism VARCHAR(50)  ,
	account_number       VARCHAR(50)  ,
	beneficiary_name     VARCHAR(200)  ,
	associate_name       VARCHAR(250)  ,
	Branch_name          VARCHAR(100)  ,
	transaction_desc     VARCHAR(255)  ,
	transaction_status   VARCHAR(20)  ,
	triggering_indicator_cd VARCHAR(3)  ,
	created_timestamp    TIMESTAMP  ,
	date_key             NUMERIC(8)  ,
	time_key             NUMERIC(6)  ,
	CONSTRAINT  XPKFSK_ALERT_TRANSACTION PRIMARY KEY (fsk_alert_transaction_pk)
);

CREATE  INDEX FCFKC.XIF2FSK_ALERT_TRANSACTION ON FCFKC.FSK_ALERT_TRANSACTION
(alert_id   ASC);

CREATE  INDEX FCFKC.XIF3FSK_ALERT_TRANSACTION ON FCFKC.FSK_ALERT_TRANSACTION
(alerted_entity_level_code   ASC,alerted_entity_number   ASC);

CREATE TABLE FCFKC.FSK_ALERT_TX_AGG
(
	fsk_alert_tx_agg_pk  NUMERIC(12) NOT NULL ,
	alert_id             NUMERIC(12)  ,
	aggregate_type_code  VARCHAR(35)  ,
	group_code           VARCHAR(30)  ,
	group_desc           VARCHAR(30)  ,
	aggregate_amt        NUMERIC(15,3)  ,
	created_timestamp    TIMESTAMP  ,
	CONSTRAINT  XPKFSK_ALERT_TX_AGG PRIMARY KEY (fsk_alert_tx_agg_pk)
);

CREATE  INDEX FCFKC.XIF1FSK_ALERT_TX_AGG ON FCFKC.FSK_ALERT_TX_AGG
(alert_id   ASC);

CREATE TABLE FCFKC.FSK_ENTITY_TRANSACTION
(
	fsk_entity_transaction_pk NUMERIC(22) NOT NULL ,
	alerted_entity_level_code CHAR(3)  ,
	alerted_entity_number VARCHAR(50)  ,
	transaction_id       VARCHAR(50)  ,
	transaction_amt      NUMERIC(15,3)  ,
	transaction_cdi_desc VARCHAR(30)  ,
	primary_medium_desc  VARCHAR(30)  ,
	secondary_medium_desc VARCHAR(30)  ,
	transaction_date     TIMESTAMP  ,
	transaction_mechanism VARCHAR(50)  ,
	account_number       VARCHAR(50)  ,
	beneficiary_name     VARCHAR(200)  ,
	associate_name       VARCHAR(250)  ,
	Branch_name          VARCHAR(100)  ,
	transaction_desc     VARCHAR(255)  ,
	transaction_status   VARCHAR(20)  ,
	created_timestamp    TIMESTAMP  ,
	date_key             NUMERIC(8)  ,
	time_key             NUMERIC(6)  ,
	household_number     VARCHAR(50)  ,
	CONSTRAINT  XPKFSK_ENTITY_TRANSACTION PRIMARY KEY (fsk_entity_transaction_pk)
);

CREATE  INDEX FCFKC.XIF1FSK_ENTITY_TRANSACTION ON FCFKC.FSK_ENTITY_TRANSACTION
(alerted_entity_level_code   ASC,alerted_entity_number   ASC);

CREATE TABLE FCFKC.FSK_ENTITY_TX_AGG
(
	fsk_entity_tx_agg_pk NUMERIC(12) NOT NULL ,
	alerted_entity_level_code CHAR(3)  ,
	alerted_entity_number VARCHAR(50)  ,
	aggregate_type_code  VARCHAR(4)  ,
	group_code           VARCHAR(50)  ,
	group_desc           VARCHAR(50)  ,
	aggregate_amt        NUMERIC(15,3)  ,
	created_timestamp    TIMESTAMP  ,
	CONSTRAINT  XPKFSK_ENTITY_TX_AGG PRIMARY KEY (fsk_entity_tx_agg_pk)
);

CREATE  INDEX FCFKC.XIF1FSK_ENTITY_TX_AGG ON FCFKC.FSK_ENTITY_TX_AGG
(alerted_entity_level_code   ASC,alerted_entity_number   ASC);

---- Create Grants for new tables
GRANT SELECT, INSERT, DELETE, UPDATE on FCFKC.FSK_ALERT_TX_AGG to FCFBU1;
GRANT SELECT, INSERT, DELETE, UPDATE on FCFKC.FSK_ENTITY_TX_AGG to FCFBU1;
GRANT SELECT, INSERT, DELETE, UPDATE on FCFKC.FSK_ALERTED_ENTITY to FCFBU1;
GRANT SELECT, INSERT, DELETE, UPDATE on FCFKC.FSK_ALERT_TRANSACTION to FCFBU1;
GRANT SELECT, INSERT, DELETE, UPDATE on FCFKC.FSK_ENTITY_TRANSACTION to FCFBU1;


---- Create Views
CREATE  VIEW FCFBU1.FSK_ALERT_TX_AGG AS SELECT * FROM FCFKC.FSK_ALERT_TX_AGG;
CREATE  VIEW FCFBU1.FSK_ENTITY_TX_AGG AS SELECT * FROM FCFKC.FSK_ENTITY_TX_AGG;
CREATE  VIEW FCFBU1.FSK_ALERTED_ENTITY AS SELECT * FROM FCFKC.FSK_ALERTED_ENTITY;
CREATE  VIEW FCFBU1.FSK_ALERT_TRANSACTION AS SELECT * FROM FCFKC.FSK_ALERT_TRANSACTION;
CREATE  VIEW FCFBU1.FSK_ENTITY_TRANSACTION AS SELECT * FROM FCFKC.FSK_ENTITY_TRANSACTION;


-- modify FSC_PARTY_DIM for Beneficial Ownership support
ALTER TABLE FCFCORE.FSC_PARTY_DIM ADD COLUMN ben_own_exempt_ind   CHAR(1)  NULL DEFAULT 'N';
CREATE OR REPLACE VIEW FCFBU1.FSC_PARTY_DIM AS SELECT * FROM FCFCORE.FSC_PARTY_DIM;

-- modify FSC_ACCOUNT_DIM for Beneficial Ownership support
ALTER TABLE FCFCORE.FSC_ACCOUNT_DIM
      ADD COLUMN opened_by_party_number       VARCHAR(50) NULL
      ADD COLUMN opened_by_party_name         VARCHAR(200) NULL
      ADD COLUMN opened_by_party_title        VARCHAR(50) NULL
;
CREATE OR REPLACE VIEW FCFBU1.FSC_ACCOUNT_DIM AS SELECT * FROM FCFCORE.FSC_ACCOUNT_DIM;

ALTER TABLE FCFKC.FSK_CASE
   ALTER COLUMN case_description SET DATA TYPE VARCHAR(100);

CREATE OR REPLACE VIEW FCFBU1.FSK_CASE AS SELECT * FROM FCFKC.FSK_CASE;
