--------------------------------------------------------------
--------------------------------------------------------------
--KNOWLEDGE CENTER TABLE, INDEX, AND TABLESPACE CREATION TEMPLATE
--------------------------------------------------------------
--This script is a template for creating the tablespaces, tables,
--indexes, and constraints required for the 'KNOWLEDGE CENTER' AML
--schema.
--
--This script is only a template.  It must be customized
--to the physical environment and volume of data expected.
--
--This script must be run as an account with DBA privileges.
--
--This script assumes that one banking segment is being
--created (FCFBU1).
--------------------------------------------------------------
--------------------------------------------------------------
CREATE TABLE FCFKC.FSK_ACCOUNT_EVENT_ALERT (
     ALERT_ID             NUMERIC(12)     NOT NULL,
     TRANSACTION_KEY      NUMERIC(12)     NOT NULL,
     ACCOUNT_KEY          NUMERIC(12)     NOT NULL,
     DATE_KEY             NUMERIC(8,0)     NOT NULL,
     TRANSACTION_TYPE_KEY NUMERIC(12)     NOT NULL,
     TIME_KEY             NUMERIC(6)     NOT NULL,
     COUNTRY_KEY          NUMERIC(5)     NOT NULL,
     BRANCH_KEY           NUMERIC(12)     NOT NULL,
     TRANSACTION_STATUS_KEY NUMERIC(5)     NOT NULL,
     TRIGGER_IND          CHAR(1),
     PRIMARY KEY (ALERT_ID, TRANSACTION_KEY)
);
CREATE INDEX XIE1FSK_ACCOUNT_EVENT_ALERT ON 
FCFKC.FSK_ACCOUNT_EVENT_ALERT( account_key );
CREATE INDEX XIE2FSK_ACCOUNT_EVENT_ALERT ON 
FCFKC.FSK_ACCOUNT_EVENT_ALERT( transaction_key );
CREATE INDEX XIE3FSK_ACCOUNT_EVENT_ALERT ON 
FCFKC.FSK_ACCOUNT_EVENT_ALERT( transaction_type_key );
CREATE INDEX XIE4FSK_ACCOUNT_EVENT_ALERT ON 
FCFKC.FSK_ACCOUNT_EVENT_ALERT( branch_key );
CREATE INDEX XIE5FSK_ACCOUNT_EVENT_ALERT ON 
FCFKC.FSK_ACCOUNT_EVENT_ALERT( date_key );

CREATE TABLE FCFKC.FSK_ACCOUNT_KEYS_ACC (
     ALERT_ID             NUMERIC(12)     NOT NULL,
     ACCOUNT_KEY          NUMERIC(12)     NOT NULL,
     RUN_DATE             DATE,
     PRIMARY KEY (ALERT_ID, ACCOUNT_KEY)
);

CREATE TABLE FCFKC.FSK_ACCOUNT_KEYS_ASC (
     ALERT_ID             NUMERIC(12)     NOT NULL,
     ACCOUNT_KEY          NUMERIC(12)     NOT NULL,
     RUN_DATE             DATE,
     PRIMARY KEY (ALERT_ID, ACCOUNT_KEY)
);
CREATE INDEX XIE1FSK_ACCOUNT_KEYS_ASC ON 
FCFKC.FSK_ACCOUNT_KEYS_ASC( account_key );

CREATE TABLE FCFKC.FSK_ACCOUNT_KEYS_HHD (
     ALERT_ID             NUMERIC(12)     NOT NULL,
     ACCOUNT_KEY          NUMERIC(12)     NOT NULL,
     RUN_DATE             DATE,
     PRIMARY KEY (ALERT_ID, ACCOUNT_KEY)
);
CREATE INDEX XIEFSK_ACCOUNT_KEYS_HHD ON 
FCFKC.FSK_ACCOUNT_KEYS_HHD( account_key );

CREATE TABLE FCFKC.FSK_ACCOUNT_KEYS_PTY (
     ALERT_ID             NUMERIC(12)     NOT NULL,
     ACCOUNT_KEY          NUMERIC(12)     NOT NULL,
     RUN_DATE             DATE,
     PRIMARY KEY (ALERT_ID, ACCOUNT_KEY)
);
CREATE INDEX XIE1FSK_ACCOUNT_KEYS_PTY ON 
FCFKC.FSK_ACCOUNT_KEYS_PTY( account_key );

CREATE TABLE FCFKC.FSK_ACCOUNT_PROFILE_ALERT (
     ALERT_ID             NUMERIC(12)     NOT NULL,
     MONTH_KEY            NUMERIC(6,0)     NOT NULL,
     ACCOUNT_NUMBER       VARCHAR(50)     NOT NULL,
     TRANSACTIONS_COUNT   NUMERIC(10,0),
     DEPOSITS_COUNT       NUMERIC(10,0),
     WITHDRAWALS_COUNT    NUMERIC(10,0),
     WIRES_COUNT          NUMERIC(10,0),
     CASH_TRANSACTIONS_COUNT NUMERIC(10,0),
     ACCOUNT_VALUE_AMOUNT NUMERIC(18,5),
     TOTAL_TRANSACTIONS_AMOUNT NUMERIC(18,5),
     TOTAL_CREDITS_AMOUNT NUMERIC(18,5),
     TOTAL_DEBITS_AMOUNT  NUMERIC(18,5),
     TOTAL_CASH_DEBITS_AMOUNT NUMERIC(18,5),
     TOTAL_CASH_CREDITS_AMOUNT NUMERIC(18,5),
     TOTAL_WIRE_CREDITS_AMOUNT NUMERIC(18,5),
     TOTAL_WIRE_DEBITS_AMOUNT NUMERIC(18,5),
     BEGINNING_BALANCE_AMOUNT NUMERIC(18,5),
     AVERAGE_DAILY_BALANCE_AMOUNT NUMERIC(18,5),
     ENDING_CASH_BALANCE_AMOUNT NUMERIC(18,5),
     MAX_ACCOUNT_VALUE_AMOUNT NUMERIC(18,5),
     MIN_ACCOUNT_VALUE_AMOUNT NUMERIC(18,5),
     AVG_ACCOUNT_VALUE_AMOUNT NUMERIC(18,5),
     CUST_INITIATED_TRANS_COUNT NUMERIC(10),
     LARGEST_CREDIT_AMOUNT NUMERIC(18,5),
     LARGEST_DEBIT_AMOUNT NUMERIC(18,5),
     PRIMARY KEY (ALERT_ID, MONTH_KEY, ACCOUNT_NUMBER)
);

CREATE TABLE FCFKC.FSK_ACCOUNT_TRADE_ALERT (
     ALERT_ID             NUMERIC(12)     NOT NULL,
     TRANSACTION_KEY      NUMERIC(12)     NOT NULL,
     ACCOUNT_KEY          NUMERIC(12)     NOT NULL,
     BRANCH_KEY           NUMERIC(12),
     TRANSACTION_TYPE_KEY NUMERIC(12),
     TRANSACTION_STATUS_KEY NUMERIC(5),
     TRADE_DATE_KEY       NUMERIC(8,0),
     ASSOCIATE_KEY        NUMERIC(12),
     EXECUTION_TIME_KEY   NUMERIC(6),
     POSTED_DATE_KEY      NUMERIC(8)     NOT NULL,
     SETTLEMENT_DATE_KEY  NUMERIC(8,0)     NOT NULL,
     QUANTITY_EXECUTED    NUMERIC(15,5),
     EXECUTION_PRICE      NUMERIC(10,5),
     TRANSACTION_CURRENCY_KEY NUMERIC(5),
     PRINCIPAL_AMOUNT_IN_TXN_CCY NUMERIC(15,5),
     PRINCIPAL_AMOUNT     NUMERIC(15,5),
     PRINCIPAL_AMOUNT_IN_ACCT_CCY NUMERIC(15,5)     NOT NULL,
     TRIGGER_IND          CHAR(1),
     PRIMARY KEY (ALERT_ID, TRANSACTION_KEY)
);
CREATE INDEX XIE1FSK_ACCOUNT_TRADE_ALERT ON 
FCFKC.FSK_ACCOUNT_TRADE_ALERT( account_key );
CREATE INDEX XIE2FSK_ACCOUNT_TRADE_ALERT ON 
FCFKC.FSK_ACCOUNT_TRADE_ALERT( transaction_key,transaction_type_key );
CREATE INDEX XIE3FSK_ACCOUNT_TRADE_ALERT ON 
FCFKC.FSK_ACCOUNT_TRADE_ALERT( associate_key );

CREATE TABLE FCFKC.FSK_ALERT (
     ALERT_ID             NUMERIC(12)     NOT NULL,
     PRODUCT_TYPE         CHAR(3)     NOT NULL,
     ALERT_STATUS_CODE    CHAR(3)     NOT NULL,
     MONEY_LAUNDERING_RISK_SCORE NUMERIC(3)     NOT NULL,
     TERROR_FINANCING_RISK_SCORE NUMERIC(3),
     ALERT_DESCRIPTION    VARCHAR(100)     NOT NULL,
     PRIMARY_ENTITY_LEVEL_CODE CHAR(3)     NOT NULL,
     ALERTED_ENTITY_NUMBER VARCHAR(50)     NOT NULL,
     ALERTED_ENTITY_NAME  VARCHAR(35),
     PRIMARY_ENTITY_NUMBER VARCHAR(50)     NOT NULL,
     PRIMARY_ENTITY_KEY   NUMERIC(12),
     PRIMARY_ENTITY_NAME  VARCHAR(35),
     SCENARIO_ID          NUMERIC(12),
     SCENARIO_NAME        VARCHAR(35),
     SUPPRESSION_END_DATE DATE,
     ACTUAL_VALUES_TEXT   VARCHAR(255),
     RUN_DATE             DATE     NOT NULL,
     CREATE_DATE          DATE     NOT NULL,
     CREATE_USER_ID       VARCHAR(60)     NOT NULL,
     EMPLOYEE_IND         CHAR(1),
     VERSION_NUMBER       NUMERIC(10)     NOT NULL,
     LOGICAL_DELETE_IND   CHAR(1)     NOT NULL,
     ALERT_TYPE_CD        VARCHAR(32),
     ALERT_CATEGORY_CD    VARCHAR(32),
     ALERT_SUBCATEGORY_CD VARCHAR(32),
     ALERTED_ENTITY_KEY   NUMERIC(12),
     ALERTED_ENTITY_LEVEL_CODE CHAR(3),
     ENTITY_SEGMENT_ID    NUMERIC(12),
     PRIMARY KEY (ALERT_ID)
);
CREATE INDEX XIE5FSK_ALERT ON 
FCFKC.FSK_ALERT( primary_entity_key );
CREATE INDEX XIE6FSK_ALERT ON 
FCFKC.FSK_ALERT( primary_entity_name );
CREATE INDEX XIE9FSK_ALERT ON 
FCFKC.FSK_ALERT( primary_entity_number );

CREATE TABLE FCFKC.FSK_ALERTED_ENTITY (
     ALERTED_ENTITY_LEVEL_CODE VARCHAR(3)     NOT NULL,
     ALERTED_ENTITY_NUMBER VARCHAR(50)     NOT NULL,
     ALERTED_ENTITY_NAME  VARCHAR(35),
     ALERTS_CNT           NUMERIC(4),
     TRANSACTIONS_CNT     NUMERIC(8),
     AGGREGATE_AMT        NUMERIC(15,3),
     AGE_OLDEST_ALERT     NUMERIC(4),
     RISK_SCORE_CODE      VARCHAR(32),
     MONEY_LAUNDERING_SCORE NUMERIC(4),
     EMPLOYEE_IND         CHAR(1),
     OWNER_USERID         VARCHAR(240),
     POLITICALLY_EXPOSED_PERSON_IND CHAR(1),
     CREATED_TIMESTAMP    DATE,
     ENTITY_SEGMENT_ID    NUMERIC(12),
     PRIMARY KEY (ALERTED_ENTITY_LEVEL_CODE, ALERTED_ENTITY_NUMBER)
);

CREATE TABLE FCFKC.FSK_ALERT_CASE (
     CASE_ID              NUMERIC(12)     NOT NULL,
     ALERT_ID             NUMERIC(12)     NOT NULL,
     LSTUPDATE_USER_ID    VARCHAR(60)     NOT NULL,
     LSTUPDATE_DATE       DATE     NOT NULL,
     VERSION_NUMBER       NUMERIC(10)     NOT NULL,
     PRIMARY KEY (CASE_ID, ALERT_ID)
);
CREATE INDEX XIE1FSK_ALERT_CASE ON 
FCFKC.FSK_ALERT_CASE( alert_id );

CREATE TABLE FCFKC.FSK_ALERT_EMAIL (
     EMAIL_ID             NUMERIC(12)     NOT NULL,
     ALERT_ID             NUMERIC(12)     NOT NULL,
     EMAIL_TO_TEXT        VARCHAR(2000)     NOT NULL,
     EMAIL_CC_TEXT        VARCHAR(2000),
     EMAIL_SUBJECT_DESC   VARCHAR(255),
     EMAIL_MESSAGE_TEXT   VARCHAR(2000),
     CREATE_DATE          DATE     NOT NULL,
     CREATE_USER_ID       VARCHAR(60)     NOT NULL,
     PRIMARY KEY (EMAIL_ID)
);

CREATE TABLE FCFKC.FSK_ALERT_EVENT (
     EVENT_ID             NUMERIC(12)     NOT NULL,
     ALERT_ID             NUMERIC(12)     NOT NULL,
     EVENT_TYPE_CODE      CHAR(3)     NOT NULL,
     EVENT_DESCRIPTION    VARCHAR(255),
     CREATE_DATE          DATE     NOT NULL,
     CREATE_USER_ID       VARCHAR(60)     NOT NULL,
     PRIMARY KEY (EVENT_ID)
);
CREATE INDEX XIE1FSK_ALERT_EVENT ON 
FCFKC.FSK_ALERT_EVENT( create_date,event_type_code,alert_id );

CREATE TABLE FCFKC.FSK_ALERT_NEIGHBOR (
     ALERT_ID             NUMERIC(12)     NOT NULL,
     TARGET_ACCOUNT_NUMBER VARCHAR(50)     NOT NULL,
     NEIGHBOR_ACCOUNT_NUMBER VARCHAR(50)     NOT NULL,
     DISTANCE             NUMERIC(4,3),
     PRIMARY KEY (ALERT_ID, TARGET_ACCOUNT_NUMBER, NEIGHBOR_ACCOUNT_NUMBER)
);
CREATE INDEX XIE1FSK_ALERT_NEIGHBOR ON 
FCFKC.FSK_ALERT_NEIGHBOR( target_account_number );
CREATE INDEX XIE2FSK_ALERT_NEIGHBOR ON 
FCFKC.FSK_ALERT_NEIGHBOR( neighbor_account_number );

CREATE TABLE FCFKC.FSK_ALERT_REMINDER (
     ALERT_ID             NUMERIC(12)     NOT NULL,
     REMINDER_DATE        DATE     NOT NULL,
     USER_LONG_ID         VARCHAR(60)     NOT NULL,
     REMINDER_SENT_IND    CHAR(1),
     PRIMARY KEY (ALERT_ID, REMINDER_DATE, USER_LONG_ID)
);

CREATE TABLE FCFKC.FSK_ALERT_RISK_FACTOR (
     ENTITY_NUMBER        VARCHAR(50)     NOT NULL,
     ALERT_ID             NUMERIC(12)     NOT NULL,
     SCENARIO_ID          NUMERIC(12)     NOT NULL,
     ENTITY_LEVEL_CODE    CHAR(3)     NOT NULL,
     ACTUAL_VALUES_TEXT   VARCHAR(255),
     PRIMARY KEY (ENTITY_NUMBER, ALERT_ID, SCENARIO_ID)
);
CREATE INDEX XIE2FSK_ALERT_RISK_FACTOR ON 
FCFKC.FSK_ALERT_RISK_FACTOR( entity_number );

CREATE TABLE FCFKC.FSK_ALERT_TRANSACTION (
     FSK_ALERT_TRANSACTION_PK NUMERIC(22)     NOT NULL,
     ALERTED_ENTITY_LEVEL_CODE VARCHAR(3),
     ALERTED_ENTITY_NUMBER VARCHAR(50),
     ALERT_ID             NUMERIC(12),
     TRANSACTION_ID       VARCHAR(50),
     TRANSACTION_AMT      NUMERIC(15,3),
     TRANSACTION_CDI_DESC VARCHAR(30),
     PRIMARY_MEDIUM_DESC  VARCHAR(30),
     SECONDARY_MEDIUM_DESC VARCHAR(30),
     TRANSACTION_DATE     DATE,
     TRANSACTION_MECHANISM VARCHAR(50),
     ACCOUNT_NUMBER       VARCHAR(50),
     BENEFICIARY_NAME     VARCHAR(200),
     ASSOCIATE_NAME       VARCHAR(250),
     BRANCH_NAME          VARCHAR(100),
     TRANSACTION_DESC     VARCHAR(255),
     TRANSACTION_STATUS   VARCHAR(20),
     TRIGGERING_INDICATOR_CD VARCHAR(3),
     CREATED_TIMESTAMP    DATE,
     DATE_KEY             NUMERIC(8),
     TIME_KEY             NUMERIC(6),
     PRIMARY KEY (FSK_ALERT_TRANSACTION_PK)
);
CREATE INDEX XIF3FSK_ALERT_TRANSACTION ON 
FCFKC.FSK_ALERT_TRANSACTION( alerted_entity_level_code,alerted_entity_number );

CREATE TABLE FCFKC.FSK_ALERT_TX_AGG (
     FSK_ALERT_TX_AGG_PK  NUMERIC(12)     NOT NULL,
     ALERT_ID             NUMERIC(12),
     AGGREGATE_TYPE_CODE  VARCHAR(35),
     GROUP_CODE           VARCHAR(30),
     GROUP_DESC           VARCHAR(30),
     AGGREGATE_AMT        NUMERIC(15,3),
     CREATED_TIMESTAMP    DATE,
     PRIMARY KEY (FSK_ALERT_TX_AGG_PK)
);
CREATE INDEX XIF1FSK_ALERT_TX_AGG ON 
FCFKC.FSK_ALERT_TX_AGG( alert_id );

CREATE TABLE FCFKC.FSK_ASSESSMENT_ROUTING_RULE (
     ROUTING_RULE_ID      NUMERIC(12)     NOT NULL,
     LIST_ID              NUMERIC(12),
     RISK_ASSESSMENT_COLUMN_NAME VARCHAR(30)     NOT NULL,
     ROUTE_PRIORITY_NUMBER NUMERIC(3),
     ASSESSMENT_TYPE_CD   VARCHAR(32),
     ASSESSMENT_CATEGORY_CD VARCHAR(32),
     ASSESSMENT_SUBCATEGORY_CD VARCHAR(32),
     ROUTING_USER_LONG_ID VARCHAR(60),
     PRIMARY KEY (ROUTING_RULE_ID)
);

CREATE TABLE FCFKC.FSK_ASSESSMENT_SEQUENCE (
     NEXT_SEQUENCE_ID     NUMERIC(12)     NOT NULL
);

CREATE TABLE FCFKC.FSK_ATTACHMENT (
     ATTACHMENT_ID        NUMERIC(12)     NOT NULL,
     ATTACHMENT_NAME      VARCHAR(255)     NOT NULL,
     ATTACHMENT_DESC      VARCHAR(255),
     ATTACHMENT_PATH      VARCHAR(2000)     NOT NULL,
     ATTACHMENT_MIME_TYPE_DESC VARCHAR(255)     NOT NULL,
     CREATE_DATE          DATE     NOT NULL,
     CREATE_USER_ID       VARCHAR(60)     NOT NULL,
     OBJECT_TYPE_CD       CHAR(3)     NOT NULL,
     OBJECT_ID            VARCHAR(50)     NOT NULL,
     LOGICAL_DELETE_IND   CHAR(1)     NOT NULL,
     COMMENT_ID           NUMERIC(12),
     ATTACHMENT_SIZE      NUMERIC(12)     NOT NULL,
     PRIMARY KEY (ATTACHMENT_ID)
);

CREATE TABLE FCFKC.FSK_CASE (
     CASE_ID              NUMERIC(12)     NOT NULL,
     CASE_CATEGORY_CODE   VARCHAR(32)     NOT NULL,
     CASE_SUB_CATEGORY_CODE VARCHAR(32)     NOT NULL,
     CASE_PRIORITY_CODE   VARCHAR(32)     NOT NULL,
     CASE_TYPE_CODE       VARCHAR(32)     NOT NULL,
     CASE_CLOSE_REASON_CODE VARCHAR(3),
     CASE_DESCRIPTION     VARCHAR(100),
     CASE_SUMMARY         VARCHAR(2000),
     AGGREGATE_AMT        NUMERIC(15,3),
     LE_CONTACTED_IND     CHAR(1)     NOT NULL,
     LE_CONTACT_AGENCY    VARCHAR(150),
     LE_CONTACT_NAME      VARCHAR(150),
     LE_CONTACT_PHONE     VARCHAR(16),
     LE_CONTACT_PHONE_EXT VARCHAR(16),
     LE_CONTACT_DATE      DATE,
     CREATE_DATE          DATE     NOT NULL,
     CREATE_USER_ID       VARCHAR(60)     NOT NULL,
     OPENED_IND           CHAR(1)     NOT NULL,
     MODIFIED_IND         CHAR(1)     NOT NULL,
     EMPLOYEE_IND         CHAR(1)     NOT NULL,
     CASE_STATUS_CODE     VARCHAR(3)     NOT NULL,
     FIRST_TRANSACTION_DATE DATE,
     LAST_TRANSACTION_DATE DATE,
     VERSION_NUMBER       NUMERIC(10)     NOT NULL,
     LOGICAL_DELETE_IND   CHAR(1)     NOT NULL,
     LSTUPDATE_USER_ID    VARCHAR(60),
     LSTUPDATE_DATE       DATE     NOT NULL,
     OWNER_USER_LONG_ID   VARCHAR(60),
     ACTIVATE_DATE        TIMESTAMP,
     PRIMARY KEY (CASE_ID)
);

CREATE TABLE FCFKC.FSK_CASE_ENTITY (
     CASE_ID              NUMERIC(12)     NOT NULL,
     ENTITY_LEVEL_CODE    CHAR(3)     NOT NULL,
     ENTITY_KEY           NUMERIC(12)     NOT NULL,
     ENTITY_NUMBER        VARCHAR(50),
     ENTITY_NAME          VARCHAR(35),
     PRIMARY_SUSPECT_IND  CHAR(1)     NOT NULL,
     RELATION_DESCRIPTION VARCHAR(32),
     LSTUPDATE_DATE       DATE     NOT NULL,
     LSTUPDATE_USER_ID    VARCHAR(60)     NOT NULL,
     VERSION_NUMBER       NUMERIC(10,0)     NOT NULL,
     RR_IND               CHAR(1),
     PRIMARY KEY (CASE_ID, ENTITY_LEVEL_CODE, ENTITY_KEY)
);
CREATE INDEX XIE1FSK_CASE_ENTITY ON 
FCFKC.FSK_CASE_ENTITY( case_id,entity_level_code,entity_number );

CREATE TABLE FCFKC.FSK_CASE_ENTITY_EVENT (
     EVENT_ID             NUMERIC(12)     NOT NULL,
     CASE_ID              NUMERIC(12)     NOT NULL,
     EVENT_TYPE_CODE      CHAR(3)     NOT NULL,
     ENTITY_KEY           NUMERIC(12),
     ENTITY_LEVEL_CODE    CHAR(3),
     CREATE_USER_ID       VARCHAR(60)     NOT NULL,
     CREATE_DATE          DATE     NOT NULL,
     EVENT_DESCRIPTION    VARCHAR(225),
     PRIMARY KEY (EVENT_ID)
);
CREATE INDEX XIE1FSK_CASE_ENTITY_EVENT ON 
FCFKC.FSK_CASE_ENTITY_EVENT( case_id );

CREATE TABLE FCFKC.FSK_CASE_ENTITY_TRANSACTION (
     CASE_ID              NUMERIC(12)     NOT NULL,
     ALERTED_ENTITY_NUMBER VARCHAR(50)     NOT NULL,
     ALERTED_ENTITY_LEVEL_CODE CHAR(3)     NOT NULL,
     TRANSACTION_ID       VARCHAR(50)     NOT NULL,
     ALERTED_ENTITY_KEY   NUMERIC(12),
     TRANSACTION_AMT      NUMERIC(15,3),
     TRANSACTION_CDI_DESC VARCHAR(30),
     PRIMARY_MEDIUM_DESC  VARCHAR(30),
     SECONDARY_MEDIUM_DESC VARCHAR(30),
     TRANSACTION_DATE     DATE,
     TRANSACTION_MECHANISM VARCHAR(50),
     ACCOUNT_NUMBER       VARCHAR(50),
     BENEFICIARY_NAME     VARCHAR(200)     NOT NULL,
     ASSOCIATE_NAME       VARCHAR(250),
     BRANCH_NAME          VARCHAR(100),
     TRANSACTION_DESC     VARCHAR(255),
     TRANSACTION_STATUS   VARCHAR(20),
     CREATED_TIMESTAMP    DATE,
     DATE_KEY             NUMERIC(8),
     TIME_KEY             NUMERIC(6),
     HOUSEHOLD_NAME       VARCHAR(50),
     PRIMARY KEY (CASE_ID, ALERTED_ENTITY_NUMBER, ALERTED_ENTITY_LEVEL_CODE,
      TRANSACTION_ID)
);

CREATE TABLE FCFKC.FSK_CASE_EVENT (
     EVENT_ID             NUMERIC(12)     NOT NULL,
     CASE_ID              NUMERIC(12),
     EVENT_TYPE_CODE      CHAR(3)     NOT NULL,
     EVENT_DESCRIPTION    VARCHAR(255),
     CREATE_USER_ID       VARCHAR(60)     NOT NULL,
     CREATE_DATE          DATE     NOT NULL,
     PRIMARY KEY (EVENT_ID)
);
CREATE INDEX XIE1FSK_CASE_EVENT ON 
FCFKC.FSK_CASE_EVENT( case_id );

CREATE TABLE FCFKC.FSK_CASE_TRANSACTION (
     CASE_ID              NUMERIC(12)     NOT NULL,
     ALERT_ID             NUMERIC(12)     NOT NULL,
     TRANSACTION_ID       VARCHAR(50)     NOT NULL,
     ALERTED_ENTITY_KEY   NUMERIC(12),
     ALERTED_ENTITY_LEVEL_CODE CHAR(3),
     TRANSACTION_AMT      NUMERIC(15,3),
     TRANSACTION_CDI_DESC VARCHAR(30),
     PRIMARY_MEDIUM_DESC  VARCHAR(30),
     SECONDARY_MEDIUM_DESC VARCHAR(30),
     TRANSACTION_DATE     DATE,
     TRANSACTION_MECHANISM VARCHAR(50),
     ACCOUNT_NUMBER       VARCHAR(50),
     BENEFICIARY_NAME     VARCHAR(200),
     ASSOCIATE_NAME       VARCHAR(250),
     BRANCH_NAME          VARCHAR(100),
     TRANSACTION_DESC     VARCHAR(255),
     TRANSACTION_STATUS   VARCHAR(20),
     TRIGGERING_INDICATOR_CD VARCHAR(3),
     CREATED_TIMESTAMP    DATE,
     DATE_KEY             NUMERIC(8),
     TIME_KEY             NUMERIC(6),
     PRIMARY KEY (CASE_ID, ALERT_ID, TRANSACTION_ID)
);

CREATE TABLE FCFKC.FSK_CASH_FLOW_ALERT (
     ALERT_ID             NUMERIC(12)     NOT NULL,
     TRANSACTION_KEY      NUMERIC(12)     NOT NULL,
     ACCOUNT_KEY          NUMERIC(12)     NOT NULL,
     DATE_KEY             NUMERIC(8,0)     NOT NULL,
     TIME_KEY             NUMERIC(6)     NOT NULL,
     TRANSACTION_TYPE_KEY NUMERIC(12)     NOT NULL,
     COUNTRY_KEY          NUMERIC(5)     NOT NULL,
     TRANSACTION_STATUS_KEY NUMERIC(5)     NOT NULL,
     REMITTER_EXT_PARTY_KEY NUMERIC(12),
     BENEFICIARY_EXT_PARTY_KEY NUMERIC(12)     NOT NULL,
     TRANSACTION_CURRENCY_KEY NUMERIC(5)     NOT NULL,
     BRANCH_KEY           NUMERIC(12)     NOT NULL,
     POSTED_DATE_KEY      NUMERIC(8),
     ASSOCIATE_KEY        NUMERIC(12),
     EXECUTING_PARTY_KEY  NUMERIC(12),
     EXECUTING_EXT_PARTY_KEY NUMERIC(12),
     CURRENCY_AMOUNT      NUMERIC(18,5),
     CURRENCY_AMOUNT_IN_TXN_CCY NUMERIC(18,5),
     CURRENCY_AMOUNT_IN_ACCOUNT_CCY NUMERIC(18,5),
     SECONDARY_ACCOUNT_KEY NUMERIC(12)     NOT NULL,
     RELATED_IND          CHAR(1)     NOT NULL,
     TRIGGER_IND          CHAR(1),
     THIRD_PARTY_IND      CHAR(1),
     PRIMARY KEY (ALERT_ID, TRANSACTION_KEY)
);
CREATE INDEX XIE1FSK_CASH_FLOW_ALERT ON 
FCFKC.FSK_CASH_FLOW_ALERT( account_key );
CREATE INDEX XIE2FSK_CASH_FLOW_ALERT ON 
FCFKC.FSK_CASH_FLOW_ALERT( transaction_key,transaction_type_key );
CREATE INDEX XIE3FSK_CASH_FLOW_ALERT ON 
FCFKC.FSK_CASH_FLOW_ALERT( associate_key );
CREATE INDEX XIE4FSK_CASH_FLOW_ALERT ON 
FCFKC.FSK_CASH_FLOW_ALERT( executing_party_key );
CREATE INDEX XIE5FSK_CASH_FLOW_ALERT ON 
FCFKC.FSK_CASH_FLOW_ALERT( date_key );

CREATE TABLE FCFKC.FSK_CASH_FLOW_BANK_ALERT (
     ALERT_ID             NUMERIC(12)     NOT NULL,
     BANK_KEY             NUMERIC(12)     NOT NULL,
     TRANSACTION_KEY      NUMERIC(12)     NOT NULL,
     ROLE_DESC            VARCHAR(20),
     SEQUENCE_NUMBER      NUMERIC(2),
     PRIMARY KEY (ALERT_ID, BANK_KEY, TRANSACTION_KEY)
);

CREATE TABLE FCFKC.FSK_CDD_RULE (
     CDD_RULE_ID          VARCHAR(32)     NOT NULL,
     VERSION_NO           NUMERIC(10)     NOT NULL,
     CURRENT_IND          CHAR(1),
     CDD_UPDATE_DATE      DATE     NOT NULL,
     CDD_CREATE_DATE      DATE     NOT NULL,
     CDD_RULE_NAME        VARCHAR(100)     NOT NULL,
     CDD_RULE_DESCRIPTION VARCHAR(100)     NOT NULL,
     CDD_RULE_STATUS_CODE VARCHAR(32)     NOT NULL,
     CDD_RULE_TYPE_CODE   VARCHAR(32)     NOT NULL,
     CDD_RULE_SAVE_ID_FLG CHAR(1),
     CDD_RULE_ORDER_IN_GROUP NUMERIC(12)     NOT NULL,
     CDD_RULE_GROUP_ID    VARCHAR(32),
     LOGICAL_DELETE_IND   CHAR(1),
     CREATE_USER_ID       VARCHAR(60),
     LSTUPDATE_USER_ID    VARCHAR(60),
     PRIMARY KEY (CDD_RULE_ID, VERSION_NO)
);

CREATE TABLE FCFKC.FSK_CDD_RULE_GROUP (
     CDD_RULE_GROUP_ID    VARCHAR(32)     NOT NULL,
     VERSION_NO           NUMERIC(10)     NOT NULL,
     CURRENT_IND          CHAR(1),
     CDD_UPDATE_DATE      DATE     NOT NULL,
     CDD_CREATE_DATE      DATE     NOT NULL,
     CDD_RULE_GROUP_FILE_NAME VARCHAR(128),
     CDD_RULE_GROUP_TYPE  VARCHAR(32)     NOT NULL,
     CDD_RULE_GROUP_CATEGORY_CODE VARCHAR(32),
     CDD_RULE_GROUP_DESCRIPTION VARCHAR(100)     NOT NULL,
     CDD_RULE_GROUP_NAME  VARCHAR(100)     NOT NULL,
     CDD_RULE_GROUP_INPUT_DS_NAME VARCHAR(32),
     CDD_RULE_GROUP_BY_VAR_1_NAME VARCHAR(32),
     CDD_RULE_GROUP_BY_VAR_2_NAME VARCHAR(32),
     CDD_RULE_GROUP_LEVEL NUMERIC(10),
     CDD_RULE_GROUP_ORDER_IN_LEVEL NUMERIC(10),
     CDD_RULE_GROUP_SAVE_TO_KC_FLG CHAR(1),
     CDD_RULE_GROUP_SAVE_TRIG_V_FLG CHAR(1),
     LSTUPDATE_USER_ID    VARCHAR(60),
     LOGICAL_DELETE_IND   CHAR(1),
     CREATE_USER_ID       VARCHAR(60),
     PRIMARY KEY (CDD_RULE_GROUP_ID, VERSION_NO)
);

CREATE TABLE FCFKC.FSK_CDD_RULE_PARAMETER (
     CDD_RULE_VERSION_NO  NUMERIC(10)     NOT NULL,
     CDD_RULE_PARM_NAME   VARCHAR(100)     NOT NULL,
     CDD_RULE_ID          VARCHAR(32)     NOT NULL,
     CDD_RULE_PARM_DESCRIPTION VARCHAR(100)     NOT NULL,
     CDD_RULE_PARM_TYPE_CODE VARCHAR(32)     NOT NULL,
     CDD_RULE_PARM_VAL    VARCHAR(1024)     NOT NULL,
     PRIMARY KEY (CDD_RULE_VERSION_NO, CDD_RULE_PARM_NAME, CDD_RULE_ID)
);

CREATE TABLE FCFKC.FSK_CDD_SCORING_EVENT (
     CDD_SCORING_EVENT_KEY NUMERIC(12)     NOT NULL,
     PRIMARY_ENTITY_KEY   NUMERIC(12)     NOT NULL,
     PRIMARY_ENTITY_NUMBER VARCHAR(50)     NOT NULL,
     PRIMARY_ENTITY_LEVEL_CODE CHAR(3)     NOT NULL,
     CDD_RULE_ID          VARCHAR(32)     NOT NULL,
     VERSION_NO           NUMERIC(10),
     RULE_SCORE           NUMERIC(10),
     SCORE_CLASSIFICATION_CODE VARCHAR(32),
     EVENT_DATE           DATE     NOT NULL,
     AUTO_HIGH_IND        CHAR(1),
     INVESTIGATION_IND    CHAR(1),
     CATEGORY_CODE        VARCHAR(32),
     SCORE_TYPE_CODE      VARCHAR(32),
     PRIMARY KEY (CDD_SCORING_EVENT_KEY)
);
CREATE INDEX XIE2FSK_CDD_SCORING_EVENT ON 
FCFKC.FSK_CDD_SCORING_EVENT( primary_entity_number );

CREATE TABLE FCFKC.FSK_CDD_TRIGGERING_VALUES (
     CDD_TRIGGERING_VALUE_KEY NUMERIC(12)     NOT NULL,
     CDD_SCORING_EVENT_KEY NUMERIC(12)     NOT NULL,
     TRIGGERING_VALUE_ID  NUMERIC(12),
     TRIGGERING_CHAR_VALUE VARCHAR(35),
     TRIGGERING_NUM_VALUE NUMERIC(18,5),
     TRIGGERING_DATE_VALUE DATE,
     TRIGGERING_VALUE_TYPE_CODE VARCHAR(32),
     REF_TABLE_NM         VARCHAR(30),
     PRIMARY KEY (CDD_TRIGGERING_VALUE_KEY)
);

CREATE TABLE FCFKC.FSK_COMMENT (
     COMMENT_ID           NUMERIC(12)     NOT NULL,
     OBJECT_TYPE_CD       CHAR(3)     NOT NULL,
     OBJECT_ID            VARCHAR(50)     NOT NULL,
     COMMENT_TEXT         VARCHAR(2000)     NOT NULL,
     COMMENT_CATEGORY_CD  CHAR(3)     NOT NULL,
     CREATE_DATE          DATE     NOT NULL,
     CREATE_USER_ID       VARCHAR(60)     NOT NULL,
     LSTUPDATE_USER_ID    VARCHAR(60),
     LSTUPDATE_DATE       DATE,
     LOGICAL_DELETE_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (COMMENT_ID)
);
CREATE INDEX XIE1FSK_COMMENT ON 
FCFKC.FSK_COMMENT( object_type_cd,object_id );

CREATE TABLE FCFKC.FSK_ENHANCED_ALERT (
     ALERT_ID             NUMERIC(12)     NOT NULL,
     COLUMN_NAME          CHAR(32)     NOT NULL,
     COLUMN_TYPE_CODE     CHAR(1)     NOT NULL,
     COLUMN_VALUE_NUMBER  FLOAT,
     COLUMN_VALUE_CHAR_TEXT VARCHAR(2000),
     PRIMARY KEY (ALERT_ID, COLUMN_NAME)
);
CREATE INDEX XIE1FSK_ENHANCED_ALERT ON 
FCFKC.FSK_ENHANCED_ALERT( alert_id );

CREATE TABLE FCFKC.FSK_ENHANCED_ALERT_RISK_FACTOR (
     COLUMN_NAME          CHAR(32)     NOT NULL,
     ENTITY_NUMBER        VARCHAR(50)     NOT NULL,
     ALERT_ID             NUMERIC(12)     NOT NULL,
     SCENARIO_ID          NUMERIC(12)     NOT NULL,
     COLUMN_TYPE_CODE     CHAR(1)     NOT NULL,
     COLUMN_VALUE_NUMBER  FLOAT,
     COLUMN_VALUE_CHAR_TEXT VARCHAR(2000),
     PRIMARY KEY (COLUMN_NAME, ENTITY_NUMBER, ALERT_ID, SCENARIO_ID)
);

CREATE TABLE FCFKC.FSK_ENTITY_EVENT (
     EVENT_ID             NUMERIC(12)     NOT NULL,
     CASE_ID              NUMERIC(12),
     EVENT_TYPE_CODE      CHAR(3)     NOT NULL,
     EVENT_DESCRIPTION    VARCHAR(255),
     ENTITY_NUMBER        VARCHAR(50)     NOT NULL,
     ENTITY_LEVEL_CODE    CHAR(3)     NOT NULL,
     CREATE_USER_ID       VARCHAR(60)     NOT NULL,
     CREATE_DATE          DATE     NOT NULL,
     PRIMARY KEY (EVENT_ID)
);
CREATE INDEX XIE1FSK_ENTITY_EVENT ON 
FCFKC.FSK_ENTITY_EVENT( case_id );

CREATE TABLE FCFKC.FSK_ENTITY_TRANSACTION (
     FSK_ENTITY_TRANSACTION_PK NUMERIC(22)     NOT NULL,
     ALERTED_ENTITY_LEVEL_CODE VARCHAR(3),
     ALERTED_ENTITY_NUMBER VARCHAR(50),
     TRANSACTION_ID       VARCHAR(50),
     TRANSACTION_AMT      NUMERIC(15,3),
     TRANSACTION_CDI_DESC VARCHAR(30),
     PRIMARY_MEDIUM_DESC  VARCHAR(30),
     SECONDARY_MEDIUM_DESC VARCHAR(30),
     TRANSACTION_DATE     DATE,
     TRANSACTION_MECHANISM VARCHAR(50),
     ACCOUNT_NUMBER       VARCHAR(50),
     BENEFICIARY_NAME     VARCHAR(200),
     ASSOCIATE_NAME       VARCHAR(250),
     BRANCH_NAME          VARCHAR(100),
     TRANSACTION_DESC     VARCHAR(255),
     TRANSACTION_STATUS   VARCHAR(20),
     CREATED_TIMESTAMP    DATE,
     DATE_KEY             NUMERIC(8),
     TIME_KEY             NUMERIC(6),
     HOUSEHOLD_NUMBER     VARCHAR(50),
     PRIMARY KEY (FSK_ENTITY_TRANSACTION_PK)
);
CREATE INDEX XIF1FSK_ENTITY_TRANSACTION ON 
FCFKC.FSK_ENTITY_TRANSACTION( alerted_entity_level_code,alerted_entity_number );

CREATE TABLE FCFKC.FSK_ENTITY_TX_AGG (
     FSK_ENTITY_TX_AGG_PK NUMERIC(12)     NOT NULL,
     ALERTED_ENTITY_LEVEL_CODE VARCHAR(3),
     ALERTED_ENTITY_NUMBER VARCHAR(50),
     AGGREGATE_TYPE_CODE  VARCHAR(4),
     GROUP_CODE           VARCHAR(50),
     GROUP_DESC           VARCHAR(50),
     AGGREGATE_AMT        NUMERIC(15,3),
     CREATED_TIMESTAMP    DATE,
     PRIMARY KEY (FSK_ENTITY_TX_AGG_PK)
);
CREATE INDEX XIF1FSK_ENTITY_TX_AGG ON 
FCFKC.FSK_ENTITY_TX_AGG( alerted_entity_level_code,alerted_entity_number );

CREATE TABLE FCFKC.FSK_ERROR_LOG (
     STORED_PROCEDURE_NAME VARCHAR(35),
     CREATE_DATE          DATE,
     SQL_STATE            VARCHAR(35),
     SQL_CODE             VARCHAR(35),
     SQL_ERROR_MESSAGE    VARCHAR(255)
);

CREATE TABLE FCFKC.FSK_HEADER (
     HEADER_ID            NUMERIC(12)     NOT NULL,
     HEADER_NAME          VARCHAR(32)     NOT NULL,
     HEADER_DESCRIPTION   VARCHAR(255)     NOT NULL,
     ENTITY_LEVEL_CODE    CHAR(3)     NOT NULL,
     DENORM_TABLE_NAME    VARCHAR(32),
     ALERT_TABLE_NAME     VARCHAR(24)     NOT NULL,
     HEADER_AUTOGEN_IND   CHAR(1)     NOT NULL,
     HEADER_LOCATION_DESC VARCHAR(255),
     SOURCE_TYPE_DESC     VARCHAR(32)     NOT NULL,
     CREATE_USER_ID       VARCHAR(60)     NOT NULL,
     CREATE_DATE          DATE     NOT NULL,
     LSTUPDATE_USER_ID    VARCHAR(60),
     LSTUPDATE_DATE       DATE,
     HEADER_HOST_DESC     VARCHAR(50)     NOT NULL,
     VERSION_NUMBER       NUMERIC(5),
     LOGICAL_DELETE_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (HEADER_ID)
);

CREATE TABLE FCFKC.FSK_HEADER_ELEMENT (
     HEADER_ID            NUMERIC(12)     NOT NULL,
     ELEMENT_NAME         VARCHAR(35)     NOT NULL,
     ELEMENT_TYPE_CODE    CHAR(6)     NOT NULL,
     ELEMENT_LENGTH_COUNT NUMERIC(8),
     ELEMENT_FORMAT_CODE  CHAR(12)     NOT NULL,
     ELEMENT_LABEL_DESC   VARCHAR(35)     NOT NULL,
     ELEMENT_USAGE_DESC   VARCHAR(35),
     PRIMARY KEY (HEADER_ID, ELEMENT_NAME)
);

CREATE TABLE FCFKC.FSK_INT_XFER (
     REMITTER_ACCOUNT_NUMBER VARCHAR(304)     NOT NULL,
     REMITTER_NAME        VARCHAR(304)     NOT NULL,
     REMITTER_PARTY_KEY   NUMERIC(12)     NOT NULL,
     BENEFICIARY_ACCOUNT_NUMBER VARCHAR(304)     NOT NULL,
     BENEFICIARY_NAME     VARCHAR(304)     NOT NULL,
     BENEFICIARY_PARTY_KEY NUMERIC(12)     NOT NULL,
     DATE_KEY             NUMERIC(8,0)     NOT NULL,
     CURRENCY_AMOUNT      NUMERIC(18,5)     NOT NULL,
     EDGE_TYPE_CODE       CHAR(4)     NOT NULL
);

CREATE TABLE FCFKC.FSK_JOB_CALENDAR (
     JOB_CALENDAR_ID      NUMERIC(5)     NOT NULL,
     CALENDAR_DATE        DATE,
     RUNDATE_IND          CHAR(1),
     DAILY_RUNDATE_IND    CHAR(1)     NOT NULL,
     WEEKLY_RUNDATE_IND   CHAR(1)     NOT NULL,
     MONTHLY_RUNDATE_IND  CHAR(1)     NOT NULL,
     STATUS_IND           CHAR(1)     NOT NULL,
     BUSINESS_DAY_COUNT   NUMERIC(15),
     PRIMARY KEY (JOB_CALENDAR_ID)
);

CREATE TABLE FCFKC.FSK_LIST (
     LIST_ID              NUMERIC(12)     NOT NULL,
     LIST_CATEGORY_ID     NUMERIC(12),
     LIST_NAME            VARCHAR(35),
     LIST_DESC            VARCHAR(255),
     VALIDATION_TYPE_CODE VARCHAR(4)     NOT NULL,
     CREATE_DATE          DATE,
     CREATE_USER_ID       VARCHAR(60),
     DELETE_DATE          DATE,
     DELETE_USER_ID       VARCHAR(60),
     LOGICAL_DELETE_IND   CHAR(1),
     PRIMARY KEY (LIST_ID)
);

CREATE TABLE FCFKC.FSK_LIST_CATEGORY (
     LIST_CATEGORY_ID     NUMERIC(12)     NOT NULL,
     LIST_CATEGORY_NAME   VARCHAR(35)     NOT NULL,
     LIST_CATEGORY_DESC   VARCHAR(255),
     CREATE_DATE          DATE,
     CREATE_USER_ID       VARCHAR(60),
     DELETE_DATE          DATE,
     DELETE_USER_ID       VARCHAR(60),
     LOGICAL_DELETE_IND   CHAR(1),
     PRIMARY KEY (LIST_CATEGORY_ID)
);

CREATE TABLE FCFKC.FSK_LIST_ELEMENT (
     LIST_ELEMENT_ID      NUMERIC(12)     NOT NULL,
     LIST_ID              NUMERIC(12),
     LIST_ELEMENT_DESC    VARCHAR(35),
     LIST_ELEMENT_VALUE   VARCHAR(75)     NOT NULL,
     CREATE_DATE          DATE,
     CREATE_USER_ID       VARCHAR(60),
     DELETE_DATE          DATE,
     DELETE_USER_ID       VARCHAR(60),
     LOGICAL_DELETE_IND   CHAR(1),
     PRIMARY KEY (LIST_ELEMENT_ID)
);
CREATE INDEX XIE1FSK_LIST_ELEMENT ON 
FCFKC.FSK_LIST_ELEMENT( list_element_value );

CREATE TABLE FCFKC.FSK_LOV (
     LOV_TYPE_NAME        VARCHAR(64)     NOT NULL,
     LOV_TYPE_CODE        VARCHAR(64)     NOT NULL,
     LOV_LANGUAGE_DESC    VARCHAR(20)     NOT NULL,
     LOV_TYPE_DESC        VARCHAR(100)     NOT NULL,
     LOV_SORT_POSITION_NUMBER INTEGER,
     ACTIVE_FLG           CHAR(1)     NOT NULL,
     PRIMARY KEY (LOV_TYPE_NAME, LOV_TYPE_CODE, LOV_LANGUAGE_DESC)
);

CREATE TABLE FCFKC.FSK_NN_ENTITY (
     PRIMARY_ENTITY_NUMBER VARCHAR(76)     NOT NULL,
     PRIMARY_ENTITY_LEVEL_CODE CHAR(3)     NOT NULL,
     ALERT_ID             NUMERIC(12)     NOT NULL,
     PRIMARY KEY (PRIMARY_ENTITY_NUMBER, PRIMARY_ENTITY_LEVEL_CODE, ALERT_ID)
);
CREATE INDEX XIE1FSK_NN_ENTITY ON 
FCFKC.FSK_NN_ENTITY( alert_id );

CREATE TABLE FCFKC.FSK_NN_PARTY (
     ALERT_ID             NUMERIC(12)     NOT NULL,
     PARTY_NUMBER         VARCHAR(76)     NOT NULL,
     PRIMARY KEY (ALERT_ID, PARTY_NUMBER)
);
CREATE INDEX XIE1FSK_NN_PARTY ON 
FCFKC.FSK_NN_PARTY( party_number );

CREATE TABLE FCFKC.FSK_PARTY_PROFILE_ALERT (
     ALERT_ID             NUMERIC(12)     NOT NULL,
     MONTH_KEY            NUMERIC(6,0)     NOT NULL,
     PARTY_NUMBER         VARCHAR(50)     NOT NULL,
     AGGREGATE_ASSETS_AMOUNT NUMERIC(18,5),
     TRANSACTIONS_COUNT   NUMERIC(10,0),
     DEPOSITS_COUNT       NUMERIC(10,0),
     WITHDRAWALS_COUNT    NUMERIC(10,0),
     WIRES_COUNT          NUMERIC(10,0),
     CASH_TRANSACTIONS_COUNT NUMERIC(10,0),
     ACCOUNT_VALUE_AMOUNT NUMERIC(18,5),
     TOTAL_TRANSACTIONS_AMOUNT NUMERIC(18,5),
     TOTAL_CREDITS_AMOUNT NUMERIC(18,5),
     TOTAL_DEBITS_AMOUNT  NUMERIC(18,5),
     TOTAL_CASH_DEBITS_AMOUNT NUMERIC(18,5),
     TOTAL_CASH_CREDITS_AMOUNT NUMERIC(18,5),
     TOTAL_WIRE_CREDITS_AMOUNT NUMERIC(18,5),
     TOTAL_WIRE_DEBITS_AMOUNT NUMERIC(18,5),
     LARGEST_CREDIT_AMOUNT NUMERIC(18,5),
     LARGEST_DEBIT_AMOUNT NUMERIC(18,5),
     FUNDS_PAYMENT_SVCS_COUNT NUMERIC(10),
     FUNDS_TRANSFER_COUNT NUMERIC(10),
     MONETARY_INSTRUMENT_COUNT NUMERIC(10),
     PRIMARY KEY (ALERT_ID, MONTH_KEY, PARTY_NUMBER)
);
CREATE INDEX XIE1FSK_PARTY_PROFILE_ALERT ON 
FCFKC.FSK_PARTY_PROFILE_ALERT( party_number );

CREATE TABLE FCFKC.FSK_PREFERENCE (
     PREF_NAME            VARCHAR(255)     NOT NULL,
     PREF_VALUE           VARCHAR(255)     NOT NULL,
     PREF_TYPE            VARCHAR(8)     NOT NULL,
     PREF_VALUE_DEFAULT   VARCHAR(255),
     PRIMARY KEY (PREF_NAME)
);

CREATE TABLE FCFKC.FSK_RC_EFILE (
     EFILE_KEY            NUMERIC(12)     NOT NULL,
     EFILE_ID             VARCHAR(32),
     EFILE_STATUS_CODE    VARCHAR(32),
     EFILE_DESC           VARCHAR(100),
     FORM_CONFIG_KEY      NUMERIC(6),
     COVERAGE_BEGIN_DATE  DATE,
     COVERAGE_END_DATE    DATE,
     EFILE_AGENCY_REF_ID  VARCHAR(32),
     EFILE_AGENCY_STATUS_CODE VARCHAR(32),
     OUTPUT_CREATE_DATE   DATE,
     OUTPUT_FILE_SIZE     NUMERIC(10),
     OUTPUT_LINE_COUNT    NUMERIC(10),
     OUTPUT_NAME          VARCHAR(100),
     OUTPUT_PATH_NAME     VARCHAR(100),
     OUTPUT_REPORT_COUNT  NUMERIC(10),
     TRANSMISSION_DATE    DATE,
     TRANSMISSION_ID      VARCHAR(100),
     OUTPUT_ZIP_NAME      VARCHAR(32),
     RESPONSE_PROCESS_DATE DATE,
     RESPONSE_FILE_NAME   VARCHAR(100),
     DIRECT_TRANSFER_EFILE_NAME VARCHAR(100),
     CREATE_USER_ID       VARCHAR(60),
     CREATE_DATE          DATE     NOT NULL,
     LSTUPDATE_DATE       DATE     NOT NULL,
     LSTUPDATE_USER_ID    VARCHAR(60)     NOT NULL,
     VERSION_NUMBER       NUMERIC(10)     NOT NULL,
     LOGICAL_DELETE_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (EFILE_KEY)
);

CREATE TABLE FCFKC.FSK_RC_EFILE_REPORT (
     EFILE_KEY            NUMERIC(12)     NOT NULL,
     REPORT_KEY           NUMERIC(12)     NOT NULL,
     REPORT_SEQ_NUMBER    NUMERIC(6),
     FILE_STATUS_CODE     VARCHAR(32),
     REPORT_AGENCY_REF_ID VARCHAR(100),
     PRIMARY KEY (EFILE_KEY, REPORT_KEY)
);

CREATE TABLE FCFKC.FSK_RC_FORM_CODE_MAPPING (
     FORM_CONFIG_KEY      NUMERIC(6)     NOT NULL,
     FORMAT_NAME          VARCHAR(60)     NOT NULL,
     INPUT_CODE           VARCHAR(60),
     OUTPUT_CODE          VARCHAR(60)
);

CREATE TABLE FCFKC.FSK_RC_FORM_CONFIG (
     FORM_CONFIG_KEY      NUMERIC(6)     NOT NULL,
     FORM_AGENCY_CODE     VARCHAR(32)     NOT NULL,
     FORM_TYPE_CODE       VARCHAR(32)     NOT NULL,
     IMPLEMENTATION_TYPE_CODE VARCHAR(32),
     FORM_COUNTRY_CODE    VARCHAR(2),
     EFFECTIVE_FROM_DATE  DATE     NOT NULL,
     EFFECTIVE_TO_DATE    DATE,
     FORM_DESC            VARCHAR(100),
     EFILE_FILE_PREFIX    VARCHAR(60),
     EFILE_DRIVER_PGM_NAME VARCHAR(60),
     EFILE_MAX_REPORT_COUNT NUMERIC(6),
     SENSITIVE_IND        CHAR(1),
     CREATE_USER_ID       VARCHAR(60),
     CREATE_DATE          DATE     NOT NULL,
     LSTUPDATE_DATE       DATE,
     LSTUPDATE_USER_ID    VARCHAR(60),
     LOGICAL_DELETE_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (FORM_CONFIG_KEY)
);

CREATE TABLE FCFKC.FSK_RC_FORM_DEFAULT (
     FORM_CONFIG_KEY      NUMERIC(6)     NOT NULL,
     ENTITY_LEVEL_CODE    VARCHAR(32)     NOT NULL,
     DEFAULT_UI_JSON      CHARACTER,
     PRIMARY KEY (FORM_CONFIG_KEY, ENTITY_LEVEL_CODE)
);

CREATE TABLE FCFKC.FSK_RC_REPORT (
     REPORT_KEY           NUMERIC(12)     NOT NULL,
     REPORT_STATUS_CODE   VARCHAR(32),
     REPORT_READY_CODE    VARCHAR(32)     NOT NULL,
     REPORT_DESC          VARCHAR(100),
     FORM_CONFIG_KEY      NUMERIC(6)     NOT NULL,
     PARENT_OBJECT_NAME   VARCHAR(100),
     PARENT_OBJECT_KEY    NUMERIC(12),
     PARENT_CREATE_DATE   DATE,
     CORRECTION_IND       CHAR(1),
     ROOT_REPORT_KEY      NUMERIC(12)     NOT NULL,
     PREV_REPORT_KEY      NUMERIC(12),
     PRIOR_AGENCY_REF_ID  VARCHAR(100),
     UI_JSON              CHARACTER,
     NARRATIVE_LONG_DESC  CHARACTER,
     CREATE_USER_ID       VARCHAR(60),
     CREATE_DATE          DATE     NOT NULL,
     LSTUPDATE_DATE       DATE     NOT NULL,
     VERSION_NUMBER       NUMERIC(10)     NOT NULL,
     LSTUPDATE_USER_ID    VARCHAR(60),
     OWNER_USER_LONG_ID   VARCHAR(60),
     LOGICAL_DELETE_IND   CHAR(1)     NOT NULL,
     SAR90_CASE_ID        NUMERIC(12),
     PRIMARY KEY (REPORT_KEY)
);

CREATE TABLE FCFKC.FSK_RC_REPORT_ENTITY (
     REPORT_KEY           NUMERIC(12)     NOT NULL,
     ENTITY_LEVEL_CODE    VARCHAR(32)     NOT NULL,
     ENTITY_KEY           NUMERIC(12)     NOT NULL,
     ENTITY_NUMBER        VARCHAR(32),
     ENTITY_NAME          VARCHAR(32),
     LSTUPDATE_DATE       DATE     NOT NULL,
     LSTUPDATE_USER_ID    VARCHAR(60)     NOT NULL,
     UI_JSON              CHARACTER,
     VERSION_NUMBER       NUMERIC(20)     NOT NULL,
     LOGICAL_DELETE_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (REPORT_KEY, ENTITY_LEVEL_CODE, ENTITY_KEY)
);

CREATE TABLE FCFKC.FSK_RC_REPORT_ENTITY_EVENT (
     EVENT_ID             NUMERIC(12)     NOT NULL,
     EVENT_TYPE_CODE      CHAR(3)     NOT NULL,
     EVENT_DESCRIPTION    VARCHAR(255),
     REPORT_KEY           NUMERIC(12)     NOT NULL,
     ENTITY_LEVEL_CODE    VARCHAR(32)     NOT NULL,
     ENTITY_KEY           NUMERIC(12)     NOT NULL,
     CREATE_USER_ID       VARCHAR(60)     NOT NULL,
     CREATE_DATE          DATE     NOT NULL,
     PRIMARY KEY (EVENT_ID)
);

CREATE TABLE FCFKC.FSK_RC_REPORT_ENTITY_INFO (
     ENTITY_TYPE_NAME     VARCHAR(50)     NOT NULL,
     ENTITY_KEY           NUMERIC(12)     NOT NULL,
     ENTITY_LEVEL_CODE    VARCHAR(32),
     ENTITY_NAME          VARCHAR(100),
     ENTITY_NUMBER        VARCHAR(32),
     ENTITY_DESCRIPTION   VARCHAR(100),
     EFFECTIVE_FROM_DATE  DATE     NOT NULL,
     EFFECTIVE_TO_DATE    DATE     NOT NULL,
     UI_JSON              CHARACTER,
     PARENT_ENTITY_NUMBER VARCHAR(32),
     DEFAULT_IND          CHAR(1),
     PRIMARY KEY (ENTITY_TYPE_NAME, ENTITY_KEY)
);

CREATE TABLE FCFKC.FSK_RC_REPORT_EVENT (
     EVENT_ID             NUMERIC(12)     NOT NULL,
     REPORT_KEY           NUMERIC(12),
     EVENT_TYPE_CODE      CHAR(3)     NOT NULL,
     EVENT_DESCRIPTION    VARCHAR(255),
     CREATE_USER_ID       VARCHAR(60)     NOT NULL,
     CREATE_DATE          DATE     NOT NULL,
     PRIMARY KEY (EVENT_ID)
);

CREATE TABLE FCFKC.FSK_REPLICATION_DATES (
     ALERT_ID             NUMERIC(12)     NOT NULL,
     START_DATE           DATE,
     START_DATE_KEY       NUMERIC(8),
     PRIMARY KEY (ALERT_ID)
);

CREATE TABLE FCFKC.FSK_RISK_ASSESSMENT (
     RISK_ASSESSMENT_ID   NUMERIC(12)     NOT NULL,
     RISK_ASSESSMENT_STATUS_CODE CHAR(3)     NOT NULL,
     RISK_CLASSIFICATION  NUMERIC(1),
     PROPOSED_RISK_CLASSIFICATION NUMERIC(1),
     PARTY_NUMBER         VARCHAR(50)     NOT NULL,
     PARTY_KEY            NUMERIC(12),
     PARTY_NAME           VARCHAR(200),
     STARTING_MONTH_KEY   NUMERIC(6,0),
     RISK_ASSESSMENT_DURATION NUMERIC(3)     NOT NULL,
     CREATE_DATE          DATE     NOT NULL,
     CREATE_USER_ID       VARCHAR(60)     NOT NULL,
     EMPLOYEE_IND         CHAR(1),
     VERSION_NUMBER       NUMERIC(10)     NOT NULL,
     LOGICAL_DELETE_IND   CHAR(1)     NOT NULL,
     ASSESSMENT_TYPE_CD   VARCHAR(32),
     ASSESSMENT_CATEGORY_CD VARCHAR(32),
     ASSESSMENT_SUBCATEGORY_CD VARCHAR(32),
     OWNER_USER_LONG_ID   VARCHAR(60),
     PRIMARY KEY (RISK_ASSESSMENT_ID)
);
CREATE INDEX XIE5FSK_RISK_ASMNT ON 
FCFKC.FSK_RISK_ASSESSMENT( party_key );
CREATE INDEX XIE9FSK_RISK_ASMNT ON 
FCFKC.FSK_RISK_ASSESSMENT( party_number );

CREATE TABLE FCFKC.FSK_RISK_ASSESSMENT_CLASSIFIER (
     RISK_ASSESSMENT_ID   NUMERIC(12)     NOT NULL,
     RISK_CLASSIFIER_ID   NUMERIC(12)     NOT NULL,
     PRIMARY KEY (RISK_ASSESSMENT_ID, RISK_CLASSIFIER_ID)
);

CREATE TABLE FCFKC.FSK_RISK_ASSESSMENT_EMAIL (
     EMAIL_ID             NUMERIC(12)     NOT NULL,
     RISK_ASSESSMENT_ID   NUMERIC(12)     NOT NULL,
     EMAIL_TO_TEXT        VARCHAR(2000)     NOT NULL,
     EMAIL_CC_TEXT        VARCHAR(2000),
     EMAIL_SUBJECT_DESC   VARCHAR(255),
     EMAIL_MESSAGE_TEXT   VARCHAR(2000),
     CREATE_DATE          DATE     NOT NULL,
     CREATE_USER_ID       VARCHAR(60)     NOT NULL,
     PRIMARY KEY (EMAIL_ID)
);

CREATE TABLE FCFKC.FSK_RISK_ASSESSMENT_EVENT (
     EVENT_ID             NUMERIC(12)     NOT NULL,
     RISK_ASSESSMENT_ID   NUMERIC(12)     NOT NULL,
     EVENT_TYPE_CODE      CHAR(3)     NOT NULL,
     EVENT_DESC           VARCHAR(255),
     CREATE_DATE          DATE     NOT NULL,
     CREATE_USER_ID       VARCHAR(60)     NOT NULL,
     PRIMARY KEY (EVENT_ID)
);

CREATE TABLE FCFKC.FSK_RISK_CLASSIFIER (
     RISK_CLASSIFIER_ID   NUMERIC(12)     NOT NULL,
     RISK_CLASSIFIER_NAME VARCHAR(35)     NOT NULL,
     RISK_CLASSIFIER_SHORT_DESC VARCHAR(35),
     RISK_CLASSIFIER_DESC VARCHAR(255),
     RISK_CLASSIFIER_TYPE_CODE CHAR(3),
     ACTIVE_IND           CHAR(1),
     WEIGHT               NUMERIC(10)     NOT NULL,
     SOURCE_TABLE         VARCHAR(35),
     SOURCE_COLUMN        VARCHAR(30),
     SOURCE_VALUE         CHAR(1),
     CLASSIFIER_FACT_COLUMN VARCHAR(30),
     OPERATOR_DESC        VARCHAR(3),
     LOCKED_IND           CHAR(1),
     CLASSIFIER_THRESHOLD NUMERIC(10),
     RISK_CLASSIFIER_CATEGORY_ID NUMERIC(12,0),
     LIST_ID              NUMERIC(12),
     CREATE_DATE          DATE,
     CREATE_USER_ID       VARCHAR(60),
     END_DATE             DATE,
     END_USER_ID          VARCHAR(60),
     VERSION_NUMBER       NUMERIC(5,0),
     CURRENT_IND          CHAR(1)     NOT NULL,
     LOGICAL_DELETE_IND   CHAR(1),
     PRIMARY KEY (RISK_CLASSIFIER_ID)
);

CREATE TABLE FCFKC.FSK_RISK_CLASSIFIER_CATEGORY (
     RISK_CLASSIFIER_CATEGORY_ID NUMERIC(12,0)     NOT NULL,
     RISK_CLASSIFIER_CATEGORY_NAME VARCHAR(35),
     RISK_CLASSIFIER_CATEGORY_DESC VARCHAR(255),
     CREATE_DATE          DATE,
     CREATE_USER_ID       VARCHAR(60),
     DELETE_DATE          DATE,
     DELETE_USER_ID       VARCHAR(60),
     LOGICAL_DELETE_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (RISK_CLASSIFIER_CATEGORY_ID)
);

CREATE TABLE FCFKC.FSK_ROUTING_CONSTRAINT (
     ROUTING_GROUP_ID     NUMERIC(12)     NOT NULL,
     ROUTING_RULE_ID      NUMERIC(12)     NOT NULL,
     CONSTRAINT_ORDER_NUMBER NUMERIC(2)     NOT NULL,
     COLUMN_NAME          VARCHAR(35),
     OPERATOR_DESC        CHAR(6),
     VALUE_DESC           VARCHAR(1024),
     COMPOUND_OPERATOR_NAME CHAR(4),
     PRIMARY KEY (ROUTING_GROUP_ID, ROUTING_RULE_ID, CONSTRAINT_ORDER_NUMBER)
);
CREATE INDEX XIF1FSK_ROUTING_CONSTRAINT ON 
FCFKC.FSK_ROUTING_CONSTRAINT( routing_rule_id,routing_group_id );

CREATE TABLE FCFKC.FSK_ROUTING_GROUP (
     ROUTING_GROUP_ID     NUMERIC(12)     NOT NULL,
     ROUTING_GROUP_NAME   VARCHAR(50)     NOT NULL,
     VERSION_NUMBER       NUMERIC(5),
     LOGICAL_DELETE_IND   CHAR(1)     NOT NULL,
     LSTUPDATE_USER_ID    VARCHAR(60),
     LSTUPDATE_DATE       DATE,
     PRIMARY KEY (ROUTING_GROUP_ID)
);

CREATE TABLE FCFKC.FSK_ROUTING_RULE (
     ROUTING_GROUP_ID     NUMERIC(12)     NOT NULL,
     ROUTING_RULE_ID      NUMERIC(12)     NOT NULL,
     ROUTE_ORDER_NUMBER   NUMERIC(3)     NOT NULL,
     ALERT_TYPE_CD        VARCHAR(32),
     ALERT_CATEGORY_CD    VARCHAR(32),
     ALERT_SUBCATEGORY_CD VARCHAR(32),
     ROUTING_USER_LONG_ID VARCHAR(60),
     PRIMARY KEY (ROUTING_GROUP_ID, ROUTING_RULE_ID, ROUTE_ORDER_NUMBER)
);

CREATE TABLE FCFKC.FSK_SCD2_COLUMNS (
     SCD2_KEY             NUMERIC(12)     NOT NULL,
     TABLE_NAME           VARCHAR(35)     NOT NULL,
     COLUMN_NAME          VARCHAR(35)     NOT NULL,
     XREF_VALID_IND       CHAR(1)     NOT NULL,
     CREATE_DATE          DATE     NOT NULL,
     END_DATE             DATE     NOT NULL,
     CREATE_USER_ID       VARCHAR(60)     NOT NULL,
     VERSION_NUMBER       NUMERIC(10)     NOT NULL,
     CURRENT_IND          CHAR(1)     NOT NULL,
     PRIMARY KEY (SCD2_KEY)
);

CREATE TABLE FCFKC.FSK_SCENARIO (
     SCENARIO_ID          NUMERIC(12)     NOT NULL,
     HEADER_ID            NUMERIC(12)     NOT NULL,
     ROOT_KEY             NUMERIC(12),
     SCENARIO_NAME        VARCHAR(32)     NOT NULL,
     SCENARIO_SHORT_DESCRIPTION VARCHAR(100)     NOT NULL,
     SCENARIO_DESCRIPTION VARCHAR(255)     NOT NULL,
     SCENARIO_CATEGORY_CODE CHAR(3)     NOT NULL,
     SCENARIO_CODE_LOCATION_DESC VARCHAR(255)     NOT NULL,
     PRODUCT_TYPE_CODE    CHAR(3)     NOT NULL,
     SCENARIO_STATUS_CODE CHAR(3)     NOT NULL,
     CURRENT_IND          CHAR(1)     NOT NULL,
     DFLT_SUPPRESS_DURATION_COUNT NUMERIC(8)     NOT NULL,
     SCENARIO_DURATION_COUNT NUMERIC(8)     NOT NULL,
     MONEY_LAUNDERING_BAYES_WEIGHT NUMERIC(15,5)     NOT NULL,
     TERROR_FINANCING_BAYES_WEIGHT NUMERIC(15,5),
     EXECUTION_PROBABILITY_RATE NUMERIC(7,7)     NOT NULL,
     RISK_FACTOR_IND      CHAR(1),
     CREATE_DATE          DATE     NOT NULL,
     CREATE_USER_ID       VARCHAR(60)     NOT NULL,
     END_DATE             DATE     NOT NULL,
     END_USER_ID          VARCHAR(60),
     VERSION_NUMBER       NUMERIC(5)     NOT NULL,
     LOGICAL_DELETE_IND   CHAR(1)     NOT NULL,
     ROUTING_GROUP_ID     NUMERIC(12),
     ORDER_IN_HEADER      NUMERIC(5),
     ALERT_TYPE_CD        VARCHAR(32),
     ALERT_CATEGORY_CD    VARCHAR(32),
     ALERT_SUBCATEGORY_CD VARCHAR(32),
     ROUTING_USER_LONG_ID VARCHAR(60),
     LSTUPDATE_DATE       DATE,
     SCENARIO_TYPE_CODE   CHAR(3),
     SCENARIO_RUN_FREQUENCY_CODE CHAR(3),
     SAVE_TRIG_TRANS_IND  CHAR(1),
     SKIP_IF_NO_TRANS_CURR_DAY_IND CHAR(1),
     ENTITY_LEVEL_CODE    CHAR(3),
     PRIMARY_ENTITY_NUMBER_VAR_NAME VARCHAR(32),
     VSD_WINDOW_NAME      VARCHAR(25),
     VSD_DEPLOYMENT_NAME  VARCHAR(255),
     LSTUPDATE_USER_ID    VARCHAR(60),
     PRIMARY KEY (SCENARIO_ID)
);

CREATE TABLE FCFKC.FSK_SCENARIO_ALERT_COLUMN (
     SCENARIO_ID          NUMERIC(12)     NOT NULL,
     COLUMN_NAME          CHAR(32)     NOT NULL,
     COLUMN_USAGE_CODE    CHAR(1)     NOT NULL,
     PRIMARY KEY (SCENARIO_ID, COLUMN_NAME)
);

CREATE TABLE FCFKC.FSK_SCENARIO_ALERT_CONSTRAINT (
     CONSTRAINT_ORDER_NUMBER NUMERIC(5)     NOT NULL,
     SCENARIO_ID          NUMERIC(12)     NOT NULL,
     LEFT_OPERAND         VARCHAR(32)     NOT NULL,
     LEFT_OPERAND_TYPE    CHAR(1)     NOT NULL,
     CONSTRAINT_OPERATOR  VARCHAR(6)     NOT NULL,
     RIGHT_OPERAND        VARCHAR(256)     NOT NULL,
     RIGHT_OPERAND_TYPE   CHAR(1)     NOT NULL,
     COMPOUND_OPERATOR    CHAR(3)     NOT NULL,
     PRIMARY KEY (CONSTRAINT_ORDER_NUMBER, SCENARIO_ID)
);

CREATE TABLE FCFKC.FSK_SCENARIO_FILTER (
     FILTER_ID            NUMERIC(12)     NOT NULL,
     FILTER_ORDER_NUMBER  NUMERIC(5)     NOT NULL,
     SCENARIO_ID          NUMERIC(12)     NOT NULL,
     FILTER_NAME          VARCHAR(35)     NOT NULL,
     SAVE_TRIG_TRANS_IND  CHAR(1)     NOT NULL,
     DAYS_NUMBER          NUMERIC(5),
     PRIMARY KEY (FILTER_ID, FILTER_ORDER_NUMBER, SCENARIO_ID)
);

CREATE TABLE FCFKC.FSK_SCENARIO_FILTER_CONSTRAINT (
     CONSTRAINT_ORDER_NUMBER NUMERIC(5)     NOT NULL,
     FILTER_ID            NUMERIC(12)     NOT NULL,
     LEFT_OPERAND         VARCHAR(32)     NOT NULL,
     LEFT_OPERAND_TYPE    CHAR(1)     NOT NULL,
     CONSTRAINT_OPERATOR  VARCHAR(6)     NOT NULL,
     RIGHT_OPERAND        VARCHAR(256)     NOT NULL,
     RIGHT_OPERAND_TYPE   CHAR(1)     NOT NULL,
     COMPOUND_OPERATOR    CHAR(3)     NOT NULL,
     PRIMARY KEY (CONSTRAINT_ORDER_NUMBER, FILTER_ID)
);

CREATE TABLE FCFKC.FSK_SCENARIO_FILTER_VARIABLE (
     VARIABLE_NAME        VARCHAR(32)     NOT NULL,
     FILTER_ID            NUMERIC(12)     NOT NULL,
     FUNCTION_NAME        VARCHAR(32)     NOT NULL,
     VARIABLE_TYPE        CHAR(1),
     PRIMARY KEY (VARIABLE_NAME, FILTER_ID)
);

CREATE TABLE FCFKC.FSK_SCENARIO_LOCALIZED_MSG (
     SCENARIO_ID          NUMERIC(12)     NOT NULL,
     LOCALE               VARCHAR(5)     NOT NULL,
     SCENARIO_MESSAGE_TEXT VARCHAR(255)     NOT NULL,
     PRIMARY KEY (SCENARIO_ID)
);

CREATE TABLE FCFKC.FSK_SCENARIO_MESSAGE (
     SCENARIO_MESSAGE_NAME CHAR(35)     NOT NULL,
     SCENARIO_MESSAGE_TEXT VARCHAR(255)     NOT NULL,
     PRIMARY KEY (SCENARIO_MESSAGE_NAME)
);

CREATE TABLE FCFKC.FSK_SCENARIO_MESSAGE_DECOMP (
     SCENARIO_MESSAGE_NAME VARCHAR(35)     NOT NULL,
     MESSAGE_SEGMENT_SEQUENCE_NBR NUMERIC(10)     NOT NULL,
     MESSAGE_SEGMENT_TEXT VARCHAR(255),
     PRIMARY KEY (SCENARIO_MESSAGE_NAME, MESSAGE_SEGMENT_SEQUENCE_NBR)
);

CREATE TABLE FCFKC.FSK_SCENARIO_MESSAGE_PARAMETER (
     PARAMETER_NUMBER     NUMERIC(5)     NOT NULL,
     SCENARIO_ID          NUMERIC(12)     NOT NULL,
     MESSAGE_PARAMETER    VARCHAR(32)     NOT NULL,
     MESSAGE_PARAMETER_TYPE CHAR(1)     NOT NULL,
     VARIABLE_FORMAT      VARCHAR(32),
     PRIMARY KEY (PARAMETER_NUMBER, SCENARIO_ID)
);

CREATE TABLE FCFKC.FSK_SCENARIO_MESSAGE_PARAMS (
     SCENARIO_MESSAGE_NAME VARCHAR(35)     NOT NULL,
     MESSAGE_PARAMETER_NBR NUMERIC(10)     NOT NULL,
     QUERY_COLUMN_PARAMETER_TEXT VARCHAR(64),
     PRIMARY KEY (SCENARIO_MESSAGE_NAME, MESSAGE_PARAMETER_NBR)
);

CREATE TABLE FCFKC.FSK_SCENARIO_PARAMETER (
     SCENARIO_ID          NUMERIC(12)     NOT NULL,
     PARM_NAME            VARCHAR(32)     NOT NULL,
     ENTITY_SEGMENT_ID    NUMERIC(12)     NOT NULL,
     PARM_VALUE           VARCHAR(1024)     NOT NULL,
     PARM_TYPE_DESC       VARCHAR(32)     NOT NULL,
     PARM_DESC            VARCHAR(255)     NOT NULL,
     BTL_PARM_VALUE       VARCHAR(1024),
     PRIMARY KEY (SCENARIO_ID, PARM_NAME, ENTITY_SEGMENT_ID)
);

CREATE TABLE FCFKC.FSK_SCENARIO_STATUS (
     STORED_PROCEDURE_NAME VARCHAR(35),
     CREATE_DATE          DATE,
     BEGIN_TIME           DATE,
     END_TIME             DATE
);

CREATE TABLE FCFKC.FSK_SEQUENCE (
     NEXT_SEQUENCE_ID     NUMERIC(12)     NOT NULL
);

CREATE TABLE FCFKC.FSK_TEMP_ASSESS (
     PARTY_KEY            NUMERIC(12)     NOT NULL,
     CREATE_DATE          DATE     NOT NULL,
     PRIMARY KEY (PARTY_KEY)
);

CREATE TABLE FCFKC.FSK_TEMP_EXT_PARTY_KEYS (
     ALERT_ID             NUMERIC(12)     NOT NULL,
     EXT_PARTY_ACCOUNT_KEY NUMERIC(12)     NOT NULL,
     RUN_DATE             DATE,
     PRIMARY KEY (ALERT_ID, EXT_PARTY_ACCOUNT_KEY)
);
CREATE INDEX XIE1FSK_TEMP_EXT_PARTY_KEYS ON 
FCFKC.FSK_TEMP_EXT_PARTY_KEYS( ext_party_account_key );

CREATE TABLE FCFKC.FSK_TEMP_NUMBER (
     PRIMARY_ENTITY_NUMBER VARCHAR(75)     NOT NULL,
     PRIMARY KEY (PRIMARY_ENTITY_NUMBER)
);

CREATE TABLE FCFKC.FSK_TEMP_TABLE (
     TEMP_CHAR_1_VALUE    VARCHAR(100),
     TEMP_CHAR_2_VALUE    VARCHAR(100),
     TEMP_CHAR_3_VALUE    VARCHAR(100),
     TEMP_CHAR_4_VALUE    VARCHAR(100),
     TEMP_DATE_1_VALUE    DATE,
     TEMP_DATE_2_VALUE    DATE,
     TEMP_DATE_3_VALUE    DATE,
     TEMP_DATE_4_VALUE    DATE,
     TEMP_NUM_1_VALUE     NUMERIC(18,5),
     TEMP_NUM_2_VALUE     NUMERIC(18,5),
     TEMP_NUM_3_VALUE     NUMERIC(18,5),
     TEMP_NUM_4_VALUE     NUMERIC(18,5)
);

CREATE TABLE FCFKC.FSK_TRANSACTION_ALERT (
     ALERT_ID             NUMERIC(12)     NOT NULL,
     TRANSACTION_KEY      NUMERIC(12)     NOT NULL,
     DATE_KEY             NUMERIC(8,0)     NOT NULL,
     TRANSACTION_REFERENCE_NUMBER VARCHAR(50)     NOT NULL,
     TRANSACTION_DESCRIPTION VARCHAR(255),
     SECURITY_NAME        VARCHAR(35),
     DEAL_NUMBER          VARCHAR(35),
     CHECK_NUMBER         VARCHAR(10),
     MECHANISM_ID         VARCHAR(40),
     PRIMARY KEY (ALERT_ID, TRANSACTION_KEY)
);
CREATE INDEX XIE1FSK_TRANSACTION_AL ON 
FCFKC.FSK_TRANSACTION_ALERT( transaction_reference_number );
CREATE INDEX XIE2FSK_TRANSACTION_AL ON 
FCFKC.FSK_TRANSACTION_ALERT( date_key );
CREATE INDEX XIE3FSK_TRANSACTION_AL ON 
FCFKC.FSK_TRANSACTION_ALERT( transaction_key );

CREATE TABLE FCFKC.FSK_UI_AVAILABILITY (
     UI_AVAILABILITY_IND  CHAR(1)     NOT NULL
);

CREATE TABLE FCFKC.FSK_UI_COLUMN (
     TABLE_UI_NAME        VARCHAR(35)     NOT NULL,
     COLUMN_UI_NAME       VARCHAR(35)     NOT NULL,
     GROUP_UI_NAME        VARCHAR(35)     NOT NULL,
     COLUMN_EXPRESSION_TEXT VARCHAR(255),
     COLUMN_LABEL_DESC    VARCHAR(64),
     COLUMN_POSITION_NUMBER NUMERIC(5),
     FORMAT_CODE          CHAR(3),
     FORMAT_MODIFIER_TEXT VARCHAR(1024),
     COLUMN_DISPLAY_LEVEL_CODE CHAR(3),
     COLUMN_SEARCH_LEVEL_CODE CHAR(3),
     SORTED_BY_POSITION_NUMBER NUMERIC(5),
     COLUMN_ACTIVE_IND    CHAR(1),
     LOCAL_KEY_DB_NAME    VARCHAR(35),
     REMOTE_KEY_DB_NAME   VARCHAR(35),
     REMOTE_TABLE_UI_NAME VARCHAR(35),
     PRIMARY KEY (TABLE_UI_NAME, COLUMN_UI_NAME)
);

CREATE TABLE FCFKC.FSK_UI_GROUP (
     GROUP_UI_NAME        VARCHAR(35)     NOT NULL,
     GROUP_LABEL_DESC     VARCHAR(64),
     GROUP_POSITION_NUMBER NUMERIC(5),
     PRIMARY KEY (GROUP_UI_NAME)
);

CREATE TABLE FCFKC.FSK_UI_TABLE (
     TABLE_UI_NAME        VARCHAR(35)     NOT NULL,
     TABLE_EXPRESSION_TEXT VARCHAR(2000),
     TABLE_LABEL_DESC     VARCHAR(64),
     TABLE_DATA_SOURCE_CODE CHAR(3),
     TABLE_SEARCH_LEVEL_CODE CHAR(3),
     TABLE_ACTIVE_IND     CHAR(1),
     PRIMARY KEY (TABLE_UI_NAME)
);