-- Updated with HF7 changes
-- Update FSK_RC_FORM_CONFIG

USE [LOCALDB]
GO

ALTER TABLE SCHKC.FSK_RC_FORM_CONFIG
  add   implementation_type_code VARCHAR(32) NULL
GO

DROP VIEW SCHBU1.FSK_RC_FORM_CONFIG
GO

CREATE VIEW SCHBU1.FSK_RC_FORM_CONFIG AS SELECT * FROM SCHKC.FSK_RC_FORM_CONFIG
GO

-- Recreate CDD Tables

DROP VIEW SCHBU1.FSK_CDD_RULE
GO

DROP VIEW SCHBU1.FSK_CDD_RULE_PARAMETER
GO

DROP VIEW SCHBU1.FSK_CDD_RULE_GROUP
GO

DROP VIEW SCHBU1.FSK_CDD_SCORING_EVENT
GO

DROP VIEW SCHBU1.FSK_CDD_TRIGGERING_VALUES
GO

DROP TABLE SCHKC.FSK_CDD_RULE_PARAMETER
GO

DROP TABLE SCHKC.FSK_CDD_RULE
GO

DROP TABLE SCHKC.FSK_CDD_RULE_GROUP
GO

DROP TABLE SCHKC.FSK_CDD_SCORING_EVENT
GO

CREATE TABLE SCHKC.FSK_CDD_RULE
(
	cdd_rule_id          VARCHAR(32) NOT NULL ,
	version_no           DECIMAL(10) NOT NULL ,
	current_ind          CHAR(1)  ,
	cdd_update_date      DATETIME NOT NULL ,
	cdd_create_date      DATETIME NOT NULL ,
	cdd_rule_name        VARCHAR(100) NOT NULL ,
	cdd_rule_description VARCHAR(100) NOT NULL ,
	cdd_rule_status_code VARCHAR(32) NOT NULL ,
	cdd_rule_type_code   VARCHAR(32) NOT NULL ,
	cdd_rule_save_id_flg CHAR(1)  ,
	cdd_rule_order_in_group DECIMAL(12) NOT NULL ,
	cdd_rule_group_id    VARCHAR(32)  ,
	logical_delete_ind   CHAR(1)  ,
	create_user_id       VARCHAR(60)  ,
	lstupdate_user_id    VARCHAR(60)  ,
	CONSTRAINT XPKFSK_CDD_RULE PRIMARY KEY CLUSTERED (cdd_rule_id,version_no))
GO

CREATE INDEX XIF1FSK_CDD_RULE ON SCHKC.FSK_CDD_RULE
(
	cdd_rule_group_id ASC
)
GO

CREATE TABLE SCHKC.FSK_CDD_RULE_GROUP
(
	cdd_rule_group_id    VARCHAR(32) NOT NULL ,
	version_no           DECIMAL(10) NOT NULL ,
	current_ind          CHAR(1)  ,
	cdd_update_date      DATETIME NOT NULL ,
	cdd_create_date      DATETIME NOT NULL ,
	cdd_rule_group_file_name VARCHAR(128)  ,
	cdd_rule_group_type  VARCHAR(32) NOT NULL ,
	cdd_rule_group_category_code VARCHAR(32)  ,
	cdd_rule_group_description VARCHAR(100) NOT NULL ,
	cdd_rule_group_name  VARCHAR(100) NOT NULL ,
	cdd_rule_group_input_ds_name VARCHAR(32)  ,
	cdd_rule_group_by_var_1_name VARCHAR(32)  ,
	cdd_rule_group_by_var_2_name VARCHAR(32)  ,
	cdd_rule_group_level DECIMAL(10)  ,
	cdd_rule_group_order_in_level DECIMAL(10)  ,
	cdd_rule_group_save_to_kc_flg CHAR(1)  ,
	cdd_rule_group_save_trig_v_flg CHAR(1)  ,
	lstupdate_user_id    VARCHAR(60)  ,
	logical_delete_ind   CHAR(1)  ,
	create_user_id       VARCHAR(60)  ,
	CONSTRAINT XPKFSK_CDD_RULE_GROUP PRIMARY KEY CLUSTERED (cdd_rule_group_id,version_no))
GO

CREATE TABLE SCHKC.FSK_CDD_RULE_PARAMETER
(
	cdd_rule_version_no  DECIMAL(10) NOT NULL ,
	cdd_rule_parm_name   VARCHAR(100) NOT NULL ,
	cdd_rule_id          VARCHAR(32) NOT NULL ,
	cdd_rule_parm_description VARCHAR(100) NOT NULL ,
	cdd_rule_parm_type_code VARCHAR(32) NOT NULL ,
	cdd_rule_parm_val    VARCHAR(1024) NOT NULL ,
	CONSTRAINT XPKFSK_CDD_RULE_PARAMETER PRIMARY KEY CLUSTERED (cdd_rule_version_no,cdd_rule_parm_name,cdd_rule_id))
GO

CREATE INDEX XIF1FSK_CDD_RULE_PARAMETER ON SCHKC.FSK_CDD_RULE_PARAMETER
(
	cdd_rule_id ASC
)
GO

CREATE TABLE SCHKC.FSK_CDD_SCORING_EVENT
(
	cdd_scoring_event_key DECIMAL(12) NOT NULL ,
	primary_entity_key   DECIMAL(12) NOT NULL ,
	primary_entity_number VARCHAR(50) NOT NULL ,
	primary_entity_level_code CHAR(3) NOT NULL ,
	cdd_rule_id          VARCHAR(32) NOT NULL ,
	version_no           DECIMAL(10)  ,
	rule_score           DECIMAL(10)  ,
	score_classification_code VARCHAR(32)  ,
	event_date           DATETIME NOT NULL ,
	auto_high_ind        CHAR(1)  ,
	investigation_ind    CHAR(1)  ,
	category_code        VARCHAR(32)  ,
	score_type_code      VARCHAR(32)  ,
	CONSTRAINT XPKFSK_CDD_SCORING_EVENT PRIMARY KEY CLUSTERED (cdd_scoring_event_key));

CREATE UNIQUE  INDEX XAK1FSK_CDD_SCORING_EVENT ON SCHKC.FSK_CDD_SCORING_EVENT
(
	cdd_scoring_event_key ASC
)
GO

CREATE UNIQUE  INDEX XAK2FSK_CDD_SCORING_EVENT ON SCHKC.FSK_CDD_SCORING_EVENT
(
	cdd_rule_id ASC, 	primary_entity_key ASC, 	event_date ASC
)
GO
CREATE INDEX XIE2FSK_CDD_SCORING_EVENT ON SCHKC.FSK_CDD_SCORING_EVENT
(
	primary_entity_number ASC
)
GO

CREATE INDEX XIF1FSK_CDD_SCORING_EVENT ON SCHKC.FSK_CDD_SCORING_EVENT
(
	cdd_rule_id ASC, 	version_no ASC
)
GO


CREATE VIEW SCHBU1.FSK_CDD_RULE AS SELECT * FROM SCHKC.FSK_CDD_RULE
GO

CREATE VIEW SCHBU1.FSK_CDD_RULE_GROUP AS SELECT * FROM SCHKC.FSK_CDD_RULE_GROUP
GO

CREATE VIEW SCHBU1.FSK_CDD_RULE_PARAMETER AS SELECT * FROM SCHKC.FSK_CDD_RULE_PARAMETER
GO

CREATE VIEW SCHBU1.FSK_CDD_SCORING_EVENT AS SELECT * FROM SCHKC.FSK_CDD_SCORING_EVENT
GO

-- update existing CDD view

CREATE VIEW SCHBU1.FSK_CDD_TRIGGERING_VALUES AS SELECT * FROM SCHKC.FSK_CDD_TRIGGERING_VALUES
GO


-- Add CDD Review Tables

CREATE TABLE SCHKC.FSK_CDD_REVIEW
(
	review_key           DECIMAL(12) NOT NULL ,
	version_number       DECIMAL(10) NOT NULL ,
	primary_entity_number VARCHAR(50) NOT NULL ,
	primary_entity_level_code CHAR(3) NOT NULL ,
	employee_ind         CHAR(1)  ,
	status_code          VARCHAR(10)  ,
	owner_user_long_id   VARCHAR(60)  ,
	initial_scoring_event_key DECIMAL(12)  ,
	initial_risk_score   DECIMAL(10)  ,
	initial_risk_rating  VARCHAR(32)  ,
	initial_auto_high_ind CHAR(1)  ,
	periodic_review_date DATETIME  ,
	last_review_date     DATETIME  ,
	next_review_date     DATETIME  ,
	review_due_date      DATETIME  ,
	final_disposition_code VARCHAR(32)  ,
	rating_override      VARCHAR(32)  ,
	ky_required          CHAR(1)  ,
	ky_completed         CHAR(1)  ,
	related_pty_required CHAR(1)  ,
	related_pty_completed CHAR(1)  ,
	neg_news_required    CHAR(1)  ,
	neg_news_completed   CHAR(1)  ,
	pub_rec_required     CHAR(1)  ,
	pub_rec_completed    CHAR(1)  ,
	susp_acty_required   CHAR(1)  ,
	susp_acty_completed  CHAR(1)  ,
	src_fw_required      CHAR(1)  ,
	src_fw_completed     CHAR(1)  ,
	trans_required       CHAR(1)  ,
	trans_completed      CHAR(1)  ,
	source_of_funds      VARCHAR(200)  ,
	source_of_wealth     VARCHAR(200)  ,
	create_date          DATETIME NOT NULL ,
	create_user_id       VARCHAR(60)  ,
	lstupdate_user_id    VARCHAR(60)  ,
	lstupdate_date       DATETIME NOT NULL ,
	CONSTRAINT XPKFSK_CDD_REVIEW PRIMARY KEY CLUSTERED (review_key))

CREATE INDEX XIE1FSK_CDD_REVIEW ON SCHKC.FSK_CDD_REVIEW
(
	primary_entity_number ASC
)
GO

CREATE INDEX XIE2FSK_CDD_REVIEW ON SCHKC.FSK_CDD_REVIEW
(
	primary_entity_level_code ASC
)
GO

CREATE INDEX XIE3FSK_CDD_REVIEW ON SCHKC.FSK_CDD_REVIEW
(
	owner_user_long_id ASC
)
GO

CREATE INDEX XIE4FSK_CDD_REVIEW ON SCHKC.FSK_CDD_REVIEW
(
	status_code ASC
)
GO

CREATE INDEX XIE5FSK_CDD_REVIEW ON SCHKC.FSK_CDD_REVIEW
(
	final_disposition_code ASC
)
GO

CREATE TABLE SCHKC.FSK_CDD_REVIEW_EVENT
(
	event_id             DECIMAL(12) NOT NULL ,
	event_type_code      VARCHAR(3) NOT NULL ,
	event_description    VARCHAR(255)  ,
	create_user_id       VARCHAR(60) NOT NULL ,
	create_date          DATETIME NOT NULL ,
	review_key           DECIMAL(12) NOT NULL ,
	CONSTRAINT XPKFSK_CDD_REVIEW_EVENT PRIMARY KEY CLUSTERED (event_id))
GO

CREATE INDEX XIF1FSK_CDD_REVIEW_EVENT ON SCHKC.FSK_CDD_REVIEW_EVENT
(
	review_key ASC
)
GO


CREATE TABLE SCHKC.FSK_CDD_EDD_REVIEW
(
	review_key           DECIMAL(12) NOT NULL ,
	edd_step_code        VARCHAR(10) NOT NULL ,
	edd_step_sort_position_number INTEGER  ,
	edd_step_required    CHAR(1)  ,
	edd_step_completed   CHAR(1)  ,
	edd_step_notes       VARCHAR(100)  ,
	CONSTRAINT XPKFSK_CDD_EDD_REVIEW PRIMARY KEY CLUSTERED (review_key,edd_step_code))
GO

CREATE INDEX XIF1FSK_CDD_EDD_REVIEW ON SCHKC.FSK_CDD_EDD_REVIEW
(
	review_key ASC
)
GO


ALTER TABLE SCHKC.FSK_CDD_REVIEW_EVENT
	ADD  CONSTRAINT FK_CDD_REVIEW_EVENT_CDD_REVIEW FOREIGN KEY (review_key) REFERENCES SCHKC.FSK_CDD_REVIEW (review_key)
GO

ALTER TABLE SCHKC.FSK_CDD_EDD_REVIEW
	ADD  CONSTRAINT FK_CDD_EDD_REVIEW_CDD_REVIEW FOREIGN KEY (review_key) REFERENCES SCHKC.FSK_CDD_REVIEW (review_key)
GO


CREATE VIEW SCHBU1.FSK_CDD_REVIEW AS SELECT * FROM SCHKC.FSK_CDD_REVIEW
GO

CREATE VIEW SCHBU1.FSK_CDD_EDD_REVIEW AS SELECT * FROM SCHKC.FSK_CDD_EDD_REVIEW
GO

CREATE VIEW SCHBU1.FSK_CDD_REVIEW_EVENT AS SELECT * FROM SCHKC.FSK_CDD_REVIEW_EVENT
GO

-- Modify FSK_RC_REPORT
ALTER TABLE SCHKC.FSK_RC_REPORT ADD SAR90_CASE_ID DECIMAL(12) NULL ;
GO
ALTER VIEW SCHBU1.FSK_RC_REPORT AS SELECT * FROM SCHKC.FSK_RC_REPORT;
GO
-- Modify FSK_CASE
ALTER TABLE SCHKC.FSK_CASE ADD  ACTIVATE_DATE DATETIME NULL ;
GO
ALTER VIEW SCHBU1.FSK_CASE AS SELECT * FROM SCHKC.FSK_CASE;
GO

-- Modify FSK_RC_REPORT_ENTITY_INFO

ALTER TABLE SCHKC.FSK_RC_REPORT_ENTITY_INFO ADD
	PARENT_ENTITY_NUMBER VARCHAR(32) NULL,
	DEFAULT_IND CHAR(1) NULL;
	
GO

DROP VIEW SCHBU1.FSK_RC_REPORT_ENTITY_INFO
GO

CREATE VIEW SCHBU1.FSK_RC_REPORT_ENTITY_INFO AS SELECT * FROM SCHKC.FSK_RC_REPORT_ENTITY_INFO
GO

-- Update FSC_EXT_PARTY_ACCOUNT_DIM, add SCD2 columns

ALTER TABLE SCHCORE.FSC_EXT_PARTY_ACCOUNT_DIM
ADD
       change_begin_date    DATETIME DEFAULT GETDATE() NOT NULL,
       change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00' NOT NULL,
       change_current_ind   CHAR(1) DEFAULT 'Y' NOT NULL;
GO

ALTER VIEW SCHBU1.FSC_EXT_PARTY_ACCOUNT_DIM AS SELECT * FROM SCHCORE.FSC_EXT_PARTY_ACCOUNT_DIM
GO


-- Recreate the Alert Triage Datamart to contain entity numbers

---- Drop Datamart Views 
DROP VIEW SCHBU1.FSK_ALERT_TX_AGG
GO

DROP VIEW SCHBU1.FSK_ENTITY_TX_AGG
GO

DROP VIEW SCHBU1.FSK_ALERTED_ENTITY
GO

DROP VIEW SCHBU1.FSK_ENTITY_TRANSACTION
GO

DROP VIEW SCHBU1.FSK_ALERT_TRANSACTION
GO


---- Drop Datamart Tables
ALTER TABLE SCHKC.FSK_ALERT_TRANSACTION
DROP CONSTRAINT R_358
GO

ALTER TABLE SCHKC.FSK_ALERT_TRANSACTION
DROP CONSTRAINT R_370
GO

ALTER TABLE SCHKC.FSK_ALERT_TX_AGG
DROP CONSTRAINT R_365
GO

ALTER TABLE SCHKC.FSK_ENTITY_TRANSACTION
DROP CONSTRAINT R_404
GO

ALTER TABLE SCHKC.FSK_ENTITY_TX_AGG
DROP CONSTRAINT R_369
GO

DROP TABLE SCHKC.FSK_ENTITY_TX_AGG
GO

DROP TABLE SCHKC.FSK_ALERT_TX_AGG
GO

DROP TABLE SCHKC.FSK_ENTITY_TRANSACTION
GO

---- DROP TABLE SCHKC.FSK_ALERTED_ENTITY
---- GO

DROP TABLE SCHKC.FSK_ALERT_TRANSACTION
GO

---- Drop indexes constraint and column
DROP INDEX XAK1FSK_ALERTED_ENTITY ON SCHKC.FSK_ALERTED_ENTITY;
ALTER TABLE SCHKC.FSK_ALERTED_ENTITY DROP CONSTRAINT XPKFSK_ALERTED_ENTITY;
ALTER TABLE SCHKC.FSK_ALERTED_ENTITY DROP COLUMN alerted_entity_key;
ALTER TABLE SCHKC.FSK_ALERTED_ENTITY ALTER COLUMN alerted_entity_number VARCHAR(50) NOT NULL;

CREATE UNIQUE  INDEX XAK1FSK_ALERTED_ENTITY ON SCHKC.FSK_ALERTED_ENTITY
(
	alerted_entity_number  ASC, 	alerted_entity_level_code ASC
)
GO

CREATE TABLE SCHKC.FSK_ALERT_TRANSACTION
(
	fsk_alert_transaction_pk DECIMAL(22) NOT NULL ,
	alerted_entity_level_code CHAR(3)  ,
	alerted_entity_number VARCHAR(50)  ,
	alert_id             DECIMAL(12)  ,
	transaction_id       VARCHAR(50)  ,
	transaction_amt      NUMERIC(15,3)  ,
	transaction_cdi_desc VARCHAR(30)  ,
	primary_medium_desc  VARCHAR(30)  ,
	secondary_medium_desc VARCHAR(30)  ,
	transaction_date     DATETIME  ,
	transaction_mechanism VARCHAR(50)  ,
	account_number       VARCHAR(50)  ,
	beneficiary_name     VARCHAR(200)  ,
	associate_name       VARCHAR(250)  ,
	Branch_name          VARCHAR(100)  ,
	transaction_desc     VARCHAR(255)  ,
	transaction_status   VARCHAR(20)  ,
	triggering_indicator_cd VARCHAR(3)  ,
	created_timestamp    DATETIME  ,
	date_key             DECIMAL(8)  ,
	time_key             DECIMAL(6)  ,
	CONSTRAINT XPKFSK_ALERT_TRANSACTION PRIMARY KEY CLUSTERED (fsk_alert_transaction_pk))
GO

CREATE INDEX XIF2FSK_ALERT_TRANSACTION ON SCHKC.FSK_ALERT_TRANSACTION
(
	alert_id ASC
)
GO

CREATE INDEX XIF3FSK_ALERT_TRANSACTION ON SCHKC.FSK_ALERT_TRANSACTION
(
	alerted_entity_level_code ASC, 	alerted_entity_number  ASC
)
GO

CREATE TABLE SCHKC.FSK_ALERT_TX_AGG
(
	fsk_alert_tx_agg_pk  DECIMAL(12) NOT NULL ,
	alert_id             DECIMAL(12)  ,
	aggregate_type_code  VARCHAR(35)  ,
	group_code           VARCHAR(30)  ,
	group_desc           VARCHAR(30)  ,
	aggregate_amt        DECIMAL(15,3)  ,
	created_timestamp    DATETIME  ,
	CONSTRAINT XPKFSK_ALERT_TX_AGG PRIMARY KEY CLUSTERED (fsk_alert_tx_agg_pk))
GO

CREATE INDEX XIF1FSK_ALERT_TX_AGG ON SCHKC.FSK_ALERT_TX_AGG
(
	alert_id ASC
)
GO

CREATE TABLE SCHKC.FSK_ENTITY_TRANSACTION
(
	fsk_entity_transaction_pk DECIMAL(22) NOT NULL ,
	alerted_entity_level_code CHAR(3)  ,
        alerted_entity_number VARCHAR(50)  ,
	transaction_id       VARCHAR(50)  ,
	transaction_amt      NUMERIC(15,3)  ,
	transaction_cdi_desc VARCHAR(30)  ,
	primary_medium_desc  VARCHAR(30)  ,
	secondary_medium_desc VARCHAR(30)  ,
	transaction_date     DATETIME  ,
	transaction_mechanism VARCHAR(50)  ,
	account_number       VARCHAR(50)  ,
	beneficiary_name     VARCHAR(200)  ,
	associate_name       VARCHAR(250)  ,
	Branch_name          VARCHAR(100)  ,
	transaction_desc     VARCHAR(255)  ,
	transaction_status   VARCHAR(20)  ,
	created_timestamp    DATETIME  ,
	date_key             DECIMAL(8)  ,
	time_key             DECIMAL(6)  ,
	household_number     VARCHAR(50)  ,
	CONSTRAINT XPKFSK_ENTITY_TRANSACTION PRIMARY KEY CLUSTERED (fsk_entity_transaction_pk))
GO

CREATE INDEX XIF1FSK_ENTITY_TRANSACTION ON SCHKC.FSK_ENTITY_TRANSACTION
(
	alerted_entity_level_code ASC, 	alerted_entity_number ASC
)
GO

CREATE TABLE SCHKC.FSK_ENTITY_TX_AGG
(
	fsk_entity_tx_agg_pk DECIMAL(12) NOT NULL ,
	alerted_entity_level_code CHAR(3)  ,
        alerted_entity_number VARCHAR(50)  ,
	aggregate_type_code  VARCHAR(4)  ,
	group_code           VARCHAR(50)  ,
	group_desc           VARCHAR(50)  ,
	aggregate_amt        DECIMAL(15,3)  ,
	created_timestamp    DATETIME  ,
	CONSTRAINT XPKFSK_ENTITY_TX_AGG PRIMARY KEY CLUSTERED (fsk_entity_tx_agg_pk))
GO

CREATE INDEX XIF1FSK_ENTITY_TX_AGG ON SCHKC.FSK_ENTITY_TX_AGG
(
	alerted_entity_level_code ASC, 	alerted_entity_number ASC
)
GO

---- Create Datamart Views 
CREATE  VIEW SCHBU1.FSK_ALERT_TX_AGG AS SELECT * FROM SCHKC.FSK_ALERT_TX_AGG
GO

CREATE  VIEW SCHBU1.FSK_ENTITY_TX_AGG AS SELECT * FROM SCHKC.FSK_ENTITY_TX_AGG
GO

CREATE  VIEW SCHBU1.FSK_ALERTED_ENTITY AS SELECT * FROM SCHKC.FSK_ALERTED_ENTITY
GO

CREATE  VIEW SCHBU1.FSK_ALERT_TRANSACTION AS SELECT * FROM SCHKC.FSK_ALERT_TRANSACTION
GO

CREATE  VIEW SCHBU1.FSK_ENTITY_TRANSACTION AS SELECT * FROM SCHKC.FSK_ENTITY_TRANSACTION
GO

-- modify FSC_PARTY_DIM for Beneficial Ownership support


ALTER TABLE SCHCORE.FSC_PARTY_DIM
ADD
       ben_own_exempt_ind   CHAR(1) DEFAULT 'N' NULL;
GO
ALTER VIEW SCHBU1.FSC_PARTY_DIM AS SELECT * FROM SCHCORE.FSC_PARTY_DIM
GO

-- modify FSC_ACCOUNT_DIM for Beneficial Ownership support

ALTER TABLE SCHCORE.FSC_ACCOUNT_DIM
ADD
       opened_by_party_number       VARCHAR(50) NULL ,
       opened_by_party_name         VARCHAR(200) NULL ,
       opened_by_party_title        VARCHAR(50) NULL;
GO
ALTER VIEW SCHBU1.FSC_ACCOUNT_DIM AS SELECT * FROM SCHCORE.FSC_ACCOUNT_DIM
GO

ALTER TABLE SCHKC.FSK_CASE ALTER COLUMN case_description VARCHAR(100)
GO
ALTER VIEW SCHBU1.FSK_CASE AS SELECT * FROM SCHKC.FSK_CASE
GO


CREATE TABLE SCHKC.FSK_SEGMENT (
  entity_segment_key  DECIMAL(12) NOT NULL,
  entity_segment_id   DECIMAL(12) NOT NULL,
  segment_name        NVARCHAR(50),
  segment_description NVARCHAR(100),
  lstupdate_user      VARCHAR(60),
  logical_delete_ind  CHAR(1),
  active_ind          CHAR(1),
  change_begin_date   DATETIME DEFAULT GETDATE() NOT NULL,
  change_end_date     DATETIME DEFAULT '5999-01-01T00:00:00' NOT NULL,
  change_current_ind  CHAR(1) DEFAULT 'Y' NOT NULL,
  CONSTRAINT XPKFSK_SEGMENT PRIMARY KEY CLUSTERED (entity_segment_key)
)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_DIM   ADD entity_segment_id DECIMAL(12) NULL
GO
ALTER TABLE SCHCORE.FSC_PARTY_DIM     ADD entity_segment_id DECIMAL(12) NULL
GO
ALTER TABLE SCHKC.FSK_ALERT           ADD entity_segment_id DECIMAL(12) NULL
GO
ALTER TABLE SCHKC.FSK_ALERTED_ENTITY  ADD alerted_entity_segment_id DECIMAL(12) NULL
GO
ALTER TABLE SCHKC.FSK_ALERTED_ENTITY  ALTER COLUMN alerted_entity_name NVARCHAR(200)
GO
ALTER TABLE SCHKC.FSK_ALERTED_ENTITY  DROP COLUMN owner_userid
GO


CREATE VIEW SCHBU1.FSK_SEGMENT AS SELECT * FROM SCHKC.FSK_SEGMENT
GO
ALTER VIEW SCHBU1.FSC_PARTY_DIM AS SELECT * FROM SCHCORE.FSC_PARTY_DIM
GO
ALTER VIEW SCHBU1.FSK_ALERTED_ENTITY AS SELECT * FROM SCHKC.FSK_ALERTED_ENTITY
GO


ALTER TABLE SCHKC.FSK_SCENARIO_PARAMETER DROP CONSTRAINT  PK_SCENARIO_PARAMETER;
GO
ALTER TABLE SCHKC.FSK_SCENARIO_PARAMETER
ADD
       btl_parm_value      NVARCHAR(1024) NULL ,
       entity_segment_id   DECIMAL(12) DEFAULT -1 NOT NULL
GO
ALTER TABLE SCHKC.FSK_SCENARIO_PARAMETER ADD CONSTRAINT PK_SCENARIO_PARAMETER PRIMARY KEY CLUSTERED (scenario_id, parm_name, entity_segment_id)
GO	
ALTER VIEW SCHBU1.FSK_SCENARIO_PARAMETER AS SELECT * FROM SCHKC.FSK_SCENARIO_PARAMETER
GO

ALTER TABLE SCHKC.FSK_SCENARIO
ADD
       segments_enabled_ind CHAR(1) DEFAULT 'N' NULL,
       btl_enabled_ind      CHAR(1) DEFAULT 'N' NULL
GO
ALTER VIEW SCHBU1.FSK_SCENARIO AS SELECT * FROM SCHKC.FSK_SCENARIO
GO


-- Add queues

CREATE TABLE SCHKC.FSK_QUEUE (
  queue_key           DECIMAL(12) NOT NULL,
  queue_code          VARCHAR(32) NOT NULL,
  queue_description   NVARCHAR(100),
  access_role_name    VARCHAR(60) NOT NULL,
  lstupdate_user      VARCHAR(60),
  logical_delete_ind  CHAR(1),
  active_ind          CHAR(1),
  change_begin_date   DATETIME DEFAULT GETDATE() NOT NULL,
  change_end_date     DATETIME DEFAULT '5999-01-01T00:00:00' NOT NULL,
  change_current_ind  CHAR(1) DEFAULT 'Y' NOT NULL,
  CONSTRAINT XPKFSK_QUEUE PRIMARY KEY CLUSTERED (queue_key)
)
GO
CREATE INDEX XIE1FSK_QUEUE ON SCHKC.FSK_QUEUE
(
	queue_code ASC
)
GO

ALTER TABLE SCHKC.FSK_ALERT           ADD queue_code         VARCHAR(32) NULL
GO
ALTER TABLE SCHKC.FSK_CASE            ADD queue_code         VARCHAR(32) NULL
GO
ALTER TABLE SCHKC.FSK_CDD_REVIEW      ADD queue_code         VARCHAR(32) NULL
GO
ALTER TABLE SCHKC.FSK_RC_REPORT       ADD queue_code         VARCHAR(32) NULL
GO
ALTER TABLE SCHKC.FSK_RC_REPORT       ADD employee_ind  CHAR(1) DEFAULT 'N' NULL
GO
CREATE INDEX XEIQFSK_ALERT ON SCHKC.FSK_ALERT (queue_code ASC)
GO
CREATE INDEX XEIQFSK_CASE ON SCHKC.FSK_CASE (queue_code  ASC)
GO
CREATE INDEX XEIQFSK_CDD_REVIEW ON SCHKC.FSK_CDD_REVIEW (queue_code  ASC)
GO
CREATE INDEX XEIQFSK_RC_REPORT ON SCHKC.FSK_RC_REPORT (queue_code  ASC)
GO

CREATE VIEW SCHBU1.FSK_QUEUE AS SELECT * FROM SCHKC.FSK_QUEUE
GO
ALTER VIEW SCHBU1.FSK_CDD_REVIEW AS SELECT * FROM SCHKC.FSK_CDD_REVIEW
GO
ALTER VIEW SCHBU1.FSK_RC_REPORT AS SELECT * FROM SCHKC.FSK_RC_REPORT
GO

CREATE TABLE SCHKC.FSK_ENTITY_QUEUE (
  queue_code                VARCHAR(32) NULL,
	alerted_entity_level_code CHAR(3) NOT NULL ,
	alerted_entity_number     VARCHAR(50) NOT NULL,
	owner_userid              VARCHAR(60) NULL
)
GO
CREATE INDEX XEI1FSK_ENTITY_QUEUE ON SCHKC.FSK_ENTITY_QUEUE (alerted_entity_level_code, alerted_entity_number, queue_code, owner_userid)
GO
CREATE VIEW SCHBU1.FSK_ENTITY_QUEUE AS SELECT * FROM SCHKC.FSK_ENTITY_QUEUE
GO

ALTER TABLE SCHKC.FSK_CASE ADD case_close_date DATETIME NULL
GO
ALTER VIEW SCHBU1.FSK_CASE AS SELECT * FROM SCHKC.FSK_CASE
GO

CREATE TABLE SCHKC.FSK_RC_REPORT_ENTITY_BRIDGE (
	report_key           DECIMAL(12) NOT NULL ,
	parent_level_code    VARCHAR(32) NOT NULL ,
	parent_key           DECIMAL(12) NOT NULL ,
	entity_level_code    VARCHAR(32) NOT NULL ,
	entity_key           DECIMAL(12) NOT NULL ,
	ui_json              NVARCHAR(MAX) NULL ,
  CONSTRAINT XPKFSK_RPT_ENT_BR PRIMARY KEY CLUSTERED (report_key, parent_key, entity_key)
)
GO
ALTER TABLE SCHKC.FSK_RC_REPORT_ENTITY_BRIDGE
	ADD CONSTRAINT FSK_RC_ENT_BRIDGE_RPT FOREIGN KEY (report_key) REFERENCES SCHKC.FSK_RC_REPORT (report_key)
GO
CREATE VIEW SCHBU1.FSK_RC_REPORT_ENTITY_BRIDGE AS SELECT * FROM SCHKC.FSK_RC_REPORT_ENTITY_BRIDGE
GO

ALTER TABLE SCHKC.FSK_ALERT ALTER COLUMN alerted_entity_name VARCHAR(200)
GO
ALTER TABLE SCHKC.FSK_ALERT alter column primary_entity_name VARCHAR(200)
GO
ALTER TABLE SCHKC.FSK_CASE_ENTITY alter column entity_name VARCHAR(200)
GO
ALTER TABLE SCHKC.FSK_RC_REPORT_ENTITY alter column entity_name VARCHAR(200)
GO
ALTER TABLE SCHKC.FSK_RC_REPORT_ENTITY_INFO alter column entity_name VARCHAR(200)
GO
ALTER TABLE SCHCORE.FSC_BANK_DIM alter column bank_name VARCHAR(200)
GO
ALTER TABLE SCHCORE.FSC_ASSOCIATE_DIM alter column associate_last_name VARCHAR(200)
GO
ALTER TABLE SCHCORE.FSC_HOUSEHOLD_DIM alter column head_of_household_name VARCHAR(200)
GO
ALTER TABLE SCHCORE.FSC_ACCOUNT_DIM alter column account_name VARCHAR(200)
GO

ALTER VIEW SCHBU1.FSK_ALERT AS SELECT * FROM SCHKC.FSK_ALERT
GO
ALTER VIEW SCHBU1.FSK_CASE_ENTITY AS SELECT * FROM SCHKC.FSK_CASE_ENTITY
GO
ALTER VIEW SCHBU1.FSK_RC_REPORT_ENTITY AS SELECT * from SCHKC.FSK_RC_REPORT_ENTITY
GO
ALTER VIEW SCHBU1.FSK_RC_REPORT_ENTITY_INFO AS SELECT * from SCHKC.FSK_RC_REPORT_ENTITY_INFO
GO
ALTER VIEW SCHBU1.FSC_BANK_DIM AS SELECT * FROM SCHCORE.FSC_BANK_DIM
GO
ALTER VIEW SCHBU1.FSC_ASSOCIATE_DIM AS SELECT * FROM SCHCORE.FSC_ASSOCIATE_DIM
GO
ALTER VIEW SCHBU1.FSC_HOUSEHOLD_DIM AS SELECT * FROM SCHCORE.FSC_HOUSEHOLD_DIM
GO
ALTER VIEW SCHBU1.FSC_ACCOUNT_DIM AS SELECT * FROM SCHCORE.FSC_ACCOUNT_DIM
GO

ALTER VIEW SCHBU1.FSC_TRANSACTION_VIEW (account_key, account_number, branch_key, date_key, time_key, transaction_type_key, transaction_key,
currency_amount, transaction_reference_number, transaction_description, security_name, deal_number, bank_name_1, role_desc_1, bank_name_2,
role_desc_2, bank_name_3, role_desc_3, bank_name_4, role_desc_4, bank_name_5, role_desc_5, bank_name_6, role_desc_6) AS SELECT CFF.account_key,
ACC.account_number, CFF.branch_key, CFF.date_key, CFF.time_key, CFF.transaction_type_key, CFF.transaction_key, CFF.currency_amount, TD.transaction_reference_number,
TD.transaction_description, TD.security_name, TD.deal_number, BD.BANK_NAME AS bank_name_1, CFBB.Role_Desc AS role_desc_1, BD2.BANK_NAME AS bank_name_2,
 CFBB2.Role_Desc AS role_desc_2, BD3.BANK_NAME AS bank_name_3, CFBB3.Role_Desc AS role_desc_3, BD4.BANK_NAME AS bank_name_4, CFBB4.Role_Desc AS role_desc_4,
BD5.BANK_NAME AS bank_name_5, CFBB5.Role_Desc AS role_desc_5, BD6.BANK_NAME AS bank_name_6, CFBB6.Role_Desc AS role_desc_6
FROM SCHCORE.FSC_CASH_FLOW_FACT CFF JOIN SCHCORE.FSC_TRANSACTION_DIM TD ON CFF.transaction_key = TD.transaction_key
JOIN SCHCORE.FSC_ACCOUNT_DIM ACC ON CFF.account_key = ACC.account_key  LEFT JOIN SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB
ON CFF.TRANSACTION_KEY = CFBB.TRANSACTION_KEY AND CFBB.SEQUENCE_NUMBER = 1 LEFT JOIN SCHCORE.FSC_BANK_DIM BD
ON CFBB.BANK_KEY = BD.BANK_KEY LEFT JOIN SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB2 ON CFF.TRANSACTION_KEY = CFBB2.TRANSACTION_KEY
AND CFBB2.SEQUENCE_NUMBER = 2  LEFT JOIN SCHCORE.FSC_BANK_DIM BD2 ON CFBB2.BANK_KEY = BD2.BANK_KEY
LEFT JOIN SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB3 ON CFF.TRANSACTION_KEY = CFBB3.TRANSACTION_KEY AND CFBB3.SEQUENCE_NUMBER = 3
LEFT JOIN SCHCORE.FSC_BANK_DIM BD3 ON CFBB3.BANK_KEY = BD3.BANK_KEY  LEFT JOIN SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB4
ON CFF.TRANSACTION_KEY = CFBB4.TRANSACTION_KEY AND CFBB4.SEQUENCE_NUMBER = 4 LEFT JOIN SCHCORE.FSC_BANK_DIM BD4
ON CFBB4.BANK_KEY = BD4.BANK_KEY  LEFT JOIN SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB5 ON CFF.TRANSACTION_KEY = CFBB5.TRANSACTION_KEY
AND CFBB5.SEQUENCE_NUMBER = 5  LEFT JOIN SCHCORE.FSC_BANK_DIM BD5 ON CFBB5.BANK_KEY = BD5.BANK_KEY
LEFT JOIN SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB6 ON CFF.TRANSACTION_KEY = CFBB6.TRANSACTION_KEY AND CFBB6.SEQUENCE_NUMBER = 6
LEFT JOIN SCHCORE.FSC_BANK_DIM BD6 ON CFBB6.BANK_KEY = BD6.BANK_KEY
UNION ALL(SELECT AEF.account_key,
ACC.account_number, AEF.branch_key, AEF.date_key, AEF.time_key, AEF.transaction_type_key, AEF.transaction_key, 0, TD.transaction_reference_number, TD.transaction_description,
TD.security_name, TD.deal_number, '', '', '', '', '', '', '', '', '', '', '', '' FROM SCHCORE.FSC_ACCOUNT_EVENT_FACT AEF JOIN SCHCORE.FSC_ACCOUNT_DIM ACC
ON AEF.account_key = ACC.account_key  JOIN SCHCORE.FSC_TRANSACTION_DIM TD ON AEF.transaction_key = TD.transaction_key
UNION ALL
(SELECT ATF.account_key, ACC.account_number, ATF.branch_key, ATF.trade_date_key AS date_key,
ATF.execution_time_key AS time_key, ATF.transaction_type_key, ATF.transaction_key, ATF.principal_amount AS currency_amount, TD.transaction_reference_number,
TD.transaction_description, TD.security_name, TD.deal_number, '', '', '', '', '', '', '', '', '', '', '', '' FROM SCHCORE.FSC_ACCOUNT_TRADE_FACT ATF
JOIN SCHCORE.FSC_ACCOUNT_DIM ACC ON ATF.account_key = ACC.account_key  JOIN SCHCORE.FSC_TRANSACTION_DIM TD
ON ATF.transaction_key = TD.transaction_key))
GO

-- Recreate Fundstracker's FSK_INT_XFER table with time_key included
DROP VIEW SCHBU1.FSK_INT_XFER
GO

DROP TABLE SCHKC.FSK_INT_XFER
GO

CREATE TABLE SCHKC.FSK_INT_XFER
(
    remitter_account_number VARCHAR(304) NOT NULL ,
    remitter_name        NVARCHAR(304) NOT NULL ,
    remitter_party_key   DECIMAL(12) NOT NULL ,
    beneficiary_account_number VARCHAR(304) NOT NULL ,
    beneficiary_name     NVARCHAR(304) NOT NULL ,
    beneficiary_party_key DECIMAL(12) NOT NULL ,
    date_key             DECIMAL(8) NOT NULL ,
    time_key             DECIMAL(6) NOT NULL ,
    currency_amount      DECIMAL(18,5) NOT NULL ,
    edge_type_code       CHAR(4) NOT NULL )
GO

CREATE INDEX IDX_1_FSK_INT_XFER ON SCHKC.FSK_INT_XFER
( remitter_account_number ASC, beneficiary_account_number ASC )
GO

CREATE  VIEW SCHBU1.FSK_INT_XFER AS SELECT * FROM SCHKC.FSK_INT_XFER
GO


-- Added columns
ALTER TABLE SCHCORE.FSC_PARTY_DIM   ADD purge_date         DATETIME NULL;
GO

-- Replace/create views of altered/created tables
ALTER VIEW SCHBU1.FSC_PARTY_DIM AS SELECT * FROM SCHCORE.FSC_PARTY_DIM
GO

-- Change preference value lengths
ALTER TABLE SCHKC.FSK_PREFERENCE ALTER COLUMN PREF_VALUE VARCHAR(4000)
GO
ALTER TABLE SCHKC.FSK_PREFERENCE ALTER COLUMN PREF_VALUE_DEFAULT VARCHAR(4000)
GO
ALTER VIEW SCHBU1.FSK_PREFERENCE AS SELECT * FROM SCHKC.FSK_PREFERENCE
GO

-- add lock columns to alerted entity
ALTER TABLE SCHKC.FSK_ALERTED_ENTITY ADD lock_userid VARCHAR(32) NULL, lock_timestamp DATETIME NULL
GO
ALTER VIEW SCHBU1.FSK_ALERTED_ENTITY AS SELECT * FROM SCHKC.FSK_ALERTED_ENTITY
GO

-- add lock columns to report
ALTER TABLE SCHKC.FSK_RC_REPORT ADD lock_userid VARCHAR(32) NULL, lock_timestamp DATETIME NULL
GO
ALTER VIEW SCHBU1.FSK_RC_REPORT AS SELECT * FROM SCHKC.FSK_RC_REPORT
GO

-- add lock columns to cdd review
ALTER TABLE SCHKC.FSK_CDD_REVIEW ADD lock_userid VARCHAR(32) NULL, lock_timestamp DATETIME NULL
GO
ALTER VIEW SCHBU1.FSK_CDD_REVIEW AS SELECT * FROM SCHKC.FSK_CDD_REVIEW
GO

-- add lock columns to efile
ALTER TABLE SCHKC.FSK_RC_EFILE ADD lock_userid VARCHAR(32) NULL, lock_timestamp DATETIME NULL
GO
ALTER VIEW SCHBU1.FSK_RC_EFILE AS SELECT * FROM SCHKC.FSK_RC_EFILE
GO

-- add lock columns to case
ALTER TABLE SCHKC.FSK_CASE ADD lock_userid VARCHAR(32) NULL, lock_timestamp DATETIME NULL
GO
ALTER VIEW SCHBU1.FSK_CASE AS SELECT * FROM SCHKC.FSK_CASE
GO

-- add update info columns to alerted entity
ALTER TABLE SCHKC.FSK_ALERTED_ENTITY ADD lstupdate_user_id VARCHAR(32) NULL, lstupdate_date DATETIME NULL
GO
ALTER VIEW SCHBU1.FSK_ALERTED_ENTITY AS SELECT * FROM SCHKC.FSK_ALERTED_ENTITY
GO

-- add efile event table
CREATE TABLE SCHKC.FSK_RC_EFILE_EVENT
(
	event_id             DECIMAL(12) NOT NULL ,
	efile_key           DECIMAL(12) NOT NULL ,
	event_type_code      VARCHAR(3) NOT NULL ,
	event_description    VARCHAR(255)  ,
	create_user_id       VARCHAR(60) NOT NULL ,
	create_date          DATETIME NOT NULL ,
	CONSTRAINT XPKFSK_RC_EFILE_EVENT PRIMARY KEY CLUSTERED (event_id))
GO

CREATE INDEX XIF1FSK_RC_EFILE_EVENT ON SCHKC.FSK_RC_EFILE_EVENT ( efile_key ASC )
GO

ALTER TABLE SCHKC.FSK_RC_EFILE_EVENT
	ADD  CONSTRAINT FK_EFILE_EVENT_EFILE FOREIGN KEY (efile_key) REFERENCES SCHKC.FSK_RC_EFILE (efile_key)
GO

CREATE VIEW SCHBU1.FSK_RC_EFILE_EVENT AS SELECT * FROM SCHKC.FSK_RC_EFILE_EVENT
GO
