-- Update FSK_RC_FORM_CONFIG 

USE [LOCALDB]
GO

ALTER TABLE SCHKC.FSK_RC_FORM_CONFIG
  add   implementation_type_code VARCHAR(32) NULL
GO

DROP VIEW SCHBU1.FSK_RC_FORM_CONFIG
GO

CREATE VIEW SCHBU1.FSK_RC_FORM_CONFIG AS SELECT * FROM SCHKC.FSK_RC_FORM_CONFIG
GO

-- Recreate CDD Tables

DROP VIEW SCHBU1.FSK_CDD_RULE
GO

DROP VIEW SCHBU1.FSK_CDD_RULE_PARAMETER
GO

DROP VIEW SCHBU1.FSK_CDD_RULE_GROUP
GO

DROP VIEW SCHBU1.FSK_CDD_SCORING_EVENT
GO

DROP VIEW SCHBU1.FSK_CDD_TRIGGERING_VALUES
GO

DROP TABLE SCHKC.FSK_CDD_RULE_PARAMETER
GO

DROP TABLE SCHKC.FSK_CDD_RULE
GO

DROP TABLE SCHKC.FSK_CDD_RULE_GROUP
GO

DROP TABLE SCHKC.FSK_CDD_SCORING_EVENT
GO

CREATE TABLE SCHKC.FSK_CDD_RULE
(
	cdd_rule_id          VARCHAR(32) NOT NULL ,
	version_no           DECIMAL(10) NOT NULL ,
	current_ind          CHAR(1)  ,
	cdd_update_date      DATETIME NOT NULL ,
	cdd_create_date      DATETIME NOT NULL ,
	cdd_rule_name        VARCHAR(100) NOT NULL ,
	cdd_rule_description VARCHAR(100) NOT NULL ,
	cdd_rule_status_code VARCHAR(32) NOT NULL ,
	cdd_rule_type_code   VARCHAR(32) NOT NULL ,
	cdd_rule_save_id_flg CHAR(1)  ,
	cdd_rule_order_in_group DECIMAL(12) NOT NULL ,
	cdd_rule_group_id    VARCHAR(32)  ,
	logical_delete_ind   CHAR(1)  ,
	create_user_id       VARCHAR(60)  ,
	lstupdate_user_id    VARCHAR(60)  ,
	CONSTRAINT XPKFSK_CDD_RULE PRIMARY KEY CLUSTERED (cdd_rule_id,version_no))
GO

CREATE INDEX XIF1FSK_CDD_RULE ON SCHKC.FSK_CDD_RULE
(
	cdd_rule_group_id ASC
)
GO

CREATE TABLE SCHKC.FSK_CDD_RULE_GROUP
(
	cdd_rule_group_id    VARCHAR(32) NOT NULL ,
	version_no           DECIMAL(10) NOT NULL ,
	current_ind          CHAR(1)  ,
	cdd_update_date      DATETIME NOT NULL ,
	cdd_create_date      DATETIME NOT NULL ,
	cdd_rule_group_file_name VARCHAR(128)  ,
	cdd_rule_group_type  VARCHAR(32) NOT NULL ,
	cdd_rule_group_category_code VARCHAR(32)  ,
	cdd_rule_group_description VARCHAR(100) NOT NULL ,
	cdd_rule_group_name  VARCHAR(100) NOT NULL ,
	cdd_rule_group_input_ds_name VARCHAR(32)  ,
	cdd_rule_group_by_var_1_name VARCHAR(32)  ,
	cdd_rule_group_by_var_2_name VARCHAR(32)  ,
	cdd_rule_group_level DECIMAL(10)  ,
	cdd_rule_group_order_in_level DECIMAL(10)  ,
	cdd_rule_group_save_to_kc_flg CHAR(1)  ,
	cdd_rule_group_save_trig_v_flg CHAR(1)  ,
	lstupdate_user_id    VARCHAR(60)  ,
	logical_delete_ind   CHAR(1)  ,
	create_user_id       VARCHAR(60)  ,
	CONSTRAINT XPKFSK_CDD_RULE_GROUP PRIMARY KEY CLUSTERED (cdd_rule_group_id,version_no))
GO

CREATE TABLE SCHKC.FSK_CDD_RULE_PARAMETER
(
	cdd_rule_version_no  DECIMAL(10) NOT NULL ,
	cdd_rule_parm_name   VARCHAR(100) NOT NULL ,
	cdd_rule_id          VARCHAR(32) NOT NULL ,
	cdd_rule_parm_description VARCHAR(100) NOT NULL ,
	cdd_rule_parm_type_code VARCHAR(32) NOT NULL ,
	cdd_rule_parm_val    VARCHAR(1024) NOT NULL ,
	CONSTRAINT XPKFSK_CDD_RULE_PARAMETER PRIMARY KEY CLUSTERED (cdd_rule_version_no,cdd_rule_parm_name,cdd_rule_id))
GO

CREATE INDEX XIF1FSK_CDD_RULE_PARAMETER ON SCHKC.FSK_CDD_RULE_PARAMETER
(
	cdd_rule_id ASC
)
GO

CREATE TABLE SCHKC.FSK_CDD_SCORING_EVENT
(
	cdd_scoring_event_key DECIMAL(12) NOT NULL ,
	primary_entity_key   DECIMAL(12) NOT NULL ,
	primary_entity_number VARCHAR(50) NOT NULL ,
	primary_entity_level_code CHAR(3) NOT NULL ,
	cdd_rule_id          VARCHAR(32) NOT NULL ,
	version_no           DECIMAL(10)  ,
	rule_score           DECIMAL(10)  ,
	score_classification_code VARCHAR(32)  ,
	event_date           DATETIME NOT NULL ,
	auto_high_ind        CHAR(1)  ,
	investigation_ind    CHAR(1)  ,
	category_code        VARCHAR(32)  ,
	score_type_code      VARCHAR(32)  ,
	CONSTRAINT XPKFSK_CDD_SCORING_EVENT PRIMARY KEY CLUSTERED (cdd_scoring_event_key));

CREATE UNIQUE  INDEX XAK1FSK_CDD_SCORING_EVENT ON SCHKC.FSK_CDD_SCORING_EVENT
(
	cdd_scoring_event_key ASC
)
GO

CREATE UNIQUE  INDEX XAK2FSK_CDD_SCORING_EVENT ON SCHKC.FSK_CDD_SCORING_EVENT
(
	cdd_rule_id ASC, 	primary_entity_key ASC, 	event_date ASC
)
GO
CREATE INDEX XIE2FSK_CDD_SCORING_EVENT ON SCHKC.FSK_CDD_SCORING_EVENT
(
	primary_entity_number ASC
)
GO

CREATE INDEX XIF1FSK_CDD_SCORING_EVENT ON SCHKC.FSK_CDD_SCORING_EVENT
(
	cdd_rule_id ASC, 	version_no ASC
)
GO


CREATE VIEW SCHBU1.FSK_CDD_RULE AS SELECT * FROM SCHKC.FSK_CDD_RULE
GO

CREATE VIEW SCHBU1.FSK_CDD_RULE_GROUP AS SELECT * FROM SCHKC.FSK_CDD_RULE_GROUP
GO

CREATE VIEW SCHBU1.FSK_CDD_RULE_PARAMETER AS SELECT * FROM SCHKC.FSK_CDD_RULE_PARAMETER
GO

CREATE VIEW SCHBU1.FSK_CDD_SCORING_EVENT AS SELECT * FROM SCHKC.FSK_CDD_SCORING_EVENT
GO

-- update existing CDD view

CREATE VIEW SCHBU1.FSK_CDD_TRIGGERING_VALUES AS SELECT * FROM SCHKC.FSK_CDD_TRIGGERING_VALUES
GO


-- Add CDD Review Tables

CREATE TABLE SCHKC.FSK_CDD_REVIEW
(
	review_key           DECIMAL(12) NOT NULL ,
	version_number       DECIMAL(10) NOT NULL ,
	primary_entity_number VARCHAR(50) NOT NULL ,
	primary_entity_level_code CHAR(3) NOT NULL ,
	employee_ind         CHAR(1)  ,
	status_code          VARCHAR(10)  ,
	owner_user_long_id   VARCHAR(60)  ,
	initial_scoring_event_key DECIMAL(12)  ,
	initial_risk_score   DECIMAL(10)  ,
	initial_risk_rating  VARCHAR(32)  ,
	initial_auto_high_ind CHAR(1)  ,
	periodic_review_date DATETIME  ,
	last_review_date     DATETIME  ,
	next_review_date     DATETIME  ,
	review_due_date      DATETIME  ,
	final_disposition_code VARCHAR(32)  ,
	rating_override      VARCHAR(32)  ,
	ky_required          CHAR(1)  ,
	ky_completed         CHAR(1)  ,
	related_pty_required CHAR(1)  ,
	related_pty_completed CHAR(1)  ,
	neg_news_required    CHAR(1)  ,
	neg_news_completed   CHAR(1)  ,
	pub_rec_required     CHAR(1)  ,
	pub_rec_completed    CHAR(1)  ,
	susp_acty_required   CHAR(1)  ,
	susp_acty_completed  CHAR(1)  ,
	src_fw_required      CHAR(1)  ,
	src_fw_completed     CHAR(1)  ,
	trans_required       CHAR(1)  ,
	trans_completed      CHAR(1)  ,
	source_of_funds      VARCHAR(200)  ,
	source_of_wealth     VARCHAR(200)  ,
	create_date          DATETIME NOT NULL ,
	create_user_id       VARCHAR(60)  ,
	lstupdate_user_id    VARCHAR(60)  ,
	lstupdate_date       DATETIME NOT NULL ,
	CONSTRAINT XPKFSK_CDD_REVIEW PRIMARY KEY CLUSTERED (review_key))

CREATE INDEX XIE1FSK_CDD_REVIEW ON SCHKC.FSK_CDD_REVIEW
(
	primary_entity_number ASC
)
GO

CREATE INDEX XIE2FSK_CDD_REVIEW ON SCHKC.FSK_CDD_REVIEW
(
	primary_entity_level_code ASC
)
GO

CREATE INDEX XIE3FSK_CDD_REVIEW ON SCHKC.FSK_CDD_REVIEW
(
	owner_user_long_id ASC
)
GO

CREATE INDEX XIE4FSK_CDD_REVIEW ON SCHKC.FSK_CDD_REVIEW
(
	status_code ASC
)
GO

CREATE INDEX XIE5FSK_CDD_REVIEW ON SCHKC.FSK_CDD_REVIEW
(
	final_disposition_code ASC
)
GO

CREATE TABLE SCHKC.FSK_CDD_REVIEW_EVENT
(
	event_id             DECIMAL(12) NOT NULL ,
	event_type_code      VARCHAR(3) NOT NULL ,
	event_description    VARCHAR(255)  ,
	create_user_id       VARCHAR(60) NOT NULL ,
	create_date          DATETIME NOT NULL ,
	review_key           DECIMAL(12) NOT NULL ,
	CONSTRAINT XPKFSK_CDD_REVIEW_EVENT PRIMARY KEY CLUSTERED (event_id))
GO

CREATE INDEX XIF1FSK_CDD_REVIEW_EVENT ON SCHKC.FSK_CDD_REVIEW_EVENT
(
	review_key ASC
)
GO


CREATE TABLE SCHKC.FSK_CDD_EDD_REVIEW
(
	review_key           DECIMAL(12) NOT NULL ,
	edd_step_code        VARCHAR(10) NOT NULL ,
	edd_step_sort_position_number INTEGER  ,
	edd_step_required    CHAR(1)  ,
	edd_step_completed   CHAR(1)  ,
	edd_step_notes       VARCHAR(100)  ,
	CONSTRAINT XPKFSK_CDD_EDD_REVIEW PRIMARY KEY CLUSTERED (review_key,edd_step_code))
GO

CREATE INDEX XIF1FSK_CDD_EDD_REVIEW ON SCHKC.FSK_CDD_EDD_REVIEW
(
	review_key ASC
)
GO


ALTER TABLE SCHKC.FSK_CDD_REVIEW_EVENT
	ADD  CONSTRAINT FK_CDD_REVIEW_EVENT_CDD_REVIEW FOREIGN KEY (review_key) REFERENCES SCHKC.FSK_CDD_REVIEW (review_key)
GO

ALTER TABLE SCHKC.FSK_CDD_EDD_REVIEW
	ADD  CONSTRAINT FK_CDD_EDD_REVIEW_CDD_REVIEW FOREIGN KEY (review_key) REFERENCES SCHKC.FSK_CDD_REVIEW (review_key)
GO


CREATE VIEW SCHBU1.FSK_CDD_REVIEW AS SELECT * FROM SCHKC.FSK_CDD_REVIEW
GO

CREATE VIEW SCHBU1.FSK_CDD_EDD_REVIEW AS SELECT * FROM SCHKC.FSK_CDD_EDD_REVIEW
GO

CREATE VIEW SCHBU1.FSK_CDD_REVIEW_EVENT AS SELECT * FROM SCHKC.FSK_CDD_REVIEW_EVENT
GO