-- Update FSC_EXT_PARTY_ACCOUNT_DIM with SCD2 columns

ALTER TABLE FCFCORE.FSC_EXT_PARTY_ACCOUNT_DIM ADD change_begin_date    TIMESTAMP(6) NOT NULL DEFAULT current_timestamp;
ALTER TABLE FCFCORE.FSC_EXT_PARTY_ACCOUNT_DIM ADD change_end_date      TIMESTAMP(6) NOT NULL  DEFAULT TIMESTAMP '5999-01-01 00:00:00.000000';
ALTER TABLE FCFCORE.FSC_EXT_PARTY_ACCOUNT_DIM ADD change_current_ind   CHAR(1) NOT NULL DEFAULT 'Y';

DROP VIEW FCFBU1.FSC_EXT_PARTY_ACCOUNT_DIM;
CREATE VIEW FCFBU1.FSC_EXT_PARTY_ACCOUNT_DIM AS SELECT * FROM FCFCORE.FSC_EXT_PARTY_ACCOUNT_DIM;

-- Recreate the Alert Triage Datamart to contain entity numbers

---- Drop Datamart Views 
DROP VIEW FCFBU1.FSK_ALERT_TX_AGG;
DROP VIEW FCFBU1.FSK_ENTITY_TX_AGG;
DROP VIEW FCFBU1.FSK_ALERTED_ENTITY;
DROP VIEW FCFBU1.FSK_ENTITY_TRANSACTION;
DROP VIEW FCFBU1.FSK_ALERT_TRANSACTION;

---- Drop Datamart Tables
DROP TABLE FCFKC.FSK_ENTITY_TX_AGG; 
DROP TABLE FCFKC.FSK_ALERT_TX_AGG; 
DROP TABLE FCFKC.FSK_ENTITY_TRANSACTION; 
-- DROP TABLE FCFKC.FSK_ALERTED_ENTITY;
DROP TABLE FCFKC.FSK_ALERT_TRANSACTION; 

RENAME TABLE FCFKC.FSK_ALERTED_ENTITY TO FCFKC.FSK_ALERTED_ENTITY_TOGO;

---- Create Tables;
CREATE SET TABLE FCFKC.FSK_ALERTED_ENTITY,
	 NO FALLBACK,
	 NO BEFORE JOURNAL,
	 NO AFTER JOURNAL,
	 CHECKSUM = DEFAULT
(
	alerted_entity_level_code CHAR(3) NOT NULL ,
	alerted_entity_number VARCHAR(50) NOT NULL ,
	alerted_entity_name  VARCHAR(35)  ,
	alerts_cnt           DECIMAL(4)  ,
	transactions_cnt     DECIMAL(8)  ,
	aggregate_amt        DECIMAL(15,3)  ,
	age_oldest_alert     DECIMAL(4)  ,
	risk_Score_code      VARCHAR(32)  ,
	money_laundering_score DECIMAL(4)  ,
	employee_ind         CHAR(1)  ,
	owner_userid         VARCHAR(240)  ,
	politically_exposed_person_ind CHAR(1)  ,
	created_timestamp    TIMESTAMP(6)
)
	UNIQUE PRIMARY INDEX XPKFSK_ALERTED_ENTITY(alerted_entity_level_code,alerted_entity_number);

INSERT INTO FCFKC.FSK_ALERTED_ENTITY (
  alerted_entity_level_code,alerted_entity_number,alerted_entity_name,alerts_cnt,
	transactions_cnt,aggregate_amt,age_oldest_alert,risk_Score_code,money_laundering_score,employee_ind,owner_userid,
	politically_exposed_person_ind,	created_timestamp
	)
	SELECT
	alerted_entity_level_code,alerted_entity_number,alerted_entity_name,alerts_cnt,
	transactions_cnt,aggregate_amt,age_oldest_alert,risk_Score_code,money_laundering_score,employee_ind,owner_userid,
	politically_exposed_person_ind,	created_timestamp
	from
	FCFKC.FSK_ALERTED_ENTITY_TOGO;

DROP TABLE FCFKC.FSK_ALERTED_ENTITY_TOGO;

CREATE SET TABLE FCFKC.FSK_ALERT_TRANSACTION,
	 NO FALLBACK, 
	 NO BEFORE JOURNAL, 
	 NO AFTER JOURNAL, 
	 CHECKSUM = DEFAULT
(
	fsk_alert_transaction_pk DECIMAL(22) NOT NULL ,
	alerted_entity_level_code CHAR(3)  ,
        alerted_entity_number VARCHAR(50)  ,
	alert_id             DECIMAL(12)  ,
	transaction_id       VARCHAR(50)  ,
	transaction_amt      NUMERIC(15,3)  ,
	transaction_cdi_desc VARCHAR(30)  ,
	primary_medium_desc  VARCHAR(30)  ,
	secondary_medium_desc VARCHAR(30)  ,
	transaction_date     TIMESTAMP  ,
	transaction_mechanism VARCHAR(50)  ,
	account_number       VARCHAR(50)  ,
	beneficiary_name     VARCHAR(200)  ,
	associate_name       VARCHAR(250)  ,
	Branch_name          VARCHAR(100)  ,
	transaction_desc     VARCHAR(255)  ,
	transaction_status   VARCHAR(20)  ,
	triggering_indicator_cd VARCHAR(3)  ,
	created_timestamp    TIMESTAMP  ,
	date_key             DECIMAL(8)  ,
	time_key             DECIMAL(6)  
)
	UNIQUE PRIMARY INDEX XPKFSK_ALERT_TRANSACTION(fsk_alert_transaction_pk);

CREATE  INDEX XIF2FSK_ALERT_TRANSACTION(alert_id) ON FCFKC.FSK_ALERT_TRANSACTION;

CREATE  INDEX XIF3FSK_ALERT_TRANSACTION(alerted_entity_level_code, alerted_entity_number) ON FCFKC.FSK_ALERT_TRANSACTION;

CREATE SET TABLE FCFKC.FSK_ALERT_TX_AGG,
	 NO FALLBACK, 
	 NO BEFORE JOURNAL, 
	 NO AFTER JOURNAL, 
	 CHECKSUM = DEFAULT
(
	fsk_alert_tx_agg_pk  DECIMAL(12) NOT NULL ,
	alert_id             DECIMAL(12)  ,
	aggregate_type_code  VARCHAR(35)  ,
	group_code           VARCHAR(30)  ,
	group_desc           VARCHAR(30)  ,
	aggregate_amt        DECIMAL(15,3)  ,
	created_timestamp    TIMESTAMP  
)
	UNIQUE PRIMARY INDEX XPKFSK_ALERT_TX_AGG(fsk_alert_tx_agg_pk);

CREATE  INDEX XIF1FSK_ALERT_TX_AGG(alert_id) ON FCFKC.FSK_ALERT_TX_AGG;

CREATE SET TABLE FCFKC.FSK_ENTITY_TRANSACTION,
	 NO FALLBACK, 
	 NO BEFORE JOURNAL, 
	 NO AFTER JOURNAL, 
	 CHECKSUM = DEFAULT
(
	fsk_entity_transaction_pk DECIMAL(22) NOT NULL ,
	alerted_entity_level_code CHAR(3)  ,
        alerted_entity_number VARCHAR(50)  ,
	transaction_id       VARCHAR(50)  ,
	transaction_amt      NUMERIC(15,3)  ,
	transaction_cdi_desc VARCHAR(30)  ,
	primary_medium_desc  VARCHAR(30)  ,
	secondary_medium_desc VARCHAR(30)  ,
	transaction_date     TIMESTAMP  ,
	transaction_mechanism VARCHAR(50)  ,
	account_number       VARCHAR(50)  ,
	beneficiary_name     VARCHAR(200)  ,
	associate_name       VARCHAR(250)  ,
	Branch_name          VARCHAR(100)  ,
	transaction_desc     VARCHAR(255)  ,
	transaction_status   VARCHAR(20)  ,
	created_timestamp    TIMESTAMP  ,
	date_key             DECIMAL(8)  ,
	time_key             DECIMAL(6)  ,
	household_number     VARCHAR(50)
)
	UNIQUE PRIMARY INDEX XPKFSK_ENTITY_TRANSACTION(fsk_entity_transaction_pk);

CREATE  INDEX XIF1FSK_ENTITY_TRANSACTION(alerted_entity_level_code, alerted_entity_number) ON FCFKC.FSK_ENTITY_TRANSACTION;

CREATE SET TABLE FCFKC.FSK_ENTITY_TX_AGG,
	 NO FALLBACK, 
	 NO BEFORE JOURNAL, 
	 NO AFTER JOURNAL, 
	 CHECKSUM = DEFAULT
(
	fsk_entity_tx_agg_pk DECIMAL(12) NOT NULL ,
	alerted_entity_level_code CHAR(3)  ,
        alerted_entity_number VARCHAR(50)  ,
	aggregate_type_code  VARCHAR(4)  ,
	group_code           VARCHAR(50)  ,
	group_desc           VARCHAR(50)  ,
	aggregate_amt        DECIMAL(15,3)  ,
	created_timestamp    TIMESTAMP  
)
	UNIQUE PRIMARY INDEX XPKFSK_ENTITY_TX_AGG(fsk_entity_tx_agg_pk);

CREATE  INDEX XIF1FSK_ENTITY_TX_AGG(alerted_entity_level_code, alerted_entity_number) ON FCFKC.FSK_ENTITY_TX_AGG;

---- Create Views
CREATE  VIEW FCFBU1.FSK_ALERT_TX_AGG AS SELECT * FROM FCFKC.FSK_ALERT_TX_AGG;
CREATE  VIEW FCFBU1.FSK_ENTITY_TX_AGG AS SELECT * FROM FCFKC.FSK_ENTITY_TX_AGG;
CREATE  VIEW FCFBU1.FSK_ALERTED_ENTITY AS SELECT * FROM FCFKC.FSK_ALERTED_ENTITY;
CREATE  VIEW FCFBU1.FSK_ALERT_TRANSACTION AS SELECT * FROM FCFKC.FSK_ALERT_TRANSACTION;
CREATE  VIEW FCFBU1.FSK_ENTITY_TRANSACTION AS SELECT * FROM FCFKC.FSK_ENTITY_TRANSACTION;

-- modify FSC_PARTY_DIM for Beneficial Ownership support
ALTER TABLE FCFCORE.FSC_PARTY_DIM ADD  ben_own_exempt_ind   CHAR(1) NULL DEFAULT 'N';
DROP VIEW FCFBU1.FSC_PARTY_DIM;
CREATE VIEW FCFBU1.FSC_PARTY_DIM AS SELECT * FROM FCFCORE.FSC_PARTY_DIM;

-- modify FSC_ACCOUNT_DIM for Beneficial Ownership support
ALTER TABLE FCFCORE.FSC_ACCOUNT_DIM ADD opened_by_party_number       VARCHAR(50) NULL;
ALTER TABLE FCFCORE.FSC_ACCOUNT_DIM ADD opened_by_party_name         VARCHAR(200) NULL;
ALTER TABLE FCFCORE.FSC_ACCOUNT_DIM ADD opened_by_party_title        VARCHAR(50) NULL;
DROP VIEW FCFBU1.FSC_ACCOUNT_DIM;
CREATE VIEW FCFBU1.FSC_ACCOUNT_DIM AS SELECT * FROM FCFCORE.FSC_ACCOUNT_DIM;

ALTER TABLE FCFKC.FSK_CASE ADD case_description VARCHAR(100);
DROP VIEW FCFBU1.FSK_CASE;
CREATE VIEW FCFBU1.FSK_CASE AS SELECT * FROM FCFKC.FSK_CASE;
