-- Add segments
CREATE SET TABLE FCFKC.FSK_SEGMENT,
 	 NO FALLBACK,
	 NO BEFORE JOURNAL,
	 NO AFTER JOURNAL,
	 CHECKSUM = DEFAULT
(
  entity_segment_key  DECIMAL(12) NOT NULL,
  entity_segment_id   DECIMAL(12) NOT NULL,
  segment_name        VARCHAR(50),
  segment_description VARCHAR(100),
  lstupdate_user      VARCHAR(60),
  logical_delete_ind  CHAR(1),
  active_ind          CHAR(1),
  change_begin_date   TIMESTAMP(6) NOT NULL DEFAULT current_timestamp,
  change_end_date     TIMESTAMP(6) NOT NULL  DEFAULT TIMESTAMP '5999-01-01 00:00:00.000000',
  change_current_ind  CHAR(1) NOT NULL DEFAULT 'Y'
)
UNIQUE PRIMARY INDEX XPKFSK_SEGMENT(entity_segment_key);

ALTER TABLE FCFCORE.FSC_ACCOUNT_DIM   ADD entity_segment_id DECIMAL(12) NULL;
ALTER TABLE FCFCORE.FSC_PARTY_DIM     ADD entity_segment_id DECIMAL(12) NULL;
ALTER TABLE FCFKC.FSK_ALERT           ADD entity_segment_id DECIMAL(12) NULL;
ALTER TABLE FCFKC.FSK_ALERTED_ENTITY  ADD alerted_entity_segment_id DECIMAL(12) NULL;
ALTER TABLE FCFKC.FSK_ALERTED_ENTITY  DROP COLUMN owner_userid;
ALTER TABLE FCFKC.FSK_ALERTED_ENTITY  ADD alerted_entity_name VARCHAR(200);

CREATE  VIEW FCFBU1.FSK_SEGMENT AS SELECT * FROM FCFKC.FSK_SEGMENT;
REPLACE VIEW FCFBU1.FSC_PARTY_DIM AS SELECT * FROM FCFCORE.FSC_PARTY_DIM;
REPLACE VIEW FCFBU1.FSK_ALERTED_ENTITY AS SELECT * FROM FCFKC.FSK_ALERTED_ENTITY;

ALTER TABLE FCFKC.FSK_SCENARIO_PARAMETER ADD btl_parm_value  VARCHAR(1024) NULL;
ALTER TABLE FCFKC.FSK_SCENARIO_PARAMETER ADD entity_segment_id   DECIMAL(12) NOT NULL DEFAULT -1;
-- SECONDARY INDEX is needed so that MODIFY UNIQUE PRIMARY can be run on non-empty table
CREATE UNIQUE INDEX USI_SCENARIO_PARAMETER (scenario_id, entity_segment_id, parm_name) ON FCFKC.FSK_SCENARIO_PARAMETER;
ALTER TABLE FCFKC.FSK_SCENARIO_PARAMETER  MODIFY UNIQUE PRIMARY INDEX PK_SCENARIO_PARAMETER (scenario_id, entity_segment_id, parm_name);
REPLACE VIEW FCFBU1.FSK_SCENARIO_PARAMETER AS SELECT * FROM FCFKC.FSK_SCENARIO_PARAMETER;

ALTER TABLE FCFKC.FSK_SCENARIO ADD segments_enabled_ind CHAR(1) NULL DEFAULT 'N';
ALTER TABLE FCFKC.FSK_SCENARIO ADD btl_enabled_ind  CHAR(1) NULL DEFAULT 'N';
REPLACE VIEW FCFBU1.FSK_SCENARIO AS SELECT * FROM FCFKC.FSK_SCENARIO;

-- Add queues

CREATE SET TABLE FCFKC.FSK_QUEUE,
 	 NO FALLBACK,
	 NO BEFORE JOURNAL,
	 NO AFTER JOURNAL,
	 CHECKSUM = DEFAULT
(
  queue_key           DECIMAL(12) NOT NULL,
  queue_code          VARCHAR(32) NOT NULL,
  queue_description   VARCHAR(100),
  access_role_name    VARCHAR(60) NOT NULL,
  lstupdate_user      VARCHAR(60),
  logical_delete_ind  CHAR(1),
  active_ind          CHAR(1),
  change_begin_date   TIMESTAMP(6) NOT NULL DEFAULT current_timestamp,
  change_end_date     TIMESTAMP(6) NOT NULL  DEFAULT TIMESTAMP '5999-01-01 00:00:00.000000',
  change_current_ind  CHAR(1) NOT NULL DEFAULT 'Y'
)
UNIQUE PRIMARY INDEX XPKFSK_QUEUE (queue_key);

CREATE INDEX XIE1FSK_QUEUE (queue_code) ON FCFKC.FSK_QUEUE;

ALTER TABLE FCFKC.FSK_ALERT           ADD queue_code         VARCHAR(32) NULL;
ALTER TABLE FCFKC.FSK_CASE            ADD queue_code         VARCHAR(32) NULL;
ALTER TABLE FCFKC.FSK_CDD_REVIEW      ADD queue_code         VARCHAR(32) NULL;
ALTER TABLE FCFKC.FSK_RC_REPORT       ADD queue_code         VARCHAR(32) NULL;
ALTER TABLE FCFKC.FSK_RC_REPORT       ADD employee_ind  CHAR(1) NULL DEFAULT 'N';

CREATE INDEX FCFKC.XEIQFSK_ALERT(queue_code) ON FCFKC.FSK_ALERT;
CREATE INDEX FCFKC.XEIQFSK_CASE (queue_code) ON FCFKC.FSK_CASE;
CREATE INDEX FCFKC.XEIQFSK_CDD_REVIEW (queue_code) ON FCFKC.FSK_CDD_REVIEW;
CREATE INDEX FCFKC.XEIQFSK_RC_REPORT (queue_code) ON FCFKC.FSK_RC_REPORT;

CREATE  VIEW FCFBU1.FSK_QUEUE AS SELECT * FROM FCFKC.FSK_QUEUE;

REPLACE VIEW FCFBU1.FSK_CDD_REVIEW AS SELECT * FROM FCFKC.FSK_CDD_REVIEW;
REPLACE VIEW FCFBU1.FSK_RC_REPORT AS SELECT * FROM FCFKC.FSK_RC_REPORT;

CREATE TABLE FCFKC.FSK_ENTITY_QUEUE (
  queue_code                VARCHAR(32)  NULL,
	alerted_entity_level_code CHAR(3) NOT NULL ,
	alerted_entity_number     VARCHAR(50) NOT NULL,
	owner_userid              VARCHAR(60) NULL
)
CREATE INDEX XEI1FSK_ENTITY_QUEUE (alerted_entity_level_code, alerted_entity_number, queue_code, owner_userid) ON FCFKC.FSK_ENTITY_QUEUE;
CREATE VIEW FCFBU1.FSK_ENTITY_QUEUE AS SELECT * FROM FCFKC.FSK_ENTITY_QUEUE;

-- AML-800: Add case close date
ALTER TABLE FCFKC.FSK_CASE ADD case_close_date TIMESTAMP(6) NULL;
REPLACE VIEW FCFBU1.FSK_CASE AS SELECT * FROM FCFKC.FSK_CASE;


CREATE SET TABLE FCFKC.FSK_RC_REPORT_ENTITY_BRIDGE,
 	 NO FALLBACK,
	 NO BEFORE JOURNAL,
	 NO AFTER JOURNAL,
	 CHECKSUM = DEFAULT
(
	report_key           DECIMAL(12) NOT NULL ,
	parent_level_code    VARCHAR(32) NOT NULL ,
	parent_key           DECIMAL(12) NOT NULL ,
	entity_level_code    VARCHAR(32) NOT NULL ,
	entity_key           DECIMAL(12) NOT NULL ,
	ui_json              VARCHAR(10000)  NULL
)
UNIQUE PRIMARY INDEX XPKFSK_RPT_ENT_BR  (report_key, parent_key, entity_key);

CREATE VIEW FCFBU1.FSK_RC_REPORT_ENTITY_BRIDGE AS SELECT * FROM FCFKC.FSK_RC_REPORT_ENTITY_BRIDGE;

-- AML-1213: standardize lengths for entity name
DROP INDEX XIE6FSK_ALERT ON FCFKC.FSK_ALERT;
ALTER TABLE FCFKC.FSK_ALERT add alerted_entity_name VARCHAR(200);
ALTER TABLE FCFKC.FSK_ALERT add primary_entity_name VARCHAR(200);
ALTER TABLE FCFKC.FSK_CASE_ENTITY add entity_name VARCHAR(200);
ALTER TABLE FCFKC.FSK_RC_REPORT_ENTITY add entity_name VARCHAR(200);
ALTER TABLE FCFKC.FSK_RC_REPORT_ENTITY_INFO add entity_name VARCHAR(200);
CREATE INDEX XIE6FSK_ALERT(primary_entity_name) ON FCFKC.FSK_ALERT;

DROP INDEX XIE6FSC_ASSOCIATE_DIM ON FCFCORE.FSC_ASSOCIATE_DIM;
DROP INDEX XIE3FSC_HOUSEHOLD_DIM ON FCFCORE.FSC_HOUSEHOLD_DIM;
DROP INDEX XIE2FSC_ACCOUNT_DIM ON FCFCORE.FSC_ACCOUNT_DIM;
ALTER TABLE FCFCORE.FSC_BANK_DIM add bank_name VARCHAR(200);
ALTER TABLE FCFCORE.FSC_ASSOCIATE_DIM add associate_last_name VARCHAR(200);
ALTER TABLE FCFCORE.FSC_HOUSEHOLD_DIM add head_of_household_name VARCHAR(200);
ALTER TABLE FCFCORE.FSC_ACCOUNT_DIM add account_name VARCHAR(200);
CREATE INDEX XIE6FSC_ASSOCIATE_DIM(associate_last_name) ON FCFCORE.FSC_ASSOCIATE_DIM;
CREATE INDEX XIE3FSC_HOUSEHOLD_DIM(head_of_household_name) ON FCFCORE.FSC_HOUSEHOLD_DIM;
CREATE INDEX XIE2FSC_ACCOUNT_DIM(account_name) ON FCFCORE.FSC_ACCOUNT_DIM;

REPLACE VIEW FCFBU1.FSK_ALERT AS SELECT * FROM FCFKC.FSK_ALERT;
REPLACE VIEW FCFBU1.FSK_CASE_ENTITY AS SELECT * FROM FCFKC.FSK_CASE_ENTITY;
REPLACE VIEW FCFBU1.FSK_RC_REPORT_ENTITY AS SELECT * from FCFKC.FSK_RC_REPORT_ENTITY;
REPLACE VIEW FCFBU1.FSK_RC_REPORT_ENTITY_INFO AS SELECT * FROM FCFKC.FSK_RC_REPORT_ENTITY_INFO;
REPLACE VIEW FCFBU1.FSC_BANK_DIM AS SELECT * FROM FCFCORE.FSC_BANK_DIM;
REPLACE VIEW FCFBU1.FSC_ASSOCIATE_DIM AS SELECT * FROM FCFCORE.FSC_ASSOCIATE_DIM;
REPLACE VIEW FCFBU1.FSC_HOUSEHOLD_DIM AS SELECT * FROM FCFCORE.FSC_HOUSEHOLD_DIM;
REPLACE VIEW FCFBU1.FSC_ACCOUNT_DIM AS SELECT * FROM FCFCORE.FSC_ACCOUNT_DIM;

REPLACE VIEW FCFBU1.fsc_transaction_view (account_key, account_number, branch_key, date_key, time_key, transaction_type_key, transaction_key,
currency_amount, transaction_reference_number, transaction_description, security_name, deal_number, bank_name_1, role_desc_1, bank_name_2,
role_desc_2, bank_name_3, role_desc_3, bank_name_4, role_desc_4, bank_name_5, role_desc_5, bank_name_6, role_desc_6) AS SELECT CFF.account_key,
ACC.account_number, CFF.branch_key, CFF.date_key, CFF.time_key, CFF.transaction_type_key, CFF.transaction_key, CFF.currency_amount, TD.transaction_reference_number,
TD.transaction_description, TD.security_name, TD.deal_number, BD.BANK_NAME AS bank_name_1, CFBB.Role_Desc AS role_desc_1, BD2.BANK_NAME AS bank_name_2,
 CFBB2.Role_Desc AS role_desc_2, BD3.BANK_NAME AS bank_name_3, CFBB3.Role_Desc AS role_desc_3, BD4.BANK_NAME AS bank_name_4, CFBB4.Role_Desc AS role_desc_4,
BD5.BANK_NAME AS bank_name_5, CFBB5.Role_Desc AS role_desc_5, BD6.BANK_NAME AS bank_name_6, CFBB6.Role_Desc AS role_desc_6
FROM FCFCORE.FSC_CASH_FLOW_FACT CFF JOIN FCFCORE.FSC_TRANSACTION_DIM TD ON CFF.transaction_key = TD.transaction_key
JOIN FCFCORE.FSC_ACCOUNT_DIM ACC ON CFF.account_key = ACC.account_key  LEFT JOIN FCFCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB
ON CFF.TRANSACTION_KEY = CFBB.TRANSACTION_KEY AND CFBB.SEQUENCE_NUMBER = 1 LEFT JOIN FCFCORE.FSC_BANK_DIM BD
ON CFBB.BANK_KEY = BD.BANK_KEY LEFT JOIN FCFCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB2 ON CFF.TRANSACTION_KEY = CFBB2.TRANSACTION_KEY
AND CFBB2.SEQUENCE_NUMBER = 2  LEFT JOIN FCFCORE.FSC_BANK_DIM BD2 ON CFBB2.BANK_KEY = BD2.BANK_KEY
LEFT JOIN FCFCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB3 ON CFF.TRANSACTION_KEY = CFBB3.TRANSACTION_KEY AND CFBB3.SEQUENCE_NUMBER = 3
LEFT JOIN FCFCORE.FSC_BANK_DIM BD3 ON CFBB3.BANK_KEY = BD3.BANK_KEY  LEFT JOIN FCFCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB4
ON CFF.TRANSACTION_KEY = CFBB4.TRANSACTION_KEY AND CFBB4.SEQUENCE_NUMBER = 4 LEFT JOIN FCFCORE.FSC_BANK_DIM BD4
ON CFBB4.BANK_KEY = BD4.BANK_KEY  LEFT JOIN FCFCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB5 ON CFF.TRANSACTION_KEY = CFBB5.TRANSACTION_KEY
AND CFBB5.SEQUENCE_NUMBER = 5  LEFT JOIN FCFCORE.FSC_BANK_DIM BD5 ON CFBB5.BANK_KEY = BD5.BANK_KEY
LEFT JOIN FCFCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB6 ON CFF.TRANSACTION_KEY = CFBB6.TRANSACTION_KEY AND CFBB6.SEQUENCE_NUMBER = 6
LEFT JOIN FCFCORE.FSC_BANK_DIM BD6 ON CFBB6.BANK_KEY = BD6.BANK_KEY
UNION ALL(SELECT AEF.account_key,
ACC.account_number, AEF.branch_key, AEF.date_key, AEF.time_key, AEF.transaction_type_key, AEF.transaction_key, 0, TD.transaction_reference_number, TD.transaction_description,
TD.security_name, TD.deal_number, '', '', '', '', '', '', '', '', '', '', '', '' FROM FCFCORE.FSC_ACCOUNT_EVENT_FACT AEF JOIN FCFCORE.FSC_ACCOUNT_DIM ACC
ON AEF.account_key = ACC.account_key  JOIN FCFCORE.FSC_TRANSACTION_DIM TD ON AEF.transaction_key = TD.transaction_key
UNION ALL
(SELECT ATF.account_key, ACC.account_number, ATF.branch_key, ATF.trade_date_key AS date_key,
ATF.execution_time_key AS time_key, ATF.transaction_type_key, ATF.transaction_key, ATF.principal_amount AS currency_amount, TD.transaction_reference_number,
TD.transaction_description, TD.security_name, TD.deal_number, '', '', '', '', '', '', '', '', '', '', '', '' FROM FCFCORE.FSC_ACCOUNT_TRADE_FACT ATF
JOIN FCFCORE.FSC_ACCOUNT_DIM ACC ON ATF.account_key = ACC.account_key  JOIN FCFCORE.FSC_TRANSACTION_DIM TD
ON ATF.transaction_key = TD.transaction_key));