<?xml version="1.0"?>
<!-- ctrx_efile.xsl -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fc2="www.fincen.gov/base">
    <xsl:output method="xml" indent="yes"/>
    <xsl:template match="/collection/items">
        <fc2:EFilingBatchXML TotalAmount="{global/TotalAmount}"
                             PartyCount="{global/PartyCount}" ActivityCount="{global/ActivityCount}"
                             xsi:schemaLocation="www.fincen.gov/base EFL_CTRXBatchSchema.xsd"
                             xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                             xmlns:fc2="www.fincen.gov/base">

            <fc2:FormTypeCode>CTRX</fc2:FormTypeCode>
            <xsl:apply-templates select="report"/>
        </fc2:EFilingBatchXML>
    </xsl:template>


    <xsl:template match="report">
        <xsl:variable name="RR_transactionDate" select="transactionDate"/>
        <xsl:variable name="RR_filingTypeCode" select="filingTypeCode"/>
		<xsl:variable name="RR_contactOffice" select="contactOffice"/>
		<xsl:variable name="RR_contactPhoneNumber" select="contactPhoneNumber"/>
		<xsl:variable name="RR_contactPhoneExtension" select="contactPhoneExtension"/>

        <fc2:Activity SeqNum="{report_key}">
		
		    <xsl:apply-templates select="priorAgencyRefID"/>
			
            <fc2:FilingDateText>
                <xsl:value-of select="/collection/items/global/FilingDate"/>
            </fc2:FilingDateText>

            <fc2:ActivityAssociation SeqNum=".">
                <fc2:CorrectsAmendsPriorReportIndicator>
                    <xsl:value-of select="filingTypeCodeB"/>
                </fc2:CorrectsAmendsPriorReportIndicator>
                <fc2:FinCENDirectBackFileIndicator>
                    <xsl:value-of select="filingTypeCodeC"/>
                </fc2:FinCENDirectBackFileIndicator>
                <fc2:InitialReportIndicator>
                    <xsl:value-of select="filingTypeCodeA"/>
                </fc2:InitialReportIndicator>

            </fc2:ActivityAssociation>

            <!--
                Transmitter party(35)  and transmitter contact party(37)
            -->
            <fc2:Party SeqNum=".">

                <fc2:ActivityPartyTypeCode>35</fc2:ActivityPartyTypeCode>
                <!--  e-filing coverage period -->
                <fc2:EFilingCoverageBeginningDateText>
                    <xsl:value-of select="$RR_transactionDate"/>
                </fc2:EFilingCoverageBeginningDateText>
                <fc2:EFilingCoverageEndDateText>
                    <xsl:value-of select="$RR_transactionDate"/>
                </fc2:EFilingCoverageEndDateText>

                <fc2:PartyName SeqNum=".">
                    <fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
                    <xsl:apply-templates select="/collection/items/transmitter/TRANSMITTER_NAME"/>
                </fc2:PartyName>

                <fc2:Address SeqNum=".">
                    <xsl:apply-templates select="/collection/items/transmitter/TRANSMITTER_CITY_NAME"/>
                    <xsl:apply-templates select="/collection/items/transmitter/TRANSMITTER_COUNTRY_CODE"/>
                    <xsl:apply-templates select="/collection/items/transmitter/TRANSMITTER_STATE_CODE"/>
                    <xsl:apply-templates select="/collection/items/transmitter/TRANSMITTER_ADDRESS"/>
                    <xsl:apply-templates select="/collection/items/transmitter/TRANSMITTER_ZIP_CODE"/>
                </fc2:Address>

                <xsl:if test="/collection/items/transmitter/TRANSMITTER_TELEPHONE">
                    <fc2:PhoneNumber SeqNum=".">
                        <xsl:apply-templates select="/collection/items/transmitter/TRANSMITTER_TELEPHONE"/>
                    </fc2:PhoneNumber>
                </xsl:if>

                <fc2:PartyIdentification SeqNum=".">
                    <xsl:apply-templates select="/collection/items/transmitter/TRANSMITTER_TAX_ID"/>
                    <fc2:PartyIdentificationTypeCode>4</fc2:PartyIdentificationTypeCode>
                </fc2:PartyIdentification>

                <fc2:PartyIdentification SeqNum=".">
                    <xsl:apply-templates select="/collection/items/transmitter/TRANSMITTER_CONTROL_CODE"/>
                    <fc2:PartyIdentificationTypeCode>28</fc2:PartyIdentificationTypeCode>
                </fc2:PartyIdentification>
            </fc2:Party>
            <fc2:Party SeqNum=".">
                <fc2:ActivityPartyTypeCode>37</fc2:ActivityPartyTypeCode>
                <fc2:EFilingCoverageBeginningDateText>
                    <xsl:value-of select="$RR_transactionDate"/>
                </fc2:EFilingCoverageBeginningDateText>
                <fc2:EFilingCoverageEndDateText>
                    <xsl:value-of select="$RR_transactionDate"/>
                </fc2:EFilingCoverageEndDateText>

                <fc2:PartyName SeqNum=".">
                    <fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
                    <xsl:apply-templates select="/collection/items/transmitter/TRANSMITTER_CONTACT_NAME"/>
                </fc2:PartyName>
            </fc2:Party>

            <!--
                Reporting financial institution party(30)  and contact for assistant party(8)
            -->

            <fc2:Party SeqNum=".">
                <fc2:ActivityPartyTypeCode>30</fc2:ActivityPartyTypeCode>

                <xsl:apply-templates select="/collection/items/filer/INSTITUTION_PRIM_FED_REG_CODE"/>

                <fc2:PartyName SeqNum=".">
                    <fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
                    <xsl:apply-templates select="/collection/items/filer/INSTITUTION_LEGAL_NAME"/>
                </fc2:PartyName>

                <xsl:if test="INSTITUTION_ALTERNATE_NAME">
                    <fc2:PartyName SeqNum=".">
                        <fc2:PartyNameTypeCode>DBA</fc2:PartyNameTypeCode>
                        <xsl:apply-templates select="/collection/items/filer/INSTITUTION_ALTERNATE_NAME"/>
                    </fc2:PartyName>
                </xsl:if>

                <fc2:Address SeqNum=".">
                    <xsl:apply-templates select="/collection/items/filer/INSTITUTION_CITY_NAME"/>
                    <xsl:apply-templates select="/collection/items/filer/INSTITUTION_COUNTRY_CODE"/>
                    <xsl:apply-templates select="/collection/items/filer/INSTITUTION_STATE_CODE"/>
                    <xsl:apply-templates select="/collection/items/filer/INSTITUTION_ADDRESS"/>
                    <xsl:apply-templates select="/collection/items/filer/INSTITUTION_ZIP_CODE"/>
                </fc2:Address>
                <fc2:PartyIdentification SeqNum=".">
                    <xsl:apply-templates select="/collection/items/filer/INSTITUTION_TAX_ID"/>
                    <fc2:PartyIdentificationTypeCode>2</fc2:PartyIdentificationTypeCode>
                </fc2:PartyIdentification>


                <fc2:PartyIdentification SeqNum=".">
                    <xsl:apply-templates select="/collection/items/filer/INSTITUTION_ID"/>
                    <xsl:apply-templates select="/collection/items/filer/INSTITUTION_ID_TYPE_CODE"/>
                </fc2:PartyIdentification>

                <fc2:OrganizationClassificationTypeSubtype SeqNum=".">
                    <xsl:apply-templates select="/collection/items/filer/INSTITUTION_GAMING_TYPE_CODE"/>
                    <xsl:apply-templates select="/collection/items/filer/INSTITUTION_TYPE_CODE"/>
                    <xsl:apply-templates select="/collection/items/filer/INSTITUTION_GAMING_TYPE_OTHER"/>
                    <xsl:apply-templates select="/collection/items/filer/INSTITUTION_TYPE_OTHER"/>
                </fc2:OrganizationClassificationTypeSubtype>

            </fc2:Party>
            <fc2:Party SeqNum=".">
                <fc2:ActivityPartyTypeCode>8</fc2:ActivityPartyTypeCode>
                <fc2:PartyName SeqNum=".">
                    <fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
                    <xsl:apply-templates select="$RR_contactOffice"/>
                </fc2:PartyName>
                <fc2:PhoneNumber SeqNum=".">
				    <xsl:apply-templates select="$RR_contactPhoneExtension"/>
                    <xsl:apply-templates select="$RR_contactPhoneNumber"/>
                   
                </fc2:PhoneNumber>
            </fc2:Party>

            <!--
                Transaction location party(34)
            -->

            <xsl:apply-templates select="BRANCH"/>

            <!--
                Party  party(50,17,23,58)
            -->

            <xsl:apply-templates select="PTY"/>

            <!--
                Currency transaction
            -->

            <fc2:CurrencyTransactionActivity SeqNum=".">
			
				<fc2:AggregateTransactionIndicator>
                    <xsl:value-of select="transactionTypeE"/>
                </fc2:AggregateTransactionIndicator>			
              
                <fc2:ArmoredCarServiceIndicator>
                    <xsl:value-of select="transactionTypeA"/>
                </fc2:ArmoredCarServiceIndicator>

                <fc2:ATMIndicator>
                    <xsl:value-of select="transactionTypeB"/>
                </fc2:ATMIndicator>

                <fc2:MailDepositShipmentIndicator>
                    <xsl:value-of select="transactionTypeC"/>
                </fc2:MailDepositShipmentIndicator>

                <fc2:NightDepositIndicator>
                    <xsl:value-of select="transactionTypeD"/>
                </fc2:NightDepositIndicator>

				
                <fc2:SharedBranchingIndicator>
                    <xsl:value-of select="transactionTypeF"/>
                </fc2:SharedBranchingIndicator>


				
				<!-- 
				
                <xsl:apply-templates select="usCashInAmount"/>
                <xsl:apply-templates select="usCashOutAmount"/>
				-->
				<fc2:TotalCashInReceiveAmountText>
					<xsl:value-of select="usCashInAmount"/>
				</fc2:TotalCashInReceiveAmountText>
				<fc2:TotalCashOutAmountText>
                     <xsl:value-of select="usCashOutAmount"/>
                </fc2:TotalCashOutAmountText>
                <xsl:apply-templates select="transactionDate"/>
                <xsl:apply-templates select="usCashInAmountA"/>
                <xsl:apply-templates select="usCashInAmountB"/>
                <xsl:apply-templates select="usCashInAmountC"/>
                <xsl:apply-templates select="usCashInAmountD"/>
                <xsl:apply-templates select="usCashInAmountE"/>
                <xsl:apply-templates select="usCashInAmountF"/>
                <xsl:apply-templates select="usCashInAmountG"/>
                <xsl:apply-templates select="usCashInAmountH"/>
                <xsl:apply-templates select="usCashInAmountI"/>
                <xsl:if test="usCashInAmountOther">
                    <fc2:CurrencyTransactionActivityDetail SeqNum=".">
                        <fc2:CurrencyTransactionActivityDetailTypeCode>997</fc2:CurrencyTransactionActivityDetailTypeCode>
                        <xsl:apply-templates select="usCashInAmountOther"/>
                        <xsl:apply-templates select="usCashInTypeOther"/>
                        <fc2:OtherForeignCurrencyCountryText/>
                    </fc2:CurrencyTransactionActivityDetail>
                </xsl:if>

                <xsl:apply-templates select="usCashOutAmountA"/>
                <xsl:apply-templates select="usCashOutAmountB"/>
                <xsl:apply-templates select="usCashOutAmountC"/>
                <xsl:apply-templates select="usCashOutAmountD"/>
                <xsl:apply-templates select="usCashOutAmountE"/>
                <xsl:apply-templates select="usCashOutAmountF"/>
                <xsl:apply-templates select="usCashOutAmountG"/>
                <xsl:apply-templates select="usCashOutAmountH"/>
                <xsl:apply-templates select="usCashOutAmountI"/>
				<xsl:apply-templates select="usCashOutAmountJ"/>



                <xsl:if test="usCashOutAmountOther">
                    <fc2:CurrencyTransactionActivityDetail SeqNum=".">
                        <fc2:CurrencyTransactionActivityDetailTypeCode>998</fc2:CurrencyTransactionActivityDetailTypeCode>
                        <xsl:apply-templates select="usCashOutAmountOther"/>
                        <xsl:apply-templates select="usCashOutTypeOther"/>
                        <fc2:OtherForeignCurrencyCountryText/>
                    </fc2:CurrencyTransactionActivityDetail>
                </xsl:if>


                <xsl:apply-templates select="foreign_cash_in"/>
                <xsl:apply-templates select="foreign_cash_out"/>


            </fc2:CurrencyTransactionActivity>


        </fc2:Activity>
    </xsl:template>


    <!-- transaction location party 34 -->
    <xsl:template match="BRANCH">
        <fc2:Party SeqNum=".">
            <fc2:ActivityPartyTypeCode>34</fc2:ActivityPartyTypeCode>


            <xsl:apply-templates select="cashInAmount"/>
            <xsl:apply-templates select="cashOutAmount"/>
            <xsl:apply-templates select="BRANCH_PRIM_FED_REG_CODE"/>


            <fc2:PartyName SeqNum=".">
                <fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
                <xsl:apply-templates select="BRANCH_NAME"/>
            </fc2:PartyName>

            <xsl:if test="BRANCH_ALTERNATE_NAME">
                <fc2:PartyName SeqNum=".">
                    <fc2:PartyNameTypeCode>DBA</fc2:PartyNameTypeCode>
                    <xsl:apply-templates select="BRANCH_ALTERNATE_NAME"/>
                </fc2:PartyName>
            </xsl:if>

            <fc2:Address SeqNum=".">
                <xsl:apply-templates select="BRANCH_CITY_NAME"/>
                <xsl:apply-templates select="BRANCH_COUNTRY_CODE"/>
                <xsl:apply-templates select="BRANCH_STATE_CODE"/>
                <xsl:apply-templates select="BRANCH_ADDRESS"/>
                <xsl:apply-templates select="BRANCH_ZIP_CODE"/>
            </fc2:Address>

            <fc2:PartyIdentification SeqNum=".">
                <xsl:apply-templates select="BRANCH_TAX_ID"/>
                
				<xsl:apply-templates select="BRANCH_TAX_ID_UNKNOWN_FLAG"/>
            </fc2:PartyIdentification>

            <xsl:if test="BRANCH_ID_TYPE_CODE">
                <fc2:PartyIdentification SeqNum=".">
                    <xsl:apply-templates select="BRANCH_ID"/>
                    <xsl:apply-templates select="BRANCH_ID_TYPE_CODE"/>
                </fc2:PartyIdentification>
            </xsl:if>

            <fc2:OrganizationClassificationTypeSubtype SeqNum=".">
                <xsl:apply-templates select="BRANCH_GAMING_TYPE_CODE"/>
                <xsl:apply-templates select="BRANCH_TYPE_CTR_CODE"/>
                <xsl:apply-templates select="BRANCH_GAMING_TYPE_OTHER"/>
                <xsl:apply-templates select="BRANCH_TYPE_CTR_OTHER"/>
            </fc2:OrganizationClassificationTypeSubtype>


        </fc2:Party>

    </xsl:template>


    <xsl:template match="PTY">
        <fc2:Party SeqNum=".">
            <xsl:variable name="PTY_gender" select="gender"/>
            <xsl:variable name="PTY_IDType" select="IDType"/>
            <xsl:apply-templates select="personInvolvedTypeCode"/> 
			<xsl:apply-templates select="birthDateUnknownFlag"/>			
            <xsl:if test="$PTY_gender='B'">
                <fc2:FemaleGenderIndicator>Y</fc2:FemaleGenderIndicator>
            </xsl:if>
            <xsl:apply-templates select="birthDate"/>
            <xsl:apply-templates select="cashInAmount"/>
            <xsl:apply-templates select="cashOutAmount"/>
            <xsl:if test="$PTY_gender='A'">
                <fc2:MaleGenderIndicator>Y</fc2:MaleGenderIndicator>
            </xsl:if>

            <xsl:apply-templates select="multiTransactionFlag"/>
            <xsl:apply-templates select="entityFlag"/>
            <xsl:if test="$PTY_gender='C'">
                <fc2:UnknownGenderIndicator>Y</fc2:UnknownGenderIndicator>
            </xsl:if>

           

            <fc2:PartyName SeqNum=".">
                <xsl:apply-templates select="lastNameUnknownFlag"/>
                <xsl:apply-templates select="firstNameUnknownFlag"/>
                <fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
                <xsl:apply-templates select="lastName"/>
                <xsl:apply-templates select="firstName"/>
                <xsl:apply-templates select="middleName"/>
                <xsl:apply-templates select="suffixName"/>
            </fc2:PartyName>
            <xsl:if test="alternateName">
                <fc2:PartyName SeqNum=".">
                    <fc2:PartyNameTypeCode>AKA</fc2:PartyNameTypeCode>
                    <xsl:apply-templates select="alternateName"/>
                </fc2:PartyName>
            </xsl:if>

            <fc2:Address SeqNum=".">
                <xsl:apply-templates select="cityUnknownFlag"/>
                <xsl:apply-templates select="countryUnknownFlag"/>
                <xsl:apply-templates select="city"/>
                <xsl:apply-templates select="countryCode"/>
                <xsl:apply-templates select="stateCode"/>
                <xsl:apply-templates select="address"/>
                <xsl:apply-templates select="postalCode"/>
				<xsl:apply-templates select="stateUnknownFlag"/>
                <xsl:apply-templates select="addressUnknownFlag"/>                
                <xsl:apply-templates select="postalCodeUnknownFlag"/>
            </fc2:Address>

            <fc2:PhoneNumber SeqNum=".">
                <xsl:apply-templates select="contactPhoneExtension"/>
                <xsl:apply-templates select="contactPhoneNumber"/>

            </fc2:PhoneNumber>

            <fc2:PartyIdentification SeqNum=".">
                <xsl:apply-templates select="TaxID"/>
                <xsl:apply-templates select="TaxIDType"/>
                <xsl:apply-templates select="TaxIDUnknownFlag"/>
            </fc2:PartyIdentification>

            <fc2:PartyIdentification SeqNum=".">

                <xsl:if test="$PTY_IDType='A'">
                    <fc2:IdentificationPresentUnknownIndicator>Y</fc2:IdentificationPresentUnknownIndicator>
                </xsl:if>

                <xsl:apply-templates select="IDAuthorityCountryCode"/>
                <xsl:apply-templates select="IDAuthorityStateCode"/>
                <xsl:apply-templates select="IDTypeOther"/>
                <xsl:apply-templates select="IDNumber"/>

                <xsl:if test="$PTY_IDType!='A'">
                    <fc2:PartyIdentificationTypeCode>
                        <xsl:value-of select="$PTY_IDType"/>
                    </fc2:PartyIdentificationTypeCode>
                </xsl:if>


            </fc2:PartyIdentification>

            <fc2:PartyOccupationBusiness SeqNum=".">
                <fc2:NAICSCode>
                    <xsl:value-of select="NAICS"/>
                </fc2:NAICSCode>
                <fc2:OccupationBusinessText>
                    <xsl:value-of select="occupation"/>
                </fc2:OccupationBusinessText>


            </fc2:PartyOccupationBusiness>

            <fc2:ElectronicAddress SeqNum=".">
                <xsl:apply-templates select="emailAddress"/>
            </fc2:ElectronicAddress>

            <xsl:apply-templates select="party_acct_in"/>
            <xsl:apply-templates select="party_acct_out"/>

        </fc2:Party>

    </xsl:template>

    <xsl:template match="foreign_cash_in">

        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>53</fc2:CurrencyTransactionActivityDetailTypeCode>
            <xsl:apply-templates select="foreignCashInAmount"/>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <xsl:apply-templates select="foreignCashInCountryCode"/>
        </fc2:CurrencyTransactionActivityDetail>

    </xsl:template>


    <xsl:template match="foreign_cash_out">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>54</fc2:CurrencyTransactionActivityDetailTypeCode>
            <xsl:apply-templates select="foreignCashOutAmount"/>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <xsl:apply-templates select="foreignCashOutCountryCode"/>
        </fc2:CurrencyTransactionActivityDetail>

    </xsl:template>

    <xsl:template match="party_acct_in">
        <fc2:Account SeqNum=".">
            <xsl:apply-templates select="cashInAcctID"/>
            <fc2:PartyAccountAssociation SeqNum=".">
                <fc2:PartyAccountAssociationTypeCode>8</fc2:PartyAccountAssociationTypeCode>
            </fc2:PartyAccountAssociation>
        </fc2:Account>
    </xsl:template>


    <xsl:template match="party_acct_out">
        <fc2:Account SeqNum=".">
            <xsl:apply-templates select="cashOutAcctID"/>
            <fc2:PartyAccountAssociation SeqNum=".">
                <fc2:PartyAccountAssociationTypeCode>9</fc2:PartyAccountAssociationTypeCode>
            </fc2:PartyAccountAssociation>
        </fc2:Account>
    </xsl:template>


    <!--
    programmatically generated field definition starts here
    -->
    <xsl:template match="/collection/items/transmitter/TRANSMITTER_NAME">
        <fc2:RawPartyFullName>
            <xsl:value-of select="."/>
        </fc2:RawPartyFullName>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/TRANSMITTER_ADDRESS">
        <fc2:RawStreetAddress1Text>
            <xsl:value-of select="."/>
        </fc2:RawStreetAddress1Text>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/TRANSMITTER_CITY_NAME">
        <fc2:RawCityText>
            <xsl:value-of select="."/>
        </fc2:RawCityText>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/TRANSMITTER_STATE_CODE">
        <fc2:RawStateCodeText>
            <xsl:value-of select="."/>
        </fc2:RawStateCodeText>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/TRANSMITTER_ZIP_CODE">
        <fc2:RawZIPCode>
            <xsl:value-of select="."/>
        </fc2:RawZIPCode>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/TRANSMITTER_COUNTRY_CODE">
        <fc2:RawCountryCodeText>
            <xsl:value-of select="."/>
        </fc2:RawCountryCodeText>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/TRANSMITTER_TELEPHONE">
        <fc2:PhoneNumberText>
            <xsl:value-of select="."/>
        </fc2:PhoneNumberText>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/TRANSMITTER_CONTACT_NAME">
        <fc2:RawPartyFullName>
            <xsl:value-of select="."/>
        </fc2:RawPartyFullName>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/TRANSMITTER_TAX_ID">
        <fc2:PartyIdentificationNumberText>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationNumberText>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/TRANSMITTER_CONTROL_CODE">
        <fc2:PartyIdentificationNumberText>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationNumberText>
    </xsl:template>
    <xsl:template match="/collection/items/filer/INSTITUTION_PRIM_FED_REG_CODE">
        <fc2:PrimaryRegulatorTypeCode>
            <xsl:value-of select="."/>
        </fc2:PrimaryRegulatorTypeCode>
    </xsl:template>
    <xsl:template match="/collection/items/filer/INSTITUTION_LEGAL_NAME">
        <fc2:RawPartyFullName>
            <xsl:value-of select="."/>
        </fc2:RawPartyFullName>
    </xsl:template>
    <xsl:template match="/collection/items/filer/INSTITUTION_ALTERNATE_NAME">
        <fc2:RawPartyFullName>
            <xsl:value-of select="."/>
        </fc2:RawPartyFullName>
    </xsl:template>
    <xsl:template match="/collection/items/filer/INSTITUTION_ADDRESS">
        <fc2:RawStreetAddress1Text>
            <xsl:value-of select="."/>
        </fc2:RawStreetAddress1Text>
    </xsl:template>
    <xsl:template match="/collection/items/filer/INSTITUTION_CITY_NAME">
        <fc2:RawCityText>
            <xsl:value-of select="."/>
        </fc2:RawCityText>
    </xsl:template>
    <xsl:template match="/collection/items/filer/INSTITUTION_STATE_CODE">
        <fc2:RawStateCodeText>
            <xsl:value-of select="."/>
        </fc2:RawStateCodeText>
    </xsl:template>
    <xsl:template match="/collection/items/filer/INSTITUTION_ZIP_CODE">
        <fc2:RawZIPCode>
            <xsl:value-of select="."/>
        </fc2:RawZIPCode>
    </xsl:template>
    <xsl:template match="/collection/items/filer/INSTITUTION_COUNTRY_CODE">
        <fc2:RawCountryCodeText>
            <xsl:value-of select="."/>
        </fc2:RawCountryCodeText>
    </xsl:template>
    <xsl:template match="/collection/items/filer/INSTITUTION_TAX_ID">
        <fc2:PartyIdentificationNumberText>
            <xsl:value-of select="."/>			
        </fc2:PartyIdentificationNumberText>
		
    </xsl:template>
    <xsl:template match="/collection/items/filer/INSTITUTION_TYPE_CODE">
        <fc2:OrganizationTypeID>
            <xsl:value-of select="."/>
        </fc2:OrganizationTypeID>
    </xsl:template>
    <xsl:template match="/collection/items/filer/INSTITUTION_TYPE_OTHER">
        <fc2:OtherOrganizationTypeText>
            <xsl:value-of select="."/>
        </fc2:OtherOrganizationTypeText>
    </xsl:template>
    <xsl:template match="/collection/items/filer/INSTITUTION_GAMING_TYPE_CODE">
        <fc2:OrganizationSubtypeID>
            <xsl:value-of select="."/>
        </fc2:OrganizationSubtypeID>
    </xsl:template>
    <xsl:template match="/collection/items/filer/INSTITUTION_GAMING_TYPE_OTHER">
        <fc2:OtherOrganizationSubTypeText>
            <xsl:value-of select="."/>
        </fc2:OtherOrganizationSubTypeText>
    </xsl:template>
    <xsl:template match="/collection/items/filer/INSTITUTION_ID_TYPE_CODE">
        <fc2:PartyIdentificationTypeCode>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationTypeCode>
    </xsl:template>
    <xsl:template match="/collection/items/filer/INSTITUTION_ID">
        <fc2:PartyIdentificationNumberText>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationNumberText>
    </xsl:template>
    <xsl:template match="BRANCH_PRIM_FED_REG_CODE">
        <fc2:PrimaryRegulatorTypeCode>
            <xsl:value-of select="."/>
        </fc2:PrimaryRegulatorTypeCode>
    </xsl:template>
    <xsl:template match="BRANCH_NAME">
        <fc2:RawPartyFullName>
            <xsl:value-of select="."/>
        </fc2:RawPartyFullName>
    </xsl:template>
    <xsl:template match="BRANCH_ALTERNATE_NAME">
        <fc2:RawPartyFullName>
            <xsl:value-of select="."/>
        </fc2:RawPartyFullName>
    </xsl:template>
    <xsl:template match="BRANCH_TAX_ID">
        <fc2:PartyIdentificationNumberText>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationNumberText>
		<fc2:PartyIdentificationTypeCode>2</fc2:PartyIdentificationTypeCode>
    </xsl:template>
	<xsl:template match="BRANCH_TAX_ID_UNKNOWN_FLAG">
        <fc2:TINUnknownIndicator>Y</fc2:TINUnknownIndicator>
    </xsl:template>
    <xsl:template match="BRANCH_ADDRESS">
        <fc2:RawStreetAddress1Text>
            <xsl:value-of select="."/>
        </fc2:RawStreetAddress1Text>
    </xsl:template>
    <xsl:template match="BRANCH_CITY_NAME">
        <fc2:RawCityText>
            <xsl:value-of select="."/>
        </fc2:RawCityText>
    </xsl:template>
    <xsl:template match="BRANCH_STATE_CODE">
        <fc2:RawStateCodeText>
            <xsl:value-of select="."/>
        </fc2:RawStateCodeText>
    </xsl:template>
    <xsl:template match="BRANCH_ZIP_CODE">
        <fc2:RawZIPCode>
            <xsl:value-of select="."/>
        </fc2:RawZIPCode>
    </xsl:template>
    <xsl:template match="BRANCH_COUNTRY_CODE">
        <fc2:RawCountryCodeText>
            <xsl:value-of select="."/>
        </fc2:RawCountryCodeText>
    </xsl:template>
    <xsl:template match="BRANCH_TYPE_CTR_CODE">
        <fc2:OrganizationTypeID>
            <xsl:value-of select="."/>
        </fc2:OrganizationTypeID>
    </xsl:template>
    <xsl:template match="BRANCH_TYPE_CTR_OTHER">
        <fc2:OtherOrganizationTypeText>
            <xsl:value-of select="."/>
        </fc2:OtherOrganizationTypeText>
    </xsl:template>
    <xsl:template match="BRANCH_GAMING_TYPE_CODE">
        <fc2:OrganizationSubtypeID>
            <xsl:value-of select="."/>
        </fc2:OrganizationSubtypeID>
    </xsl:template>
    <xsl:template match="BRANCH_GAMING_TYPE_OTHER">
        <fc2:OtherOrganizationSubTypeText>
            <xsl:value-of select="."/>
        </fc2:OtherOrganizationSubTypeText>
    </xsl:template>
    <xsl:template match="BRANCH_ID_TYPE_CODE">
        <fc2:PartyIdentificationTypeCode>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationTypeCode>
    </xsl:template>
    <xsl:template match="BRANCH_ID">
        <fc2:PartyIdentificationNumberText>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationNumberText>
    </xsl:template>
    <xsl:template match="priorAgencyRefID">
        <fc2:EFilingPriorDocumentNumber>
            <xsl:value-of select="."/>
        </fc2:EFilingPriorDocumentNumber>
    </xsl:template>
    <xsl:template match="transactionDate">
        <fc2:TransactionDateText>
            <xsl:value-of select="."/>
        </fc2:TransactionDateText>
    </xsl:template>
    <xsl:template match="usCashInAmount">
        <fc2:TotalCashInReceiveAmountText>
            <xsl:value-of select="."/>
        </fc2:TotalCashInReceiveAmountText>
    </xsl:template>
    <xsl:template match="usCashInAmountA">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>55</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashInAmountB">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>46</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashInAmountC">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>23</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashInAmountD">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>12</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashInAmountE">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>14</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashInAmountF">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>49</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashInAmountG">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>18</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashInAmountH">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>21</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashInAmountI">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>25</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashInTypeOther">
        <fc2:OtherCurrencyTransactionActivityDetailText>
            <xsl:value-of select="."/>
        </fc2:OtherCurrencyTransactionActivityDetailText>
    </xsl:template>
    <xsl:template match="usCashInAmountOther">
        <fc2:DetailTransactionAmountText>
            <xsl:value-of select="."/>
        </fc2:DetailTransactionAmountText>
    </xsl:template>
    <xsl:template match="usCashOutAmount">
        <fc2:TotalCashOutAmountText>
            <xsl:value-of select="."/>
        </fc2:TotalCashOutAmountText>
    </xsl:template>
    <xsl:template match="usCashOutAmountA">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>56</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashOutAmountB">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>30</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashOutAmountC">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>32</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashOutAmountD">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>13</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashOutAmountE">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>15</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashOutAmountF">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>48</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashOutAmountG">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>28</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashOutAmountH">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>31</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashOutAmountI">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>33</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashOutAmountJ">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>34</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="usCashOutTypeOther">
        <fc2:OtherCurrencyTransactionActivityDetailText>
            <xsl:value-of select="."/>
        </fc2:OtherCurrencyTransactionActivityDetailText>
    </xsl:template>
    <xsl:template match="usCashOutAmountOther">
        <fc2:DetailTransactionAmountText>
            <xsl:value-of select="."/>
        </fc2:DetailTransactionAmountText>
    </xsl:template>
    <xsl:template match="contactOffice">
        <fc2:RawPartyFullName>
            <xsl:value-of select="."/>
        </fc2:RawPartyFullName>
    </xsl:template>
    <xsl:template match="contactPhoneNumber">
        <fc2:PhoneNumberText>
            <xsl:value-of select="."/>
        </fc2:PhoneNumberText>
    </xsl:template>
    <xsl:template match="contactPhoneExtension">
        <fc2:PhoneNumberExtensionText>
            <xsl:value-of select="."/>
        </fc2:PhoneNumberExtensionText>
    </xsl:template>
  
    <xsl:template match="foreignCashInAmount">
        <fc2:DetailTransactionAmountText>
            <xsl:value-of select="."/>
        </fc2:DetailTransactionAmountText>
    </xsl:template>
    <xsl:template match="foreignCashInCountryCode">
        <fc2:OtherForeignCurrencyCountryText>
            <xsl:value-of select="."/>
        </fc2:OtherForeignCurrencyCountryText>
    </xsl:template>
    <xsl:template match="foreignCashOutAmount">
        <fc2:DetailTransactionAmountText>
            <xsl:value-of select="."/>
        </fc2:DetailTransactionAmountText>
    </xsl:template>
    <xsl:template match="foreignCashOutCountryCode">
        <fc2:OtherForeignCurrencyCountryText>
            <xsl:value-of select="."/>
        </fc2:OtherForeignCurrencyCountryText>
    </xsl:template>
    <xsl:template match="personInvolvedTypeCode">
        <fc2:ActivityPartyTypeCode>
            <xsl:value-of select="."/>
        </fc2:ActivityPartyTypeCode>
    </xsl:template>
    <xsl:template match="multiTransactionFlag">
        <fc2:MultipleTransactionsPersonsIndividualsIndicator>Y</fc2:MultipleTransactionsPersonsIndividualsIndicator>
    </xsl:template>
    <xsl:template match="lastName">
        <fc2:RawEntityIndividualLastName>
            <xsl:value-of select="."/>
        </fc2:RawEntityIndividualLastName>
    </xsl:template>
    <xsl:template match="entityFlag">
        <fc2:PartyAsEntityOrganizationIndicator>Y</fc2:PartyAsEntityOrganizationIndicator>
    </xsl:template>
    <xsl:template match="lastNameUnknownFlag">
        <fc2:EntityLastNameUnknownIndicator>Y</fc2:EntityLastNameUnknownIndicator>
    </xsl:template>
    <xsl:template match="firstName">
        <fc2:RawIndividualFirstName>
            <xsl:value-of select="."/>
        </fc2:RawIndividualFirstName>
    </xsl:template>
    <xsl:template match="firstNameUnknownFlag">
        <fc2:FirstNameUnknownIndicator>Y</fc2:FirstNameUnknownIndicator>
    </xsl:template>
    <xsl:template match="middleName">
        <fc2:RawIndividualMiddleName>
            <xsl:value-of select="."/>
        </fc2:RawIndividualMiddleName>
    </xsl:template>
    <xsl:template match="suffixName">
        <fc2:RawIndividualNameSuffixText>
            <xsl:value-of select="."/>
        </fc2:RawIndividualNameSuffixText>
    </xsl:template>
    <xsl:template match="alternateName">
        <fc2:RawEntityIndividualLastName>
            <xsl:value-of select="."/>
        </fc2:RawEntityIndividualLastName>
    </xsl:template>
    <xsl:template match="address">
        <fc2:RawStreetAddress1Text>
            <xsl:value-of select="."/>
        </fc2:RawStreetAddress1Text>
    </xsl:template>
    <xsl:template match="addressUnknownFlag">
        <fc2:StreetAddressUnknownIndicator>Y</fc2:StreetAddressUnknownIndicator>
    </xsl:template>
    <xsl:template match="city">
        <fc2:RawCityText>
            <xsl:value-of select="."/>
        </fc2:RawCityText>
    </xsl:template>
    <xsl:template match="cityUnknownFlag">
        <fc2:CityUnknownIndicator>Y</fc2:CityUnknownIndicator>
    </xsl:template>
    <xsl:template match="stateCode">
        <fc2:RawStateCodeText>
            <xsl:value-of select="."/>
        </fc2:RawStateCodeText>
    </xsl:template>
    <xsl:template match="stateUnknownFlag">
        <fc2:StateCodeUnknownIndicator>Y</fc2:StateCodeUnknownIndicator>
    </xsl:template>
    <xsl:template match="postalCode">
        <fc2:RawZIPCode>
            <xsl:value-of select="."/>
        </fc2:RawZIPCode>
    </xsl:template>
    <xsl:template match="postalCodeUnknownFlag">
        <fc2:ZIPCodeUnknownIndicator>Y</fc2:ZIPCodeUnknownIndicator>
    </xsl:template>
    <xsl:template match="countryCode">
        <fc2:RawCountryCodeText>
            <xsl:value-of select="."/>
        </fc2:RawCountryCodeText>
    </xsl:template>
    <xsl:template match="countryUnknownFlag">
        <fc2:CountryCodeUnknownIndicator>Y</fc2:CountryCodeUnknownIndicator>
    </xsl:template>
    <xsl:template match="TaxID">
        <fc2:PartyIdentificationNumberText>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationNumberText>
    </xsl:template>
    <xsl:template match="TaxIDUnknownFlag">
        <fc2:TINUnknownIndicator>Y</fc2:TINUnknownIndicator>
    </xsl:template>
    <xsl:template match="TaxIDType">
        <fc2:PartyIdentificationTypeCode>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationTypeCode>
    </xsl:template>
    <xsl:template match="birthDate">
        <fc2:IndividualBirthDateText>
            <xsl:value-of select="."/>
        </fc2:IndividualBirthDateText>
    </xsl:template>
    <xsl:template match="birthDateUnknownFlag">
        <fc2:BirthDateUnknownIndicator>Y</fc2:BirthDateUnknownIndicator>
    </xsl:template>
    <xsl:template match="contactPhoneNumber">
        <fc2:PhoneNumberText>
            <xsl:value-of select="."/>
        </fc2:PhoneNumberText>
    </xsl:template>
    <xsl:template match="contactPhoneExtension">
        <fc2:PhoneNumberExtensionText>
            <xsl:value-of select="."/>
        </fc2:PhoneNumberExtensionText>
    </xsl:template>
    <xsl:template match="emailAddress">
        <fc2:ElectronicAddressText>
            <xsl:value-of select="."/>
        </fc2:ElectronicAddressText>
    </xsl:template>
    <xsl:template match="IDTypeOther">
        <fc2:OtherPartyIdentificationTypeText>
            <xsl:value-of select="."/>
        </fc2:OtherPartyIdentificationTypeText>
    </xsl:template>
    <xsl:template match="IDAuthorityStateCode">
        <fc2:OtherIssuerStateText>
            <xsl:value-of select="."/>
        </fc2:OtherIssuerStateText>
    </xsl:template>
    <xsl:template match="IDAuthorityCountryCode">
        <fc2:OtherIssuerCountryText>
            <xsl:value-of select="."/>
        </fc2:OtherIssuerCountryText>
    </xsl:template>
    <xsl:template match="IDNumber">
        <fc2:PartyIdentificationNumberText>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationNumberText>
    </xsl:template>
    <xsl:template match="cashInAmount">
        <fc2:IndividualEntityCashInAmountText>
            <xsl:value-of select="."/>
        </fc2:IndividualEntityCashInAmountText>
    </xsl:template>
    <xsl:template match="cashOutAmount">
        <fc2:IndividualEntityCashOutAmountText>
            <xsl:value-of select="."/>
        </fc2:IndividualEntityCashOutAmountText>
    </xsl:template>
    <xsl:template match="cashInAcctID">
        <fc2:AccountNumberText>
            <xsl:value-of select="."/>
        </fc2:AccountNumberText>
    </xsl:template>
    <xsl:template match="cashOutAcctID">
        <fc2:AccountNumberText>
            <xsl:value-of select="."/>
        </fc2:AccountNumberText>
    </xsl:template>


    <!--
    programmatically generated field definition ends here
    -->

</xsl:stylesheet>