/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_custom_sample_put.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Sample program to demonstrate how to save a custom report. 
|          This macro is called by rc_custom_2 stored process. 
+------------------------------------------------------------------------------+
| USAGE: 
|          form_config_key      = form key  (form key of the shipped sample is 901) 
|          form_type_code       = form type (form type of the shipped sample is SAMPLE) 
|          form_efile_record_id = record id of the form (record ID of the shipped sammple is 3A)
|          report_status_includedYN = Y or N to indicate whether the form supports editing of REPORT_STATUS_CODE. 
|                                 Y for the shipped sample.
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro rc_custom_sample_put(  form_config_key=
                            , form_type_code=
                            , form_efile_record_id= 
                            , report_status_includedYN= 
                           );                          


%inc rc_tmplt(&form_type_code._macro_value_js.sas);


data &form_type_code._&form_efile_record_id;
    if 0 then set rc_db.&form_type_code._&form_efile_record_id(%fcf_get_ds_opts(lib_name=rc_db, ds_name=&form_type_code._&form_efile_record_id));
    %save_value_&form_type_code._&form_efile_record_id;
    report_key=&report_key;
    entity_key=&entity_key;
    entity_level_code="&entity_level_code";
    row_seq_number=&row_seq_number;
    output;
run;

proc sql;
     delete from rc_db.&form_type_code._&form_efile_record_id(%fcf_get_ds_opts(lib_name=rc_db, ds_name=&form_type_code._&form_efile_record_id))
     where report_key=&report_key
           and entity_key=&entity_key
           and entity_level_code="&entity_level_code"
           and row_seq_number=&row_seq_number
;
proc append base=rc_db.&form_type_code._&form_efile_record_id(%fcf_get_ds_opts(lib_name=rc_db, ds_name=&form_type_code._&form_efile_record_id, output_ds=Y))
           data=&form_type_code._&form_efile_record_id force;
run;

%if %upcase(&report_status_includedYN)=Y %then
%do;
   %let orig_report_status_code=;
    proc sql noprint;
         select distinct report_status_code into :orig_report_status_code
         from seg_kc.fsk_rc_report
         where report_key=&report_key
    ;
    quit;
 
        %let request_url=&fcf_service_RegulatoryReports/&report_key?businessUnit=&segKCDBUser;
         filename srv_resp temp;
          
          filename srv_rpt TEMP;

         proc http url="&request_url"                     
                     out=srv_rpt
                     method="GET"
                     ct="application/json" 
                     HTTP_TOKENAUTH                       
               %if %str(&rc_webusername) ne %str() and
                   %str(&rc_webpassword) ne %str() %then
               %do;                             
                     webusername="&rc_webusername" webpassword="&rc_webpassword"  
               %end;    
                     
           ;
           run;
           
 
             filename srv_in TEMP;

           data _null_;
                 infile srv_rpt;
                 file   srv_in;
                 length stmt $ 32767;
                 input;
                 putlog _infile_;
                 stmt= tranwrd(_infile_, '"statusCode":"'||strip(symgetc('ORIG_REPORT_STATUS_CODE'))||'"',
                                         '"statusCode":"'||strip(symgetc('REPORT_STATUS_CODE'))||'"');
                 put stmt;
                 putlog stmt;
           run; 
      
 
           proc http url="&request_url"
                     in=srv_in
                     out=srv_resp
                     method="PUT"
                     ct="application/json" 
                     HTTP_TOKENAUTH                       
               %if %str(&rc_webusername) ne %str() and
                   %str(&rc_webpassword) ne %str() %then
               %do;                             
                     webusername="&rc_webusername" webpassword="&rc_webpassword"  
               %end;    
                     
           ;
           run;      
       

 

%end;


%let stp_url=http://&SYSTCPIPHOSTNAME:7980/SASStoredProcess/do;
%let aml_url=http://&SYSTCPIPHOSTNAME:7980/SASComplianceSolutionsMid;



    
data _null_;    
    file _webout ;
    length tmpstmt $ 512;

    link HTML_INIT;     
    link FORM_INIT;    
    link FORM_TERM;
    link HTML_TERM;

    return;
     
    /*
    HTML_INIT:

    put '<html>';
    put '<body>';
    put "<h1>&form_type_code &form_efile_record_id for report &report_key is saved successfully.</h1>";
    tmpstmt='';
    return; 
 */
     HTML_INIT:

    put '<html>';
    put '<head>';
    put @5 '<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">';
    *tmpstmt='<link rel="stylesheet" type="text/css" href="'||"&aml_url"
         ||'/stylesheets/app.min.css" href2="app.min.css">';
    tmpstmt='<link rel="stylesheet" type="text/css" href="'||"%trim(&aml_url)"
            ||'/stylesheets/app.min.css" href2="app.min.css">';

    put @5 tmpstmt; tmpstmt='';
    put @5 '<style>';
    put @8 '@font-face {';
    put @10 "font-family: 'AvenirNext';";
    tmpstmt="src: url('"||
            "&aml_url"||"/fonts/avenir_next/AvenirNextLT-Regular.woff') format('woff');";
    put @10  tmpstmt $; tmpstmt='';
    put @10 'font-weight: 400;';
    put @10 'font-style: normal;';
    put @8 '}';
    put @8 '@font-face {';
    put "        font-family: 'AvenirNext';";
    tmpstmt="src: url('"||
            "&aml_url"||"/fonts/avenir_next/AvenirNextLT-Light.woff') format('woff');";
    put @10 tmpstmt; tmpstmt='';
    put @10 'font-weight: 300;';
    put @10 'font-style: normal;';
    put @8 '}';
    put @8 '@font-face {';
    put @10 "font-family: 'AvenirNext';";
    tmpstmt="src: url('"||
             "&aml_url"||"/fonts/avenir_next/AvenirNextLT-Demi.woff') format('woff');";
    put @10 tmpstmt; tmpstmt='';            
    put @10 'font-weight: 600;';
    put @10 'font-style: normal;';
    put @8 '}';
    put @5 '</style>';
    put '</head>';
   

    put '<body onload="populate();" style="padding-top: 5px">';
    
    tmpstmt='';
     
     
    return;
 


    FORM_INIT:

    tmpstmt='<form id="'||"&form_type_code"||'"'||' name="'||"&form_type_code"||'"';
    put @3 tmpstmt; tmpstmt='';

    tmpstmt=' action="'||strip("&stp_url")||'"   method="GET">';
    put tmpstmt; tmpstmt='';

    put '<INPUT TYPE="HIDDEN" NAME="_program" VALUE="/System/Applications/SAS Compliance Solutions/Compliance Solutions Svr/Application SAS Code/rc_custom_form">';
    put '<INPUT TYPE="HIDDEN" NAME="_ACTION" VALUE="form,execute">';
    tmpstmt='<INPUT TYPE="HIDDEN" NAME="segment_id" VALUE="'||"&segment_id"||'">';
    put tmpstmt;    
    tmpstmt='<INPUT TYPE="HIDDEN" NAME="reportkey" VALUE="'||"&report_key"||'">';
    put tmpstmt;
    
    tmpstmt='<div class="panel panel-primary" style="max-width: 600px">';
    put @5 tmpstmt; tmpstmt='';
    tmpstmt='<div class="panel-body">';
    put @5 tmpstmt; tmpstmt='';  
    tmpstmt=' <div class="aml-heading text-primary">Report '||"&report_key saved."||'</div>';
    put @5 tmpstmt; tmpstmt='';
          
    return;

    FORM_TERM:
    put '</div>';
    put ' <div class="button">';
    put '      <button type="Back">Back</button>';
    put '</div>';
    put;
    put '</form>';
     
    return;  
 
    HTML_TERM:    
    put @3 '</body>';
    put '</html>';
    return;

run;

%mend;
/* 
options mprint;
proc printto log='/usr/tmp/tmp.log' new;
run;
%put _all_; 
*/

%rc_custom_sample_put(  form_config_key=&form_config_key
                      , form_type_code=&form_type_code
                      , form_efile_record_id=&form_efile_record_id
                      , report_status_includedYN=Y 
                      );
/*
proc printto;
run;
*/
 
