<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fc2="www.fincen.gov/base">
	<xsl:output method="xml" indent="yes"/>
	<xsl:template match="/EfileCollection">
		<fc2:EFilingBatchXML ActivityCount="{count(reportCollections/reportCollection/report)}"
							 PartyCount="{3*count(reportCollections/reportCollection/report/subjects)}"
							 xsi:schemaLocation="www.fincen.gov/base EFL_DOEPXBatchSchema.xsd"
							 xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
							 xmlns:fc2="www.fincen.gov/base">
			<fc2:FormTypeCode>DOEPX</fc2:FormTypeCode>
			<xsl:apply-templates select="reportCollections/reportCollection/report/reportUiJSON"/>
		</fc2:EFilingBatchXML>
	</xsl:template>

	<xsl:template match="reportCollections/reportCollection/report/reportUiJSON">

		<fc2:Activity SeqNum="{../reportKey}">

			<xsl:if test="../priorAgencyRefId">
				<fc2:EFilingPriorDocumentNumber>
					<xsl:value-of select="../priorAgencyRefId"/>
				</fc2:EFilingPriorDocumentNumber>
			</xsl:if>

			<fc2:FilingDateText>
				<xsl:call-template name="convertDate">
					<xsl:with-param name="inputDateTime" select="/EfileCollection/currentDate" />
				</xsl:call-template>
			</fc2:FilingDateText>

			<fc2:ActivityAssociation SeqNum=".">
				<xsl:if test="filingTypeCode='C'">
					<fc2:ExemptionRevokedIndicator>Y</fc2:ExemptionRevokedIndicator>
				</xsl:if>
				<xsl:if test="filingTypeCode='B'">
					<fc2:ExemptionAmendedIndicator>Y</fc2:ExemptionAmendedIndicator>
				</xsl:if>
				<xsl:if test="filingTypeCode='A'">
					<fc2:InitialDesignationIndicator>Y</fc2:InitialDesignationIndicator>
				</xsl:if>
			</fc2:ActivityAssociation>

			<!--
                Transmitter party(35),
                Transmitter contact party(37)
            -->

			<xsl:apply-templates select="/EfileCollection/fincenTransmitter"/>

			<!--

			Designated contact office party(3)
			-->
			<xsl:call-template name="authorizedOfficial"/>


			<!--
			Subject Party  party(11)
			-->

			<xsl:apply-templates select="../subjects/entityUiJSON"/>

			<!--
                Filing Institution party(45)
            -->

			<xsl:apply-templates select="/EfileCollection/fincenFiler"/>


			<!-- Designation Exempt Activity -->
			<fc2:DesignationExemptActivity SeqNum=".">

				<fc2:ExemptBasisTypeCode>
					<xsl:value-of select="../subjects/entityUiJSON/exemptPersonTypeCode"/>
				</fc2:ExemptBasisTypeCode>

				<fc2:ExemptEffectiveBeginDateText>
					<xsl:call-template name="convertDate">
						<xsl:with-param name="inputDateTime" select="effectiveDate"/>
					</xsl:call-template>
				</fc2:ExemptEffectiveBeginDateText>

			</fc2:DesignationExemptActivity>

		</fc2:Activity>
	</xsl:template>





	<!--   Transmitter -->
	<xsl:template match="/EfileCollection/fincenTransmitter">
		<!--   Transmitter party(35)     -->
		<fc2:Party SeqNum=".">

			<fc2:ActivityPartyTypeCode>35</fc2:ActivityPartyTypeCode>
			<fc2:PartyName SeqNum=".">
				<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
				<fc2:RawPartyFullName>
					<xsl:value-of select="transmitterName"/>
				</fc2:RawPartyFullName>
			</fc2:PartyName>

			<fc2:Address SeqNum=".">

				<fc2:RawCityText>
					<xsl:value-of select="transmitterCityName"/>
				</fc2:RawCityText>

				<fc2:RawCountryCodeText>
					<xsl:value-of select="transmitterCountryCode"/>
				</fc2:RawCountryCodeText>


				<fc2:RawStateCodeText>
					<xsl:value-of select="transmitterStateCode"/>
				</fc2:RawStateCodeText>

				<fc2:RawStreetAddress1Text>
					<xsl:value-of select="transmitterAddress"/>
				</fc2:RawStreetAddress1Text>


				<fc2:RawZIPCode>
					<xsl:value-of select="transmitterZipCode"/>
				</fc2:RawZIPCode>

			</fc2:Address>

			<xsl:if test="transmitterTelephone !=''">
				<fc2:PhoneNumber SeqNum=".">
					<fc2:PhoneNumberText>
						<xsl:value-of select="transmitterTelephone"/>
					</fc2:PhoneNumberText>
				</fc2:PhoneNumber>
			</xsl:if>

			<fc2:PartyIdentification SeqNum=".">
				<fc2:PartyIdentificationNumberText>
					<xsl:value-of select="transmitterTaxId"/>
				</fc2:PartyIdentificationNumberText>
				<fc2:PartyIdentificationTypeCode>2</fc2:PartyIdentificationTypeCode>
			</fc2:PartyIdentification>

			<fc2:PartyIdentification SeqNum=".">
				<fc2:PartyIdentificationNumberText>
					<xsl:value-of select="transmitterControlCode"/>
				</fc2:PartyIdentificationNumberText>

				<fc2:PartyIdentificationTypeCode>28</fc2:PartyIdentificationTypeCode>
			</fc2:PartyIdentification>
		</fc2:Party>

		<!--   Transmitter contact party(37) -->
		<fc2:Party SeqNum=".">
			<fc2:ActivityPartyTypeCode>37</fc2:ActivityPartyTypeCode>

			<fc2:PartyName SeqNum=".">
				<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
				<fc2:RawPartyFullName>
					<xsl:value-of select="transmitterContactName"/>
				</fc2:RawPartyFullName>

			</fc2:PartyName>
		</fc2:Party>
	</xsl:template>


	<xsl:template match="fincenFiler">

		<fc2:Party SeqNum=".">
			<fc2:ActivityPartyTypeCode>45</fc2:ActivityPartyTypeCode>

			<fc2:PrimaryRegulatorTypeCode>
				<xsl:call-template name="map">
					<xsl:with-param name="source" select="'institutionPrimFedRegCode'"/>
					<xsl:with-param name="code" select="/EfileCollection/fincenFiler/institutionPrimFedRegCode/."/>
				</xsl:call-template>
			</fc2:PrimaryRegulatorTypeCode>

			<fc2:PartyName SeqNum=".">
				<fc2:RawPartyFullName>
					<xsl:value-of select="/EfileCollection/fincenFiler/institutionLegalName"/>
				</fc2:RawPartyFullName>
			</fc2:PartyName>


			<fc2:Address SeqNum=".">

				<fc2:RawCityText>
					<xsl:value-of select="/EfileCollection/fincenFiler/institutionCityName"/>
				</fc2:RawCityText>
				<fc2:RawStateCodeText>
					<xsl:value-of select="/EfileCollection/fincenFiler/institutionStateCode"/>
				</fc2:RawStateCodeText>
				<fc2:RawStreetAddress1Text>
					<xsl:value-of select="/EfileCollection/fincenFiler/institutionAddress"/>
				</fc2:RawStreetAddress1Text>
				<fc2:RawZIPCode>
					<xsl:value-of select="/EfileCollection/fincenFiler/institutionZipCode"/>
				</fc2:RawZIPCode>
			</fc2:Address>

			<!-- EIN ID should be here -->
			<fc2:PartyIdentification SeqNum=".">
				<fc2:PartyIdentificationNumberText>
					<xsl:value-of select="/EfileCollection/fincenFiler/institutionTaxId"/>
				</fc2:PartyIdentificationNumberText>
				<fc2:PartyIdentificationTypeCode>2</fc2:PartyIdentificationTypeCode>
			</fc2:PartyIdentification>

			<!-- RSSD ID should be here -->
			<xsl:if test="/EfileCollection/fincenFiler/institutionRssdId != ''">
				<fc2:PartyIdentification SeqNum=".">
					<fc2:PartyIdentificationNumberText>
						<xsl:value-of select="/EfileCollection/fincenFiler/institutionRssdId"/>
					</fc2:PartyIdentificationNumberText>
					<fc2:PartyIdentificationTypeCode>14</fc2:PartyIdentificationTypeCode>
				</fc2:PartyIdentification>
			</xsl:if>

		</fc2:Party>

	</xsl:template>


	<!-- Authorized Official -->
	<xsl:template name="authorizedOfficial">
		<fc2:Party SeqNum=".">
			<fc2:ActivityPartyTypeCode>3</fc2:ActivityPartyTypeCode>
			<xsl:if test="contactTitle !='' or contactName !=''">
				<fc2:PartyName SeqNum=".">
					<xsl:if test="contactTitle !=''">
						<fc2:RawIndividualTitleText>
							<xsl:value-of select="contactTitle"/>
						</fc2:RawIndividualTitleText>
					</xsl:if>
					<xsl:if test="contactName !=''">
						<fc2:RawPartyFullName>
							<xsl:value-of select="contactName"/>
						</fc2:RawPartyFullName>
					</xsl:if>
				</fc2:PartyName>
			</xsl:if>
			<xsl:if test="contactPhoneExtension !='' or contactPhoneNumber !=''">
				<fc2:PhoneNumber SeqNum=".">
					<xsl:if test="contactPhoneExtension !=''">
						<fc2:PhoneNumberExtensionText>
							<xsl:apply-templates select="contactPhoneExtension"/>
						</fc2:PhoneNumberExtensionText>
					</xsl:if>
					<xsl:if test="contactPhoneNumber !=''">
						<fc2:PhoneNumberText>
							<xsl:value-of select="contactPhoneNumber"/>
						</fc2:PhoneNumberText>
					</xsl:if>
				</fc2:PhoneNumber>
			</xsl:if>
		</fc2:Party>
	</xsl:template>

	<xsl:template match="subjects/entityUiJSON">
		<fc2:Party SeqNum=".">

			<fc2:ActivityPartyTypeCode>11</fc2:ActivityPartyTypeCode>
			<xsl:if test="entityFlag='true'">
				<fc2:PartyAsEntityOrganizationIndicator>Y</fc2:PartyAsEntityOrganizationIndicator>
			</xsl:if>

			<fc2:PartyName SeqNum=".">
				<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>

				<fc2:RawEntityIndividualLastName>
					<xsl:value-of select="lastName"/>
				</fc2:RawEntityIndividualLastName>

				<xsl:if test="not(entityFlag='true')">
					<xsl:if test="firstName !=''">
						<fc2:RawIndividualFirstName>
							<xsl:value-of select="firstName"/>
						</fc2:RawIndividualFirstName>
					</xsl:if>
					<xsl:if test="middleName !=''">
						<fc2:RawIndividualMiddleName>
							<xsl:value-of select="middleName"/>
						</fc2:RawIndividualMiddleName>
					</xsl:if>
					<xsl:if test="suffix !=''">
						<fc2:RawIndividualNameSuffixText>
							<xsl:value-of select="suffix"/>
						</fc2:RawIndividualNameSuffixText>
					</xsl:if>
				</xsl:if>
			</fc2:PartyName>

			<xsl:if test="alternateName !=''">
				<fc2:PartyName SeqNum=".">
					<fc2:PartyNameTypeCode>DBA</fc2:PartyNameTypeCode>
					<fc2:RawPartyFullName>
						<xsl:value-of select="alternateName"/>
					</fc2:RawPartyFullName>
				</fc2:PartyName>
			</xsl:if>

			<fc2:Address SeqNum=".">
				<fc2:RawCityText>
					<xsl:value-of select="city"/>
				</fc2:RawCityText>
				<fc2:RawStateCodeText>
					<xsl:value-of select="stateCode"/>
				</fc2:RawStateCodeText>
				<fc2:RawStreetAddress1Text>
					<xsl:value-of select="address"/>
				</fc2:RawStreetAddress1Text>
				<fc2:RawZIPCode>
					<xsl:value-of select="postalCode"/>
				</fc2:RawZIPCode>
			</fc2:Address>

			<fc2:PhoneNumber SeqNum=".">
				<xsl:if test="phoneExtension !=''">
					<fc2:PhoneNumberExtensionText>
						<xsl:apply-templates select="phoneExtension"/>
					</fc2:PhoneNumberExtensionText>
				</xsl:if>
				<xsl:if test="phoneNumber !=''">
					<fc2:PhoneNumberText>
						<xsl:value-of select="phoneNumber"/>
					</fc2:PhoneNumberText>
				</xsl:if>
			</fc2:PhoneNumber>

			<fc2:PartyIdentification SeqNum=".">

				<xsl:if test="TaxID !=''">
					<fc2:PartyIdentificationNumberText>
						<xsl:value-of select="TaxID"/>
					</fc2:PartyIdentificationNumberText>
				</xsl:if>

				<xsl:if test="TaxIDType !=''">
					<fc2:PartyIdentificationTypeCode>
						<xsl:call-template name="map">
							<xsl:with-param name="source" select="'TaxIDType'"/>
							<xsl:with-param name="code" select="TaxIDType/."/>
						</xsl:call-template>
					</fc2:PartyIdentificationTypeCode>
				</xsl:if>

			</fc2:PartyIdentification>

			<xsl:if test="NAICS != '' or occupation != ''">
				<fc2:PartyOccupationBusiness SeqNum=".">
					<xsl:if test="NAICS != ''">
						<fc2:NAICSCode>
							<xsl:value-of select="NAICS"/>
						</fc2:NAICSCode>
					</xsl:if>
					<xsl:if test="occupation != ''">
						<fc2:OccupationBusinessText>
							<xsl:value-of select="occupation"/>
						</fc2:OccupationBusinessText>
					</xsl:if>
				</fc2:PartyOccupationBusiness>
			</xsl:if>

			<xsl:if test="emailAddress !=''">
				<fc2:ElectronicAddress SeqNum=".">
					<fc2:ElectronicAddressText>
						<xsl:value-of select="emailAddress"/>
					</fc2:ElectronicAddressText>
				</fc2:ElectronicAddress>
			</xsl:if>

		</fc2:Party>

	</xsl:template>

	<xsl:template name="convertDate">
		<xsl:param name="inputDateTime" />
		<xsl:variable name="year">
			<xsl:value-of select="substring($inputDateTime,1,4)" />
		</xsl:variable>
		<xsl:variable name="month">
			<xsl:value-of select="substring($inputDateTime,6,2)" />
		</xsl:variable>
		<xsl:variable name="day">
			<xsl:value-of select="substring($inputDateTime,9,2)" />
		</xsl:variable>
		<xsl:value-of select="concat($year,$month,$day)" />
	</xsl:template>

	<xsl:template name="map">
		<xsl:param name="source"/>
		<xsl:param name="code"/>

		<xsl:if test="($source='institutionPrimFedRegCode') and ($code='B')">1</xsl:if>
		<xsl:if test="($source='institutionPrimFedRegCode') and ($code='C')">2</xsl:if>
		<xsl:if test="($source='institutionPrimFedRegCode') and ($code='D')">7</xsl:if>
		<xsl:if test="($source='institutionPrimFedRegCode') and ($code='E')">3</xsl:if>
		<xsl:if test="($source='institutionPrimFedRegCode') and ($code='F')">4</xsl:if>


		<xsl:if test="($source='TaxIDType') and ($code='A')">2</xsl:if>
		<xsl:if test="($source='TaxIDType') and ($code='B')">1</xsl:if>


	</xsl:template>
</xsl:stylesheet>


