/*******************************************************************************/
/* Load FINCEN ctr configuration data                                          */
/* To test one the code without loading the data,set rc_debug to Y             */
/*******************************************************************************/


%macro rc_fincen_load_form_config_ctr; 

data rc_form_config_ctr;
    if 0 then set seg_kc.fsk_rc_form_config;
    form_config_key=&form_config_key;
    form_agency_code='FINCEN';
    form_type_code="&form_type_code";
    form_country_code='US';
    effective_from_date='01JUL2012:00:00:00'dt;    
    form_desc='FinCEN Currency Transaction Report (CTR)';
    efile_file_prefix='fincen-ctr-v1';
    efile_driver_pgm_name='rc_efile_fincen_new_driver';
    efile_max_report_count=60;
    create_user_id="&sysuserid";
    create_date=datetime();
    sensitive_ind='Y';
    logical_delete_ind='N';
    output;
run;
%if &rc_debug = N %then
%do;
    proc sql;
         delete from seg_kc.fsk_rc_form_default
         where form_config_key=&form_config_key;

         delete from seg_kc.fsk_rc_form_code_mapping
         where form_config_key=&form_config_key;

         delete from seg_kc.fsk_rc_form_config
         where form_config_key=&form_config_key;
    quit;

    proc append base=seg_kc.fsk_rc_form_config (dbforce=yes) data=rc_form_config_ctr force;
    run;
%end;

%mend;

%macro rc_fincen_load_efile_ctr;
/**********************************************************/
/* Load record level efile configuration data             */
/**********************************************************/

/* Record level configuration data */

data efile_record_config_ctr;
if 0 then set rc_cfg.form_efile_record_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config));

     infile  rc_tmplt(rc_fincen_ctr_efile_record_config.csv)  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
             retain form_config_key &form_config_key;
             retain form_efile_record_seq_number;
     input form_efile_record_id $
           form_efile_record_desc $
           record_sort_order
           record_length 
           source_table_name $
           source_entity_level_code  $
           source_group_name $
           
    ;
    drop record_sort_order  ;
    form_config_key=&form_config_key;
    if form_efile_record_id > '' then 
    do;     
        form_efile_record_seq_number+1;
        output;
    end;

run;
 
/* Field level configuration data */


data efile_field_config_ctr;
if 0 then set rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config));

     
           
     infile  rc_tmplt(rc_fincen_ctr_efile_field_config.csv)  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
     
     input 
           form_efile_record_id $
           target_field_start_position 
           target_field_end_position 
           target_field_short_desc $
           target_field_length
           target_field_desc $
           target_field_name   $           
           source_field_name   $
           source_field_type   $
           source_field_type_parm_list $
           source_field_default_value $
           source_field_mapped_flg $
           target_field_num_flg $           
           target_sas_format_name $
           
          
    ;
   
    form_config_key=&form_config_key;
    form_efile_field_seq_number=_n_; 


    
    drop form_efile_record_seq_number ; /* to be assigned in the next step */
     
run;
proc sql noprint;
     create table form_efile_field_config_ctr as
     select a.*, b.form_efile_record_seq_number
     from efile_field_config_ctr as a,
          efile_record_config_ctr as b
     where a.form_efile_record_id=b.form_efile_record_id
     order by form_efile_record_seq_number,  form_efile_field_seq_number;
quit;

%if &sysrc <= 4 and &rc_debug=N %then
%do;
   proc sql;
     delete 
     from rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config))
     where form_config_key=&form_config_key;

     delete 
     from rc_cfg.form_efile_record_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config))
     where form_config_key=&form_config_key;
   quit;

    proc append base=rc_cfg.form_efile_record_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config, output_ds=Y))
                data=efile_record_config_ctr force; 
    run;

    proc append base=rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config, output_ds=Y))
                data=form_efile_field_config_ctr
                force; 
    run;
%end;

%mend;

%macro rc_fincen_load_ref_ctr;

/******************************************************************************/
/*  Load reference table values                                               */
/******************************************************************************/

data lov_ctr;
          
     infile  rc_tmplt(rc_fincen_ctr_efile_ref.csv)
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
   
   length tmp_word source_ref_list$ 32767;
   if 0 then set rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config));
   if 0 then set seg_kc.fsk_lov;
   input 
           form_efile_record_id $
           target_field_name $
           target_field_length
           target_field_desc $
           source_field_name $
           source_ref_list $                
    ;
    
    retain lov_language_desc 'en';
    retain active_flg 'Y';
     
    keep lov_type_name lov_type_code lov_type_desc  
         lov_sort_position_number active_flg lov_language_desc;
   
    
    tmp_word='';
    tmp_i=1;
    do until (scan(source_ref_list,tmp_i,'|')='');
       tmp_word=left(scan(source_ref_list,tmp_i,'|'));
       lov_type_name="&form_type_code"||'.'||strip(form_efile_record_id)||'.'
                    ||strip(source_field_name);
       lov_type_code=substr(tmp_word,1,1);
       lov_type_desc=left(substr(tmp_word,2));
       lov_sort_position_number=tmp_i;
       output;
       tmp_i+1;
    end;
 
run;

%if &syserr <= 4 and &rc_debug=N %then
%do;
     
     proc sql noprint;
         delete from seg_kc.fsk_lov as ref
         where exists 
          (select lov_type_name
          from lov_ctr as ctr
          where ctr.lov_type_name=ref.lov_type_name 
           );

     
    proc append base=seg_kc.fsk_lov data=lov_ctr force;
    run;
%end;
%mend;


%macro rc_fincen_load_mapping_ctr;

/******************************************************************************/
/*  Load code mapping table                                               */
/******************************************************************************/

data code_mapping_ctr;
          
     infile  rc_tmplt(rc_fincen_ctr_code_mapping.csv)
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;  
   
  
   if 0 then set seg_kc.fsk_rc_form_code_mapping;
   form_config_key=&form_config_key;
   input 
            format_name $
            input_code  $
            output_code $ 
    ;
    if format_name ne '' /* and input_code ne '' */ then output;
 
run;

%if &syserr <= 4 and &rc_debug=N %then
%do;
     
     proc sql noprint;
         delete from seg_kc.fsk_rc_form_code_mapping 
     where form_config_key=&form_config_key;

     
     proc append base=seg_kc.fsk_rc_form_code_mapping (dbforce=yes) 
                data=code_mapping_ctr force;
    run;

%end;
%mend;

%macro rc_fincen_load_error_code_ctr;

/****************************************************************/
/* Load FINCEN ctr error codes                                  */
/****************************************************************/


data rc_cfg.ctr_fincen_error_code(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=ctr_fincen_error_code, output_ds=Y));

     attrib ERROR_CODE  length=$4 label='Error Code'
            ERROR_DESC length=$4000 label='Error Description'
            ERROR_RECORD_TYPE length=$2 label='Record Type'
            ERROR_TYPE_CODE length=$1 label='Error Type'
     ;
        
       
      
      infile  rc_tmplt(rc_fincen_ctr_error_code.csv)  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
             
     input error_code $
           error_desc $
           error_record_type $
           error_type_code $
                     
    ;
run;

%mend;



%macro rc_add_lov_ctr;


 data add_lov_ctr;
      if 0 then set seg_kc.fsk_lov;
      retain lov_language_desc 'en';
      retain active_flg 'Y';       
      lov_type_name="RC_FORM_NAME_SHORT";              
      lov_type_code="&form_config_key";
      lov_type_desc="&form_type_code";
      lov_sort_position_number=&form_config_key;
      output;
      lov_type_name="RC_FORM_NAME_LONG";              
      lov_type_code="&form_config_key";
      lov_type_desc='FinCEN Currency Transaction Report (CTR)';
      lov_sort_position_number=&form_config_key;
      output;
          
 run;

 %if &syserr <= 4 and &rc_debug=N %then
 %do;
     
     proc sql noprint;
         delete from seg_kc.fsk_lov as ref
         where exists 
          (select lov_type_name
          from add_lov_ctr as ctr
          where ctr.lov_type_name=ref.lov_type_name and ctr.lov_type_code=ref.lov_type_code
           );

     
    proc append base=seg_kc.fsk_lov data=add_lov_ctr force;
    run;
%end;    

%mend;

 

/* Change rc_debug to Y for testing */
%let rc_debug=N;
/* Adjust the sequence number if it has been used */
%let form_config_key=302;
%let form_type_code=CTR;
 
%rc_fincen_load_form_config_ctr;   /* load form configuration data         */

%rc_fincen_load_efile_ctr;         /* load efile definition                */ 

%rc_fincen_load_ref_ctr;

%rc_fincen_load_error_code_ctr; 

%rc_fincen_load_mapping_ctr;

%rc_efile_gen_sasddl(form_config_key=&form_config_key,
                     form_type_code=&form_type_code, 
                     ddlfref=rc_tmplt,
                     outlib=rc_db);

%inc rc_tmplt(&form_type_code._ddl.sas);


%rc_efile_gen_macro_wrt_efile(form_config_key=&form_config_key,
                  form_type_code=&form_type_code,
                  input_or_put="put");
              


%rc_efile_gen_macro_xpose_node( form_config_key=&form_config_key,
                       form_type_code=&form_type_code);

%rc_efile_gen_json_schema(form_config_key=&form_config_key
                          , form_type_code=&form_type_code
                           );

%rc_efile_gen_json_default(form_config_key=&form_config_key
                          , form_type_code=&form_type_code);

%rc_add_lov_ctr;





