/*******************************************************************************/
/* Load FINCEN doepx configuration data                                        */
/* To test one the code without loading the data,set rc_debug to Y             */
/*******************************************************************************/


%macro rc_fincen_load_form_config_doepx; 

data rc_form_config_doepx;
    if 0 then set seg_kc.fsk_rc_form_config;
    form_config_key=&form_config_key;
    form_agency_code='FINCEN';
    form_type_code="&form_type_code";
    form_country_code='US';
    effective_from_date='01JAN2020:00:00:00'dt;    
    form_desc='FinCEN Designation of Exempt Person (DOEPX)';
    efile_file_prefix='fincen-doepx-v1';
    efile_driver_pgm_name='rc_efile_fincen_new_driver';
    efile_max_report_count=60;
    create_user_id="&sysuserid";
    create_date=datetime();
    sensitive_ind='Y';
    implementation_type_code='303';
    logical_delete_ind='N';
    output;
run;

%if &syserr <= 4 and &rc_debug = N %then
%do;
   /* Check if there is any existing reports with the same form config key */
   %let doepxReportExistYN=N;
    proc sql noprint;      
         select 'Y' into :doepxReportExistYN
         from seg_kc.fsk_rc_report
         where form_config_key=&form_config_key
         ;
    quit;
    /* if no report exists, delete the current configuration and add a new one */
    %if &doepxReportExistYN=N %then
    %do; 

        proc sql;        
             delete from seg_kc.fsk_rc_form_config
             where form_config_key=&form_config_key;
        quit; 

        proc append base=seg_kc.fsk_rc_form_config (dbforce=yes) data=rc_form_config_doepx force;
        run;
    
    %end;
    %else
    %do; 
        /* if report exists and the current form_type_code is 'DOEP' */
        /*    upgrade it to DOEPX                                    */
         proc sql noprint;
              update seg_kc.fsk_rc_form_config
              set form_type_code="DOEPX",
                  effective_from_date='01JAN2020:00:00:00'dt,
                  effective_to_date=. ,   
                  form_desc='FinCEN Designation of Exempt Person (DOEPX)',
                  efile_file_prefix='fincen-doepx-v1',                   
                  logical_delete_ind='N'
              where form_config_key=&form_config_key and form_type_code='DOEP'
            ; 
         quit;

    %end;

    proc sql noprint;
         delete from seg_kc.fsk_rc_form_default
         where form_config_key=&form_config_key;
         delete from seg_kc.fsk_rc_form_code_mapping
         where form_config_key=&form_config_key;
    quit;
%end;

%mend;

%macro rc_fincen_load_efile_doepx;
/**********************************************************/
/* Load record level efile configuration data             */
/**********************************************************/

/* Record level configuration data */

data efile_record_config_doepx;
if 0 then set rc_cfg.form_efile_record_config (%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config));

     infile  rc_tmplt(rc_fincen_doepx_efile_record_config.csv)  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
             retain form_config_key &form_config_key;
             retain form_efile_record_seq_number;
     input form_efile_record_id $
           form_efile_record_desc $
           record_sort_order
           record_length 
           source_table_name $
           source_entity_level_code  $
           source_group_name $
           
    ;
    drop record_sort_order  ;
    form_config_key=&form_config_key;
    if form_efile_record_id > '' then 
    do;     
        form_efile_record_seq_number+1;
        output;
    end;

run;
 
/* Field level configuration data */


data efile_field_config_doepx;
if 0 then set rc_cfg.form_efile_field_config (%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config));

     
           
     infile  rc_tmplt(rc_fincen_doepx_efile_field_config.csv)  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
     
     input 
           form_efile_record_id $
           target_field_start_position 
           target_field_end_position 
           target_field_short_desc $
           target_field_length
           target_field_desc $
           target_field_name   $           
           source_field_name   $
           source_field_type   $
           source_field_type_parm_list $
           source_field_default_value $
           source_field_mapped_flg $
           target_field_num_flg $           
           target_sas_format_name $
           
          
    ;
   
    form_config_key=&form_config_key;
    form_efile_field_seq_number=_n_; 


    
    drop form_efile_record_seq_number ; /* to be assigned in the next step */
     
run;
proc sql noprint;
     create table form_efile_field_config_doepx as
     select a.*, b.form_efile_record_seq_number
     from efile_field_config_doepx as a,
          efile_record_config_doepx as b
     where a.form_efile_record_id=b.form_efile_record_id
     order by form_efile_record_seq_number,  form_efile_field_seq_number;
quit;

%if &sysrc <= 4 and &rc_debug=N %then
%do;
   proc sql;
     delete 
     from rc_cfg.form_efile_field_config (%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config))
     where form_config_key=&form_config_key;

     delete 
     from rc_cfg.form_efile_record_config (%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config))
     where form_config_key=&form_config_key;
   quit;

    proc append base=rc_cfg.form_efile_record_config  (%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config, output_ds=Y))
                data=efile_record_config_doepx force; 
    run;

    proc append base=rc_cfg.form_efile_field_config (%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config, output_ds=Y))
                data=form_efile_field_config_doepx
                force; 
    run;
%end;

%mend;

%macro rc_fincen_load_ref_doepx;

/******************************************************************************/
/*  Load reference table values                                               */
/******************************************************************************/


data lov_doepx;
          
    infile  rc_tmplt(rc_fincen_doepx_ref.csv)
            dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
   
    length tmp_word source_ref_list$ 32767;
    if 0 then set seg_kc.fsk_lov;
    input
           lov_type_name $            
           source_ref_list $                
     ;
    
    retain lov_language_desc 'en';
    retain active_flg 'Y';
     
    keep lov_type_name lov_type_code lov_type_desc
         lov_sort_position_number active_flg lov_language_desc;
   
    
    tmp_word='';
    tmp_i=1;
    do until (scan(source_ref_list,tmp_i,'|')='');
       tmp_word=left(scan(source_ref_list,tmp_i,'|')); 
       /* use the first space to separate the code from the description */     
       lov_type_code=substrn(tmp_word,1,indexc(tmp_word,' ')-1);
       lov_type_desc=substrn(tmp_word,indexc(tmp_word,' '));
       lov_sort_position_number=tmp_i;
       output;
       tmp_i+1;
    end;
 
run;
 

%if &syserr <= 4 and &rc_debug=N %then
%do;
     
     proc sql noprint;
         delete from seg_kc.fsk_lov as ref
         where exists 
          (select lov_type_name
          from lov_doepx as doepx
          where doepx.lov_type_name=ref.lov_type_name 
           );

     
    proc append base=seg_kc.fsk_lov data=lov_doepx force;
    run;
%end;
%mend;


%macro rc_fincen_load_mapping_doepx;

/******************************************************************************/
/*  Load code mapping table                                               */
/******************************************************************************/

data code_mapping_doepx;
          
     infile  rc_tmplt(rc_fincen_doepx_code_mapping.csv)
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;  
   
  
   if 0 then set seg_kc.fsk_rc_form_code_mapping;
   form_config_key=&form_config_key;
   input 
            format_name $
            input_code  $
            output_code $ 
    ;
    if format_name ne '' /* and input_code ne '' */ then output;
 
run;

%if &syserr <= 4 and &rc_debug=N %then
%do;
     
     proc sql noprint;
         delete from seg_kc.fsk_rc_form_code_mapping 
     where form_config_key=&form_config_key;

     
     proc append base=seg_kc.fsk_rc_form_code_mapping (dbforce=yes) 
                data=code_mapping_doepx force;
    run;

%end;
%mend;

%macro rc_fincen_load_error_code_doepx;

/****************************************************************/
/* Load FINCEN doepx error codes                                  */
/****************************************************************/

data rc_cfg.doepx_fincen_error_code(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=doepx_fincen_error_code, output_ds=Y));


      attrib ERROR_RECORD_TYPE length=$32 label='Error record type'
             ERROR_CODE  length=$10 label='Error Type Code'
             ERROR_DESC length=$4000 label='Error Text'              
             ERROR_TYPE_CODE length=$1 label='Error Severity Code' 
             ERROR_TYPE_TEXT length=$32 label='Error Severity Description'
             ASSOC_ELEMENT length=$256 label='Associated Element(s)'
             FIELD_REFERENCE length=$4000 label='Field Reference'
      ;
   
     infile rc_tmplt(rc_fincen_doepx_error_code.csv)  
             dsd lrecl=32764 truncover firstobs=2  delimiter=',' ;            
     input error_record_type $
           error_code $          
           error_desc $             
           error_type_text $
           assoc_element $
           field_reference $
    ;
   
    error_desc=compress(error_desc,,'kw');
    assoc_element=compress(assoc_element,,'kw');
    field_reference=compress(field_reference,,'kw');

    select (error_type_text);
        when ('Fatal') error_type_code='F';    
        when ('Warning (Primary)') error_type_code='P';
        when ('Warning') error_type_code='S';
        otherwise;
    end;

  run;


%mend;


%macro rc_add_lov_doepx;


 data add_lov_doepx;
      if 0 then set seg_kc.fsk_lov;
      retain lov_language_desc 'en';
      retain active_flg 'Y';       
      lov_type_name="RC_FORM_NAME_SHORT";              
      lov_type_code="&form_config_key";
      lov_type_desc="&form_type_code";
      lov_sort_position_number=&form_config_key;
      output;
      lov_type_name="RC_FORM_NAME_LONG";              
      lov_type_code="&form_config_key";
      lov_type_desc='FinCEN Designation of Exempt Person (DOEPX)';
      lov_sort_position_number=&form_config_key;
      output;
          
 run;

 %if &syserr <= 4 and &rc_debug=N %then
 %do;
     
     proc sql noprint;
         delete from seg_kc.fsk_lov as ref
         where exists 
          (select lov_type_name
          from add_lov_doepx as doepx
          where doepx.lov_type_name=ref.lov_type_name and doepx.lov_type_code=ref.lov_type_code
           );

     
    proc append base=seg_kc.fsk_lov data=add_lov_doepx force;
    run;
%end;    

%mend;

 
 

/* Change rc_debug to Y for testing */
%let rc_debug=N;
/* Adjust the sequence number if it has been used */
%let form_config_key=303;
%let form_type_code=DOEPX;
 
%rc_fincen_load_form_config_doepx;   /* load form configuration data         */

%rc_fincen_load_efile_doepx;         /* load efile definition                */ 

%rc_fincen_load_ref_doepx;

%rc_fincen_load_error_code_doepx; 

%rc_fincen_load_mapping_doepx;


%rc_efile_gen_json_schema(form_config_key=&form_config_key
                          , form_type_code=&form_type_code
                           );

%rc_efile_gen_json_default(form_config_key=&form_config_key
                          , form_type_code=&form_type_code);

%rc_add_lov_doepx;






