 

%macro rc_updt_fincen_institution;

%if %sysfunc(exist(rc_cfg.fincen_institution)) %then
%do;
   %let form_key_exist=N;

    proc contents data=RC_CFG.FINCEN_INSTITUTION(%fcf_get_ds_opts(lib_name=RC_CFG, ds_name=FINCEN_INSTITUTION))
                   out=rc_cfg_tab_cols(keep=name)
                  noprint;
     run;

    data _null_;
     set rc_cfg_tab_cols;
      if upcase(name) eq 'FORM_CONFIG_KEY' then
      do;
         call symputx('form_key_exist','Y');
         stop;
      end;
     run;
 
    %if &form_key_exist=N %then
    %do;
       proc sql noprint;      
       alter table rc_cfg.fincen_institution(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=fincen_institution))
       add FORM_CONFIG_KEY integer label='Form Config Key', 
           CONTACT_NAME char(150) label='Contact Name', 
           CONTACT_TITLE char(35) label='Contact Title' 
       ;


       update rc_cfg.fincen_institution(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=fincen_institution))
       set   form_config_key=301
       ;
       quit;
    %end;

%end;
%mend;

%macro rc_updt_fincen_branch;


%if %sysfunc(exist(rc_cfg.fincen_branch)) %then
%do;
   %let branch_alt_name_exist=N;

    proc contents data=RC_CFG.FINCEN_BRANCH(%fcf_get_ds_opts(lib_name=RC_CFG, ds_name=FINCEN_BRANCH))
                   out=rc_cfg_tab_cols(keep=name)
                  noprint;
     run;

    data _null_;
     set rc_cfg_tab_cols;
      if upcase(name) eq 'BRANCH_ALTERNATE_NAME' then
      do;
         call symputx('branch_alt_name_exist','Y');
         stop;
      end;
     run;
 
    %if &branch_alt_name_exist=N %then
    %do;
       proc sql noprint;      
       alter table rc_cfg.fincen_branch(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=fincen_branch))
       add BRANCH_ALTERNATE_NAME CHAR(150)  label='Branch Alternate Name';
       quit;
    %end;

%end;

%mend;


%macro rc_add_lov_sar;


 data add_lov_sar;
      if 0 then set seg_kc.fsk_lov;
      retain lov_language_desc 'en';
      retain active_flg 'Y';       
      lov_type_name="RC_FORM_NAME_SHORT";              
      lov_type_code='301';
      lov_type_desc='SAR';
      lov_sort_position_number=301;
      output;
      lov_type_name="RC_FORM_NAME_LONG";              
      lov_type_code='301';
      lov_type_desc='FinCEN Suspicious Activity Report (SAR)';
      lov_sort_position_number=301;
      output;
          
 run;

 %if &syserr <= 4 and &rc_debug=N %then
 %do;
     
     proc sql noprint;
         delete from seg_kc.fsk_lov as ref
         where exists 
          (select lov_type_name
          from add_lov_sar as sar
          where sar.lov_type_name=ref.lov_type_name and sar.lov_type_code=ref.lov_type_code
           );

     
    proc append base=seg_kc.fsk_lov data=add_lov_sar force;
    run;
%end;    

%mend;


%macro rc_updt_sar;

 proc sql;
      update seg_kc.fsk_rc_form_config
      set form_desc='FinCEN Suspicious Activity Report (SAR)'
      where form_config_key=301;
 quit;

 /* Set error type as Fatal for error code starting with letter F */
 proc sql;
      update rc_cfg.sar_fincen_error_code(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=sar_fincen_error_code))
      set error_type_code='F'
      where substr(error_code,1,1)='F'
      ;

 /* standardize the source field name for contact information */
 proc sql;
      update rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config))
      set source_field_name='contactOffice'
      where form_config_key=301 
            and form_efile_record_id='3A'
            and target_field_name = 'SAR_CONTACT_OFFICE'
            ;
      update rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config))
      set source_field_name='contactPhoneNumber'
      where form_config_key=301 
            and form_efile_record_id='3A'
            and target_field_name = 'SAR_PHONE_NUMBER'
            ;
      update rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config))
      set source_field_name='contactPhoneExtension'
      where form_config_key=301 
            and form_efile_record_id='3A'
            and target_field_name = 'SAR_PHONE_EXTENSION'
            ;
     /* using branch number instead of branch ID for location code */
     /* because Branch ID is an ID assigned by the regulator.      */
     /* It may not be unique.                                      */
      update rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config))
      set target_field_name='BRANCH_NUMBER'
      where form_config_key=301 
            and form_efile_record_id='2C'
            and target_field_name = 'BRANCH_ID'
            ;
      quit;

      %let branch_id_exist=N;

      proc contents data=RC_DB.SAR_2C(%fcf_get_ds_opts(lib_name=RC_DB, ds_name=SAR_2C))
                     out=rc_db_tab_cols(keep=name)
                    noprint;
       run;

      data _null_;
       set rc_db_tab_cols;
        if upcase(name) eq 'BRANCH_ID' then
        do;
           call symputx('branch_id_exist','Y');
           stop;
        end;
       run;
 
     %if &branch_id_exist=Y %then
     %do;
      
        proc datasets lib=RC_DB nolist;
             modify SAR_2C;
             rename BRANCH_ID=BRANCH_NUMBER;

        quit;
      
     %end;

      
    %rc_efile_gen_macro_xpose_node( form_config_key=301,
                           form_type_code=SAR);

    %rc_efile_gen_json_schema(form_config_key=301
                              , form_type_code=SAR
                               );

    %rc_efile_gen_json_default(form_config_key=301
                              , form_type_code=SAR);

 
    %rc_efile_gen_macro_wrt_efile(form_config_key=301,
                  form_type_code=SAR,
                  input_or_put="put");
              

     /* Update FINCEN SAR error codes with custom errors                                */

     data rc_cfg.sar_fincen_error_code(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=sar_fincen_error_code, output_ds=Y));

          attrib ERROR_CODE  length=$4 label='Error Code'
                 ERROR_DESC length=$4000 label='Error Description'
                 ERROR_RECORD_TYPE length=$2 label='Record Type'
                 ERROR_TYPE_CODE length=$1 label='Error Type'
          ;
        
       
      
          infile rc_tmplt(rc_fincen_sar_error_code.csv)  
                 dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
             
          input error_code $
                error_desc $
                error_record_type $
                error_type_code $
                     
    ;
run;
   
   


%mend;


%macro rc_fincen_load_ref_naics;

/*******************************************************************************/
/*  LOAD NAICS codes                                                           */
/*******************************************************************************/
 
 

data fsk_lov_naics;

     if 0 then set seg_kc.fsk_lov;     
        
     infile  rc_tmplt(2014NAICS.csv)  
             dsd lrecl=32764 truncover  delimiter=',' ;
     length tmp_str expr $ 128;
     retain lov_type_name 'NAICS';
     retain lov_language_desc 'en';
     retain lov_type_code lov_type_desc lov_sort_position_number; 
     drop str_len expr  tmp_str;
   
     input tmp_str $;
      
     str_len=length(tmp_str);
     expr='/\d{'||strip(put(str_len,best.))||'}/';
      /* check for numeric data for NAICS code */
      if prxmatch(expr,tmp_str)=1  then
      do;
         lov_type_code=tmp_str;
         lov_sort_position_number=0;
         lov_type_desc=strip(lov_type_desc)||' ('||strip(lov_type_code)||')';
         active_flg='Y';
         output;
     end;
     else lov_type_desc=strip(tmp_str);
run;

%if &syserr <= 4 and &rc_debug=N %then
%do;
     

  proc sort data= fsk_lov_naics;
     by lov_type_desc;
  run;

  data fsk_lov_naics;
       set fsk_lov_naics;
        lov_sort_position_number=_n_;
  run;

  proc sql ;
         delete from seg_kc.fsk_lov
         where lov_type_name='NAICS'
     ;
  quit;

  proc append base=seg_kc.fsk_lov (dbforce=yes) 
              data=fsk_lov_naics force;
  run;
%end;

%mend; 
 
%rc_fincen_load_ref_naics; 

%rc_updt_fincen_institution;
%rc_updt_fincen_branch;
%rc_add_lov_sar;
%rc_updt_sar;

proc datasets lib=work nowarn nolist;
     delete rc_cfg_tab_cols
            rc_db_tab_cols;
quit;
