/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_fincen_config_update_4.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Program to update regulatory console configuration data in hotfix 4.
+------------------------------------------------------------------------------+
| USAGE:   Run this program using UTF-8 SAS.
+-------------+----------------------------------------------------------------+
| COMMENTS    | This program is executed by the regulatory console deployment scripts.
+-------------+----------+----------+------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2018 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro rc_updt_fincen_branch;
    /* Add branch Tax Id unknown flag  */
    %let upgraded=N;

    proc contents data=RC_CFG.FINCEN_BRANCH(%fcf_get_ds_opts(lib_name=RC_CFG, ds_name=FINCEN_BRANCH))
                   out=rc_cfg_tab_cols(keep=name)
                  noprint;
     run;

    data _null_;
     set rc_cfg_tab_cols;
      if upcase(name) eq 'BRANCH_TAX_ID_UNKNOWN_FLAG' then
      do;
         call symputx('upgraded','Y');
         stop;
      end;
     run;
 
    %if &upgraded=N %then
    %do;
       /* Upgrade table structure of RC_CFG.FINCEN_BRANCH */
       proc sql;
       alter table rc_cfg.fincen_branch(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=fincen_branch))
       add BRANCH_TAX_ID_UNKNOWN_FLAG char(1) label='Branch Tax Id Unknown'
       ; 
       quit;
    %end;

%mend;

%rc_updt_fincen_branch;

%macro rc_updt_fincen_inst_contact;
    /* Increase CONTACT_OFFICE to char(150)  */
    %let increased=N;

    proc contents data=RC_CFG.FINCEN_INSTITUTION(%fcf_get_ds_opts(lib_name=RC_CFG, ds_name=FINCEN_INSTITUTION))
                   out=rc_cfg_tab_cols(keep=name length)
                  noprint;
     run;

    data _null_;
     set rc_cfg_tab_cols;
      if upcase(name) eq 'CONTACT_OFFICE' and length eq 150 then
      do;
         call symputx('upgraded','Y');
         stop;
      end;
     run;

    %if &increased=N %then
    %do;
       /* Upgrade table structure of RC_CFG.FINCEN_BRANCH */
       proc sql;
       alter table rc_cfg.fincen_institution(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=fincen_institution))
       modify CONTACT_OFFICE char(150)
       ; 
       quit;
    %end;
 
%mend;

%rc_updt_fincen_inst_contact;

proc datasets lib=work nowarn nolist;
     delete rc_cfg_tab_cols;
quit; 
