<?xml version="1.0"?>
<!-- sarx_efile.xsl -->
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fc2="www.fincen.gov/base">
	<xsl:output method="xml" indent="yes"/>
	<xsl:template match="/EfileCollection">
		<fc2:EFilingBatchXML ActivityCount="{count(reportCollections/reportCollection/report)}"
							 TotalAmount="{format-number(sum(reportCollections/reportCollection/report/reportUiJSON/involvedAmount),'0')}"
                             PartyCount="{count(reportCollections/reportCollection/report/subjects)}" 
							 ActivityAttachmentCount="{count(reportCollections/reportCollection/attachmentName)}"
							 AttachmentCount="{count(reportCollections/reportCollection/attachmentName)}"
                             xsi:schemaLocation="www.fincen.gov/base EFL_SARXBatchSchema.xsd"
                             xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                             xmlns:fc2="www.fincen.gov/base">

			<fc2:FormTypeCode>SARX</fc2:FormTypeCode>
			<xsl:apply-templates select="reportCollections/reportCollection/report/reportUiJSON"/>
		</fc2:EFilingBatchXML>
	</xsl:template>


	<xsl:template match="reportCollections/reportCollection/report/reportUiJSON">	 

		<fc2:Activity SeqNum="{../reportKey}">

			<xsl:if test="../priorAgencyRefId">
				<fc2:EFilingPriorDocumentNumber>
					<xsl:value-of select="../priorAgencyRefId"/>				 
				</fc2:EFilingPriorDocumentNumber>
			</xsl:if>

			<fc2:FilingDateText>
				<xsl:call-template name="convertDate">
					<xsl:with-param name="inputDateTime" select="/EfileCollection/currentDate" />
				</xsl:call-template>				 				 
			</fc2:FilingDateText>	

			<xsl:if test="noteToFincen !=''">
				<fc2:FilingInstitutionNotetoFinCEN>
					<xsl:value-of select="noteToFincen"/>				 
				</fc2:FilingInstitutionNotetoFinCEN>
			</xsl:if> 

			<fc2:ActivityAssociation SeqNum=".">
				<xsl:if test="continuingActivityReportFlag='true'">
					<fc2:ContinuingActivityReportIndicator>Y</fc2:ContinuingActivityReportIndicator>
				</xsl:if>
				<xsl:if test="filingTypeCode='B'">
					<fc2:CorrectsAmendsPriorReportIndicator>Y</fc2:CorrectsAmendsPriorReportIndicator>
				</xsl:if>     
				<xsl:if test="filingTypeCode='A'">           
					<fc2:InitialReportIndicator>Y</fc2:InitialReportIndicator>
				</xsl:if>
				<xsl:if test="jointReportFlag='true'">
					<fc2:JointReportIndicator>Y</fc2:JointReportIndicator>
				</xsl:if>
			</fc2:ActivityAssociation>

			<xsl:if test="../../attachmentName!=''">
				<fc2:ActivitySupportDocument SeqNum=".">
					<fc2:OriginalAttachmentFileName>
						<xsl:value-of select="../../attachmentName"/>	
					</fc2:OriginalAttachmentFileName>
				</fc2:ActivitySupportDocument>
			</xsl:if>
			<!--
                Transmitter party(35), 
				Transmitter contact party(37)
            -->

			<xsl:apply-templates select="/EfileCollection/fincenTransmitter"/>


			<!--
                Filing Institution party(30)
			-->

			<xsl:call-template name="fincenFiler">	
				<xsl:with-param name="SARInternalControlNumber" select="SARInternalControlNumber"/>					
			</xsl:call-template>	


			<!--
                 
				Designated contact office party(8)				
            -->
			<xsl:apply-templates select="contactOffice"/>

			<!--
                Law enforcement agency party(18)
            -->

			<xsl:apply-templates select="LEContactAgency"/>


			<!--
                Law enforcement name party(18)
            -->

			<xsl:apply-templates select="LEContactName"/>

			<!--
                Financial Institution Where Activity Occurred party(34)
            -->

			<xsl:apply-templates select="../institutions/entityUiJSON"/>


			<!-- 
                Subject Party  party(33)
            -->

			<xsl:apply-templates select="../subjects/entityUiJSON"/>

			<!-- Suspicious Activity -->
			<fc2:SuspiciousActivity SeqNum=".">
				<!-- AmountUnknown, CumulativeTotal and NoAmount before the Begin and End Date -->
				<xsl:if test="involvedAmountUnknownCode='A'">
					<fc2:AmountUnknownIndicator>Y</fc2:AmountUnknownIndicator>
				</xsl:if>
				<xsl:if test="cumulativeAmount != ''">
					<fc2:CumulativeTotalViolationAmountText>
						<xsl:value-of select="cumulativeAmount"/>
					</fc2:CumulativeTotalViolationAmountText>
				</xsl:if>			
				<xsl:if test="involvedAmountUnknownCode='B'">
					<fc2:NoAmountInvolvedIndicator>Y</fc2:NoAmountInvolvedIndicator>
				</xsl:if>
				<fc2:SuspiciousActivityFromDateText>
					<xsl:call-template name="convertDate">
						<xsl:with-param name="inputDateTime" select="SARBeginDate" />
					</xsl:call-template>

				</fc2:SuspiciousActivityFromDateText>
				<xsl:if test="SAREndDate !=''">
					<fc2:SuspiciousActivityToDateText>
						<xsl:call-template name="convertDate">
							<xsl:with-param name="inputDateTime" select="SAREndDate" />
						</xsl:call-template>

					</fc2:SuspiciousActivityToDateText>
				</xsl:if> 

				<fc2:TotalSuspiciousAmountText>
					<xsl:value-of select="involvedAmount"/>
				</fc2:TotalSuspiciousAmountText>

				<!-- SARStructureOther did not follow naming convention -->
				<xsl:for-each select="*[substring(name(.), 1, string-length(name(.)) - 1) = 'SARStructuredType']">
					<xsl:call-template name="SARClassification">			
						<xsl:with-param name="SARType" select="'SARStructuredType'"/>
						<xsl:with-param name="SARTypeOther" select="../SARStructuredOther/."/>
					</xsl:call-template>			
				</xsl:for-each>

				<xsl:for-each select="*[substring(name(.), 1, string-length(name(.)) - 1) = 'SARTerroristType']">
					<xsl:call-template name="SARClassification">			
						<xsl:with-param name="SARType" select="'SARTerroristType'"/>
						<xsl:with-param name="SARTypeOther" select="../SARTerroristTypeOther/."/>
					</xsl:call-template>			
				</xsl:for-each>

				<xsl:for-each select="*[substring(name(.), 1, string-length(name(.)) - 1) = 'SARFraudType']">
					<xsl:call-template name="SARClassification">			
						<xsl:with-param name="SARType" select="'SARFraudType'"/>
						<xsl:with-param name="SARTypeOther" select="../SARFraudTypeOther/."/>
					</xsl:call-template>			
				</xsl:for-each>

				<xsl:for-each select="*[substring(name(.), 1, string-length(name(.)) - 1) = 'SARCasinosType']">
					<xsl:call-template name="SARClassification">			
						<xsl:with-param name="SARType" select="'SARCasinosType'"/>
						<xsl:with-param name="SARTypeOther" select="../SARCasinosTypeOther/."/>
					</xsl:call-template>			
				</xsl:for-each>

				<xsl:for-each select="*[substring(name(.), 1, string-length(name(.)) - 1) = 'SARMoneyLaundryType']">
					<xsl:call-template name="SARClassification">			
						<xsl:with-param name="SARType" select="'SARMoneyLaundryType'"/>
						<xsl:with-param name="SARTypeOther" select="../SARMoneyLaundryTypeOther/."/>
					</xsl:call-template>			
				</xsl:for-each>

				<xsl:for-each select="*[substring(name(.), 1, string-length(name(.)) - 1) = 'SARIDType']">
					<xsl:call-template name="SARClassification">			
						<xsl:with-param name="SARType" select="'SARIDType'"/>
						<xsl:with-param name="SARTypeOther" select="../SARIDTypeOther/."/>
					</xsl:call-template>			
				</xsl:for-each>

				<xsl:for-each select="*[substring(name(.), 1, string-length(name(.)) - 1) = 'SAROtherType']">
					<xsl:call-template name="SARClassification">			
						<xsl:with-param name="SARType" select="'SAROtherType'"/>
						<xsl:with-param name="SARTypeOther" select="../SAROtherTypeOther/."/>
					</xsl:call-template>			
				</xsl:for-each>

				<xsl:for-each select="*[substring(name(.), 1, string-length(name(.)) - 1) = 'SARInsuranceType']">
					<xsl:call-template name="SARClassification">			
						<xsl:with-param name="SARType" select="'SARInsuranceType'"/>
						<xsl:with-param name="SARTypeOther" select="../SARInsuranceTypeOther/."/>
					</xsl:call-template>			
				</xsl:for-each>

				<xsl:for-each select="*[substring(name(.), 1, string-length(name(.)) - 1) = 'SARSFType']">
					<xsl:call-template name="SARClassification">			
						<xsl:with-param name="SARType" select="'SARSFType'"/>
						<xsl:with-param name="SARTypeOther" select="../SARSFTypeOther/."/>
					</xsl:call-template>			
				</xsl:for-each>

				<xsl:for-each select="*[substring(name(.), 1, string-length(name(.)) - 1) = 'SARMortgageFraudType']">
					<xsl:call-template name="SARClassification">			
						<xsl:with-param name="SARType" select="'SARMortgageFraudType'"/>
						<xsl:with-param name="SARTypeOther" select="../SARMortgageFraudTypeOther/."/>
					</xsl:call-template>			
				</xsl:for-each>

				<xsl:for-each select="*[substring(name(.), 1, string-length(name(.)) - 1) = 'SARCyberType']">
					<xsl:call-template name="SARClassification">			
						<xsl:with-param name="SARType" select="'SARCyberType'"/>
						<xsl:with-param name="SARTypeOther" select="../SARCyberTypeOther/."/>
					</xsl:call-template>			
				</xsl:for-each>
			</fc2:SuspiciousActivity>


			<xsl:apply-templates select="IPAddress"/>

			<xsl:apply-templates select="cyberEvent"/>

			<xsl:for-each select="*[substring(name(.), 1, string-length(name(.)) - 1) = 'SARProductType']">
				<xsl:call-template name="AssetClassification">			
					<xsl:with-param name="AssetType" select="'SARProductType'"/>
					<xsl:with-param name="AssetTypeOther" select="../SARProductTypeOther/."/>
				</xsl:call-template>			
			</xsl:for-each>

			<xsl:for-each select="*[substring(name(.), 1, string-length(name(.)) - 1) = 'SARInstrumentType']">
				<xsl:call-template name="AssetClassification">			
					<xsl:with-param name="AssetType" select="'SARInstrumentType'"/>
					<xsl:with-param name="AssetTypeOther" select="../SARInstrumentTypeOther/."/>
				</xsl:call-template>			
			</xsl:for-each>

			<!-- AssetsAttribute -->
			<xsl:for-each select="commodity/commodity">
				<xsl:call-template name="AssetAttributeClassification">			
					<xsl:with-param name="AssetAttributeType" select="'commodity'"/>				 
				</xsl:call-template>			
			</xsl:for-each>
			<xsl:for-each select="product/product">
				<xsl:call-template name="AssetAttributeClassification">			
					<xsl:with-param name="AssetAttributeType" select="'product'"/>

				</xsl:call-template>			
			</xsl:for-each>
			<xsl:for-each select="MIC/MIC">
				<xsl:call-template name="AssetAttributeClassification">			
					<xsl:with-param name="AssetAttributeType" select="'MIC'"/>

				</xsl:call-template>			
			</xsl:for-each>
			<xsl:for-each select="CUSIP/CUSIP">
				<xsl:call-template name="AssetAttributeClassification">			
					<xsl:with-param name="AssetAttributeType" select="'CUSIP'"/>

				</xsl:call-template>			
			</xsl:for-each>



			<xsl:apply-templates select="../reportNarrative"/>			

		</fc2:Activity>
	</xsl:template>

	<xsl:template match="IPAddress">

		<xsl:if test="IPAddress != ''">

			<fc2:ActivityIPAddress SeqNum=".">
				<fc2:ActivityIPAddressDateText>
					<xsl:call-template name="convertDate">
						<xsl:with-param name="inputDateTime" select="IPAddressUTCDate" />
					</xsl:call-template>
				</fc2:ActivityIPAddressDateText>
				<fc2:ActivityIPAddressTimeStampText>
					<xsl:value-of select = "IPAddressUTCTime"/>
				</fc2:ActivityIPAddressTimeStampText>
				<fc2:IPAddressText>
					<xsl:value-of select = "IPAddress"/>
				</fc2:IPAddressText>
			</fc2:ActivityIPAddress>
		</xsl:if>
	</xsl:template>

	<xsl:template match="cyberEvent">
		<xsl:if test="cyberEventValue != ''">
			<fc2:CyberEventIndicators SeqNum=".">
				<fc2:CyberEventDateText>
					<xsl:call-template name="convertDate">
						<xsl:with-param name="inputDateTime" select="cyberEventUTCDate" />
					</xsl:call-template>					 
				</fc2:CyberEventDateText>
				<fc2:CyberEventIndicatorsTypeCode>
					<xsl:value-of select = "cyberEventTypeCode"/>					 
				</fc2:CyberEventIndicatorsTypeCode>
				<fc2:CyberEventTimeStampText>
					<xsl:value-of select = "cyberEventUTCTime"/>
				</fc2:CyberEventTimeStampText>
				<xsl:if test="cyberEventTypeOther != ''">
					<fc2:CyberEventTypeOtherText>
						<xsl:value-of select = "cyberEventTypeOther"/>
					</fc2:CyberEventTypeOtherText>
				</xsl:if>
				<fc2:EventValueText>
					<xsl:value-of select = "cyberEventValue"/>
				</fc2:EventValueText>
			</fc2:CyberEventIndicators>
		</xsl:if>
	</xsl:template>

	<xsl:template name = "AssetAttributeClassification" >

		<xsl:param name = "AssetAttributeType" />	 
		<fc2:AssetsAttribute SeqNum=".">
			<fc2:AssetAttributeDescriptionText>
				<xsl:value-of select = "."/>
			</fc2:AssetAttributeDescriptionText>
			<fc2:AssetAttributeTypeID>
				<xsl:call-template name="map">			
					<xsl:with-param name="source" select='$AssetAttributeType'/>
					<xsl:with-param name="code" select="'*'"/>
				</xsl:call-template>
			</fc2:AssetAttributeTypeID>		
		</fc2:AssetsAttribute>		 
	</xsl:template>



	<!-- Split narrative lines into blocks of 4000. -->
	<xsl:template match="reportNarrative">

		<xsl:variable name='textLength' select="string-length()"/>
		<xsl:variable name='blockSize' select="4000"/>
		<xsl:variable name='splitNumber' select="ceiling($textLength div $blockSize)"/>

		<xsl:if test="$splitNumber &gt;= 1">
			<fc2:ActivityNarrativeInformation SeqNum=".">
				<fc2:ActivityNarrativeSequenceNumber>
					<xsl:value-of select="format-number(1,'0')"/>
				</fc2:ActivityNarrativeSequenceNumber>
				<fc2:ActivityNarrativeText>
					<xsl:value-of select="normalize-space(substring(.,1,$blockSize))"/>
				</fc2:ActivityNarrativeText>
			</fc2:ActivityNarrativeInformation>
		</xsl:if>
		<xsl:if test="$splitNumber &gt;= 2">
			<fc2:ActivityNarrativeInformation SeqNum=".">
				<fc2:ActivityNarrativeSequenceNumber>
					<xsl:value-of select="format-number(2,'0')"/>
				</fc2:ActivityNarrativeSequenceNumber>
				<fc2:ActivityNarrativeText>
					<xsl:value-of select="normalize-space(substring(.,($blockSize+1),$blockSize))"/>
				</fc2:ActivityNarrativeText>
			</fc2:ActivityNarrativeInformation>
		</xsl:if>
		<xsl:if test="$splitNumber &gt;= 3">
			<fc2:ActivityNarrativeInformation SeqNum=".">
				<fc2:ActivityNarrativeSequenceNumber>
					<xsl:value-of select="format-number(3,'0')"/>
				</fc2:ActivityNarrativeSequenceNumber>
				<fc2:ActivityNarrativeText>
					<xsl:value-of select="normalize-space(substring(.,($blockSize*2)+1,$blockSize))"/>
				</fc2:ActivityNarrativeText>
			</fc2:ActivityNarrativeInformation>
		</xsl:if>
		<xsl:if test="$splitNumber &gt;= 4">
			<fc2:ActivityNarrativeInformation SeqNum=".">
				<fc2:ActivityNarrativeSequenceNumber>
					<xsl:value-of select="format-number(4,'0')"/>
				</fc2:ActivityNarrativeSequenceNumber>
				<fc2:ActivityNarrativeText>
					<xsl:value-of select="normalize-space(substring(.,($blockSize*3)+1,$blockSize))"/>
				</fc2:ActivityNarrativeText>
			</fc2:ActivityNarrativeInformation>
		</xsl:if>
		<xsl:if test="$splitNumber &gt;= 5">
			<fc2:ActivityNarrativeInformation SeqNum=".">
				<fc2:ActivityNarrativeSequenceNumber>
					<xsl:value-of select="format-number(5,'0')"/>
				</fc2:ActivityNarrativeSequenceNumber>
				<fc2:ActivityNarrativeText>
					<xsl:value-of select="normalize-space(substring(.,($blockSize*4)+1,$blockSize))"/>
				</fc2:ActivityNarrativeText>
			</fc2:ActivityNarrativeInformation>
		</xsl:if>

	</xsl:template>



	<!--   Transmitter -->
	<xsl:template match="/EfileCollection/fincenTransmitter">
		<!--   Transmitter party(35)     -->
		<fc2:Party SeqNum=".">

			<fc2:ActivityPartyTypeCode>35</fc2:ActivityPartyTypeCode>                 
			<fc2:PartyName SeqNum=".">
				<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
				<fc2:RawPartyFullName>
					<xsl:value-of select="transmitterName"/>
				</fc2:RawPartyFullName>
			</fc2:PartyName>

			<fc2:Address SeqNum=".">

				<fc2:RawCityText>
					<xsl:value-of select="transmitterCityName"/>
				</fc2:RawCityText>

				<fc2:RawCountryCodeText>
					<xsl:value-of select="transmitterCountryCode"/>
				</fc2:RawCountryCodeText>


				<fc2:RawStateCodeText>
					<xsl:value-of select="transmitterStateCode"/>
				</fc2:RawStateCodeText>

				<fc2:RawStreetAddress1Text>
					<xsl:value-of select="transmitterAddress"/>
				</fc2:RawStreetAddress1Text>


				<fc2:RawZIPCode>
					<xsl:value-of select="transmitterZipCode"/>
				</fc2:RawZIPCode>

			</fc2:Address>

			<xsl:if test="transmitterTelephone !=''">
				<fc2:PhoneNumber SeqNum=".">					 
					<fc2:PhoneNumberText>
						<xsl:value-of select="transmitterTelephone"/>
					</fc2:PhoneNumberText>
				</fc2:PhoneNumber>
			</xsl:if>

			<fc2:PartyIdentification SeqNum=".">				 
				<fc2:PartyIdentificationNumberText>
					<xsl:value-of select="transmitterTaxId"/>
				</fc2:PartyIdentificationNumberText>
				<fc2:PartyIdentificationTypeCode>4</fc2:PartyIdentificationTypeCode>
			</fc2:PartyIdentification>

			<fc2:PartyIdentification SeqNum=".">
				<fc2:PartyIdentificationNumberText>
					<xsl:value-of select="transmitterControlCode"/>
				</fc2:PartyIdentificationNumberText>

				<fc2:PartyIdentificationTypeCode>28</fc2:PartyIdentificationTypeCode>
			</fc2:PartyIdentification>
		</fc2:Party>

		<!--   Transmitter contact party(37) -->
		<fc2:Party SeqNum=".">
			<fc2:ActivityPartyTypeCode>37</fc2:ActivityPartyTypeCode>              

			<fc2:PartyName SeqNum=".">
				<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
				<fc2:RawPartyFullName>
					<xsl:value-of select="transmitterContactName"/>
				</fc2:RawPartyFullName>

			</fc2:PartyName>
		</fc2:Party>
	</xsl:template>


	<xsl:template name="fincenFiler">
		<xsl:param name="SARInternalControlNumber"/>

		<fc2:Party SeqNum=".">
			<fc2:ActivityPartyTypeCode>30</fc2:ActivityPartyTypeCode>

			<fc2:PrimaryRegulatorTypeCode>
				<xsl:call-template name="map">			
					<xsl:with-param name="source" select="'institutionPrimFedRegCode'"/>
					<xsl:with-param name="code" select="/EfileCollection/fincenFiler/institutionPrimFedRegCode/."/>
				</xsl:call-template>	
			</fc2:PrimaryRegulatorTypeCode>

			<fc2:PartyName SeqNum=".">
				<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
				<fc2:RawPartyFullName>
					<xsl:value-of select="/EfileCollection/fincenFiler/institutionLegalName"/>
				</fc2:RawPartyFullName>
			</fc2:PartyName>

			<xsl:if test="/EfileCollection/fincenFiler/institutionAltenateName !=''">
				<fc2:PartyName SeqNum=".">
					<fc2:PartyNameTypeCode>DBA</fc2:PartyNameTypeCode>
					<fc2:RawPartyFullName>
						<xsl:value-of select="/EfileCollection/fincenFiler/institutionAlternateName"/>
					</fc2:RawPartyFullName>
				</fc2:PartyName>
			</xsl:if>

			<fc2:Address SeqNum=".">

				<fc2:RawCityText>
					<xsl:value-of select="/EfileCollection/fincenFiler/institutionCityName"/>
				</fc2:RawCityText>
				<fc2:RawCountryCodeText>
					<xsl:value-of select="/EfileCollection/fincenFiler/institutionCountryCode"/>
				</fc2:RawCountryCodeText>
				<fc2:RawStateCodeText>
					<xsl:value-of select="/EfileCollection/fincenFiler/institutionStateCode"/>
				</fc2:RawStateCodeText>
				<fc2:RawStreetAddress1Text>
					<xsl:value-of select="/EfileCollection/fincenFiler/institutionAddress"/>
				</fc2:RawStreetAddress1Text>
				<fc2:RawZIPCode>
					<xsl:value-of select="/EfileCollection/fincenFiler/institutionZipCode"/>
				</fc2:RawZIPCode>				 
			</fc2:Address>
			<fc2:PartyIdentification SeqNum=".">				 
				<fc2:PartyIdentificationNumberText>
					<xsl:value-of select="/EfileCollection/fincenFiler/institutionTaxId"/>
				</fc2:PartyIdentificationNumberText>				
				<fc2:PartyIdentificationTypeCode>
					<xsl:call-template name="map">			
						<xsl:with-param name="source" select="'institutionTaxIdType'"/>
						<xsl:with-param name="code" select="/EfileCollection/fincenFiler/institutionTaxIdType/."/>
					</xsl:call-template>	


				</fc2:PartyIdentificationTypeCode>
			</fc2:PartyIdentification>


			<fc2:PartyIdentification SeqNum=".">

				<fc2:PartyIdentificationNumberText>
					<xsl:value-of select="/EfileCollection/fincenFiler/institutionId"/>
				</fc2:PartyIdentificationNumberText>				 
				<fc2:PartyIdentificationTypeCode>
					<xsl:call-template name="map">			
						<xsl:with-param name="source" select="'institutionIdTypeCode'"/>
						<xsl:with-param name="code" select="/EfileCollection/fincenFiler/institutionIdTypeCode/."/>
					</xsl:call-template>			
				</fc2:PartyIdentificationTypeCode>
			</fc2:PartyIdentification>

			<xsl:if test="$SARInternalControlNumber">	
				<fc2:PartyIdentification SeqNum=".">
					<fc2:PartyIdentificationNumberText>
						<xsl:value-of select="$SARInternalControlNumber"/>
					</fc2:PartyIdentificationNumberText>				 
					<fc2:PartyIdentificationTypeCode>29</fc2:PartyIdentificationTypeCode>
				</fc2:PartyIdentification>
			</xsl:if>

			<xsl:choose> 
				<!-- for (Security Futures) -->
				<xsl:when test="/EfileCollection/fincenFiler/institutionTypeCode='E'">

					<xsl:for-each select="/EfileCollection/fincenFiler/*">

						<xsl:if test=".='true' and substring(local-name(.), 1, string-length(local-name(.)) - 1) = 'institutionSfTypeCode'">

							<xsl:variable name="code">
								<xsl:value-of select="substring(name(.),string-length(name(.)),1)" />
							</xsl:variable>

							<fc2:OrganizationClassificationTypeSubtype SeqNum=".">
								<fc2:OrganizationSubtypeID>
									<xsl:call-template name="map">			
										<xsl:with-param name="source" select="'institutionSfTypeCode'"/>
										<xsl:with-param name="code" select="$code"/>
									</xsl:call-template>
								</fc2:OrganizationSubtypeID>
								<fc2:OrganizationTypeID>5</fc2:OrganizationTypeID>								
								<xsl:if test="local-name(.)='institutionSfTypeCodeZ'">
									<fc2:OtherOrganizationSubTypeText>
										<xsl:value-of select="../institutionSfTypeOther"/>
									</fc2:OtherOrganizationSubTypeText>
								</xsl:if>
							</fc2:OrganizationClassificationTypeSubtype>
						</xsl:if>					  
					</xsl:for-each>
				</xsl:when>

				<!-- for gaming type  -->
				<xsl:when test="/EfileCollection/fincenFiler/institutionTypeCode='A'">
					<fc2:OrganizationClassificationTypeSubtype SeqNum=".">					 				
						<fc2:OrganizationTypeID>1</fc2:OrganizationTypeID>							 				 
					</fc2:OrganizationClassificationTypeSubtype>
				</xsl:when>			

				<!-- for other institution types -->
				<xsl:otherwise>
					<fc2:OrganizationClassificationTypeSubtype SeqNum=".">	
						<fc2:OrganizationTypeID>
							<xsl:call-template name="map">			
								<xsl:with-param name="source" select="'institutionTypeCode'"/>
								<xsl:with-param name="code" select="/EfileCollection/fincenFiler/institutionTypeCode/."/>
							</xsl:call-template>						
						</fc2:OrganizationTypeID>
						<xsl:if test="/EfileCollection/fincenFiler/institutionTypeCode='Z'">
							<fc2:OtherOrganizationTypeText>
								<xsl:value-of select="/EfileCollection/fincenFiler/institutionTypeOther"/>
							</fc2:OtherOrganizationTypeText>
						</xsl:if>					
					</fc2:OrganizationClassificationTypeSubtype>
				</xsl:otherwise>	
			</xsl:choose>
		</fc2:Party>

	</xsl:template>




	<!-- Designated contact office party(8) -->
	<xsl:template match="contactOffice">
		<fc2:Party SeqNum=".">
			<fc2:ActivityPartyTypeCode>8</fc2:ActivityPartyTypeCode>
			<fc2:PartyName SeqNum=".">
				<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
				<fc2:RawPartyFullName>
					<xsl:value-of select="."/>
				</fc2:RawPartyFullName>
			</fc2:PartyName>

			<xsl:if test="../contactPhoneNumber != ''">
				<fc2:PhoneNumber SeqNum=".">
					<xsl:if test="../contactPhoneExtension !=''">
						<fc2:PhoneNumberExtensionText>
							<xsl:apply-templates select="../contactPhoneExtension"/>
						</fc2:PhoneNumberExtensionText>
					</xsl:if>
					<fc2:PhoneNumberText>
						<xsl:value-of select="../contactPhoneNumber"/>
					</fc2:PhoneNumberText>

				</fc2:PhoneNumber>
			</xsl:if>

		</fc2:Party>
	</xsl:template>




	<!-- Law enforcement agency party 18  -->
	<xsl:template match="LEContactAgency">
		<fc2:Party SeqNum=".">
			<fc2:ActivityPartyTypeCode>18</fc2:ActivityPartyTypeCode> 

			<fc2:PartyName SeqNum=".">
				<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>				 
				<fc2:RawPartyFullName>
					<xsl:value-of select="."/>
				</fc2:RawPartyFullName>
			</fc2:PartyName>           
		</fc2:Party>
	</xsl:template>

	<!-- Law enforcement name party 19 -->
	<xsl:template match="LEContactName">
		<fc2:Party SeqNum=".">
			<fc2:ActivityPartyTypeCode>19</fc2:ActivityPartyTypeCode>

			<xsl:if test="(../LEContactDate)">
				<fc2:ContactDateText> 
					<xsl:call-template name="convertDate">
						<xsl:with-param name="inputDateTime" select="../LEContactDate" />
					</xsl:call-template>
				</fc2:ContactDateText>
			</xsl:if>

			<fc2:PartyName SeqNum=".">
				<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
				<fc2:RawPartyFullName>
					<xsl:value-of select="."/>
				</fc2:RawPartyFullName>                
			</fc2:PartyName>


			<xsl:if test="(../LEContactTelephone)">
				<fc2:PhoneNumber SeqNum=".">
					<xsl:if test="(../LEContactTelephoneExt !='')">
						<fc2:PhoneNumberExtensionText>
							<xsl:value-of select="../LEContactTelephoneExt"/>
						</fc2:PhoneNumberExtensionText>	
					</xsl:if>					
					<fc2:PhoneNumberText>
						<xsl:value-of select="../LEContactTelephone"/>
					</fc2:PhoneNumberText>
				</fc2:PhoneNumber>
			</xsl:if>


		</fc2:Party>
	</xsl:template>

	<!-- Financial Institution Where Activity Occurred Party 34 -->
	<xsl:template match="institutions/entityUiJSON">
		<fc2:Party SeqNum=".">

			<fc2:ActivityPartyTypeCode>34</fc2:ActivityPartyTypeCode>
			<xsl:if test="lossAmount != ''">	
				<fc2:LossToFinancialAmountText>
					<xsl:value-of select="lossAmount"/>
				</fc2:LossToFinancialAmountText>
			</xsl:if>
			<xsl:if test="count(../relationships)=0">					
				<fc2:NoBranchActivityInvolvedIndicator>Y</fc2:NoBranchActivityInvolvedIndicator>
			</xsl:if>

			<xsl:if test="institutionRoleCode='B'">
				<fc2:PayLocationIndicator>Y</fc2:PayLocationIndicator>
			</xsl:if>
			<fc2:PrimaryRegulatorTypeCode>
				<xsl:call-template name="map">			
					<xsl:with-param name="source" select="'institutionPrimFedRegCode'"/>
					<xsl:with-param name="code" select="institutionPrimFedRegCode/."/>
				</xsl:call-template>	
			</fc2:PrimaryRegulatorTypeCode>
			<xsl:if test="institutionRoleCode='A'">
				<fc2:SellingLocationIndicator>Y</fc2:SellingLocationIndicator>
			</xsl:if>


			<xsl:if test="institutionRoleCode='C'">
				<fc2:SellingPayingLocationIndicator>Y</fc2:SellingPayingLocationIndicator>
			</xsl:if>

			<fc2:PartyName SeqNum=".">
				<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
				<fc2:RawPartyFullName>
					<xsl:value-of select="institutionLegalName"/>
				</fc2:RawPartyFullName>
			</fc2:PartyName>

			<xsl:if test="institutionAltenateName !=''">
				<fc2:PartyName SeqNum=".">
					<fc2:PartyNameTypeCode>DBA</fc2:PartyNameTypeCode>
					<fc2:RawPartyFullName>
						<xsl:value-of select="institutionAlternateName"/>
					</fc2:RawPartyFullName>
				</fc2:PartyName>
			</xsl:if>

			<fc2:Address SeqNum=".">
				<xsl:if test="count(institutionCityName)=0">
					<fc2:CityUnknownIndicator>Y</fc2:CityUnknownIndicator>
				</xsl:if>
				<xsl:if test="count(institutionCountryCode)=0">
					<fc2:CountryCodeUnknownIndicator>Y</fc2:CountryCodeUnknownIndicator>
				</xsl:if>
				<xsl:if test="institutionCityName !=''">
					<fc2:RawCityText>
						<xsl:value-of select="institutionCityName"/>
					</fc2:RawCityText>
				</xsl:if>
				<xsl:if test="institutionCountryCode !=''">
					<fc2:RawCountryCodeText>
						<xsl:value-of select="institutionCountryCode"/>
					</fc2:RawCountryCodeText>
				</xsl:if>
				<xsl:if test="institutionStateCode !=''">
					<fc2:RawStateCodeText>
						<xsl:value-of select="institutionStateCode"/>
					</fc2:RawStateCodeText>
				</xsl:if>
				<xsl:if test="institutionAddress !=''">
					<fc2:RawStreetAddress1Text>
						<xsl:value-of select="institutionAddress"/>
					</fc2:RawStreetAddress1Text>
				</xsl:if>
				<xsl:if test="institutionZipCode !=''">
					<fc2:RawZIPCode>
						<xsl:value-of select="institutionZipCode"/>
					</fc2:RawZIPCode>
				</xsl:if>				 
				<xsl:if test="count(institutionAddress)=0">
					<fc2:StreetAddressUnknownIndicator>Y</fc2:StreetAddressUnknownIndicator>
				</xsl:if>
				<xsl:if test="count(institutionZipCode)=0">
					<fc2:ZIPCodeUnknownIndicator>Y</fc2:ZIPCodeUnknownIndicator>
				</xsl:if>				
			</fc2:Address>
			<fc2:PartyIdentification SeqNum=".">
				<xsl:choose>
					<xsl:when test="institutionTaxId !=''">			
						<fc2:PartyIdentificationNumberText>
							<xsl:value-of select="institutionTaxId"/>
						</fc2:PartyIdentificationNumberText>				
						<fc2:PartyIdentificationTypeCode>
							<xsl:call-template name="map">			
								<xsl:with-param name="source" select="'institutionTaxIdType'"/>
								<xsl:with-param name="code" select="institutionTaxIdType/."/>
							</xsl:call-template>
						</fc2:PartyIdentificationTypeCode>
					</xsl:when>
					<xsl:otherwise>						 
						<fc2:TINUnknownIndicator>Y</fc2:TINUnknownIndicator>
					</xsl:otherwise>
				</xsl:choose>	

			</fc2:PartyIdentification>

			<xsl:if test="institutionId !=''">
				<fc2:PartyIdentification SeqNum=".">
					<fc2:PartyIdentificationNumberText>
						<xsl:value-of select="institutionId"/>
					</fc2:PartyIdentificationNumberText>				 
					<fc2:PartyIdentificationTypeCode>
						<xsl:call-template name="map">			
							<xsl:with-param name="source" select="'institutionIdTypeCode'"/>
							<xsl:with-param name="code" select="institutionIdTypeCode/."/>
						</xsl:call-template>			
					</fc2:PartyIdentificationTypeCode>
				</fc2:PartyIdentification>
			</xsl:if>			

			<xsl:if test="internalFileNumber">	
				<fc2:PartyIdentification SeqNum=".">
					<fc2:PartyIdentificationNumberText>
						<xsl:value-of select="internalFileNumber"/>
					</fc2:PartyIdentificationNumberText>				 
					<fc2:PartyIdentificationTypeCode>29</fc2:PartyIdentificationTypeCode>
				</fc2:PartyIdentification>
			</xsl:if>

			<xsl:choose> 
				<!-- for (Security Futures) -->
				<xsl:when test="institutionTypeCode='E'">

					<xsl:for-each select="*">

						<xsl:if test=".='true' and substring(local-name(.), 1, string-length(local-name(.)) - 1) = 'institutionSfTypeCode'">

							<xsl:variable name="code">
								<xsl:value-of select="substring(name(.),string-length(name(.)),1)" />
							</xsl:variable>
							<!-- do not include SF type codes B and X for party 43 (institution where activity occurred)	-->		
							<xsl:if test="not ($code='B' or $code='J' or $code='K')">
								<fc2:OrganizationClassificationTypeSubtype SeqNum=".">
									<fc2:OrganizationSubtypeID>
										<xsl:call-template name="map">			
											<xsl:with-param name="source" select="'institutionSfTypeCode'"/>
											<xsl:with-param name="code" select="$code"/>
										</xsl:call-template>
									</fc2:OrganizationSubtypeID>
									<fc2:OrganizationTypeID>5</fc2:OrganizationTypeID>

									<xsl:if test="local-name(.)='institutionSfTypeCodeZ'">
										<fc2:OtherOrganizationSubTypeText>
											<xsl:value-of select="../institutionSfTypeOther"/>
										</fc2:OtherOrganizationSubTypeText>
									</xsl:if>
								</fc2:OrganizationClassificationTypeSubtype>
							</xsl:if>	
						</xsl:if>					  
					</xsl:for-each>
				</xsl:when>

				<!-- for gaming type  -->
				<xsl:when test="institutionTypeCode='A'">
					<fc2:OrganizationClassificationTypeSubtype SeqNum=".">	
						<!-- only party 34 has gaming types and other -->									
						<xsl:variable name="code">
							<xsl:value-of select="substring(name(.),string-length(name(.)),1)" />
						</xsl:variable>
						<fc2:OrganizationSubtypeID>
							<xsl:call-template name="map">			
								<xsl:with-param name="source" select="'institutionGamingTypeCode'"/>
								<xsl:with-param name="code" select="institutionGamingTypeCode"/>
							</xsl:call-template>
						</fc2:OrganizationSubtypeID>

						<fc2:OrganizationTypeID>1</fc2:OrganizationTypeID>

						<fc2:OtherOrganizationSubTypeText>
							<xsl:value-of select="institutionGamingTypeOther"/>
						</fc2:OtherOrganizationSubTypeText>


					</fc2:OrganizationClassificationTypeSubtype>
				</xsl:when>			

				<!-- for other institution types -->
				<xsl:otherwise>
					<fc2:OrganizationClassificationTypeSubtype SeqNum=".">	
						<fc2:OrganizationTypeID>
							<xsl:call-template name="map">			
								<xsl:with-param name="source" select="'institutionTypeCode'"/>
								<xsl:with-param name="code" select="institutionTypeCode/."/>
							</xsl:call-template>						
						</fc2:OrganizationTypeID>
						<xsl:if test="institutionTypeCode='Z'">
							<fc2:OtherOrganizationTypeText>
								<xsl:value-of select="institutionTypeOther"/>
							</fc2:OtherOrganizationTypeText>
						</xsl:if>					
					</fc2:OrganizationClassificationTypeSubtype>
				</xsl:otherwise>	
			</xsl:choose>




			<xsl:if test="../relationships">
				<fc2:PartyAssociation SeqNum=".">
					<xsl:apply-templates select="../relationships/reportEntity/entityUiJSON"/>
				</fc2:PartyAssociation>
			</xsl:if>
		</fc2:Party>


	</xsl:template>
	<!-- Branch Where Activity Occurred Party 46 -->
	<xsl:template match="relationships/reportEntity/entityUiJSON">

		<fc2:Party SeqNum=".">
			<fc2:ActivityPartyTypeCode>46</fc2:ActivityPartyTypeCode>


			<xsl:if test="../../bridgeUiJSON/branchRoleCode='B'">
				<fc2:PayLocationIndicator>Y</fc2:PayLocationIndicator>
			</xsl:if>

			<xsl:if test="../../bridgeUiJSON/branchRoleCode='A'">
				<fc2:SellingLocationIndicator>Y</fc2:SellingLocationIndicator>
			</xsl:if>

			<xsl:if test="../../bridgeUiJSON/branchRoleCode='C'">
				<fc2:SellingPayingLocationIndicator>Y</fc2:SellingPayingLocationIndicator>
			</xsl:if> 

			<fc2:Address SeqNum=".">

				<fc2:RawCityText>
					<xsl:value-of select="branchCityName"/>
				</fc2:RawCityText>

				<fc2:RawCountryCodeText>
					<xsl:value-of select="branchCountryCode"/>
				</fc2:RawCountryCodeText>


				<fc2:RawStateCodeText>
					<xsl:value-of select="branchStateCode"/>
				</fc2:RawStateCodeText>

				<fc2:RawStreetAddress1Text>
					<xsl:value-of select="branchAddress"/>
				</fc2:RawStreetAddress1Text>

				<fc2:RawZIPCode>
					<xsl:value-of select="branchZipCode"/>
				</fc2:RawZIPCode> 
			</fc2:Address>

			<xsl:if test="branchRssdId !=''">
				<xsl:apply-templates select="branchRssdId"/> 
			</xsl:if>


		</fc2:Party>
	</xsl:template>
	<xsl:template match="subjects/entityUiJSON">
		<fc2:Party SeqNum=".">

			<fc2:ActivityPartyTypeCode>33</fc2:ActivityPartyTypeCode>

			<xsl:if test="not(corroborativeStatementFiler='true')">
				<fc2:AdmissionConfessionNoIndicator>Y</fc2:AdmissionConfessionNoIndicator>
			</xsl:if>
			<xsl:if test="corroborativeStatementFiler='true'">
				<fc2:AdmissionConfessionYesIndicator>Y</fc2:AdmissionConfessionYesIndicator>
			</xsl:if> 			
			<xsl:if test="subjectDetailsUnknownFlag='true'">
				<fc2:AllCriticalSubjectInformationUnavailableIndicator>Y</fc2:AllCriticalSubjectInformationUnavailableIndicator>
			</xsl:if> 			 
			<xsl:if test="birthDateUnknownFlag='true' and not((entityFlag='true') or (subjectDetailsUnknownFlag='true')) ">
				<fc2:BirthDateUnknownIndicator>Y</fc2:BirthDateUnknownIndicator>
			</xsl:if> 
			<xsl:if test="subjectRoleCode='C'">
				<fc2:BothPurchaserSenderPayeeReceiveIndicator>Y</fc2:BothPurchaserSenderPayeeReceiveIndicator>
			</xsl:if>	
			<xsl:if test="gender='B' and not(entityFlag='true')">
				<fc2:FemaleGenderIndicator>Y</fc2:FemaleGenderIndicator>
			</xsl:if>
			<xsl:if test="birthDate and not((entityFlag='true') or (subjectDetailsUnknownFlag='true'))">
				<fc2:IndividualBirthDateText>
					<xsl:call-template name="convertDate">
						<xsl:with-param name="inputDateTime" select="birthDate" />
					</xsl:call-template>					 
				</fc2:IndividualBirthDateText>				
			</xsl:if>		 
			<xsl:if test="gender='A' and not(entityFlag='true')">
				<fc2:MaleGenderIndicator>Y</fc2:MaleGenderIndicator>
			</xsl:if>
			<xsl:if test="noAccountFlag='true' or count(subjectAccount/accountID) = 0">
				<fc2:NoKnownAccountInvolvedIndicator>Y</fc2:NoKnownAccountInvolvedIndicator>
			</xsl:if>
			<xsl:if test="entityFlag='true'">
				<fc2:PartyAsEntityOrganizationIndicator>Y</fc2:PartyAsEntityOrganizationIndicator>
			</xsl:if>
			<xsl:if test="subjectRoleCode='B'">
				<fc2:PayeeReceiverIndicator>Y</fc2:PayeeReceiverIndicator>
			</xsl:if>
			<xsl:if test="subjectRoleCode='A'">
				<fc2:PurchaserSenderIndicator>Y</fc2:PurchaserSenderIndicator>
			</xsl:if>
			<xsl:if test="gender='C' and not(entityFlag='true')">
				<fc2:UnknownGenderIndicator>Y</fc2:UnknownGenderIndicator>
			</xsl:if>

			<xsl:if test="not(subjectDetailsUnknownFlag='true')">
				<fc2:PartyName SeqNum=".">

					<xsl:if test="lastNameUnknownFlag='true'">
						<fc2:EntityLastNameUnknownIndicator>Y</fc2:EntityLastNameUnknownIndicator>
					</xsl:if>
					<xsl:if test="not(entityFlag='true') and firstNameUnknownFlag='true'">						 
						<fc2:FirstNameUnknownIndicator>Y</fc2:FirstNameUnknownIndicator>
					</xsl:if>

					<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
					<xsl:if test="lastName !=''">
						<fc2:RawEntityIndividualLastName>
							<xsl:value-of select="lastName"/>
						</fc2:RawEntityIndividualLastName>
					</xsl:if>
					<xsl:if test="not(entityFlag='true')">
						<xsl:if test="firstName !=''">
							<fc2:RawIndividualFirstName>
								<xsl:value-of select="firstName"/>
							</fc2:RawIndividualFirstName>
						</xsl:if>
						<xsl:if test="middleName !=''">
							<fc2:RawIndividualMiddleName>
								<xsl:value-of select="middleName"/>
							</fc2:RawIndividualMiddleName>
						</xsl:if>
						<xsl:if test="suffix !=''">	 
							<fc2:RawIndividualNameSuffixText>
								<xsl:value-of select="suffix"/>
							</fc2:RawIndividualNameSuffixText>
						</xsl:if>	 
					</xsl:if>
				</fc2:PartyName>
			</xsl:if>

			<xsl:apply-templates select="subjectAlternateName"/>

			<xsl:if test="not(subjectDetailsUnknownFlag='true')">			
				<xsl:apply-templates select="subjectAddress"/>
			</xsl:if>

			<xsl:apply-templates select="subjectPhone"/> 

			<xsl:if test="not(subjectDetailsUnknownFlag='true')">
				<xsl:choose>
					<xsl:when test="noSubjectIDFlag ='true'">
						<fc2:PartyIdentification SeqNum=".">
							<fc2:IdentificationPresentUnknownIndicator>Y</fc2:IdentificationPresentUnknownIndicator>
						</fc2:PartyIdentification>	
					</xsl:when>	
					<xsl:otherwise>
						<xsl:apply-templates select="subjectID"/>
					</xsl:otherwise>		
				</xsl:choose>
			</xsl:if> 
			<xsl:if test="not(subjectDetailsUnknownFlag='true')">	
				<fc2:PartyIdentification SeqNum=".">					

					<xsl:if test="TaxID !=''">
						<fc2:PartyIdentificationNumberText>
							<xsl:value-of select="TaxID"/>
						</fc2:PartyIdentificationNumberText>
					</xsl:if>

					<xsl:if test="TaxIDType !=''">
						<fc2:PartyIdentificationTypeCode>
							<xsl:call-template name="map">			
								<xsl:with-param name="source" select="'TaxIDType'"/>
								<xsl:with-param name="code" select="TaxIDType/."/>
							</xsl:call-template>
						</fc2:PartyIdentificationTypeCode>
					</xsl:if>
					<xsl:if test="TaxIDUnknownFlag ='true'">

						<fc2:TINUnknownIndicator>Y</fc2:TINUnknownIndicator>
					</xsl:if>

				</fc2:PartyIdentification>
			</xsl:if> 


			<fc2:PartyOccupationBusiness SeqNum=".">
				<fc2:NAICSCode>
					<xsl:value-of select="NAICS"/>
				</fc2:NAICSCode>
				<fc2:OccupationBusinessText>
					<xsl:value-of select="occupation"/>
				</fc2:OccupationBusinessText>
			</fc2:PartyOccupationBusiness>

			<xsl:apply-templates select="subjectEmail"/> 

			<xsl:apply-templates select="subjectUrl"/> 

			<xsl:apply-templates select="../relationships/bridgeUiJSON"/>	

			<xsl:if test="count(subjectAccount/accountID) > 0">
				<fc2:PartyAccountAssociation SeqNum=".">
					<fc2:PartyAccountAssociationTypeCode>7</fc2:PartyAccountAssociationTypeCode>				
					<xsl:apply-templates select="subjectAccount"/>	
				</fc2:PartyAccountAssociation>	
			</xsl:if>			


		</fc2:Party>

	</xsl:template>  

	<xsl:template match="branchRssdId">
		<fc2:PartyIdentification SeqNum=".">
			<fc2:PartyIdentificationNumberText>
				<xsl:value-of select="."/>
			</fc2:PartyIdentificationNumberText>
			<fc2:PartyIdentificationTypeCode>14</fc2:PartyIdentificationTypeCode>
		</fc2:PartyIdentification>
	</xsl:template>


	<xsl:template match="subjectAddress">
		<xsl:if test="countryCode !='' or countryUnknownFlag ='true'">
			<fc2:Address SeqNum=".">
				<xsl:if test="cityUnknownFlag = 'true'">
					<fc2:CityUnknownIndicator>Y</fc2:CityUnknownIndicator>
				</xsl:if>
				<xsl:if test="countryUnknownFlag ='true'">
					<fc2:CountryCodeUnknownIndicator>Y</fc2:CountryCodeUnknownIndicator>
				</xsl:if>
				<xsl:if test="city !=''">
					<fc2:RawCityText>
						<xsl:value-of select="city"/>
					</fc2:RawCityText>
				</xsl:if>
				<xsl:if test="countryCode !=''">
					<fc2:RawCountryCodeText>
						<xsl:value-of select="countryCode"/>
					</fc2:RawCountryCodeText>
				</xsl:if>
				<xsl:if test="stateCode !=''">
					<fc2:RawStateCodeText>
						<xsl:value-of select="stateCode"/>
					</fc2:RawStateCodeText>
				</xsl:if>
				<xsl:if test="address !=''">
					<fc2:RawStreetAddress1Text>
						<xsl:value-of select="address"/>
					</fc2:RawStreetAddress1Text>
				</xsl:if>
				<xsl:if test="postalCode !=''">
					<fc2:RawZIPCode>
						<xsl:value-of select="postalCode"/>
					</fc2:RawZIPCode>
				</xsl:if>
				<xsl:if test="stateUnknownFlag = 'true'">
					<fc2:StateCodeUnknownIndicator>Y</fc2:StateCodeUnknownIndicator>
				</xsl:if>
				<xsl:if test="addressUnknownFlag = 'true'">
					<fc2:StreetAddressUnknownIndicator>Y</fc2:StreetAddressUnknownIndicator>
				</xsl:if>
				<xsl:if test="postalCodeUnknownFlag = 'true'">
					<fc2:ZIPCodeUnknownIndicator>Y</fc2:ZIPCodeUnknownIndicator>
				</xsl:if>				
			</fc2:Address>
		</xsl:if>
	</xsl:template>

	<xsl:template match="subjectPhone">
		<xsl:if test="phoneNumber !=''">
			<fc2:PhoneNumber SeqNum=".">
				<fc2:PhoneNumberExtensionText>
					<xsl:value-of select="phoneExtension"/>
				</fc2:PhoneNumberExtensionText>
				<fc2:PhoneNumberText>
					<xsl:value-of select="phoneNumber"/>
				</fc2:PhoneNumberText>
				<fc2:PhoneNumberTypeCode>								
					<xsl:call-template name="map">			
						<xsl:with-param name="source" select="'phoneTypeCode'"/>
						<xsl:with-param name="code" select="phoneTypeCode/."/>
					</xsl:call-template>		
				</fc2:PhoneNumberTypeCode>

			</fc2:PhoneNumber>
		</xsl:if>
	</xsl:template>

	<xsl:template match="subjectAlternateName">
		<xsl:if test="alternateName !=''">
			<fc2:PartyName SeqNum=".">
				<fc2:PartyNameTypeCode>AKA</fc2:PartyNameTypeCode>
				<fc2:RawPartyFullName>
					<xsl:value-of select="alternateName"/>
				</fc2:RawPartyFullName>
			</fc2:PartyName>
		</xsl:if>
	</xsl:template>

	<xsl:template match="subjectID">
		<!-- check for IDNumber only for non empty row -->
		<xsl:if test="IDNumber !=''">
			<fc2:PartyIdentification SeqNum=".">
				<fc2:OtherIssuerCountryText>
					<xsl:value-of select="IDAuthorityCountryCode"/>
				</fc2:OtherIssuerCountryText>
				<fc2:OtherIssuerStateText>
					<xsl:value-of select="IDAuthorityStateCode"/>
				</fc2:OtherIssuerStateText>	
				<fc2:OtherPartyIdentificationTypeText>
					<xsl:value-of select="IDTypeOther"/>
				</fc2:OtherPartyIdentificationTypeText>
				<fc2:PartyIdentificationNumberText>
					<xsl:value-of select="IDNumber"/>
				</fc2:PartyIdentificationNumberText>
				<fc2:PartyIdentificationTypeCode>
					<xsl:call-template name="map">			
						<xsl:with-param name="source" select="'IDType'"/>
						<xsl:with-param name="code" select="IDType/."/>
					</xsl:call-template>
				</fc2:PartyIdentificationTypeCode>
			</fc2:PartyIdentification>
		</xsl:if>
	</xsl:template>

	<xsl:template match="subjectEmail">
		<xsl:if test="emailAddress !=''">
			<fc2:ElectronicAddress SeqNum=".">
				<fc2:ElectronicAddressText>
					<xsl:value-of select="emailAddress"/>
				</fc2:ElectronicAddressText>
				<fc2:ElectronicAddressTypeCode>E</fc2:ElectronicAddressTypeCode>
			</fc2:ElectronicAddress>
		</xsl:if>

	</xsl:template> 

	<xsl:template match="subjectUrl">
		<xsl:if test="URLAddress !=''">
			<fc2:ElectronicAddress SeqNum=".">
				<fc2:ElectronicAddressText>
					<xsl:value-of select="URLAddress"/>
				</fc2:ElectronicAddressText>
				<fc2:ElectronicAddressTypeCode>U</fc2:ElectronicAddressTypeCode>
			</fc2:ElectronicAddress>
		</xsl:if>
	</xsl:template>

	<xsl:template match="relationships/bridgeUiJSON">

		<fc2:PartyAssociation SeqNum=".">
			<xsl:if test="subjectRelationTypeB='true'">	
				<fc2:AccountantIndicator>Y</fc2:AccountantIndicator>
			</xsl:if>
			<xsl:if test="statusDate != ''">	
				<fc2:ActionTakenDateText>
					<xsl:call-template name="convertDate">
						<xsl:with-param name="inputDateTime" select="statusDate" />
					</xsl:call-template>					 
				</fc2:ActionTakenDateText>
			</xsl:if>
			<xsl:if test="subjectRelationTypeC='true'">	
				<fc2:AgentIndicator>Y</fc2:AgentIndicator>
			</xsl:if>			
			<xsl:if test="subjectRelationTypeD='true'">	
				<fc2:AppraiserIndicator>Y</fc2:AppraiserIndicator>
			</xsl:if>
			<xsl:if test="subjectRelationTypeE='true'">	
				<fc2:AttorneyIndicator>Y</fc2:AttorneyIndicator>
			</xsl:if>
			<xsl:if test="subjectRelationTypeF='true'">	
				<fc2:BorrowerIndicator>Y</fc2:BorrowerIndicator>
			</xsl:if>
			<xsl:if test="subjectRelationTypeG='true'">	
				<fc2:CustomerIndicator>Y</fc2:CustomerIndicator>
			</xsl:if>
			<xsl:if test="subjectRelationTypeH='true'">	
				<fc2:DirectorIndicator>Y</fc2:DirectorIndicator>
			</xsl:if>
			<xsl:if test="subjectRelationTypeI='true'">	
				<fc2:EmployeeIndicator>Y</fc2:EmployeeIndicator>
			</xsl:if>
			<xsl:if test="subjectRelationTypeJ='true'">	
				<fc2:NoRelationshipToInstitutionIndicator>Y</fc2:NoRelationshipToInstitutionIndicator>
			</xsl:if>
			<xsl:if test="subjectRelationTypeK='true'">	
				<fc2:OfficerIndicator>Y</fc2:OfficerIndicator>
			</xsl:if>
			<xsl:if test="subjectRelationTypeZ='true'">	
				<fc2:OtherPartyAssociationTypeText>
					<xsl:value-of select="subjectRelationTypeOther"/>
				</fc2:OtherPartyAssociationTypeText>
			</xsl:if>
			<xsl:if test="subjectRelationTypeZ='true'">	
				<fc2:OtherRelationshipIndicator>Y</fc2:OtherRelationshipIndicator>
			</xsl:if>
			<xsl:if test="subjectRelationTypeL='true'">	
				<fc2:OwnerShareholderIndicator>Y</fc2:OwnerShareholderIndicator>
			</xsl:if>
			<xsl:if test="statusCode='A'">	
				<fc2:RelationshipContinuesIndicator>Y</fc2:RelationshipContinuesIndicator>
			</xsl:if>
			<xsl:if test="statusCode='D'">	
				<fc2:ResignedIndicator>Y</fc2:ResignedIndicator>
			</xsl:if>
			<xsl:if test="../reportEntity/entityUiJSON/institutionTaxId">	
				<fc2:SubjectRelationshipFinancialInstitutionTINText>
					<xsl:value-of select="../reportEntity/entityUiJSON/institutionTaxId"/>
				</fc2:SubjectRelationshipFinancialInstitutionTINText>
			</xsl:if>
			<xsl:if test="statusCode='C'">	
				<fc2:SuspendedBarredIndicator>Y</fc2:SuspendedBarredIndicator>
			</xsl:if>
			<xsl:if test="statusCode='B'">	
				<fc2:TerminatedIndicator>Y</fc2:TerminatedIndicator>
			</xsl:if>
		</fc2:PartyAssociation>
	</xsl:template> 

	<xsl:template match="subjectAccount">
		<xsl:if test="accountID !=''">
			<fc2:Party SeqNum=".">
				<fc2:ActivityPartyTypeCode>41</fc2:ActivityPartyTypeCode>
				<xsl:if test="accountInstitutionNonUSFlag='true'">	
					<fc2:NonUSFinancialInstitutionIndicator>Y</fc2:NonUSFinancialInstitutionIndicator>
				</xsl:if>
				<xsl:if test="accountInstitutionTaxID !=''">	
					<fc2:PartyIdentification SeqNum=".">
						<fc2:PartyIdentificationNumberText>
							<xsl:value-of select="accountInstitutionTaxID"/>
						</fc2:PartyIdentificationNumberText>
						<fc2:PartyIdentificationTypeCode>4</fc2:PartyIdentificationTypeCode>
					</fc2:PartyIdentification>
				</xsl:if>				 
				<fc2:Account SeqNum=".">
					<fc2:AccountNumberText>
						<xsl:value-of select="accountID"/>
					</fc2:AccountNumberText>
					<fc2:PartyAccountAssociation SeqNum=".">
						<xsl:if test="accountClosedFlag='true'">	
							<fc2:AccountClosedIndicator>Y</fc2:AccountClosedIndicator>
						</xsl:if>
						<fc2:PartyAccountAssociationTypeCode>5</fc2:PartyAccountAssociationTypeCode>
					</fc2:PartyAccountAssociation>
				</fc2:Account>				 			

			</fc2:Party>
		</xsl:if>
	</xsl:template>

	<xsl:template name="convertDate">
		<xsl:param name="inputDateTime" />
		<xsl:variable name="year">
			<xsl:value-of select="substring($inputDateTime,1,4)" />
		</xsl:variable>
		<xsl:variable name="month">
			<xsl:value-of select="substring($inputDateTime,6,2)" />
		</xsl:variable>
		<xsl:variable name="day">
			<xsl:value-of select="substring($inputDateTime,9,2)" />
		</xsl:variable>
		<xsl:value-of select="concat($year,$month,$day)" />
	</xsl:template>

	<xsl:template name="SARClassification">

		<xsl:param name="SARType" />
		<xsl:param name="SARTypeOther" />

		<xsl:if test="(.='true')">
			<xsl:variable name="code">
				<xsl:value-of select="substring(name(.), string-length(name(.)),1)" />
			</xsl:variable>		
			<fc2:SuspiciousActivityClassification SeqNum=".">
				<xsl:if test="$code='Z'">
					<fc2:OtherSuspiciousActivityTypeText>
						<xsl:value-of select='$SARTypeOther'/>
					</fc2:OtherSuspiciousActivityTypeText>
				</xsl:if>
				<fc2:SuspiciousActivitySubtypeID>
					<xsl:call-template name="map">			
						<xsl:with-param name="source" select='$SARType'/>
						<xsl:with-param name="code" select='$code'/>
					</xsl:call-template>
				</fc2:SuspiciousActivitySubtypeID>
				<fc2:SuspiciousActivityTypeID>
					<xsl:call-template name="map">			
						<xsl:with-param name="source" select='$SARType'/>
						<xsl:with-param name="code" select="'*'"/>
					</xsl:call-template>
				</fc2:SuspiciousActivityTypeID>
			</fc2:SuspiciousActivityClassification>
		</xsl:if>
	</xsl:template>

	<xsl:template name = "AssetClassification" >
		<xsl:param name = "AssetType" />
		<xsl:param name="AssetTypeOther"/>
		<xsl:if test="(.='true')">
			<xsl:variable name="code">
				<xsl:value-of select="substring(name(.), string-length(name(.)),1)" />
			</xsl:variable>		 
			<fc2:Assets SeqNum=".">
				<xsl:variable name="AssetTypeValue">
					<xsl:value-of select = "."/>
				</xsl:variable>
				<fc2:AssetSubtypeID>
					<xsl:call-template name="map">			
						<xsl:with-param name="source" select='$AssetType'/>
						<xsl:with-param name="code" select='$code'/>
					</xsl:call-template>
				</fc2:AssetSubtypeID>
				<fc2:AssetTypeID>
					<xsl:call-template name="map">			
						<xsl:with-param name="source" select='$AssetType'/>
						<xsl:with-param name="code" select="'*'"/>
					</xsl:call-template>
				</fc2:AssetTypeID>

				<xsl:if test="$code='Z'">
					<fc2:OtherAssetSubtypeText>						 
						<xsl:value-of select='$AssetTypeOther'/>						 
					</fc2:OtherAssetSubtypeText>
				</xsl:if>

			</fc2:Assets>
		</xsl:if>
	</xsl:template>


	<xsl:template name="map">
		<xsl:param name="source"/>
		<xsl:param name="code"/>
		<xsl:if test="($source='institutionSfTypeCode') and ($code='A')">535</xsl:if>
		<xsl:if test="($source='institutionSfTypeCode') and ($code='B')">534</xsl:if>
		<xsl:if test="($source='institutionSfTypeCode') and ($code='X')">541</xsl:if>
		<xsl:if test="($source='institutionSfTypeCode') and ($code='C')">508</xsl:if>
		<xsl:if test="($source='institutionSfTypeCode') and ($code='D')">504</xsl:if>
		<xsl:if test="($source='institutionSfTypeCode') and ($code='E')">513</xsl:if>
		<xsl:if test="($source='institutionSfTypeCode') and ($code='F')">540</xsl:if>
		<xsl:if test="($source='institutionSfTypeCode') and ($code='G')">514</xsl:if>
		<xsl:if test="($source='institutionSfTypeCode') and ($code='H')">539</xsl:if>
		<xsl:if test="($source='institutionSfTypeCode') and ($code='I')">533</xsl:if>
		<xsl:if test="($source='institutionSfTypeCode') and ($code='Y')">542</xsl:if>
		<xsl:if test="($source='institutionSfTypeCode') and ($code='J')">528</xsl:if>
		<xsl:if test="($source='institutionSfTypeCode') and ($code='K')">529</xsl:if>
		<xsl:if test="($source='institutionSfTypeCode') and ($code='L')">503</xsl:if>
		<xsl:if test="($source='institutionSfTypeCode') and ($code='Z')">5999</xsl:if>
		<xsl:if test="($source='institutionPrimFedRegCode') and ($code='A')">9</xsl:if>
		<xsl:if test="($source='institutionPrimFedRegCode') and ($code='B')">1</xsl:if>
		<xsl:if test="($source='institutionPrimFedRegCode') and ($code='C')">2</xsl:if>
		<xsl:if test="($source='institutionPrimFedRegCode') and ($code='D')">7</xsl:if>
		<xsl:if test="($source='institutionPrimFedRegCode') and ($code='E')">3</xsl:if>
		<xsl:if test="($source='institutionPrimFedRegCode') and ($code='F')">4</xsl:if>
		<xsl:if test="($source='institutionPrimFedRegCode') and ($code='G')">6</xsl:if>
		<xsl:if test="($source='institutionPrimFedRegCode') and ($code='H')">13</xsl:if>
		<xsl:if test="($source='institutionPrimFedRegCode') and ($code='Z')">99</xsl:if>
		<xsl:if test="($source='institutionTypeCode') and ($code='A')">1</xsl:if>
		<xsl:if test="($source='institutionTypeCode') and ($code='B')">2</xsl:if>
		<xsl:if test="($source='institutionTypeCode') and ($code='C')">3</xsl:if>
		<xsl:if test="($source='institutionTypeCode') and ($code='D')">4</xsl:if>
		<xsl:if test="($source='institutionTypeCode') and ($code='E')">5</xsl:if>
		<xsl:if test="($source='institutionTypeCode') and ($code='F')">11</xsl:if>
		<xsl:if test="($source='institutionTypeCode') and ($code='G')">12</xsl:if>
		<xsl:if test="($source='institutionTypeCode') and ($code='Z')">999</xsl:if>
		<xsl:if test="($source='institutionGamingTypeCode') and ($code='A')">101</xsl:if>
		<xsl:if test="($source='institutionGamingTypeCode') and ($code='B')">102</xsl:if>
		<xsl:if test="($source='institutionGamingTypeCode') and ($code='C')">103</xsl:if>
		<xsl:if test="($source='institutionGamingTypeCode') and ($code='Z')">1999</xsl:if>
		<xsl:if test="($source='institutionIdTypeCode') and ($code='A')">10</xsl:if>
		<xsl:if test="($source='institutionIdTypeCode') and ($code='B')">11</xsl:if>
		<xsl:if test="($source='institutionIdTypeCode') and ($code='C')">12</xsl:if>
		<xsl:if test="($source='institutionIdTypeCode') and ($code='D')">14</xsl:if>
		<xsl:if test="($source='institutionIdTypeCode') and ($code='E')">13</xsl:if>
		<xsl:if test="($source='institutionTaxIdType') and ($code='A')">2</xsl:if>
		<xsl:if test="($source='institutionTaxIdType') and ($code='B')">1</xsl:if>
		<xsl:if test="($source='institutionTaxIdType') and ($code='C')">9</xsl:if>		
		<xsl:if test="($source='SARStructuredType') and ($code='A')">111</xsl:if>
		<xsl:if test="($source='SARStructuredType') and ($code='B')">112</xsl:if>
		<xsl:if test="($source='SARStructuredType') and ($code='C')">106</xsl:if>
		<xsl:if test="($source='SARStructuredType') and ($code='D')">113</xsl:if>
		<xsl:if test="($source='SARStructuredType') and ($code='E')">114</xsl:if>
		<xsl:if test="($source='SARStructuredType') and ($code='Z')">1999</xsl:if>
		<xsl:if test="($source='SARTerroristType') and ($code='A')">701</xsl:if>
		<xsl:if test="($source='SARTerroristType') and ($code='Z')">7999</xsl:if>
		<xsl:if test="($source='SARFraudType') and ($code='A')">320</xsl:if>
		<xsl:if test="($source='SARFraudType') and ($code='B')">322</xsl:if>
		<xsl:if test="($source='SARFraudType') and ($code='C')">321</xsl:if>
		<xsl:if test="($source='SARFraudType') and ($code='D')">301</xsl:if>
		<xsl:if test="($source='SARFraudType') and ($code='E')">304</xsl:if>
		<xsl:if test="($source='SARFraudType') and ($code='F')">305</xsl:if>
		<xsl:if test="($source='SARFraudType') and ($code='G')">323</xsl:if>
		<xsl:if test="($source='SARFraudType') and ($code='H')">308</xsl:if>
		<xsl:if test="($source='SARFraudType') and ($code='I')">309</xsl:if>
		<xsl:if test="($source='SARFraudType') and ($code='J')">324</xsl:if>
		<xsl:if test="($source='SARFraudType') and ($code='K')">310</xsl:if>
		<xsl:if test="($source='SARFraudType') and ($code='L')">325</xsl:if>
		<xsl:if test="($source='SARFraudType') and ($code='M')">312</xsl:if>
		<xsl:if test="($source='SARFraudType') and ($code='Z')">3999</xsl:if>
		<xsl:if test="($source='SARCasinosType') and ($code='A')">1201</xsl:if>
		<xsl:if test="($source='SARCasinosType') and ($code='B')">1202</xsl:if>
		<xsl:if test="($source='SARCasinosType') and ($code='C')">1203</xsl:if>
		<xsl:if test="($source='SARCasinosType') and ($code='D')">1204</xsl:if>
		<xsl:if test="($source='SARCasinosType') and ($code='Z')">12999</xsl:if>
		<xsl:if test="($source='SARMoneyLaundryType') and ($code='A')">801</xsl:if>
		<xsl:if test="($source='SARMoneyLaundryType') and ($code='B')">824</xsl:if>
		<xsl:if test="($source='SARMoneyLaundryType') and ($code='C')">820</xsl:if>
		<xsl:if test="($source='SARMoneyLaundryType') and ($code='D')">821</xsl:if>
		<xsl:if test="($source='SARMoneyLaundryType') and ($code='E')">804</xsl:if>
		<xsl:if test="($source='SARMoneyLaundryType') and ($code='F')">805</xsl:if>
		<xsl:if test="($source='SARMoneyLaundryType') and ($code='G')">822</xsl:if>
		<xsl:if test="($source='SARMoneyLaundryType') and ($code='H')">806</xsl:if>
		<xsl:if test="($source='SARMoneyLaundryType') and ($code='I')">807</xsl:if>
		<xsl:if test="($source='SARMoneyLaundryType') and ($code='J')">808</xsl:if>
		<xsl:if test="($source='SARMoneyLaundryType') and ($code='K')">809</xsl:if>
		<xsl:if test="($source='SARMoneyLaundryType') and ($code='L')">823</xsl:if>
		<xsl:if test="($source='SARMoneyLaundryType') and ($code='M')">812</xsl:if>
		<xsl:if test="($source='SARMoneyLaundryType') and ($code='Z')">8999</xsl:if>
		<xsl:if test="($source='SARIDType') and ($code='A')">401</xsl:if>
		<xsl:if test="($source='SARIDType') and ($code='B')">402</xsl:if>
		<xsl:if test="($source='SARIDType') and ($code='C')">403</xsl:if>
		<xsl:if test="($source='SARIDType') and ($code='D')">409</xsl:if>
		<xsl:if test="($source='SARIDType') and ($code='E')">404</xsl:if>
		<xsl:if test="($source='SARIDType') and ($code='F')">405</xsl:if>
		<xsl:if test="($source='SARIDType') and ($code='Z')">4999</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='A')">920</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='B')">901</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='C')">917</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='D')">921</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='E')">903</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='F')">904</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='G')">926</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='H')">927</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='I')">905</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='J')">922</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='K')">924</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='L')">907</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='M')">908</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='N')">909</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='O')">910</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='P')">925</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='Q')">928</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='R')">911</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='S')">913</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='Z')">9999</xsl:if>
		<xsl:if test="($source='SARInsuranceType') and ($code='A')">501</xsl:if>
		<xsl:if test="($source='SARInsuranceType') and ($code='B')">502</xsl:if>
		<xsl:if test="($source='SARInsuranceType') and ($code='C')">504</xsl:if>
		<xsl:if test="($source='SARInsuranceType') and ($code='D')">505</xsl:if>
		<xsl:if test="($source='SARInsuranceType') and ($code='E')">506</xsl:if>
		<xsl:if test="($source='SARInsuranceType') and ($code='F')">507</xsl:if>
		<xsl:if test="($source='SARInsuranceType') and ($code='Z')">5999</xsl:if>
		<xsl:if test="($source='SARSFType') and ($code='A')">601</xsl:if>
		<xsl:if test="($source='SARSFType') and ($code='B')">608</xsl:if>
		<xsl:if test="($source='SARSFType') and ($code='C')">603</xsl:if>
		<xsl:if test="($source='SARSFType') and ($code='D')">604</xsl:if>
		<xsl:if test="($source='SARSFType') and ($code='E')">609</xsl:if>
		<xsl:if test="($source='SARSFType') and ($code='Z')">6999</xsl:if>
		<xsl:if test="($source='SARMortgageFraudType') and ($code='A')">1005</xsl:if>
		<xsl:if test="($source='SARMortgageFraudType') and ($code='B')">1001</xsl:if>
		<xsl:if test="($source='SARMortgageFraudType') and ($code='C')">1006</xsl:if>
		<xsl:if test="($source='SARMortgageFraudType') and ($code='D')">1003</xsl:if>
		<xsl:if test="($source='SARMortgageFraudType') and ($code='E')">1007</xsl:if>
		<xsl:if test="($source='SARMortgageFraudType') and ($code='Z')">10999</xsl:if>
		<xsl:if test="($source='SARCyberType') and ($code='A')">1101</xsl:if>
		<xsl:if test="($source='SARCyberType') and ($code='B')">1102</xsl:if>
		<xsl:if test="($source='SARCyberType') and ($code='Z')">11999</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='A')">2</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='B')">3</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='C')">4</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='D')">5</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='E')">6</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='F')">46</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='G')">7</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='H')">8</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='I')">9</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='J')">11</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='K')">10</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='L')">12</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='M')">47</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='N')">13</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='O')">14</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='P')">16</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='Q')">17</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='R')">18</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='S')">19</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='T')">20</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='Z')">30</xsl:if>
		<xsl:if test="($source='SARInstrumentType') and ($code='A')">31</xsl:if>
		<xsl:if test="($source='SARInstrumentType') and ($code='B')">32</xsl:if>
		<xsl:if test="($source='SARInstrumentType') and ($code='C')">33</xsl:if>
		<xsl:if test="($source='SARInstrumentType') and ($code='D')">34</xsl:if>
		<xsl:if test="($source='SARInstrumentType') and ($code='E')">35</xsl:if>
		<xsl:if test="($source='SARInstrumentType') and ($code='F')">36</xsl:if>
		<xsl:if test="($source='SARInstrumentType') and ($code='G')">37</xsl:if>
		<xsl:if test="($source='SARInstrumentType') and ($code='H')">38</xsl:if>
		<xsl:if test="($source='SARInstrumentType') and ($code='I')">39</xsl:if>
		<xsl:if test="($source='SARInstrumentType') and ($code='Z')">41</xsl:if>
		<xsl:if test="($source='phoneTypeCode') and ($code='A')">R</xsl:if>
		<xsl:if test="($source='phoneTypeCode') and ($code='B')">W</xsl:if>
		<xsl:if test="($source='phoneTypeCode') and ($code='C')">M</xsl:if>
		<xsl:if test="($source='phoneTypeCode') and ($code='D')">F</xsl:if>	 
		<xsl:if test="($source='IDType') and ($code='A')">5</xsl:if>
		<xsl:if test="($source='IDType') and ($code='B')">6</xsl:if>
		<xsl:if test="($source='IDType') and ($code='C')">7</xsl:if>
		<xsl:if test="($source='IDType') and ($code='Z')">999</xsl:if>
		<xsl:if test="($source='TaxIDType') and ($code='A')">2</xsl:if>
		<xsl:if test="($source='TaxIDType') and ($code='B')">1</xsl:if>
		<xsl:if test="($source='TaxIDType') and ($code='C')">9</xsl:if>
		<xsl:if test="($source='SARStructuredType') and ($code='*')">1</xsl:if>
		<xsl:if test="($source='SARTerroristType') and ($code='*')">7</xsl:if>
		<xsl:if test="($source='SARFraudType') and ($code='*')">3</xsl:if>
		<xsl:if test="($source='SARCasinosType') and ($code='*')">12</xsl:if>
		<xsl:if test="($source='SARMoneyLaundryType') and ($code='*')">8</xsl:if>
		<xsl:if test="($source='SARIDType') and ($code='*')">4</xsl:if>
		<xsl:if test="($source='SAROtherType') and ($code='*')">9</xsl:if>
		<xsl:if test="($source='SARInsuranceType') and ($code='*')">5</xsl:if>
		<xsl:if test="($source='SARSFType') and ($code='*')">6</xsl:if>
		<xsl:if test="($source='SARMortgageFraudType') and ($code='*')">10</xsl:if>
		<xsl:if test="($source='SARCyberType') and ($code='*')">11</xsl:if>
		<xsl:if test="($source='SARProductType') and ($code='*')">5</xsl:if>
		<xsl:if test="($source='SARInstrumentType') and ($code='*')">6</xsl:if>
		<xsl:if test="($source='commodity') and ($code='*')">2</xsl:if>
		<xsl:if test="($source='product') and ($code='*')">3</xsl:if>
		<xsl:if test="($source='MIC') and ($code='*')">4</xsl:if>
		<xsl:if test="($source='CUSIP') and ($code='*')">1</xsl:if>
	</xsl:template>
</xsl:stylesheet>
