/*------------------------------------------------------------------------------
 *    NAME: cdd_main_process.sas
 *   TITLE: SAS Customer Due Diligence Main Process
 * PRODUCT: SAS Customer Due Diligence
 *  SYSTEM: UNIX/Windows
 * Note: called by cdd_main_process_job.sas
 *       This is the main process to include the steps needed for CDD scoring 
 *       Job log will be saved to JOB_STAT.JOB_STATISTICS
 *------------------------------------------------------------------------------*/

/*-------------------------------------------------------------------
 * Copyright (c) 2013-2014 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

/*-------------------------------------------------------------------
 *      Host and Site specific customizations may be REQUIRED
 *-------------------------------------------------------------------*/

%macro cdd_main_process;
  /*-----------------------------------------------
   * Generate SAS code required for CDD process
   *----------------------------------------------*/
  %cdd_section_header(Section=CDD_CODEGEN);
      %global cdd_sm_codegen_path prop_status;
      %let prop_status=0;
      %let cdd_sm_codegen_path = !CDDROOT/rule/codegen;
      %fcf_get_property_value(property=fcf.svr.cdd.codegenPath, output_property_value=cdd_sm_codegen_path, output_status=prop_status);
      %if &prop_status ne 0 %then %do;
        %let cdd_sm_codegen_path = !CDDROOT/rule/codegen;
        %put WARNING: Codegen path not found in preferences. Using default value &cdd_sm_codegen_path.;
      %end;

      %let cdd_gen_success_flg=0;
      %cdd_generate_rules(     codegen_path=&cdd_sm_codegen_path,
                               outlib=work,
                               gen_type=KC,
                               cdd_gen_success_flg_mvar=cdd_gen_success_flg);
     %if &cdd_gen_success_flg = 0 %then %do;
        %goto MACRO_END;
     %end;
  %cdd_section_footer(Section=CDD_CODEGEN);


  /*------------------------------------------------------------------------------
   * Get last as of date and the new as of date 
   * Global macro variables CDD_LAST_ASOFDTTM and CDD_RUN_ASOFDTTM will be created 
   *------------------------------------------------------------------------------*/
  %if not %symexist(CDD_SKIP_ASOFDTTM) %then %let CDD_SKIP_ASOFDTTM=N;
  %if (&CDD_SKIP_ASOFDTTM eq Y) %then %do;
        %goto CDD_PREP_SECTION;
  %end;
  %cdd_section_header(Section=CDD_ASOFDTTM);
     /* if a specific cdd run as of date time is needed, use   */
     /* %cdd_asofdttm(action=NEW,runosfdttm=<desired datetime> */
     %cdd_asofdttm(action=NEW);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %goto MACRO_END;
     %end;
  
  %cdd_section_footer(Section=CDD_ASOFDTTM);

  %CDD_PREP_SECTION:
  /*-----------------------------------------------
   * Create data files for CDD scoring in CM_PREP
   *----------------------------------------------*/
  %cdd_section_header(Section=CDD_PREP);
     %let cdd_prep_success_flg=0;
     %cdd_prep(cdd_prep_success_flg_mvar=cdd_prep_success_flg);
     %if &cdd_prep_success_flg=0 %then %do;
        %goto MACRO_END;
     %end;
  %cdd_section_footer(Section=CDD_PREP);

  %let entity_obs_count=%fcf_get_observation_count(table=cjobstat.cddds_entity_list, nonotes=Y, sasdataset=Y);
   
  %if &entity_obs_count> 0 %then %do;
      /*-----------------------------------------
       * CDD Customer Risk Ranking Process (CRR)
       *----------------------------------------*/
      %cdd_section_header(Section=CDD_CRR);
        /*----------------------------------
        * Make the UI unavailable to users
        *----------------------------------*/
        %fcf_set_ui_availability(availability_ind=N);

        %let cdd_crr_success_flg=0;
        %cdd_crr_driver(cdd_crr_success_flg_mvar=cdd_crr_success_flg);

        /*--------------------------------
        * Make the UI available to users
        *--------------------------------*/
        %fcf_set_ui_availability(availability_ind=Y);

        %if &cdd_crr_success_flg=0 %then %do;
            %goto MACRO_END;
        %end;
      %cdd_section_footer(Section=CDD_CRR);
  %end;

   /*-------------------------------------------------------------
    * Flag run as of date as used
    * It will be used for the next scoring as cdd_last_asofdttm
   *-------------------------------------------------------------*/
    %cdd_section_header(Section=CDD_ASOFDTTM);
  
     %cdd_asofdttm(action=FLAG);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %goto MACRO_END;
     %end;
  
  %cdd_section_footer(Section=CDD_ASOFDTTM);

  %MACRO_END:

   %fcf_set_ui_availability(availability_ind=Y);

   %if &trans_rc eq 3 or &trans_rc ge 5 %then
      %cdd_error;
   %else %do;
      %cdd_success;
   %end;

%mend cdd_main_process;


