/*==============================================================================
|                               SAS SAMPLE FILE
|
| NAME:    closed_loans_prep.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================

PREP FILE DESCRIPTION
---------------------
Creates closed_loans prep data set

PREP FILE NOTES
---------------
1. The required values for ROLE_KEY and ROLE_DESC in the
FSC_PARTY_ACCOUNT_BRIDGE are as follows:

ROLE_KEY-'ROLE_DESC'
====================
1-'PRIMARY OWNER'
2-'SECONDARY OWNER'
3-'SIGNER'
4-'BENEFICIARY'
5-'INSURED'
6-'BORROWER'
7-'CO-BORROWER'

PREP DATA SET(S) CREATED
------------------------
MST_PREP.CLOSED_LOANS

PREP DATA SET(S) SORT ORDER
----------------------------

| Data Set                         Field                           Sort Order
|--------------------------------|-------------------------------|--------------
|CLOSED_LOANS                    |PARTY_NUMBER                   |1
|CLOSED_LOANS                    |ACCOUNT_CLOSE_DATE             |2

PREP DATA SET(S) VOLUME
-----------------------
1. All loans closed in the past year.

PREP DATA SET(S) NOTES
----------------------
None

================================================================================
SCENARIO(S) SUPPORTED:

- SAS10083
==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2014 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

 proc sql;
   create table mst_prep.closed_loans as

    select a.account_number,
           datepart(a.account_close_date) as account_close_date,
           datepart(a.account_open_date) as account_open_date,
           datepart(a.maturity_date) as maturity_date,
           a.original_loan_amount,
           a.product_name,
           a.product_type_name,
           b.party_number,
           b.entity_segment_id,
           c.role_desc
      from seg_kc.fsc_account_dim a,
           seg_kc.fsc_party_dim b,
           seg_kc.fsc_party_account_bridge c,
           seg_kc.fsc_account_event_fact d,
           seg_kc.fsc_transaction_type_dim e
     where a.account_key = c.account_key
       and d.account_key = a.account_key
       and b.party_key = c.party_key
       and d.transaction_type_key = e.transaction_type_key
       and e.primary_medium_desc = 'ACCOUNT CLOSE'
       and c.role_key in (6,7)
       and c.change_current_ind = 'Y'
       and d.date_key <= &runasofdate
     order by party_number,
              account_close_date;
 quit;
