/*==============================================================================
|                               SAS SAMPLE FILE
|
| NAME:    insurance_transactions_prep.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================


PREP FILE DESCRIPTION
---------------------
Creates party/account insurance_transactions prep data sets


PREP FILE NOTES
---------------
1. This code converts date_key from an integer value in yyyymmdd format to a SAS
date value. The converted value of date_key is then output to the prep data set
as required by dependent scenario(s).

The value of date_key is not converted from an integer value in yyyymmdd format
as used in the where clause(s), as this value is compared to runasofdate which
is also an integer value in yyyymmdd format.


PREP DATA SET(S) CREATED
------------------------
MST_PREP.INS_PARTY_TRANSACTIONS
MST_PREP.INS_ACCOUNT_TRANSACTIONS


PREP DATA SET(S) SORT ORDER
----------------------------

| Data Set                         Field                           Sort Order
|--------------------------------|-------------------------------|--------------
|INS_ACCOUNT_TRANSACTIONS        |ACCOUNT_NUMBER                 |1
|INS_ACCOUNT_TRANSACTIONS        |DATE_KEY                       |2
|INS_PARTY_TRANSACTIONS          |PARTY_NUMBER                   |1
|INS_PARTY_TRANSACTIONS          |DATE_KEY                       |2


PREP DATA SET(S) VOLUME
-----------------------
1. Contingent on the maximum scenario duration of the scenarios registered to
this prep data set.


PREP DATA SET(S) NOTES
----------------------
None


================================================================================
SCENARIO(S) SUPPORTED:

- SAS10049
- SAS10050
- SAS10052
- SAS10056
- SAS10064
==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2013 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

   proc sql;

      create table ins_acct_trans as

      select
         a.account_number,
         a.account_open_date,
         a.account_type_desc,
         b.currency_amount,
         b.date_key,
         b.third_party_ind,
         b.transaction_key,
         c.party_number,
         a.entity_segment_id as acc_entity_segment_id,
         c.entity_segment_id as pty_entity_segment_id,
         e.mechanism_desc,
         e.primary_medium_desc,
         e.secondary_medium_desc,
         e.transaction_cdi_code

      from
         seg_kc.fsc_account_dim as a,
         seg_kc.fsc_cash_flow_fact as b,
         seg_kc.fsc_party_dim as c,
         seg_kc.fsc_party_account_bridge as d,
         seg_kc.fsc_transaction_type_dim as e

      where
         a.account_key = d.account_key and
         b.account_key = a.account_key and
         b.date_key <= &runasofdate and
         b.transaction_type_key = e.transaction_type_key and
         c.party_key = d.party_key and
         d.role_key = 1 and
         d.change_current_ind = 'Y'

      union all

      select
         a.account_number,
         a.account_open_date,
         a.account_type_desc,
         0 as currency_amount,
         b.date_key,
         ' ' as third_party_ind,
         b.transaction_key,
         c.party_number,
         a.entity_segment_id as acc_entity_segment_id,
         c.entity_segment_id as pty_entity_segment_id,
         e.mechanism_desc,
         e.primary_medium_desc,
         e.secondary_medium_desc,
         e.transaction_cdi_code

      from
         seg_kc.fsc_account_dim as a,
         seg_kc.fsc_account_event_fact as b,
         seg_kc.fsc_party_dim as c,
         seg_kc.fsc_party_account_bridge as d,
         seg_kc.fsc_transaction_type_dim as e

      where
         a.account_key = d.account_key and
         b.account_key = a.account_key and
         b.date_key <= &runasofdate and
         b.transaction_type_key = e.transaction_type_key and
         c.party_key = d.party_key and
         d.role_key = 1 and
         d.change_current_ind   = 'Y';

   quit;

   data ins_acct_trans;
      set ins_acct_trans;
      date_key=input(put(date_key,8.),yymmdd8.);
   run;

  /* INS_ACCOUNT_TRANSACTIONS */
   proc sort data=ins_acct_trans
       out = mst_prep.ins_account_transactions (rename=(acc_entity_segment_id=entity_segment_id)
                                                drop=party_number
                                                     mechanism_desc
                                                     third_party_ind
                                                     pty_entity_segment_id);
       by account_number date_key;
   run;

  /* INS_PARTY_TRANSACTIONS */
   proc sort data=ins_acct_trans
       out = mst_prep.ins_party_transactions(rename=(pty_entity_segment_id=entity_segment_id)
                                               drop=account_open_date
                                                    acc_entity_segment_id);
       by party_number date_key;
   run;
