/*==============================================================================
|                               SAS SAMPLE FILE
|
| NAME:    profile_analysis.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================


SAMPLE FILE DESCRIPTION
-----------------------
Creates stg_dim.fsc_account_analysis_stage data set as a prequel to loading
fsc_account_analysis_dim.


SAMPLE FILE NOTES
-----------------
1. This code creates the staging table stg_dim.fsc_account_analysis_stage which
primarily contains derived values to be loaded into fsc_account_analysis_dim.
Please refer to the additional documentation on the meaning and possible
modifications for these values.  Additionaly, this code can be run to analyze
only one month's data or N months data.  Both query configurations are included.


SAMPLE DATA SET(S) CREATED
--------------------------
STG_DIM.FSC_ACCOUNT_ANALYSIS_STAGE


SAMPLE DATA SET(S) SORT ORDER
-----------------------------

| Data Set                         Field                           Sort Order
|--------------------------------|-------------------------------|--------------
|FSC_ACCOUNT_ANALYSIS_STAGE      |ACCOUNT_NUMBER                 |1


SAMPLE DATA SET(S) VOLUME
-------------------------
Contingent on the maximum scenario duration of the scenarios registered to this
prep data set.


SAMPLE DATA SET(S) NOTES
------------------------
None


================================================================================
| SCENARIO(S) SUPPORTED:
|
| SAS10086 - Deposits in Excess of Expectations
| SAS10087 - Withdrawals in Excess of Expectations
| SAS10088 - Deposit Count in Excess of Expectations
| SAS10089 - Withdrawal Count in Excess of Expectations
| SAS10090 - Increased Account Activity
| SAS10091 - Unexpected High Velocity Funds
================================================================================


==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

/*
   Use proc sql to move account_profile into SAS. If you are not using all
   rows of the profile table, you should limit the rows here.
*/


/*
   This sql statement will only retrieve observations where the month
   key matches the current month
*/

/*
   proc sql noprint;
      select put(max( month_key ),best6.) into: curr_month
      from seg_kc.fsc_account_profile_fact;
      create table apt as
      select account_number, total_credits_amount, total_debits_amount,
      deposits_count, withdrawals_count, largest_credit_amount,
      largest_debit_amount,
      intnx('MONTH', input("&curr_month",YYMMN6.), 0, 'E') as last_activity_date
      from seg_kc.fsc_account_profile_fact
      where account_number in
      ( select account_number
        from seg_kc.fsc_account_profile_fact
        where month_key = &curr_month )
        order by account_number;
   quit;
*/

/*
  This query will retrieve observations where the distinct count of months is
  greater than or equal to 3.
*/

   proc sql noprint;
      select put(max( month_key ),best6.) into: curr_month
      from seg_kc.fsc_account_profile_fact;
      create table apt as
      select month_key, account_number, total_credits_amount, total_debits_amount,
      deposits_count, withdrawals_count, largest_credit_amount,
      largest_debit_amount,
      intnx('MONTH', input("&curr_month",YYMMN6.), 0, 'E') as last_activity_date
      from seg_kc.fsc_account_profile_fact
      where account_number in
      ( select account_number from seg_kc.fsc_account_profile_fact
        group by account_number having count( distinct month_key ) >= 3
       )
      order by account_number, month_key;
   quit;


data stg_dim.fsc_account_analysis_stage (keep = account_number
                                         expected_incoming_amount
                                         expected_outgoing_amount
                                         expected_incoming_count
                                         expected_outgoing_count
                                         increased_behavior_credit_amt
                                         increased_behavior_debit_amt
                                         increased_behavior_credit_cnt
                                         increased_behavior_debit_cnt
                                         expected_credit_ceiling_amount
                                         expected_debit_ceiling_amount
                                         last_activity_date);
   set apt; by account_number;

   format last_activity_date NLDATM.;

   last_activity_date = dhms(last_activity_date,11,59,59);


   if first.account_number then do;
      agg1 = total_credits_amount;
      max1 = total_credits_amount;
      next1 = 0;
      agg2 = total_debits_amount;
      max2 = total_debits_amount;
      next2 = 0;
      agg3 = deposits_count;
      max3 = deposits_count;
      next3 = 0;
      agg4 = withdrawals_count;
      max4 = withdrawals_count;
      next4 = 0;
      max5 = largest_credit_amount;
      next5 = 0;
      max6 = largest_debit_amount;
      next6 = 0;
      month_count = 1;
   end;
   else do;
      agg1 = agg1 + total_credits_amount;
      if total_credits_amount > max1 then do;
         next1 = max1;
         max1 = total_credits_amount;
      end;
      else if total_credits_amount > next1 then next1 = total_credits_amount;
      agg2 = agg2 + total_debits_amount;
      if total_debits_amount > max2 then do;
         next2 = max2;
         max2 = total_debits_amount;
      end;
      else if total_debits_amount > next2 then next2 = total_debits_amount;
      agg3 = agg3 + deposits_count;
      if deposits_count > max3 then do;
         next3 = max3;
         max3 = deposits_count;
      end;
      else if deposits_count > next3 then next3 = deposits_count;
      agg4 = agg4 + withdrawals_count;
      if withdrawals_count > max4 then do;
         next4 = max4;
         max4 = withdrawals_count;
      end;
      else if withdrawals_count > next4 then next4 = withdrawals_count;
      if largest_credit_amount > max5 then do;
         next5 = max5;
         max5 = largest_credit_amount;
      end;
      else if largest_credit_amount > next5 then next5 = largest_credit_amount;
      if largest_debit_amount > max6 then do;
         next6 = max6;
         max6 = largest_debit_amount;
      end;
      else if largest_debit_amount > next6 then next6 = largest_debit_amount;
      month_count + 1;
   end;
   if last.account_number then do;
      recent1 = total_credits_amount;
      recent2 = total_debits_amount;
      recent3 = deposits_count;
      recent4 = withdrawals_count;
      avg1 = agg1/month_count;
      avg2 = agg2/month_count;
      avg3 = agg3/month_count;
      avg4 = agg4/month_count;
      expected_incoming_amount = (avg1 + next1)/2;
      expected_outgoing_amount = (avg2 + next2)/2;
      expected_incoming_count = (avg3 + next3)/2;
      expected_outgoing_count = (avg4 + next4)/2;
      expected_credit_ceiling_amount = next5;
      expected_debit_ceiling_amount = next6;
      if recent1 = max1 and recent1 >= 1.5 * avg1 then
         increased_behavior_credit_amt = max(1.5 * avg1,next1);
      else increased_behavior_credit_amt = 0;
      if recent2 = max2 and recent2 >= 1.5 * avg2 then
         increased_behavior_debit_amt = max(1.5 * avg2,next2);
      else increased_behavior_debit_amt = 0;
      if recent3 = max3 and recent3 >= 1.5 * avg3 then
         increased_behavior_credit_cnt = max(1.5 * avg3,next3);
      else increased_behavior_credit_cnt = 0;
      if recent4 = max4 and recent4 >= 1.5 * avg4 then
         increased_behavior_debit_cnt = max(1.5 * avg4,next4);
      else increased_behavior_debit_cnt = 0;
      output;
   end;
   retain _ALL_;
run;
