/*==============================================================================
|                               SAS SAMPLE FILE
|
| NAME:    cdd_prep_country_risk.sas
| PRODUCT: SAS Customer Due Diligence
| SYSTEM:  UNIX/WINDOWS
================================================================================
+------------------------------------------------------------------------------+
| COMMENTS:
|   INPUTS:
|      RELATIONSHIP_TYPE_CODE= list of PARTY_ASSOC.RELATIONSHIP_TYPE_CODE 
|                             to be included in the country prep file when
|                             deriving the country of residence.
|                             If the parameter is blank, PARTY_ASSOC will not be used  
+------------------------------------------------------------------------------+

PREP FILE DESCRIPTION
---------------------
Creates country_risk_prep data set


PREP FILE NOTES
---------------
None


PREP DATA SET(S) CREATED
------------------------
CM_PREP.CDDDS_COUNTRY_RISK_PREP


PREP DATA SET(S) SORT ORDER
----------------------------

| Data Set                         Field                           Sort Order
|--------------------------------|-------------------------------|--------------
|CDDDS_COUNTRY_RISK_PREP         |PRIMARY_ENTITY_NUMBER          |1
|                                |ATTRIBUTE_CODE                 |2
|                                |ATTRIBUTE_CHAR_VALUE           |3
|                                |PRIMARY_ENTITY_KEY             |4 
Sort by PRIMARY_ENTITY_KEY is added in case the same PRIMARY_ENTITY_NUMBER has different PRIMARY_ENTITY_KEY. This is to ensure that
when joining the multiple attribute score tables in the CRR process with have the most recent 
PARTY_KEY



PREP DATA SET(S) VOLUME
-----------------------
1. One to many ATTRIBUTE_CODE per PARTY_KEY


PREP DATA SET(S) NOTES
----------------------
1. 3 character Country codes should be used in the SEG_KC database
2. $CNTRY_SCORE and $SANCTION_CNTRY formats are created by %cdd_prep_lookup_fmt.
3. Source data to support ATTRIBUTE_CODE:
4. RESIDENT: FSC_PARTY_DIM.RESIDENT_COUNTRY_CODE              
5. CITIZENSHIP: FSC_PARTY_DIM.RESIDENT_COUNTRY_CODE
6. REGISTRATION: FSC_PARTY_DIM.ORG_COUNTRY_OF_BUSINESS_CODE
7. MAILING: FSC_PARTY_DIM.MAILING_COUNTRY_CODE
8. STREET: FSC_PARTY_DIM.STREET_COUNTRY_CODE
9. <FSC_ADDRESS_DIM.ADDRESS_TYPE_CODE>: FSC_ADDRESS_DIM.COUNTRY_CODE 
10. <FSC_PARTY_ASSOC.RELATED_ATTRIBUTE_TYPE_CODE>_RESIDENT (e.g. BENE_OWNER_RESIDENT or DIERCTOR_RESIDENT): 
    FSC_PARTY_DIM.RESIDENT_COUNTRY_CODE of FSC_PARTY_ASSOC.RELATED_PARTY_NUMBER
   


================================================================================
RULE(S) SUPPORTED:


==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2013-2018 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/


%macro cdd_prep_country_risk(relationship_type_code_list='BENE_OWNER' 'DIRECTOR' 'UBO' 'CNTR'
                             );

  /*------------------------------------------
   * Set error code to 0 and message to blank
   *------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;

  /* If relationship_type_code is blank, initialize it to  ' ' */
  %if %nrbquote(&relationship_type_code_list)=%nrbquote() %then %let relationship_type_code_list='';

/*******************************************************/
/* Attributes are pulled based on party number         */
/* not primary_entity_key to support identical parties */
/*******************************************************/
 
proc sql noprint;
    create table country_party_dim as
    select 
            a.primary_entity_number
           ,a.party_type_desc
           ,a.party_number  
           ,b.residence_country_code
           ,b.citizenship_country_code
           ,b.org_country_of_business_code
           ,b.street_country_code 
           ,b.mailing_country_code 
    from cjobstat.cddds_entity_list as a
    left join seg_kc.fsc_party_dim as b
    on a.party_number=b.party_number 
       and b.change_current_ind='Y'
    order by primary_entity_number
;

    create table cddds_country_1 as
    select distinct
            a.primary_entity_number
           ,a.party_type_desc
           ,a.party_number
           ,b.address_type_code as ATTRIBUTE_CODE 'Attribute Code' length=32
           ,b.country_code
    from cjobstat.cddds_entity_list as a
    left join seg_kc.fsc_address_dim as b
    on a.party_number=b.primary_entity_number
       and a.primary_entity_level_code=b.primary_entity_level_code
       and b.change_current_ind='Y'
    order by primary_entity_number
;

   %fcf_rcset(&syserr)
         %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=%sysfunc(sasmsg(sashelp.cddmsg,CDD_CRR_MACRO_ABORT,NOQUOTE,&sysmacroname))  ;
              %fcf_put_error;
              %goto MACRO_END;
        %end;  

/* Create country attribute prep file from FSC_PARTY_ASSOC */

     create table cddds_related_party as
     select   distinct
              strip(a.relationship_type_code)||'_'||'RESIDENCE' as ATTRIBUTE_CODE
            , a.related_attribute_type_code
            , a.related_attribute_num_value
            , a.related_attribute_char_value
            , a.related_attribute_date_value
            , a.party_number as RELATED_PARTY_NUMBER
            , b.primary_entity_key
            , b.primary_entity_number
            , b.party_number
            , b.party_type_desc
            , c.residence_country_code as COUNTRY_CODE 'COUNTRY_CODE'
     from (select distinct
                  x.*,
                  y.attribute_type_code as RELATED_ATTRIBUTE_TYPE_CODE 'RELATED ATTRIBUTE_TYPE_CODE',
                  y.attribute_num_value as RELATED_ATTRIBUTE_NUM_VALUE 'RELATED_ATTRIBUTE_NUM_VALUE',
                  y.attribute_num_value as RELATED_ATTRIBUTE_DATE_VALUE 'RELATED_ATTRIBUTE_DATE_VALUE',
                  y.attribute_char_value as RELATED_ATTRIBUTE_CHAR_VALUE 'RELATED_ATTRIBUTE_CHAR_VALUE'
          from seg_kc.fsc_party_assoc 
               (where=(relationship_type_code in  (&relationship_type_code_list) 
                       and change_current_ind='Y')
                ) 
                as x
          left join seg_kc.fsc_party_assoc_attribute as y
          on         
                 y.change_current_ind='Y'
             and x.party_number=y.party_number
             and x.related_party_number=y.related_party_number
             and x.relationship_type_code=y.relationship_type_code
          ) as a,
          cjobstat.cddds_entity_list as b,
          seg_kc.fsc_party_dim as c
     where               
               c.change_current_ind='Y'
           and a.related_party_number=b.party_number
           and a.related_party_number=c.party_number

     ;
quit;
   %fcf_rcset(&syserr)
         %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=%sysfunc(sasmsg(sashelp.cddmsg,CDD_CRR_MACRO_ABORT,NOQUOTE,&sysmacroname))  ;
              %fcf_put_error;
              %goto MACRO_END;
        %end;     

/* transpose country_party_dim columns into attribute records  */
data cddds_country_2;
     /* use the county_code attribute in fsc_address_dim to define country_code */
     if 0 then set seg_kc.fsc_address_dim (keep=country_code);
     set country_party_dim;
          
      length ATTRIBUTE_CODE $ 32
      ;
      label ATTRIBUTE_CODE='ATTRIBUTE_CODE'
      ;
      if party_type_desc='ORGANIZATION' then
      do;
         attribute_code='REGISTRATION';
         country_code=org_country_of_business_code;
         output;

         attribute_code='MAILING';
         country_code=mailing_country_code;
         output;

         attribute_code='STREET';
         country_code=street_country_code;
          output;

      end;
      else
      do;
          attribute_code='RESIDENCE';
          country_code=residence_country_code;
          output;

          attribute_code='CITIZENSHIP';
          country_code=citizenship_country_code;
          output;         
          
      end;

      drop  residence_country_code citizenship_country_code
            street_country_code mailing_country_code 
            org_country_of_business_code 
     ;

RETURN;

run;

   %fcf_rcset(&syserr)
         %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=%sysfunc(sasmsg(sashelp.cddmsg,CDD_CRR_MACRO_ABORT,NOQUOTE,&sysmacroname))  ;
              %fcf_put_error;
              %goto MACRO_END;
        %end;  

/* combine all country attribute prep files */

data cddds_country_all;
     set cddds_country_1
         cddds_country_2
         cddds_related_party 
     ;
     length LOOKUP_SCORE 8
            SANCTION_COUNTRY_IND $ 1
            ATTRIBUTE_CHAR_VALUE $ 32
            REF_TABLE_NM         $ 30
            ;
     label LOOKUP_SCORE='LOOKUP_SCORE'
           SANCTION_COUNTRY_IND='SANCTION_COUNTRY_IND'
     ;
     lookup_score=input(put(country_code,$cntry_score.),best.);
     sanction_country_ind=put(country_code,$sanction_cntry.);
     attribute_char_value=country_code;
     ref_table_nm='RT_CDD_COUNTRY';
     if attribute_code = '' or attribute_char_value= '' then delete;
     drop country_code;
run;
   %fcf_rcset(&syserr)
         %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=%sysfunc(sasmsg(sashelp.cddmsg,CDD_CRR_MACRO_ABORT,NOQUOTE,&sysmacroname))  ;
              %fcf_put_error;
              %goto MACRO_END;
        %end;  

/* remove all duplicate records */
proc sort data=cddds_country_all nodup force;
     by primary_entity_number attribute_code attribute_char_value;
run;

   %fcf_rcset(&syserr)
   %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=%sysfunc(sasmsg(sashelp.cddmsg,CDD_CRR_MACRO_ABORT,NOQUOTE,&sysmacroname))  ;
              %fcf_put_error;
              %goto MACRO_END;
   %end;

/* Left join the prep file with FSC_PARTY_DIM */
/* to make sure that there is at least one record per internal party */
/* All Prep file must contain the following columns */
/*    PRIMARY_ENTITY_TYPE_CODE - 'PTY'for party, 'ACC' for account, 'HHD' for household data   */ 
/*    PRIMARY_ENTITY_KEY - depending on PRIMARY_ENTITY_TYPE_CODE, it should contain            */
/*                         PARTY_KEY, ACCOUNT_KEY, or HOUSEHOLD_KEY value                      */ 
/*    PRIMARY_ENTITY_NUMBER - depending on PRIMARY_ENTITY_TYPE_CODE, it should contain         */
/*                            PARTY_NUMBER, ACCOUNT_NUMBER, or HOUSEHOLD_NUMBER value          */ 
 

     proc sql ;
     create table cm_prep.cddds_country_risk_prep as
     select  distinct
              a.*
            , b.attribute_code 'Attribute Code'
            , b.attribute_char_value 'Attribute Value (char)'
            , b.lookup_score 'Lookup Score'
            , b.ref_table_nm
            , b.sanction_country_ind 'Sanctioned Country Indicator'
            , b.related_attribute_type_code 'Related Party Attribute Type Code' 
            , b.related_attribute_char_value 'Related Party Attribute Value (char)'
            , b.related_attribute_num_value 'Related Party Attribute Value (num)'
            , b.related_attribute_date_value 'Related Party Attribute Value (date)'
            , b.related_party_number 'Related Party Number'
     from cjobstat.cddds_entity_list
            /* remove party_number from output to main only one unique attribute result per entity */
               (drop=party_number)  
                as a
     left join cddds_country_all as b
     on a.primary_entity_number=b.primary_entity_number
     order by primary_entity_number, attribute_code, attribute_char_value, primary_entity_key DESC
 
     ;
   quit;
   %fcf_rcset(&syserr)
   %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
          %let _fcfmsg_=%sysfunc(sasmsg(sashelp.cddmsg,CDD_CRR_MACRO_ABORT,NOQUOTE,&sysmacroname))  ;
          %fcf_put_error;
          %goto MACRO_END;
   %end;

%MACRO_END:

   %if &trans_rc eq 3 or &trans_rc ge 5 %then
      %cdd_error;
   %else %do;
      %cdd_success;
   %end;

%mend;
