/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    cdd_rule_definition.sas
| PRODUCT: SAS Customer Due Diligence
| SYSTEM:  Windows Unix
| DESC:    initialize Rule Group
+------------------------------------------------------------------------------+
| USAGE:   This macro is used in the generated code for each rule.  It must
|          produce SAS code that can be executed inside a SAS DATA step.
|
| PARAMETERS:
|   cdd_rule_id - Rule ID, used to identify the rule that produced the score
|
|   version_no - version of the rule that was used by CRR process
|
|   cdd_rule_type - rule type for the rule as defined in UI
|
|   file_name - full file name for the rule source code
|
|   cdd_rule_save_rule_id_ind - if 1 then rule id and version_no should be
|                               saved in the output dataset, if 0 then the 
|                               rule id of the previously executed rule will
|                               be saved, if all rules in the group have this
|                               flag set to 0 then rule_id from the input data 
|                               set will be saved to the output data set.
|   category_code - code used to populate CATEGORY_CODE variable in the output
|                   data set. CATEGORY_CODE is required for all rules that 
|                   process category attributes, i.e. before Category 
|                   Aggregation rules are executed. This code is used by UI to
|                   display the scores.
|   input_ds_name - name of the original data set with the parties to be scored.
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2013-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro cdd_rule_definition(cdd_rule_id=, version_no=, cdd_rule_type=,
                           file_name=, cdd_rule_save_id_flg=, 
                           category_code=, input_ds_name= );

  %if &cdd_rule_type ne CUSTOM %then %do;
	  %if &cdd_rule_save_id_flg eq 1 or &cdd_rule_save_id_flg eq Y %then %do;
	          CDD_RULE_ID="&cdd_rule_id";
	          VERSION_NO=&version_no;
	  %end;
	  %if &input_ds_name ne and &category_code ne %then %do;
	          CATEGORY_CODE = "&category_code";
  	  %end;
  %end;
  %inc "&file_name";

%mend cdd_rule_definition;


