/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    cdd_sm_read_config_data.sas
| PRODUCT: SAS Customer Due Diligence
| SYSTEM:  Windows, Unix
| DESC:    Macro to read Scenario Manager config values into global variables.
+------------------------------------------------------------------------------+
| PARAMETERS:
|   app_name
|     specifies the name of the application in the metadata repository.
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2013-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro cdd_sm_read_config_data(app_name=);

    /* global variables for Rule Manager */
    %global cdd_sm_rule_path cdd_sm_hdr_path cddwork cdd_sm_rc cdd_sm_codegen_path cdd_sm_prep_lib cdd_sm_rule_group_path prop_status;


  /* indicate if there were errors while executing CDD STP
   * it could be used to terminate STP using goto statement without using ABORT statement
   * when this is necessary. Updating ref tables uses this flag.
   */
   %global cdd_stp_error_flg;
   %let cdd_stp_error_flg = 0;



    /* use work libname for all temp datasets - can be changed for debugging */
    %let cddwork = work;

    /* path to rule source code */
    %let cdd_sm_rule_path=!CDDROOT/rule/rule_code_active/;
    /* path to rule group source code */
    %let cdd_sm_rule_group_path=!CDDROOT/rule/rule_group_code_active/;
    /* path to codegen */
    %let cdd_sm_codegen_path=!CDDROOT/rule/codegen/;
    %let cdd_sm_codegen_path_prop=cdd.codegen.location;
    /* name of the prep data sets library*/
    %let cdd_sm_prep_lib=CM_PREP;
    %let cdd_sm_prep_lib_prop=cdd.prep.lib;

    %let prop_status=0;
    %fcf_get_property_value(property=fcf.svr.cdd.rule.sourcePath, output_property_value=cdd_sm_rule_path, output_status=prop_status);
    %if &prop_status ne 0 %then %do;
        %put WARNING: Rule source path not found in preferences. Using default value.;
        %let cdd_sm_rule_path = !CDDROOT/rule/rule_code_active;
    %end;

    %fcf_get_property_value(property=fcf.svr.cdd.rulegroup.sourcePath, output_property_value=cdd_sm_rule_group_path, output_status=prop_status);
    %if &prop_status ne 0 %then %do;
        %put WARNING: Rule group source path not found in preferences. Using default value.;
        %let cdd_sm_rule_group_path = !CDDROOT/rule/rule_group_code_active;
    %end;

    %fcf_get_property_value(property=fcf.svr.cdd.codegenPath, output_property_value=cdd_sm_codegen_path, output_status=prop_status);
    %if &prop_status ne 0 %then %do;
        %put WARNING: Codegen path not found in preferences. Using default value.;
        %let cdd_sm_codegen_path = !CDDROOT/rule/codegen;
    %end;

    %let cdd_sm_prep_lib=CM_PREP;

    %put NOTE: Codegen location            : &cdd_sm_codegen_path;
    %put NOTE: Rule source code path       : &cdd_sm_rule_path;
    %put NOTE: Rule group path             : &cdd_sm_rule_group_path;
    %put NOTE: Prep data sets library name : &cdd_sm_prep_lib;
%mend cdd_sm_read_config_data;



