/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    fcf_get_aml_lookup_table.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
| DESC:    Use this macro to get the AML lookup table for a specific locale
|          Output table is generated using the best match for locale.
|          First exact match is used, then locale language component used for match and
|          if none found then default value is used
+------------------------------------------------------------------------------+
| USAGE:   %fcf_get_aml_lookup_table(tabName=RT_ENTITY_LEVEL, locale=&_USERLOCALE)
+------------------------------------------------------------------------------+
| PARAMETERS:
|       tabName - table name must match FSK_LOV.LOV_TYPE_NAME
|       locale - locale to extract values
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_get_aml_lookup_table(tabName=, locale=);
    %let fcf_config_locale_opt = %sysfunc(sasmsg(sashelp.fcflocale, &fcf_config_locale, N));
    %let language = %KSUBSTR(&locale, 1, 2);
    proc sql;
        create table &tabName %fcf_get_ds_opts(ds_name=&tabName, output_ds=Y, add_parens=Y) as
        select
            coalesce(rf.LOV_LANGUAGE_DESC, rl.LOV_LANGUAGE_DESC, "&locale") as LOV_LANGUAGE_DESC,
            r.LOV_TYPE_NAME,
            r.LOV_TYPE_CODE,
            coalesce(rf.LOV_TYPE_DESC, rl.LOV_TYPE_DESC, r.LOV_TYPE_DESC) as LOV_TYPE_DESC,
            r.LOV_SORT_POSITION_NUMBER,
            r.ACTIVE_FLG
        from seg_kc.fsk_lov r
        left join seg_kc.fsk_lov rf
             on lower(rf.LOV_LANGUAGE_DESC) = lower("&locale")
             AND rf.LOV_TYPE_NAME = "&tabName"
             AND rf.LOV_TYPE_CODE = r.LOV_TYPE_CODE
        left join seg_kc.fsk_lov rl
             on lower(rl.LOV_LANGUAGE_DESC) = lower("&language")
             AND rl.LOV_TYPE_NAME = "&tabName"
             AND rl.LOV_TYPE_CODE = r.LOV_TYPE_CODE
        where r.LOV_TYPE_NAME = "&tabName" and lower(r.LOV_LANGUAGE_DESC) = "&fcf_config_locale_opt"
        ;
    quit;
    %if &SQLOBS = 0 %then %do;
        /* if default does not exists, then this is an error, empty table is created */
        proc sql;
            create table &tabName %fcf_get_ds_opts(ds_name=&tabName, output_ds=Y, add_parens=Y) like seg_kc.fsk_lov;
        quit;
        %let table_not_found_msg = %sysfunc(sasmsg(sashelp.fcfmsg, ref_tab_not_found, N, &tabName));
        %put ERROR: &table_not_found_msg;
    %end;
%mend fcf_get_aml_lookup_table;
