/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    fcf_purge_efiles.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
| DESC:    Purge files related to FSK_RC_EFILE records being purged
+------------------------------------------------------------------------------+
| USAGE: %fcf_purge_efiles;
+------------------------------------------------------------------------------+
| COMMENTS: 
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2019 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_purge_efiles;

  /*------------
   * Set Module
   *------------*/
  %local _fcfmodule_;
  %let _fcfmodule_=FCF_PURGE_EFILES;

  /*--------------------------------------
   * Call prefcf_purge_efiles stub macro.
   *--------------------------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*-------------------------------------------
   * Set error code to 0 and message to blank.
   *-------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;

  data _null_;
    fcfroot = sysget('FCFROOT');
    putlog "NOTE: FCF: FCFROOT=" fcfroot;
   run;

  /*---------------------------------------------
   * from $FCFROOT/custom/config/rc_autoexec.sas 
   *---------------------------------------------*/
  %put NOTE: FCF: &=RCDATA_PATH;
  %put NOTE: FCF: &=RC_EFILE_PATH;
  %put NOTE: FCF: &=RC_EFILE_RESP_PATH;

  /*------------------------------------------------------
   * &RCDATA_PATH/attachments is by default the same as
   * $FCFROOT/regulatoryConsole/attachments
   * &RCDATA_PATH and others used below come from
   * $FCFROOT/custom/source/rc_global_mvar.sas
   * which can be customized.
   *------------------------------------------------------*/

  /*--------------------------------------------------------------------------------
   * Get files in &RCDATA_PATH/attachments which are related to efiles being purged
   *--------------------------------------------------------------------------------*/
  data reg_console_attachments(keep=efile_key attachment_path);
    if 0 then set rc_efile_purged(keep=efile_key);
    if 0 then set &db_lib_kc..fsk_attachment(keep=attachment_path);
    if _n_ eq 1 then
    do;
       declare hash hh (dataset:'efl_to_delete(keep=efile_key)');
       hh.definekey ('efile_key');
       hh.definedone();
    end;
    fname = "delfile";
    rc = filename(fname,"&RCDATA_PATH.&slash.attachments&slash.");
    did = dopen(fname);
    if did gt 0 then
    do i = 1 to dnum(did);
       f_name = dread(did,i);
       underscore_position = indexc(f_name,'_');
       efile_key = input(trim(substr(f_name,6,underscore_position-6)),best.);    /* efile<efile_key>_*.* */
       if hh.find() eq 0 then
       do;
          attachment_path = "&RCDATA_PATH.&slash.attachments&slash." || f_name;
          output;
       end;
    end;
    else
    do;
       msg = sysmsg();
       putlog msg;
       call symputx('trans_rc',999999);
    end;
    if did gt 0 then
    do;
       rc = dclose(did);
    end;
    stop;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error selecting regulatoryConsole attachments;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %fcf_purge_attachments(in_ds=reg_console_attachments);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %goto MACRO_END;
  %end;

  /*----------------------------------------------------------------------
   * Get files in &RC_EFILE_PATH which are related to efiles being purged
   * ($FCFROOT/regulatoryConsole/efiles)
   *----------------------------------------------------------------------*/
  data reg_console_efiles(keep=efile_key attachment_path);
   set rc_efile_purged;
    if 0 then set &db_lib_kc..fsk_attachment(keep=attachment_path);
    if output_path_name ne '' then
    do; 
       if output_name ne '' then
       do;
          attachment_path = "&RC_EFILE_PATH.&slash." || trim(output_path_name) || "&slash" || output_name;
          output;
       end;
       if output_zip_name ne '' then
       do;
          attachment_path = "&RC_EFILE_PATH.&slash." || trim(output_path_name) || "&slash" || output_zip_name;
          output;
       end;
    end;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error selecting regulatoryConsole efiles;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %fcf_purge_attachments(in_ds=reg_console_efiles);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %goto MACRO_END;
  %end;

  /*---------------------------------------------------------------------------------------
   * Get files in &RCDATA_PATH/FINCEN_SDTM_efiles which are related to efiles being purged
   * ($FCFROOT/regulatoryConsole/FINCEN_SDTM_efiles)
   *---------------------------------------------------------------------------------------*/
  data reg_console_FINCEN_SDTM_efiles(keep=efile_key attachment_path);
   set rc_efile_purged;
    if 0 then set &db_lib_kc..fsk_attachment(keep=attachment_path);
    if output_path_name ne '' and
       direct_transfer_efile_name ne '' then
    do;
       attachment_path = "&RCDATA_PATH.&slash.FINCEN_SDTM_efiles&slash." || trim(output_path_name) || "&slash" || direct_transfer_efile_name;
       output;
    end;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error selecting regulatoryConsole FINCEN SDTM efiles;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %fcf_purge_attachments(in_ds=reg_console_FINCEN_SDTM_efiles);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %goto MACRO_END;
  %end;

  /*---------------------------------------------------------------------------
   * Get files in &RC_EFILE_RESP_PATH which are related to efiles being purged
   * ($FCFROOT/regulatoryConsole/efiles_responses)
   * If response_file_name has a value we don't know whether it's in this
   * directory or in FINCEN_SDTM_efiles_responses (see below) so we must try
   * to delete it from both.
   *---------------------------------------------------------------------------*/
  data reg_console_efiles_responses(keep=efile_key attachment_path);
   set rc_efile_purged;
    if 0 then set &db_lib_kc..fsk_attachment(keep=attachment_path);
    if 0 then set &db_lib_kc..fsk_attachment(keep=attachment_path rename=(attachment_path=attachment_pathp));
    if output_path_name ne '' and
       response_file_name ne '' then
    do;
       attachment_path = "&RC_EFILE_RESP_PATH.&slash." || trim(output_path_name) || "&slash" || response_file_name;
       attachment_pathp = "&RC_EFILE_RESP_PATH.&slash." || trim(output_path_name) || "&slash" || trim(response_file_name) || "p";
       fname = "delfile";
       rc = filename(fname, attachment_path);
       if rc eq 0 then
       do;
          if fexist(fname) then     /* there's a (small) chance the .xml will exist */
          do;
             output;
          end;
          else                      /* but if it doesn't then we'll try to delete the processed file (.xmlp) */
          do;
             attachment_path = attachment_pathp;
             output;
          end;
       end;
       else
       do;
          attachment_path = attachment_pathp;
          output;
       end;
    end;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error selecting regulatoryConsole efiles responses;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %fcf_purge_attachments(in_ds=reg_console_efiles_responses);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %goto MACRO_END;
  %end;

  /*-------------------------------------------------------------------------------------------------
   * Get files in &RCDATA_PATH/FINCEN_SDTM_efiles_responses which are related to efiles being purged
   * ($FCFROOT/regulatoryConsole/FINCEN_SDTM_efiles_responses)
   * If response_file_name has a value we don't know whether it's in this directory or in
   * efiles_responses (see above) so we must try to delete it from both.
   *-------------------------------------------------------------------------------------------------*/
  data FINCEN_SDTM_efiles_responses(keep=efile_key attachment_path);
   set rc_efile_purged;
    if 0 then set &db_lib_kc..fsk_attachment(keep=attachment_path);
    if 0 then set &db_lib_kc..fsk_attachment(keep=attachment_path rename=(attachment_path=attachment_pathp));
    if output_path_name ne '' and
       response_file_name ne '' then
    do;
       attachment_path = "&RCDATA_PATH.&slash.FINCEN_SDTM_efiles_responses&slash." || trim(output_path_name) || "&slash" || response_file_name;
       attachment_pathp = "&RCDATA_PATH.&slash.FINCEN_SDTM_efiles_responses&slash." || trim(output_path_name) || "&slash" || trim(response_file_name) || "p";
       fname = "delfile";
       rc = filename(fname, attachment_path);
       if rc eq 0 then
       do;
          if fexist(fname) then     /* there's a (small) chance the .xml will exist */
          do;
             output;
          end;
          else                      /* but if it doesn't then we'll try to delete the processed file (.xmlp) */
          do;
             attachment_path = attachment_pathp;
             output;
          end;
       end;
       else
       do;
          attachment_path = attachment_pathp;
          output;
       end;
    end;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error selecting regulatoryConsole FINCEN SDTM efiles responses;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %fcf_purge_attachments(in_ds=FINCEN_SDTM_efiles_responses);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %goto MACRO_END;
  %end;

  /*-------------------------------------------------------------------------------------------
   * All data for the old forms are saved in rc_data.<form_type_code>_* for ease of reporting.
   * To delete all the data for an e-file, we need to loop through all the tables and delete
   * the records with efile_key=<efile_key>.
   * The subject data are in <form_type_code>_4* but we'll delete the e-file data from all
   * tables to be consistent.
   *-------------------------------------------------------------------------------------------*/

  /*---------------------------------------------------------------------
   * First get all the form_type_code values for the efiles being purged
   *---------------------------------------------------------------------*/
  proc sort data=rc_efile_purged(keep=form_config_key)
             out=unique_form_config_key nodupkeys;
    by form_config_key;
   run;

  proc sort data=&db_lib_kc..fsk_rc_form_config(keep=form_config_key form_type_code)
             out=rc_form_config;
    by form_config_key;
   run;

  data rc_form_config;
    merge rc_form_config(in=a) unique_form_config_key(in=b);
    by form_config_key;
    if a and b;
   run;

  %let rc_form_config_count = 0;

  data _null_;
    if 0 then set work.rc_form_config nobs=nobs;
    call symputx('rc_form_config_count',nobs);
    stop;
   run;

  %put NOTE: FCF: &=rc_form_config_count;

  /*----------------------------
   * For each form_type_code...
   * (SAR, SARX...)
   *----------------------------*/ 
  %do i = 1 %to &rc_form_config_count;
     %let form_config_key=;
     %let form_type_code=;

     data _null_;
      set work.rc_form_config;
       if _n_ eq &i then
       do;
          call symputx('form_config_key',form_config_key);
          call symput('form_type_code',form_type_code);
       end;
      run;

     %put NOTE: FCF: &=FORM_CONFIG_KEY   &=FORM_TYPE_CODE;

     /*----------------------------------------------------------------
      * Get the regulatory console data sets we'll need to delete from
      *----------------------------------------------------------------*/
     data rc_datasets(keep=memname);
      set sashelp.vtable;
       where libname="RC_DB" and memtype="DATA" and upcase(memname) eq: "&FORM_TYPE_CODE";
      run;

     /*--------------------------------------------------------------
      * Get the efile keys we'll need to look for in those data sets
      *--------------------------------------------------------------*/
     data rc_efiles(keep=efile_key);
      set rc_efile_purged(keep=efile_key form_config_key);
       if form_config_key eq &form_config_key;
      run;
      
     %let rc_datasets_count = 0;

     data _null_;
       if 0 then set work.rc_datasets nobs=nobs;
       call symputx('rc_datasets_count',nobs);
       stop;
      run;

     %put NOTE: FCF: &=rc_datasets_count;

     /*-----------------------------------------------------------
      * Now look in each of those data sets for records to delete
      *-----------------------------------------------------------*/
     %do j = 1 %to &rc_datasets_count;

        %let memname=;

        data _null_;
         set work.rc_datasets;
          if _n_ eq &j then
          do;
             call symput('memname',memname);
          end;
         run;

        %put NOTE: FCF: Purging from Regulatory Console data set rc_db.&memname;

        data %if %upcase(&test_run) eq N %then
             %do;
                rc_db.&memname(%fcf_get_ds_opts(lib_name=rc_db, ds_name=&memname, output_ds=Y))
             %end;
             ds_rows_purged(keep=efile_key)
             ;
         set rc_db.&memname(%fcf_get_ds_opts(lib_name=rc_db, ds_name=&memname));
          drop rc;
          if _n_ eq 1 then
          do;
             declare hash hh (dataset:"rc_efiles");
                          hh.definekey ("efile_key");
                          hh.definedone();
          end;
          rc = hh.find();
          if rc eq 0 then
          do;
             output ds_rows_purged;
             %if %upcase(&test_run) eq N %then
             %do;
                delete;
             %end;
          end;
          %if %upcase(&test_run) eq N %then
          %do;
             else
             do;
                output rc_db.&memname;
             end;
          %end;
         run;

        %fcf_rcset(&syserr);
        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
            %let _fcfmsg_=ERROR: FCF: Error deleting from Regulatory Console data set rc_db.&memname;
            %let trans_rc = 999999;
            %fcf_put_error;
            %goto MACRO_END;
        %end;

        proc sort data=ds_rows_purged;
          by efile_key;
         run;

        data ds_rows_purged;
         set ds_rows_purged;
          by efile_key;
          if first.efile_key then
             rec_purged = 0;
          rec_purged + 1;
          if last.efile_key then
             output;
         run;

        %fcf_purge_add_to_log_ds(in_ds=ds_rows_purged,
                                 libname=rc_db,
                                 table=&memname,
                                 rolled_up=Y,
                                 key_1=efile_key,
                                 key_1_type=N
                                );

        %if &trans_rc eq 3 or &trans_rc ge 5 %then
        %do;
            %goto MACRO_END;
        %end;
     %end;
  %end;


  %MACRO_END:

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
     %fcf_execute_macro(fcf_error);
  %else %do;
     %fcf_execute_macro(post&_fcfmodule_);
     %fcf_execute_macro(fcf_success);
  %end;

%mend fcf_purge_efiles;

