/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    fcf_purge_from_core.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
| DESC:    Delete data from the Core 
+------------------------------------------------------------------------------+
| USAGE: %fcf_purge_from_core;
+------------------------------------------------------------------------------+
| COMMENTS: 
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2019 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_purge_from_core;

  /*------------
   * Set Module
   *------------*/
  %local _fcfmodule_;
  %let _fcfmodule_=FCF_PURGE_FROM_CORE;

  /*-----------------------------------------
   * Call prefcf_purge_from_core stub macro.
   *-----------------------------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*-------------------------------------------
   * Set error code to 0 and message to blank.
   *-------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;

  %put NOTE: FCF: Deleting from the Core.;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.pty_to_delete_num)) and
      %sysfunc(exist(purgekey.pty_to_delete_key)) and
      %sysfunc(exist(purgekey.acc_to_delete_key)) and
      %sysfunc(exist(purgekey.acc_to_delete_num)) and
      %sysfunc(exist(purgekey.hhd_to_delete_key)) and
      %sysfunc(exist(purgekey.hhd_to_delete_num)) %then
  %do;
     data pty_to_delete_num;
      set purgekey.pty_to_delete_num(%fcf_get_ds_opts(lib_name=purgekey, ds_name=pty_to_delete_num));
      run;

     data pty_to_delete_key;
      set purgekey.pty_to_delete_key(%fcf_get_ds_opts(lib_name=purgekey, ds_name=pty_to_delete_key));
      run;

     data acc_to_delete_key;
      set purgekey.acc_to_delete_key(%fcf_get_ds_opts(lib_name=purgekey, ds_name=acc_to_delete_key));
      run;

     data acc_to_delete_num;
      set purgekey.acc_to_delete_num(%fcf_get_ds_opts(lib_name=purgekey, ds_name=acc_to_delete_num));
      run;

     data hhd_to_delete_key;
      set purgekey.hhd_to_delete_key(%fcf_get_ds_opts(lib_name=purgekey, ds_name=hhd_to_delete_key));
      run;

     data hhd_to_delete_num;
      set purgekey.hhd_to_delete_num(%fcf_get_ds_opts(lib_name=purgekey, ds_name=hhd_to_delete_num));
      run;

     %goto BEGIN_CORE_PURGE;
  %end;

  /*-----------------------------
   * Are there parties to purge?
   *-----------------------------*/
  %let parties_to_purge_count = 0;

  data _null_;
    if 0 then set work.parties_to_purge nobs=nobs;
    call symputx('parties_to_purge_count',nobs);
    stop;
   run;
    
  %if &parties_to_purge_count = 0 %then
  %do;
     %let _fcfmsg_=NOTE: FCF: No parties are eligible to be purged.;
     %fcf_put_error;
  %end;

  /*------------------------------------------------
   * Remove duplicate parties in case there are any 
   *------------------------------------------------*/
  proc sort data=parties_to_purge nodupkey;
    by party_number;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %let _fcfmsg_=ERROR: FCF: Unable to sort data set parties_to_purge by party_number.;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  /*--------------------------------------------------------------------
   * Also need party keys to determine if party is eligible for purging
   *--------------------------------------------------------------------*/
  data party_numbers_and_keys(keep=party_number party_key);
    set parties_to_purge(keep=party_number);
    _record_count_ = 1;
    drop _record_count_;
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_core..fsc_party_dim(keep=party_key party_number
                                       dbkey=(party_number))
                                      key=dbkey;
        if _iorc_ = %sysrc(_sok) then
           output;
        else
        do;
           _error_ = 0;
           if _iorc_ = %sysrc(_dsenom) and _record_count_ eq 1 then
              putlog 'NOTE: FCF: Party number ' party_number "not found in &db_lib_core..fsc_party_dim.";
        end;
       _record_count_ + 1;
    end;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %let _fcfmsg_=ERROR: FCF: Unable to retrieve party keys.;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  proc datasets lib=work nowarn nolist;
    delete parties_to_purge;
  quit;

  /*-----------------------------------------------------------------------
   * Get eligible parties to purge.  This must come after the purge by
   * retention days as what's left after that helps determine eligibility.
   *-----------------------------------------------------------------------*/
  %fcf_purge_get_eligible_ents(in_ds=party_numbers_and_keys,
                              out_ds=eligible_parties,
                              entity_level_code=PTY);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
    %goto MACRO_END;
  %end;

  proc datasets lib=work nowarn nolist;
    delete party_numbers_and_keys;
  quit;

  /*-----------------------------------------------------------------------
   * Due to SCD (Slowly Changing Dimensions) there may be multiple records
   * per party number.  Create a new data set without the duplicates.
   *-----------------------------------------------------------------------*/
  proc sort data=eligible_parties(keep=party_number)
             out=pty_to_delete_num nodupkey;
    by party_number;
   run;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     data purgekey.pty_to_delete_num(%fcf_get_ds_opts(lib_name=purgekey, ds_name=pty_to_delete_num, output_ds=Y));
      set pty_to_delete_num;
      run;
  %end;

  /*--------------------------------------
   * Create a data set with just the keys
   *--------------------------------------*/
  proc sort data=eligible_parties(keep=party_key)
             out=pty_to_delete_key nodupkey;   /* shouldn't need nodupkey but just in case */
    by party_key;
   run;

  proc datasets lib=work nowarn nolist;
    delete eligible_parties;
  quit;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     data purgekey.pty_to_delete_key(%fcf_get_ds_opts(lib_name=purgekey, ds_name=pty_to_delete_key, output_ds=Y));
      set pty_to_delete_key;
      run;
  %end;

  /*--------------------------------------
   * Get the accounts for those customers 
   *--------------------------------------*/
  /* one to many join */
  data acc_for_pty_to_delete;
   set pty_to_delete_key(keep=party_key);
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_core..fsc_party_account_bridge(keep=party_key account_key change_current_ind
                                                 dbkey=party_key)
                                                 key=dbkey;
       if _iorc_ = %sysrc(_sok) then
          output;
       else
          _error_ = 0;
    end;
   run;

   proc sort data=acc_for_pty_to_delete(keep=account_key)
              out=acc_for_pty_to_delete_key nodupkeys;
     by account_key;
    run;

  proc datasets lib=work nowarn nolist;
    delete acc_for_pty_to_delete;
  quit;

  /*----------------------------------------
   * Get the households for those customers
   *----------------------------------------*/
  /* one to many join */
  data hhd_for_pty_to_delete;
   set pty_to_delete_key(keep=party_key);
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_core..fsc_household_party_bridge(keep=party_key household_key change_current_ind
                                                   dbkey=party_key)
                                                   key=dbkey;
       if _iorc_ = %sysrc(_sok) then
          output;
       else
          _error_ = 0;
    end;
   run;

   proc sort data=hhd_for_pty_to_delete(keep=household_key)
              out=hhd_for_pty_to_delete_key nodupkeys;
     by household_key;
    run;

  proc datasets lib=work nowarn nolist;
    delete hhd_for_pty_to_delete;
  quit;

  /*--------------------------------------------
   * Get all customers linked to those accounts
   *--------------------------------------------*/
  /* one to many join */
  data all_pty_linked_to_acc;
   set acc_for_pty_to_delete_key(keep=account_key);
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_core..fsc_party_account_bridge(keep=party_key account_key change_current_ind
                                                 dbkey=account_key)
                                                 key=dbkey;
       if _iorc_ = %sysrc(_sok) then
          output;
       else
          _error_ = 0;
    end;
   run;

  proc datasets lib=work nowarn nolist;
    delete acc_for_pty_to_delete_key;
  quit;

  proc sort data=all_pty_linked_to_acc(keep=party_key account_key)
             out=all_pty_linked_to_acc_keys nodupkey;
    by party_key account_key;
   run;

  proc datasets lib=work nowarn nolist;
    delete all_pty_linked_to_acc;
  quit;

  /*----------------------------------------------
   * Get all customers linked to those households
   *----------------------------------------------*/
  /* one to many join */
  data all_pty_linked_to_hhd;
   set hhd_for_pty_to_delete_key(keep=household_key);
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_core..fsc_household_party_bridge(keep=party_key household_key change_current_ind
                                                   dbkey=household_key)
                                                   key=dbkey;
       if _iorc_ = %sysrc(_sok) then
          output;
       else
          _error_ = 0;
    end;
   run;

  proc datasets lib=work nowarn nolist;
    delete hhd_for_pty_to_delete_key;
  quit;

  proc sort data=all_pty_linked_to_hhd(keep=party_key household_key)
             out=all_pty_linked_to_hhd_keys nodupkey;
    by party_key household_key;
   run;

  proc datasets lib=work nowarn nolist;
    delete all_pty_linked_to_hhd;
  quit;

  /*--------------------------------------------------------------
   * Now add whether each customer requested to be deleted or not
   *--------------------------------------------------------------*/
  data all_pty_linked_to_acc_keys;
    length customer_requested_to_be_deleted $1;
    merge all_pty_linked_to_acc_keys(in=a) pty_to_delete_key(in=b);
    by party_key;
    if a;
    if b then
       customer_requested_to_be_deleted = 'Y';
    else
       customer_requested_to_be_deleted = 'N';
   run;

  data all_pty_linked_to_hhd_keys;
    length customer_requested_to_be_deleted $1;
    merge all_pty_linked_to_hhd_keys(in=a) pty_to_delete_key(in=b);
    by party_key;
    if a;
    if b then
       customer_requested_to_be_deleted = 'Y';
    else
       customer_requested_to_be_deleted = 'N';
   run;

  /*----------------------------------------------------------------
   * We only want to delete accounts where the customer is the only
   * customer on the account, or if all customers on the account
   * have requested to be removed in this run of the job.
   *----------------------------------------------------------------*/
  proc sort data=all_pty_linked_to_acc_keys;
    by account_key;
   run;

  data acc_to_delete_key_pre_eligible(keep=account_key)
       acc_to_not_delete(keep=account_key)
       ;
    length okay_to_delete $1;
    retain okay_to_delete;
    set all_pty_linked_to_acc_keys;
    by account_key;
    if first.account_key then
       okay_to_delete = 'Y';
    if customer_requested_to_be_deleted eq 'N' then
       okay_to_delete = 'N';
    if last.account_key then
    do;
       if okay_to_delete eq 'Y' then
          output acc_to_delete_key_pre_eligible;
       else
          output acc_to_not_delete;
    end;
   run;

  proc datasets lib=work nowarn nolist;
    delete all_pty_linked_to_acc_keys
           acc_to_not_delete
           ;
  quit;

  /*------------------------------------------------------------------------
   * Also need account numbers to determine if account is eligible to purge
   *------------------------------------------------------------------------*/
  data account_numbers_and_keys(keep=account_number account_key);
    set acc_to_delete_key_pre_eligible(keep=account_key);
    _record_count_ = 1;
    drop _record_count_;
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_core..fsc_account_dim(keep=account_key account_number
                                         dbkey=(account_key))
                                        key=dbkey;
        if _iorc_ = %sysrc(_sok) then
           output;
        else
        do;
           _error_ = 0;
           if _iorc_ = %sysrc(_dsenom) and _record_count_ eq 1 then
              putlog 'NOTE: FCF: Account key ' account_key "not found in &db_lib_core..fsc_account_dim.";
        end;
       _record_count_ + 1;
    end;
   run;

  proc datasets lib=work nowarn nolist;
    delete acc_to_delete_key_pre_eligible;
  quit;

  /*-----------------------------------------------------------------------
   * Get eligible accounts to purge.  This must come after the purge by
   * retention days as what's left after that helps determine eligibility.
   *-----------------------------------------------------------------------*/
  %fcf_purge_get_eligible_ents(in_ds=account_numbers_and_keys,
                               out_ds=eligible_accounts,
                               entity_level_code=ACC);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
    %goto MACRO_END;
  %end;

  proc datasets lib=work nowarn nolist;
    delete account_numbers_and_keys;
  quit;

  proc sort data=eligible_accounts(keep=account_key)
             out=acc_to_delete_key nodupkey;
    by account_key;
   run;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     data purgekey.acc_to_delete_key(%fcf_get_ds_opts(lib_name=purgekey, ds_name=acc_to_delete_key, output_ds=Y));
      set acc_to_delete_key;
      run;
  %end;

  proc sort data=eligible_accounts(keep=account_number)
             out=acc_to_delete_num nodupkey;
    by account_number;
   run;

  proc datasets lib=work nowarn nolist;
    delete eligible_accounts;
  quit;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     data purgekey.acc_to_delete_num(%fcf_get_ds_opts(lib_name=purgekey, ds_name=acc_to_delete_num, output_ds=Y));
      set acc_to_delete_num;
      run;
  %end;

  /*------------------------------------------------------------------
   * We only want to delete households where the customer is the only
   * customer in the household, or if all customers in the household
   * have requested to be removed in this run of the job.
   *------------------------------------------------------------------*/
  proc sort data=all_pty_linked_to_hhd_keys;
    by household_key;
   run;

  data hhd_to_delete_key_1(keep=household_key)
       hhd_to_not_delete_1(keep=household_key)
       ;
    length okay_to_delete $1;
    retain okay_to_delete;
    set all_pty_linked_to_hhd_keys;
    by household_key;
    if first.household_key then
       okay_to_delete = 'Y';
    if customer_requested_to_be_deleted eq 'N' then
       okay_to_delete = 'N';
    if last.household_key then
    do;
       if okay_to_delete eq 'Y' then
          output hhd_to_delete_key_1;
       else
          output hhd_to_not_delete_1;
    end;
   run;

  proc datasets lib=work nowarn nolist;
    delete all_pty_linked_to_hhd_keys;
  quit;

  /*--------------------------------------------------------------------------
   * Above we looked at household party bridge to get the households related
   * to the parties to delete (pty_to_delete_key) but there may also be
   * households related to the accounts to delete (acc_to_delete_key) so we
   * must also look for those in the household account bridge.
   * Similar logic to above.
   *--------------------------------------------------------------------------*/
  /*---------------------------------------------------
   * Get the households for the accounts to be deleted
   *---------------------------------------------------*/
  /* one to many join */
  data hhd_for_acc_to_delete;
   set acc_to_delete_key(keep=account_key);
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_core..fsc_household_account_bridge(keep=account_key household_key change_current_ind
                                                     dbkey=account_key)
                                                     key=dbkey;
       if _iorc_ = %sysrc(_sok) then
          output;
       else
          _error_ = 0;
    end;
   run;

   proc sort data=hhd_for_acc_to_delete(keep=household_key)
              out=hhd_for_acc_to_delete_key nodupkeys;
     by household_key;
    run;

  proc datasets lib=work nowarn nolist;
    delete hhd_for_acc_to_delete;
  quit;

  /*---------------------------------------------
   * Get all accounts linked to those households
   *--------------------------------------------*/
  /* one to many join */
  data all_acc_linked_to_hhd;
   set hhd_for_acc_to_delete_key(keep=household_key);
    do until (_iorc_ ne %sysrc(_sok));
      set &db_lib_core..fsc_household_account_bridge(keep=account_key household_key change_current_ind
                                                    dbkey=household_key)
                                key=dbkey;
       if _iorc_ = %sysrc(_sok) then
          output;
       else
          _error_ = 0;
    end;
   run;

  proc datasets lib=work nowarn nolist;
    delete hhd_for_acc_to_delete_key;
  quit;

  proc sort data=all_acc_linked_to_hhd(keep=account_key household_key)
             out=all_acc_linked_to_hhd_keys nodupkey;
    by account_key household_key;
   run;

  proc datasets lib=work nowarn nolist;
    delete all_acc_linked_to_hhd;
  quit;

  /*------------------------------------------------------
   * Now add whether each account is to be deleted or not
   *------------------------------------------------------*/
  data all_acc_linked_to_hhd_keys;
    merge all_acc_linked_to_hhd_keys(in=a) acc_to_delete_key(in=b);
    by account_key;
    if a;
    if b then
       account_to_be_deleted = 'Y';
    else
       account_to_be_deleted = 'N';
   run;

  /*------------------------------------------------------------------
   * We only want to delete households where the account is the only
   * account in the household, or if all accounts linked to the
   * household are to be removed in this run of the job.
   *------------------------------------------------------------------*/
  proc sort data=all_acc_linked_to_hhd_keys;
    by household_key;
   run;

  data hhd_to_delete_key_2(keep=household_key)
       hhd_to_not_delete_2(keep=household_key)
       ;
    length okay_to_delete $1;
    retain okay_to_delete;
    set all_acc_linked_to_hhd_keys;
    by household_key;
    if first.household_key then
       okay_to_delete = 'Y';
    if account_to_be_deleted eq 'N' then
       okay_to_delete = 'N';
    if last.household_key then
    do;
       if okay_to_delete eq 'Y' then
          output hhd_to_delete_key_2;
       else
          output hhd_to_not_delete_2;
    end;
   run;

  proc datasets lib=work nowarn nolist;
    delete all_acc_linked_to_hhd_keys;
  quit;

  /*------------------------------------------------------------
   * Make sure our lists of households to delete do not contain
   * any households we determined we shouldn't delete.
   *------------------------------------------------------------*/
  data hhd_to_delete_key_3;
    merge hhd_to_delete_key_1(in=a) hhd_to_not_delete_2(in=b);
    by household_key;
    if a and not b;
   run;

  proc datasets lib=work nowarn nolist;
    delete hhd_to_delete_key_1
           hhd_to_not_delete_2
           ;
  quit;

  data hhd_to_delete_key_4;
    merge hhd_to_delete_key_2(in=a) hhd_to_not_delete_1(in=b);
    by household_key;
    if a and not b;
   run;

  proc datasets lib=work nowarn nolist;
    delete hhd_to_delete_key_2
           hhd_to_not_delete_1
           ;
  quit;

  data hhd_to_delete_key;
   set hhd_to_delete_key_3 hhd_to_delete_key_4;
   run;

  proc datasets lib=work nowarn nolist;
    delete hhd_to_delete_key_3
           hhd_to_delete_key_4
           ;
  quit;

  proc sort data=hhd_to_delete_key nodupkey;
    by household_key;
   run;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     data purgekey.hhd_to_delete_key(%fcf_get_ds_opts(lib_name=purgekey, ds_name=hhd_to_delete_key, output_ds=Y));
      set hhd_to_delete_key;
      run;
  %end;

  /*--------------------------------------------------
   * Also need household number for deleting comments
   *--------------------------------------------------*/
  data hhd_to_delete_num(keep=household_number);
    set hhd_to_delete_key(keep=household_key);
    set &db_lib_core..fsc_household_dim(keep=household_key household_number
                                        dbkey=(household_key))
                                       key=dbkey;
     if _iorc_ = %sysrc(_sok) then
        output;
     else
     do;
        _error_ = 0;
     end;
   run;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     data purgekey.pty_to_delete_num(%fcf_get_ds_opts(lib_name=purgekey, ds_name=pty_to_delete_num, output_ds=Y));
      set pty_to_delete_num;
      run;
     data purgekey.pty_to_delete_key(%fcf_get_ds_opts(lib_name=purgekey, ds_name=pty_to_delete_key, output_ds=Y));
      set pty_to_delete_key;
      run;
     data purgekey.acc_to_delete_key(%fcf_get_ds_opts(lib_name=purgekey, ds_name=acc_to_delete_key, output_ds=Y));
      set acc_to_delete_key;
      run;
     data purgekey.acc_to_delete_num(%fcf_get_ds_opts(lib_name=purgekey, ds_name=acc_to_delete_num, output_ds=Y));
      set acc_to_delete_num;
      run;
     data purgekey.hhd_to_delete_key(%fcf_get_ds_opts(lib_name=purgekey, ds_name=hhd_to_delete_key, output_ds=Y));
      set hhd_to_delete_key;
      run;
     data purgekey.hhd_to_delete_num(%fcf_get_ds_opts(lib_name=purgekey, ds_name=hhd_to_delete_num, output_ds=Y));
      set hhd_to_delete_num;
      run;
  %end;

  %BEGIN_CORE_PURGE:

  /*------------------------------------------
   * Delete from FSC_PARTY_ACCOUNT_BRIDGE
   * Must delete from the bridge table first!
   *------------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_party_account_bridge,
                        entities_ds=pty_to_delete_key,
                        key_vars=party_key,
                        one_to_many_ind=Y,
                        other_output_ds=party_account_bridge_purged,
                        other_output_ds_vars=party_key account_key role_key change_begin_date);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=party_account_bridge_purged,
                           %if %upcase(&test_run) eq Y %then
                           %do;
                           delete_in_ds_when_done=N,
                           %end;
                           libname=&db_lib_core,
                           table=fsc_party_account_bridge,
                           key_1=party_key,
                           key_1_type=N,
                           key_2=account_key,
                           key_2_type=N,
                           key_3=role_key,
                           key_3_type=N,
                           key_4=change_begin_date,
                           key_4_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*---------------------------------------------------------------
   * Shouldn't need to do this since the previous step should have
   * deleted the appropriate bridge records, but just in case.
   *---------------------------------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_party_account_bridge,
                        entities_ds=acc_to_delete_key,
                        key_vars=account_key,
                        one_to_many_ind=Y,
                        other_output_ds=party_account_bridge_purged_2,
                        other_output_ds_vars=account_key party_key role_key change_begin_date);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if %upcase(&test_run) eq Y %then
  %do;
     proc sort data=party_account_bridge_purged;
       by party_key account_key role_key change_begin_date;
      run;

     proc sort data=party_account_bridge_purged_2;
       by party_key account_key role_key change_begin_date;
      run;

     data party_account_bridge_purged_2;
       merge party_account_bridge_purged_2(in=a) party_account_bridge_purged(in=b);
       by party_key account_key role_key change_begin_date;
       if a and not b;
      run;

     proc datasets lib=work nowarn nolist;
       delete party_account_bridge_purged
              ;
     quit;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=party_account_bridge_purged_2,
                           libname=&db_lib_core,
                           table=fsc_party_account_bridge,
                           key_1=party_key,
                           key_1_type=N,
                           key_2=account_key,
                           key_2_type=N,
                           key_3=role_key,
                           key_3_type=N,
                           key_4=change_begin_date,
                           key_4_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*------------------------------------------
   * Delete from FSC_HOUSEHOLD_PARTY_BRIDGE
   * Must delete from the bridge table first!
   *------------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_household_party_bridge,
                        entities_ds=pty_to_delete_key,
                        key_vars=party_key,
                        one_to_many_ind=Y,
                        other_output_ds=household_party_bridge_purged,
                        other_output_ds_vars=party_key household_key change_begin_date);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=household_party_bridge_purged,
                           %if %upcase(&test_run) eq Y %then
                           %do;
                           delete_in_ds_when_done=N,
                           %end;
                           libname=&db_lib_core,
                           table=fsc_household_party_bridge,
                           key_1=household_key,
                           key_1_type=N,
                           key_2=party_key,
                           key_2_type=N,
                           key_3=change_begin_date,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*---------------------------------------------------------------
   * Shouldn't need to do this since the previous step should have
   * deleted the appropriate bridge records, but just in case.
   *---------------------------------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_household_party_bridge,
                        entities_ds=hhd_to_delete_key,
                        key_vars=household_key,
                        one_to_many_ind=Y,
                        other_output_ds=household_party_bridge_purged_2,
                        other_output_ds_vars=household_key party_key change_begin_date);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if %upcase(&test_run) eq Y %then
  %do;
     proc sort data=household_party_bridge_purged;
       by party_key household_key change_begin_date;
      run;

     proc sort data=household_party_bridge_purged_2;
       by party_key household_key change_begin_date;
      run;

     data household_party_bridge_purged_2;
       merge household_party_bridge_purged_2(in=a) household_party_bridge_purged(in=b);
       by party_key household_key change_begin_date;
       if a and not b;
      run;

     proc datasets lib=work nowarn nolist;
       delete household_party_bridge_purged
              ;
     quit;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=household_party_bridge_purged_2,
                           libname=&db_lib_core,
                           table=fsc_household_party_bridge,
                           key_1=household_key,
                           key_1_type=N,
                           key_2=party_key,
                           key_2_type=N,
                           key_3=change_begin_date,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*------------------------------------------
   * Delete from FSC_HOUSEHOLD_ACCOUNT_BRIDGE
   * Must delete from the bridge table first!
   *------------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_household_account_bridge,
                        entities_ds=acc_to_delete_key,
                        key_vars=account_key,
                        one_to_many_ind=Y,
                        other_output_ds=household_account_bridge_purged,
                        other_output_ds_vars=account_key household_key change_begin_date);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=household_account_bridge_purged,
                           %if %upcase(&test_run) eq Y %then
                           %do;
                           delete_in_ds_when_done=N,
                           %end;
                           libname=&db_lib_core,
                           table=fsc_household_account_bridge,
                           key_1=household_key,
                           key_1_type=N,
                           key_2=account_key,
                           key_2_type=N,
                           key_3=change_begin_date,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*---------------------------------------------------------------
   * Shouldn't need to do this since the previous step should have
   * deleted the appropriate bridge records, but just in case.
   *---------------------------------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_household_account_bridge,
                        entities_ds=hhd_to_delete_key,
                        key_vars=household_key,
                        one_to_many_ind=Y,
                        other_output_ds=household_account_bridge_purged2,
                        other_output_ds_vars=household_key account_key change_begin_date);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if %upcase(&test_run) eq Y %then
  %do;
     proc sort data=household_account_bridge_purged;
       by household_key account_key change_begin_date;
      run;

     proc sort data=household_account_bridge_purged2;
       by household_key account_key change_begin_date;
      run;

     data household_account_bridge_purged2;
       merge household_account_bridge_purged2(in=a) household_account_bridge_purged(in=b);
       by household_key account_key change_begin_date;
       if a and not b;
      run;

     proc datasets lib=work nowarn nolist;
       delete household_account_bridge_purged
              ;
     quit;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=household_account_bridge_purged2,
                           libname=&db_lib_core,
                           table=fsc_household_account_bridge,
                           key_1=household_key,
                           key_1_type=N,
                           key_2=account_key,
                           key_2_type=N,
                           key_3=change_begin_date,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-------------------------------
   * Delete from FSC_HOUSEHOLD_DIM
   *-------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_household_dim,
                        entities_ds=hhd_to_delete_key,
                        key_vars=household_key,
                        one_to_many_ind=N,
                        other_output_ds=household_purged,
                        other_output_ds_vars=household_key household_number);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=household_purged,
                           libname=&db_lib_core,
                           table=fsc_household_dim,
                           key_1=household_key,
                           key_1_type=N,
                           key_2=household_number,
                           key_2_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*--------------------------------------
   * Delete from FSC_ACCOUNT_PROFILE_FACT
   *--------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_account_profile_fact,
                        entities_ds=acc_to_delete_num,
                        key_vars=account_number,
                        one_to_many_ind=Y,
                        other_output_ds=account_profile_fact_purged,
                        other_output_ds_vars=account_number month_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=account_profile_fact_purged,
                           libname=&db_lib_core,
                           table=fsc_account_profile_fact,
                           key_1=account_number,
                           key_1_type=C,
                           key_2=month_key,
                           key_2_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-------------------------------------------
   * Delete from FSC_ACCOUNT_STATE_VECTOR_FACT
   *-------------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_account_state_vector_fact,
                        entities_ds=acc_to_delete_num,
                        key_vars=account_number,
                        one_to_many_ind=Y,
                        other_output_ds=account_state_vector_purged,
                        other_output_ds_vars=account_number date_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=account_state_vector_purged,
                           libname=&db_lib_core,
                           table=fsc_account_state_vector_fact,
                           key_1=account_number,
                           key_1_type=C,
                           key_2=date_key,
                           key_2_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*--------------------------------
   * Delete from FSC_CASH_FLOW_FACT
   *--------------------------------*/
  %let use_saved_cash_flow_1_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.trn_to_delete_cash_flow_1)) %then
  %do;
     %let use_saved_cash_flow_1_keys = 1;

     data trn_to_delete_cash_flow_1;
      set purgekey.trn_to_delete_cash_flow_1(%fcf_get_ds_opts(lib_name=purgekey, ds_name=trn_to_delete_cash_flow_1));
      run;

     %goto BEGIN_CASH_FLOW_FACT_1_PURGE;
  %end;

  /*----------------------------------------------------------------------------
   * This needs to be in a separate step in case it fails.  If the creation of
   * trn_to_delete_cash_flow_1 fails during the purge we would potentially have
   * an incomplete key data set which might leave orphaned transactions.
   * Also, because we need the transaction keys so we can delete from
   * fsc_cash_flow_bank_bridge first.
   *----------------------------------------------------------------------------*/
  data trn_to_delete_cash_flow_1(keep=transaction_key account_key date_key);
    set acc_to_delete_key(keep=account_key);
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_core..fsc_cash_flow_fact(keep=transaction_key account_key date_key
                                            dbkey=(account_key))
                                           key=dbkey;
        if _iorc_ = %sysrc(_sok) then
           output;
        else
           _error_ = 0;
    end;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %let _fcfmsg_=ERROR: FCF: Unable to create key data set trn_to_delete_cash_flow_1.;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     data purgekey.trn_to_delete_cash_flow_1(%fcf_get_ds_opts(lib_name=purgekey, ds_name=trn_to_delete_cash_flow_1, output_ds=Y));
      set trn_to_delete_cash_flow_1;
      run;
  %end;

  %BEGIN_CASH_FLOW_FACT_1_PURGE:

  /*---------------------------------------------------------------
   * Delete from fsc_cash_flow_bank_bridge first due to constraint
   *---------------------------------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_cash_flow_bank_bridge,
                        entities_ds=trn_to_delete_cash_flow_1,
                        key_vars=transaction_key,
                        one_to_many_ind=Y,
                        other_output_ds=cash_flow_bank_bridge_purged,
                        other_output_ds_vars=bank_key transaction_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=cash_flow_bank_bridge_purged,
                           %if %upcase(&test_run) eq Y %then
                           %do;
                           delete_in_ds_when_done=N,
                           %end;
                           libname=&db_lib_core,
                           table=fsc_cash_flow_bank_bridge,
                           key_1=transaction_key,
                           key_1_type=N,
                           key_2=bank_key,
                           key_2_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_from_table(table=&db_lib_core..fsc_cash_flow_fact,
                        entities_ds=acc_to_delete_key,
                        key_vars=account_key,
                        one_to_many_ind=Y,
                        other_output_ds=trn_to_delete_cash_flow_1,
                        other_output_ds_vars=transaction_key account_key date_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=trn_to_delete_cash_flow_1,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_core,
                           table=fsc_cash_flow_fact,
                           key_1=transaction_key,
                           key_1_type=N,
                           key_2=account_key,
                           key_2_type=N,
                           key_3=date_key,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if &use_saved_cash_flow_1_keys eq 1 %then
  %do;
     data trn_to_delete_cash_flow_1;
      set purgekey.trn_to_delete_cash_flow_1(%fcf_get_ds_opts(lib_name=purgekey, ds_name=trn_to_delete_cash_flow_1));
      run;
  %end;

  /*--------------------------------------------------------------------
   * Purge from FSC_CASH_FLOW_FACT by executing_party_key
   * If we don't do this we can't delete the party due to db constraint
   *--------------------------------------------------------------------*/
  %let use_saved_cash_flow_2_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.trn_to_delete_cash_flow_2)) %then
  %do;
     %let use_saved_cash_flow_2_keys = 1;

     data trn_to_delete_cash_flow_2;
      set purgekey.trn_to_delete_cash_flow_2(%fcf_get_ds_opts(lib_name=purgekey, ds_name=trn_to_delete_cash_flow_2));
      run;

     %goto BEGIN_CASH_FLOW_FACT_2_PURGE;
  %end;

  /*----------------------------------------------------------------------------
   * This needs to be in a separate step in case it fails.  If the creation of
   * trn_to_delete_cash_flow_2 fails during the purge we would potentially have
   * an incomplete key data set which might leave orphaned transactions.
   * Also, because we need the transaction keys so we can delete from
   * fsc_cash_flow_bank_bridge first.
   *----------------------------------------------------------------------------*/
  data trn_to_delete_cash_flow_2(keep=transaction_key executing_party_key date_key);
    set pty_to_delete_key(keep=party_key rename=(party_key=executing_party_key));
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_core..fsc_cash_flow_fact(keep=transaction_key executing_party_key date_key
                                            dbkey=(executing_party_key))
                                           key=dbkey;
        if _iorc_ = %sysrc(_sok) then
           output;
        else
           _error_ = 0;
    end;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %let _fcfmsg_=ERROR: FCF: Unable to create key data set trn_to_delete_cash_flow_2.;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     data purgekey.trn_to_delete_cash_flow_2(%fcf_get_ds_opts(lib_name=purgekey, ds_name=trn_to_delete_cash_flow_2, output_ds=Y));
      set trn_to_delete_cash_flow_2;
      run;
  %end;

  %BEGIN_CASH_FLOW_FACT_2_PURGE:

  /*---------------------------------------------------------------
   * Delete from fsc_cash_flow_bank_bridge first due to constraint
   *---------------------------------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_cash_flow_bank_bridge,
                        entities_ds=trn_to_delete_cash_flow_2,
                        key_vars=transaction_key,
                        one_to_many_ind=Y,
                        other_output_ds=cash_flow_bank_bridge_purged_2,
                        other_output_ds_vars=bank_key transaction_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if %upcase(&test_run) eq Y %then
  %do;
     proc sort data=cash_flow_bank_bridge_purged;
       by bank_key transaction_key;
      run;

     proc sort data=cash_flow_bank_bridge_purged_2;
       by bank_key transaction_key;
      run;

     data cash_flow_bank_bridge_purged_2;
       merge cash_flow_bank_bridge_purged_2(in=a) cash_flow_bank_bridge_purged(in=b);
       by bank_key transaction_key;
       if a and not b;
      run;

     proc datasets lib=work nowarn nolist;
       delete cash_flow_bank_bridge_purged
              ;
     quit;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=cash_flow_bank_bridge_purged_2,
                           libname=&db_lib_core,
                           table=fsc_cash_flow_bank_bridge,
                           key_1=transaction_key,
                           key_1_type=N,
                           key_2=bank_key,
                           key_2_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_from_table(table=&db_lib_core..fsc_cash_flow_fact,
                        entities_ds=pty_to_delete_key,
                        key_vars=party_key,
                        one_to_many_ind=Y,
                        rename_var_from=party_key,
                        rename_var_to=executing_party_key,
                        db_key_vars=executing_party_key,
                        other_output_ds=trn_to_delete_cash_flow_2,
                        other_output_ds_vars=transaction_key executing_party_key date_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if %upcase(&test_run) eq Y %then
  %do;
     proc sort data=trn_to_delete_cash_flow_1;
       by transaction_key;
      run;

     proc sort data=trn_to_delete_cash_flow_2;
       by transaction_key;
      run;

     data trn_to_delete_cash_flow_2;
       merge trn_to_delete_cash_flow_2(in=a) trn_to_delete_cash_flow_1(in=b);
       by transaction_key;
       if a and not b;
      run;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=trn_to_delete_cash_flow_2,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_core,
                           table=fsc_cash_flow_fact,
                           key_1=transaction_key,
                           key_1_type=N,
                           key_2=executing_party_key,
                           key_2_type=N,
                           key_3=date_key,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if &use_saved_cash_flow_2_keys eq 1 %then
  %do;
     data trn_to_delete_cash_flow_2;
      set purgekey.trn_to_delete_cash_flow_2(%fcf_get_ds_opts(lib_name=purgekey, ds_name=trn_to_delete_cash_flow_2));
      run;
  %end;

  /*------------------------------------
   * Delete from FSC_ACCOUNT_TRADE_FACT
   *------------------------------------*/
  %let use_saved_account_trade_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.trn_to_delete_account_trade)) %then
  %do;
     %let use_saved_account_trade_keys = 1;

     data trn_to_delete_account_trade;
      set purgekey.trn_to_delete_account_trade(%fcf_get_ds_opts(lib_name=purgekey, ds_name=trn_to_delete_account_trade));
      run;

     %goto BEGIN_ACCOUNT_TRADE_FACT_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*----------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * trn_to_delete_account_trade fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned transactions.
      *----------------------------------------------------------------------------*/
     data trn_to_delete_account_trade(keep=transaction_key account_key);
       set acc_to_delete_key(keep=account_key);
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_core..fsc_account_trade_fact(keep=transaction_key account_key
                                                   dbkey=(account_key))
                                                  key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set trn_to_delete_account_trade.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.trn_to_delete_account_trade(%fcf_get_ds_opts(lib_name=purgekey, ds_name=trn_to_delete_account_trade, output_ds=Y));
      set trn_to_delete_account_trade;
      run;
  %end;

  %BEGIN_ACCOUNT_TRADE_FACT_PURGE:

  %fcf_purge_from_table(table=&db_lib_core..fsc_account_trade_fact,
                        entities_ds=acc_to_delete_key,
                        key_vars=account_key,
                        one_to_many_ind=Y,
                        other_output_ds=trn_to_delete_account_trade,
                        other_output_ds_vars=transaction_key account_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=trn_to_delete_account_trade,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_core,
                           table=fsc_account_trade_fact,
                           key_1=transaction_key,
                           key_1_type=N,
                           key_2=account_key,
                           key_2_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if &use_saved_account_trade_keys eq 1 %then
  %do;
     data trn_to_delete_account_trade;
      set purgekey.trn_to_delete_account_trade(%fcf_get_ds_opts(lib_name=purgekey, ds_name=trn_to_delete_account_trade));
      run;
  %end;

  /*------------------------------------
   * Delete from FSC_ACCOUNT_EVENT_FACT
   *------------------------------------*/
  %let use_saved_account_event_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.trn_to_delete_account_event)) %then
  %do;
     %let use_saved_account_event_keys = 1;

     data trn_to_delete_account_event;
      set purgekey.trn_to_delete_account_event(%fcf_get_ds_opts(lib_name=purgekey, ds_name=trn_to_delete_account_event));
      run;

     %goto BEGIN_ACCOUNT_EVENT_FACT_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*----------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * trn_to_delete_account_event fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned transactions.
      *----------------------------------------------------------------------------*/
     data trn_to_delete_account_event(keep=transaction_key account_key date_key);
       set acc_to_delete_key(keep=account_key);
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_core..fsc_account_event_fact(keep=transaction_key account_key date_key
                                                   dbkey=(account_key))
                                                  key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set trn_to_delete_account_event.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.trn_to_delete_account_event(%fcf_get_ds_opts(lib_name=purgekey, ds_name=trn_to_delete_account_event, output_ds=Y));
      set trn_to_delete_account_event;
      run;
  %end;

  %BEGIN_ACCOUNT_EVENT_FACT_PURGE:

  %fcf_purge_from_table(table=&db_lib_core..fsc_account_event_fact,
                        entities_ds=acc_to_delete_key,
                        key_vars=account_key,
                        one_to_many_ind=Y,
                        other_output_ds=trn_to_delete_account_event,
                        other_output_ds_vars=transaction_key account_key date_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=trn_to_delete_account_event,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_core,
                           table=fsc_account_event_fact,
                           key_1=transaction_key,
                           key_1_type=N,
                           key_2=account_key,
                           key_2_type=N,
                           key_3=date_key,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if &use_saved_account_event_keys eq 1 %then
  %do;
     data trn_to_delete_account_event;
      set purgekey.trn_to_delete_account_event(%fcf_get_ds_opts(lib_name=purgekey, ds_name=trn_to_delete_account_event));
      run;
  %end;

  /*--------------------------------------------------------------------------------
   * Delete from FSC_TRANSACTION_DIM
   * Do this after FSC_CASH_FLOW_FACT/FSC_ACCOUNT_EVENT_FACT/FSC_ACCOUNT_TRADE_FACT
   * due to constraints.
   *--------------------------------------------------------------------------------*/
  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.trn_to_delete_key)) %then
  %do;
     data trn_to_delete_key;
      set purgekey.trn_to_delete_key(%fcf_get_ds_opts(lib_name=purgekey, ds_name=trn_to_delete_key));
      run;

     %goto BEGIN_TRX_PURGE;
  %end;

  data trn_to_delete_key;
   set trn_to_delete_cash_flow_1(keep=transaction_key)
       trn_to_delete_cash_flow_2(keep=transaction_key)
       trn_to_delete_account_trade(keep=transaction_key)
       trn_to_delete_account_event(keep=transaction_key)
       ;
   run;

  /* delete these now since we had to keep them around after logging */
  proc datasets lib=work nowarn nolist;
    delete trn_to_delete_cash_flow_1
           trn_to_delete_cash_flow_2
           trn_to_delete_account_trade
           trn_to_delete_account_event
           ;
  quit;

  /* shouldn't be any duplicates but just in case */
  proc sort data=trn_to_delete_key nodupkey;
    by transaction_key;
   run;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     data purgekey.trn_to_delete_key(%fcf_get_ds_opts(lib_name=purgekey, ds_name=trn_to_delete_key, output_ds=Y));
      set trn_to_delete_key;
      run;
  %end;

  %BEGIN_TRX_PURGE:


  %let use_saved_trx_nums = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.trn_to_delete_num)) %then
  %do;
     %let use_saved_trx_nums = 1;
     %goto BEGIN_TRANSACTION_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * trn_to_delete_num fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned comments and 
      * attachments related to transactions. (on a restart)
      *------------------------------------------------------------------------------*/
     data trn_to_delete_num(keep=transaction_key date_key transaction_reference_number);
       set trn_to_delete_key(keep=transaction_key);
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_core..fsc_transaction_dim(keep=transaction_key date_key transaction_reference_number
                                                dbkey=(transaction_key))
                                               key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set trn_to_delete_num.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.trn_to_delete_num(%fcf_get_ds_opts(lib_name=purgekey, ds_name=trn_to_delete_num, output_ds=Y));
      set trn_to_delete_num;
      run;
  %end;

  %BEGIN_TRANSACTION_PURGE:

  %fcf_purge_from_table(table=&db_lib_core..fsc_transaction_dim,
                        entities_ds=trn_to_delete_key,
                        key_vars=transaction_key,
                        one_to_many_ind=N,
                        other_output_ds=trn_to_delete_num,
                        other_output_ds_vars=transaction_key date_key transaction_reference_number);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=trn_to_delete_num,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_core,
                           table=fsc_transaction_dim,
                           key_1=transaction_key,
                           key_1_type=N,
                           key_2=date_key,
                           key_2_type=N,
                           key_3=transaction_reference_number,
                           key_3_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if &use_saved_trx_nums eq 1 %then
  %do;
     data trn_to_delete_num;
      set purgekey.trn_to_delete_num(%fcf_get_ds_opts(lib_name=purgekey, ds_name=trn_to_delete_num));
      run;
  %end;

  /*--------------------------------------
   * Delete from FSC_ACCOUNT_ANALYSIS_DIM
   * unique index on account_number
   *--------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_account_analysis_dim,
                        entities_ds=acc_to_delete_num,
                        key_vars=account_number,
                        one_to_many_ind=N,
                        other_output_ds=account_analysis_dim_purged,
                        other_output_ds_vars=account_number);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=account_analysis_dim_purged,
                           libname=&db_lib_core,
                           table=fsc_account_analysis_dim,
                           key_1=account_number,
                           key_1_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*----------------------------------------------------------------
   * Delete from FSC_ACCOUNT_DIM
   * Do this after the other account tables because of constraints!
   *----------------------------------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_account_dim,
                        entities_ds=acc_to_delete_key,
                        key_vars=account_key,
                        one_to_many_ind=N,
                        other_output_ds=account_dim_purged,
                        other_output_ds_vars=account_key account_number);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=account_dim_purged,
                           libname=&db_lib_core,
                           table=fsc_account_dim,
                           key_1=account_key,
                           key_1_type=N,
                           key_2=account_number,
                           key_2_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*----------------------------------------------------------------------
   * Update FSC_ACCOUNT_DIM, set opened_by_party_* to NULL if the
   * opened_by_party_number matches any of the eligible parties to purge.
   *----------------------------------------------------------------------*/
  data &db_lib_core..fsc_account_dim
       account_dim_updated(keep=account_number updated_opened_by_party_number rec_updated_by_key_counter account_key)
       ;
   set pty_to_delete_num(keep=party_number rename=(party_number=opened_by_party_number));
    rec_updated_by_key_counter = 0;
    do until (_iorc_ ne %sysrc(_sok));
       modify &db_lib_core..fsc_account_dim(cntllev=record dbkey=(opened_by_party_number)) key=dbkey;
       if _iorc_ = %sysrc(_sok) then
       do;
          rec_updated_by_key_counter + 1;
          updated_opened_by_party_number = opened_by_party_number;
          opened_by_party_number = '';
          opened_by_party_name   = '';
          opened_by_party_title  = '';
          %if %upcase(&test_run) eq N %then
          %do;
             replace &db_lib_core..fsc_account_dim;
          %end;
          output account_dim_updated;
          /* set it back so the dbkey search works */
          opened_by_party_number = updated_opened_by_party_number;
       end;
       else
       do;
          _error_ = 0;
       end;
    end;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error updating opened_by_party fields in &db_lib_core..FSC_ACCOUNT_DIM;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(rows_updated=Y,
                           in_ds=account_dim_updated,
                           libname=&db_lib_core,
                           table=fsc_account_dim,
                           key_1=updated_opened_by_party_number,
                           key_1_type=C,
                           key_2=account_number,
                           key_2_type=C,
                           key_3=account_key,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*---------------------------
   * Delete from FSC_PARTY_DIM
   *---------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_party_dim,
                        entities_ds=pty_to_delete_key,
                        key_vars=party_key,
                        one_to_many_ind=N,
                        other_output_ds=party_dim_purged,
                        other_output_ds_vars=party_key party_number);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=party_dim_purged,
                           libname=&db_lib_core,
                           table=fsc_party_dim,
                           key_1=party_key,
                           key_1_type=N,
                           key_2=party_number,
                           key_2_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*------------------------------------
   * Delete from FSC_PARTY_PROFILE_FACT
   *------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_party_profile_fact,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        other_output_ds=party_profile_fact_purged,
                        other_output_ds_vars=party_number month_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=party_profile_fact_purged,
                           libname=&db_lib_core,
                           table=fsc_party_profile_fact,
                           key_1=party_number,
                           key_1_type=C,
                           key_2=month_key,
                           key_2_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*---------------------------------
   * Delete from FSC_CLASSIFIER_FACT
   *---------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_classifier_fact,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        other_output_ds=classifier_fact_purged,
                        other_output_ds_vars=party_number month_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=classifier_fact_purged,
                           libname=&db_lib_core,
                           table=fsc_classifier_fact,
                           key_1=party_number,
                           key_1_type=C,
                           key_2=month_key,
                           key_2_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-----------------------------------
   * Delete from FSC_ENTITY_PEER_GROUP
   * Party (PTY)
   *-----------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_entity_peer_group,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        rename_var_from=party_number,
                        rename_var_to=entity_number,
                        db_key_vars=entity_number entity_level_code,
                        db_key_elc_var=entity_level_code,
                        db_key_elc_value=PTY,
                        other_output_ds=entity_peer_group_purged,
                        other_output_ds_vars=entity_number entity_level_code peer_group_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=entity_peer_group_purged,
                           libname=&db_lib_core,
                           table=fsc_entity_peer_group,
                           key_1=entity_number,
                           key_1_type=C,
                           key_2=entity_level_code,
                           key_2_type=C,
                           key_3=peer_group_id,
                           key_3_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-----------------------------------
   * Delete from FSC_ENTITY_PEER_GROUP
   * Account (ACC)
   *-----------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_entity_peer_group,
                        entities_ds=acc_to_delete_num,
                        key_vars=account_number,
                        one_to_many_ind=Y,
                        rename_var_from=account_number,
                        rename_var_to=entity_number,
                        db_key_vars=entity_number entity_level_code,
                        db_key_elc_var=entity_level_code,
                        db_key_elc_value=ACC,
                        other_output_ds=entity_peer_group_purged,
                        other_output_ds_vars=entity_number entity_level_code peer_group_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=entity_peer_group_purged,
                           libname=&db_lib_core,
                           table=fsc_entity_peer_group,
                           key_1=entity_number,
                           key_1_type=C,
                           key_2=entity_level_code,
                           key_2_type=C,
                           key_3=peer_group_id,
                           key_3_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*------------------------------------
   * Delete from FSC_ENTITY_PROFILE_AGG
   * Party (PTY)
   *------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_entity_profile_agg,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        rename_var_from=party_number,
                        rename_var_to=entity_number,
                        db_key_vars=entity_number entity_level_code,
                        db_key_elc_var=entity_level_code,
                        db_key_elc_value=PTY,
                        other_output_ds=entity_profile_agg_purged,
                        other_output_ds_vars=entity_number entity_level_code summary_period_code profile_group_id summary_begin_date_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=entity_profile_agg_purged,
                           libname=&db_lib_core,
                           table=fsc_entity_profile_agg,
                           key_1=entity_number,
                           key_1_type=C,
                           key_2=entity_level_code,
                           key_2_type=C,
                           key_3=summary_period_code,
                           key_3_type=C,
                           key_4=profile_group_id,
                           key_4_type=C,
                           key_5=summary_begin_date_key,
                           key_5_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*------------------------------------
   * Delete from FSC_ENTITY_PROFILE_AGG
   * Account (ACC)
   *------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_entity_profile_agg,
                        entities_ds=acc_to_delete_num,
                        key_vars=account_number,
                        one_to_many_ind=Y,
                        rename_var_from=account_number,
                        rename_var_to=entity_number,
                        db_key_vars=entity_number entity_level_code,
                        db_key_elc_var=entity_level_code,
                        db_key_elc_value=ACC,
                        other_output_ds=entity_profile_agg_purged,
                        other_output_ds_vars=entity_number entity_level_code summary_period_code profile_group_id summary_begin_date_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=entity_profile_agg_purged,
                           libname=&db_lib_core,
                           table=fsc_entity_profile_agg,
                           key_1=entity_number,
                           key_1_type=C,
                           key_2=entity_level_code,
                           key_2_type=C,
                           key_3=summary_period_code,
                           key_3_type=C,
                           key_4=profile_group_id,
                           key_4_type=C,
                           key_5=summary_begin_date_key,
                           key_5_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*----------------------------------------
   * Delete from FSC_ENTITY_PROFILE_HISTORY
   * Party (PTY)
   *----------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_entity_profile_history,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        rename_var_from=party_number,
                        rename_var_to=entity_number,
                        db_key_vars=entity_number entity_level_code,
                        db_key_elc_var=entity_level_code,
                        db_key_elc_value=PTY,
                        other_output_ds=entity_profile_history_purged,
                        other_output_ds_vars=entity_number entity_level_code history_period_code profile_group_id history_begin_date_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=entity_profile_history_purged,
                           libname=&db_lib_core,
                           table=fsc_entity_profile_history,
                           key_1=entity_number,
                           key_1_type=C,
                           key_2=entity_level_code,
                           key_2_type=C,
                           key_3=history_period_code,
                           key_3_type=C,
                           key_4=profile_group_id,
                           key_4_type=C,
                           key_5=history_begin_date_key,
                           key_5_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*----------------------------------------
   * Delete from FSC_ENTITY_PROFILE_HISTORY
   * Account (ACC)
   *----------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_entity_profile_history,
                        entities_ds=acc_to_delete_num,
                        key_vars=account_number,
                        one_to_many_ind=Y,
                        rename_var_from=account_number,
                        rename_var_to=entity_number,
                        db_key_vars=entity_number entity_level_code,
                        db_key_elc_var=entity_level_code,
                        db_key_elc_value=ACC,
                        other_output_ds=entity_profile_history_purged,
                        other_output_ds_vars=entity_number entity_level_code history_period_code profile_group_id history_begin_date_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=entity_profile_history_purged,
                           libname=&db_lib_core,
                           table=fsc_entity_profile_history,
                           key_1=entity_number,
                           key_1_type=C,
                           key_2=entity_level_code,
                           key_2_type=C,
                           key_3=history_period_code,
                           key_3_type=C,
                           key_4=profile_group_id,
                           key_4_type=C,
                           key_5=history_begin_date_key,
                           key_5_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*--------------------------------------------
   * Delete from FSC_ENTITY_PROFILE_SUMMARY_AGG
   * Party (PTY)
   *
   * other_output_dc naming convention different
   * due to length of table name
   *--------------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_entity_profile_summary_agg,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        rename_var_from=party_number,
                        rename_var_to=entity_number,
                        db_key_vars=entity_number entity_level_code,
                        db_key_elc_var=entity_level_code,
                        db_key_elc_value=PTY,
                        other_output_ds=entity_profile_summry_agg_purged,
                        other_output_ds_vars=entity_number entity_level_code summary_period_code profile_group_id summary_group_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=entity_profile_summry_agg_purged,
                           libname=&db_lib_core,
                           table=fsc_entity_profile_summary_agg,
                           key_1=entity_number,
                           key_1_type=C,
                           key_2=entity_level_code,
                           key_2_type=C,
                           key_3=summary_period_code,
                           key_3_type=C,
                           key_4=profile_group_id,
                           key_4_type=C,
                           key_5=summary_group_id,
                           key_5_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*--------------------------------------------
   * Delete from FSC_ENTITY_PROFILE_SUMMARY_AGG
   * Account (ACC)
   *--------------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_entity_profile_summary_agg,
                        entities_ds=acc_to_delete_num,
                        key_vars=account_number,
                        one_to_many_ind=Y,
                        rename_var_from=account_number,
                        rename_var_to=entity_number,
                        db_key_vars=entity_number entity_level_code,
                        db_key_elc_var=entity_level_code,
                        db_key_elc_value=ACC,
                        other_output_ds=entity_profile_summry_agg_purged,
                        other_output_ds_vars=entity_number entity_level_code summary_period_code profile_group_id summary_group_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=entity_profile_summry_agg_purged,
                           libname=&db_lib_core,
                           table=fsc_entity_profile_summary_agg,
                           key_1=entity_number,
                           key_1_type=C,
                           key_2=entity_level_code,
                           key_2_type=C,
                           key_3=summary_period_code,
                           key_3_type=C,
                           key_4=profile_group_id,
                           key_4_type=C,
                           key_5=summary_group_id,
                           key_5_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-----------------------------
   * Delete from FSC_PARTY_ASSOC
   *-----------------------------*/
  /* first by party_number */
  %fcf_purge_from_table(table=&db_lib_core..fsc_party_assoc,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        other_output_ds=party_assoc_purged,
                        other_output_ds_vars=party_number related_party_number relationship_type_code change_begin_date);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=party_assoc_purged,
                           %if %upcase(&test_run) eq Y %then
                           %do;
                           delete_in_ds_when_done=N,
                           %end;
                           libname=&db_lib_core,
                           table=fsc_party_assoc,
                           key_1=party_number,
                           key_1_type=C,
                           key_2=related_party_number,
                           key_2_type=C,
                           key_3=relationship_type_code,
                           key_3_type=C,
                           key_4=change_begin_date,
                           key_4_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /* next by related_party_number */
  %fcf_purge_from_table(table=&db_lib_core..fsc_party_assoc,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        rename_var_from=party_number,
                        rename_var_to=related_party_number,
                        db_key_vars=related_party_number,
                        other_output_ds=party_assoc_purged_2,
                        other_output_ds_vars=related_party_number party_number relationship_type_code change_begin_date);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if %upcase(&test_run) eq Y %then
  %do;
     proc sort data=party_assoc_purged;
       by party_number related_party_number relationship_type_code change_begin_date;
      run;

     proc sort data=party_assoc_purged_2;
       by party_number related_party_number relationship_type_code change_begin_date;
      run;

     data party_assoc_purged_2;
       merge party_assoc_purged_2(in=a) party_assoc_purged(in=b);
       by party_number related_party_number relationship_type_code change_begin_date;
       if a and not b;
      run;

     proc datasets lib=work nowarn nolist;
       delete party_assoc_purged;
     quit;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=party_assoc_purged_2,
                           libname=&db_lib_core,
                           table=fsc_party_assoc,
                           key_1=related_party_number,
                           key_1_type=C,
                           key_2=party_number,
                           key_2_type=C,
                           key_3=relationship_type_code,
                           key_3_type=C,
                           key_4=change_begin_date,
                           key_4_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*---------------------------------------
   * Delete from FSC_PARTY_ASSOC_ATTRIBUTE
   *---------------------------------------*/
  /* first by party_number */
  %fcf_purge_from_table(table=&db_lib_core..fsc_party_assoc_attribute,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        other_output_ds=party_assoc_attribute_purged,
                        other_output_ds_vars=party_number related_party_number relationship_type_code attribute_type_code change_begin_date);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=party_assoc_attribute_purged,
                           %if %upcase(&test_run) eq Y %then
                           %do;
                           delete_in_ds_when_done=N,
                           %end;
                           libname=&db_lib_core,
                           table=fsc_party_assoc_attribute,
                           key_1=party_number,
                           key_1_type=C,
                           key_2=related_party_number,
                           key_2_type=C,
                           key_3=relationship_type_code,
                           key_3_type=C,
                           key_4=attribute_type_code,
                           key_4_type=C,
                           key_5=change_begin_date,
                           key_5_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /* next by related_party_number */
  %fcf_purge_from_table(table=&db_lib_core..fsc_party_assoc_attribute,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y
                        rename_var_from=party_number,
                        rename_var_to=related_party_number,
                        db_key_vars=related_party_number,
                        other_output_ds=party_assoc_attribute_purged_2,
                        other_output_ds_vars=related_party_number party_number relationship_type_code attribute_type_code change_begin_date);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if %upcase(&test_run) eq Y %then
  %do;
     proc sort data=party_assoc_attribute_purged;
       by related_party_number party_number relationship_type_code attribute_type_code change_begin_date;
      run;

     proc sort data=party_assoc_attribute_purged_2;
       by related_party_number party_number relationship_type_code attribute_type_code change_begin_date;
      run;

     data party_assoc_attribute_purged_2;
       merge party_assoc_attribute_purged_2(in=a) party_assoc_attribute_purged(in=b);
       by related_party_number party_number relationship_type_code attribute_type_code change_begin_date;
       if a and not b;
      run;

     proc datasets lib=work nowarn nolist;
       delete party_assoc_attribute_purged;
     quit;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=party_assoc_attribute_purged_2,
                           libname=&db_lib_core,
                           table=fsc_party_assoc_attribute,
                           key_1=related_party_number,
                           key_1_type=C,
                           key_2=party_number,
                           key_2_type=C,
                           key_3=relationship_type_code,
                           key_3_type=C,
                           key_4=attribute_type_code,
                           key_4_type=C,
                           key_5=change_begin_date,
                           key_5_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-----------------------------
   * Delete from FSC_ADDRESS_DIM
   * Party (PTY)
   *-----------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_address_dim,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        rename_var_from=party_number,
                        rename_var_to=primary_entity_number,
                        db_key_vars=primary_entity_number primary_entity_level_code,
                        db_key_elc_var=primary_entity_level_code,
                        db_key_elc_value=PTY,
                        other_output_ds=address_dim_purged,
                        other_output_ds_vars=primary_entity_number primary_entity_level_code address_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=address_dim_purged,
                           libname=&db_lib_core,
                           table=fsc_address_dim,
                           key_1=primary_entity_number,
                           key_1_type=C,
                           key_2=primary_entity_level_code,
                           key_2_type=C,
                           key_3=address_key,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-----------------------------
   * Delete from FSC_ADDRESS_DIM
   * Account (ACC)
   *-----------------------------*/
  %fcf_purge_from_table(table=&db_lib_core..fsc_address_dim,
                        entities_ds=acc_to_delete_num,
                        key_vars=account_number,
                        one_to_many_ind=Y,
                        rename_var_from=account_number,
                        rename_var_to=primary_entity_number,
                        db_key_vars=primary_entity_number primary_entity_level_code,
                        db_key_elc_var=primary_entity_level_code,
                        db_key_elc_value=ACC,
                        other_output_ds=address_dim_purged,
                        other_output_ds_vars=primary_entity_number primary_entity_level_code address_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=address_dim_purged,
                           libname=&db_lib_core,
                           table=fsc_address_dim,
                           key_1=primary_entity_number,
                           key_1_type=C,
                           key_2=primary_entity_level_code,
                           key_2_type=C,
                           key_3=address_key,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;


  %MACRO_END:
 
  %if &trans_rc eq 3 or &trans_rc ge 5 %then
     %fcf_execute_macro(fcf_error);
  %else %do;
     %fcf_execute_macro(post&_fcfmodule_);
     %fcf_execute_macro(fcf_success);
  %end;

%mend fcf_purge_from_core;

