/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    fcf_purge_from_kc.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
| DESC:    Delete data from the KC
+------------------------------------------------------------------------------+
| USAGE: %fcf_purge_from_kc;
+------------------------------------------------------------------------------+
| COMMENTS: 
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2019 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_purge_from_kc;

  /*------------
   * Set Module
   *------------*/
  %local _fcfmodule_;
  %let _fcfmodule_=FCF_PURGE_FROM_KC;

  /*---------------------------------------
   * Call prefcf_purge_from_kc stub macro.
   *---------------------------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*-------------------------------------------
   * Set error code to 0 and message to blank.
   *-------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;

  %put NOTE: FCF: Deleting from the KC.;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.alt_to_delete)) and
      %sysfunc(exist(purgekey.cdr_to_delete)) %then
  %do;
     data alt_to_delete;
      set purgekey.alt_to_delete(%fcf_get_ds_opts(lib_name=purgekey, ds_name=alt_to_delete));
      run;

     data cdr_to_delete;
      set purgekey.cdr_to_delete(%fcf_get_ds_opts(lib_name=purgekey, ds_name=cdr_to_delete));
      run;

     %goto BEGIN_KC_PURGE;
  %end;

  /*----------------------------------------------------
   * Get the alerts for the deleted customers (primary)
   *----------------------------------------------------*/
  /* one to many join */
  data pty_alt_to_delete_primary(keep=alert_id);
    if 0 then set &db_lib_kc..fsk_alert(keep=primary_entity_level_code);
    primary_entity_level_code = 'PTY';
    set pty_to_delete_num(keep=party_number rename=(party_number = primary_entity_number));
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_kc..fsk_alert(keep=alert_id primary_entity_number primary_entity_level_code
                                 dbkey=(primary_entity_number primary_entity_level_code)
                                 dbsastype=(primary_entity_level_code = 'char(3)'))
                                key=dbkey;
       if _iorc_ = %sysrc(_sok) then
          output;
       else
          _error_ = 0;
    end;
   run;

  /*--------------------------------------------------------------------------------
   * Get the alerts for the deleted customers (alerted)
   * Alerted entity is the entity against which the alerts are listed in the UI ...
   * for account and household alerts, they are rolled up to the responsible party
   * (primary owner or head of household), so in the entity triage you may see
   * party, account, and household alerts bundled together under a single party
   *--------------------------------------------------------------------------------*/
  /* one to many join */
  data pty_alt_to_delete_alerted(keep=alert_id);
    if 0 then set &db_lib_kc..fsk_alert(keep=alerted_entity_level_code);
    alerted_entity_level_code = 'PTY';
    set pty_to_delete_num(keep=party_number rename=(party_number = alerted_entity_number));
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_kc..fsk_alert(keep=alert_id alerted_entity_number alerted_entity_level_code
                                 dbkey=(alerted_entity_number alerted_entity_level_code)
                                 dbsastype=(alerted_entity_level_code = 'char(3)'))
                                key=dbkey;
       if _iorc_ = %sysrc(_sok) then
          output;
       else
          _error_ = 0;
    end;
   run;

  /*---------------------------------------------------
   * Get the alerts for the deleted accounts (primary)
   *---------------------------------------------------*/
  /* one to many join */
  data acc_alt_to_delete_primary(keep=alert_id);
    if 0 then set &db_lib_kc..fsk_alert(keep=primary_entity_level_code);
    primary_entity_level_code = 'ACC';
    set acc_to_delete_num(keep=account_number rename=(account_number = primary_entity_number));
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_kc..fsk_alert(keep=alert_id primary_entity_number primary_entity_level_code
                                 dbkey=(primary_entity_number primary_entity_level_code)
                                 dbsastype=(primary_entity_level_code = 'char(3)'))
                                key=dbkey;
       if _iorc_ = %sysrc(_sok) then
          output;
       else
          _error_ = 0;
    end;
   run;

  /*-----------------------------------------------------
   * Get the alerts for the deleted households (primary)
   *-----------------------------------------------------*/
  /* one to many join */
  data hhd_alt_to_delete_primary(keep=alert_id);
    if 0 then set &db_lib_kc..fsk_alert(keep=primary_entity_level_code);
    primary_entity_level_code = 'HHD';
    set hhd_to_delete_key(keep=household_key rename=(household_key = primary_entity_key));
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_kc..fsk_alert(keep=alert_id primary_entity_key primary_entity_level_code
                                 dbkey=(primary_entity_key primary_entity_level_code)
                                 dbsastype=(primary_entity_level_code = 'char(3)'))
                                key=dbkey;
       if _iorc_ = %sysrc(_sok) then
          output;
       else
          _error_ = 0;
    end;
   run;

  data alt_to_delete;
   set pty_alt_to_delete_primary
       pty_alt_to_delete_alerted
       acc_alt_to_delete_primary
       hhd_alt_to_delete_primary
       ;
   run;

  proc datasets lib=work nowarn nolist;
    delete pty_alt_to_delete_primary
           pty_alt_to_delete_alerted
           acc_alt_to_delete_primary
           hhd_alt_to_delete_primary
           ;
  quit;

  proc sort data=alt_to_delete nodupkey;
    by alert_id;
   run;

  /*-----------------------------------------------------------------------
   * If any of those alerts are related to any remaining (open) cases then
   * don't purge them.  Remove them from the list of alerts to purge.
   *-----------------------------------------------------------------------*/
  /* one to many join */
  data alerts_linked_to_open_cases(keep=alert_id);
    set alt_to_delete(keep=alert_id);
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_kc..fsk_case_transaction(keep=alert_id
                                            dbkey=(alert_id))
                                           key=dbkey;
       if _iorc_ = %sysrc(_sok) then
          output;
       else
          _error_ = 0;
    end;
   run;

  proc sort data=alerts_linked_to_open_cases nodupkey;
    by alert_id;
   run;

  %if %upcase(&test_run) eq Y %then
  %do;
     proc sort data=case_transaction_purged;
       by alert_id;
      run;

     data alerts_linked_to_open_cases;
       merge alerts_linked_to_open_cases(in=a) case_transaction_purged(in=b keep=alert_id);
       by alert_id;
       if a and not b;
      run;
  %end;

  data alt_to_delete;
    if 0 then set &db_lib_kc..fsk_comment(keep=object_id rename=(object_id = alert_id_char));
    label alert_id_char = "alert_id_char";
    merge alt_to_delete(in=a) alerts_linked_to_open_cases(in=b);
    by alert_id;
    if a and not b;
    alert_id_char = strip(put(alert_id, best.));
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %let _fcfmsg_=ERROR: FCF: Unable to create Alert key data set alt_to_delete;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  proc datasets lib=work nowarn nolist;
    delete alerts_linked_to_open_cases;
  quit;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     data purgekey.alt_to_delete(%fcf_get_ds_opts(lib_name=purgekey, ds_name=alt_to_delete, output_ds=Y));
      set alt_to_delete;
      run;
  %end;

  /*--------------------------------------------------------------------------
   * Get the CDD review keys we'll use to purge from CDD review tables later.
   * By PTY only.
   *--------------------------------------------------------------------------*/
  /* one to many join */
  data cdr_to_delete(keep=review_key review_key_char);
    if 0 then set &db_lib_kc..fsk_cdd_review(keep=primary_entity_level_code
                                                  primary_entity_number rename=(primary_entity_number=review_key_char));
    label review_key_char = "review_key_char";
    primary_entity_level_code = 'PTY';
    set pty_to_delete_num(keep=party_number rename=(party_number = primary_entity_number));
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_kc..fsk_cdd_review(keep=review_key primary_entity_number primary_entity_level_code
                                      dbkey=(primary_entity_number primary_entity_level_code)
                                      dbsastype=(primary_entity_level_code = 'char(3)'))
                                     key=dbkey;
       if _iorc_ = %sysrc(_sok) then
       do;
          review_key_char = strip(put(review_key, best.));
          output;
       end;
       else
          _error_ = 0;
    end;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %let _fcfmsg_=ERROR: FCF: Unable to create CDD Review key data set cdr_to_delete;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     data purgekey.cdr_to_delete(%fcf_get_ds_opts(lib_name=purgekey, ds_name=cdr_to_delete, output_ds=Y));
      set cdr_to_delete;
      run;
  %end;

  %BEGIN_KC_PURGE:

  /*-----------------------------------
   * Delete from FSK_COMMENT
   * Party (PTY)
   *-----------------------------------*/
  %let use_saved_comment_pty_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.comments_to_delete_pty)) %then
  %do;
     %let use_saved_comment_pty_keys = 1;
     %goto BEGIN_COMMENT_PTY_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * comments_to_delete_pty fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned comments (on a restart)
      *------------------------------------------------------------------------------*/
     data comments_to_delete_pty(keep=object_id object_type_cd comment_id);
       if 0 then set &db_lib_kc..fsk_comment(keep=object_type_cd);
       set pty_to_delete_num(keep=party_number rename=(party_number=object_id));
       object_type_cd = "PTY";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_comment(keep=object_id object_type_cd comment_id
                                      dbkey=(object_type_cd object_id)
                                      dbsastype=(object_type_cd = 'char(3)'))
                                     key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set comments_to_delete_pty.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.comments_to_delete_pty(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_pty, output_ds=Y));
      set comments_to_delete_pty;
      run;
  %end;

  %BEGIN_COMMENT_PTY_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_comment,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        rename_var_from=party_number,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=PTY,
                        other_output_ds=comments_to_delete_pty,
                        other_output_ds_vars=object_id object_type_cd comment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=comments_to_delete_pty,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_comment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=comment_id,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if &use_saved_comment_pty_keys eq 1 %then
  %do;
     data comments_to_delete_pty;
      set purgekey.comments_to_delete_pty(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_pty));
      run;
  %end;

  /*-----------------------------------
   * Delete from FSK_COMMENT
   * Account (ACC)
   *-----------------------------------*/
  %let use_saved_comment_acc_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.comments_to_delete_acc)) %then
  %do;
     %let use_saved_comment_acc_keys = 1;
     %goto BEGIN_COMMENT_ACC_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * comments_to_delete_acc fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned comments (on a restart)
      *------------------------------------------------------------------------------*/
     data comments_to_delete_acc(keep=object_id object_type_cd comment_id);
       if 0 then set &db_lib_kc..fsk_comment(keep=object_type_cd);
       set acc_to_delete_num(keep=account_number rename=(account_number=object_id));
       object_type_cd = "ACC";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_comment(keep=object_id object_type_cd comment_id
                                      dbkey=(object_type_cd object_id)
                                      dbsastype=(object_type_cd = 'char(3)'))
                                     key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set comments_to_delete_acc.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.comments_to_delete_acc(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_acc, output_ds=Y));
      set comments_to_delete_acc;
      run;
  %end;

  %BEGIN_COMMENT_ACC_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_comment,
                        entities_ds=acc_to_delete_num,
                        key_vars=account_number,
                        one_to_many_ind=Y,
                        rename_var_from=account_number,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=ACC,
                        other_output_ds=comments_to_delete_acc,
                        other_output_ds_vars=object_id object_type_cd comment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=comments_to_delete_acc,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_comment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=comment_id,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if &use_saved_comment_acc_keys eq 1 %then
  %do;
     data comments_to_delete_acc;
      set purgekey.comments_to_delete_acc(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_acc));
      run;
  %end;

  /*-----------------------------------
   * Delete from FSK_COMMENT
   * Household (HHD)
   *-----------------------------------*/
  %let use_saved_comment_hhd_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.comments_to_delete_hhd)) %then
  %do;
     %let use_saved_comment_hhd_keys = 1;
     %goto BEGIN_COMMENT_HHD_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * comments_to_delete_hhd fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned comments (on a restart)
      *------------------------------------------------------------------------------*/
     data comments_to_delete_hhd(keep=object_id object_type_cd comment_id);
       if 0 then set &db_lib_kc..fsk_comment(keep=object_type_cd);
       set hhd_to_delete_num(keep=household_number rename=(household_number=object_id));
       object_type_cd = "HHD";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_comment(keep=object_id object_type_cd comment_id
                                      dbkey=(object_type_cd object_id)
                                      dbsastype=(object_type_cd = 'char(3)'))
                                     key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set comments_to_delete_hhd.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.comments_to_delete_hhd(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_hhd, output_ds=Y));
      set comments_to_delete_hhd;
      run;
  %end;

  %BEGIN_COMMENT_HHD_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_comment,
                        entities_ds=hhd_to_delete_num,
                        key_vars=household_number,
                        one_to_many_ind=Y,
                        rename_var_from=household_number,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=HHD,
                        other_output_ds=comments_to_delete_hhd,
                        other_output_ds_vars=object_id object_type_cd comment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=comments_to_delete_hhd,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_comment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=comment_id,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if &use_saved_comment_hhd_keys eq 1 %then
  %do;
     data comments_to_delete_hhd;
      set purgekey.comments_to_delete_hhd(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_hhd));
      run;
  %end;

  /*-----------------------------------
   * Delete from FSK_COMMENT
   * Case (CAS)
   *-----------------------------------*/
  %let use_saved_comment_cas_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.comments_to_delete_cas)) %then
  %do;
     %let use_saved_comment_cas_keys = 1;
     %goto BEGIN_COMMENT_CAS_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * comments_to_delete_cas fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned comments (on a restart)
      *------------------------------------------------------------------------------*/
     data comments_to_delete_cas(keep=object_id object_type_cd comment_id);
       if 0 then set &db_lib_kc..fsk_comment(keep=object_type_cd);
       set cas_to_delete(keep=case_id_char rename=(case_id_char=object_id));
       object_type_cd = "CAS";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_comment(keep=object_id object_type_cd comment_id
                                      dbkey=(object_type_cd object_id)
                                      dbsastype=(object_type_cd = 'char(3)'))
                                     key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set comments_to_delete_cas.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.comments_to_delete_cas(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_cas, output_ds=Y));
      set comments_to_delete_cas;
      run;
  %end;

  %BEGIN_COMMENT_CAS_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_comment,
                        entities_ds=cas_to_delete,
                        key_vars=case_id_char,
                        one_to_many_ind=Y,
                        rename_var_from=case_id_char,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=CAS,
                        other_output_ds=comments_to_delete_cas,
                        other_output_ds_vars=object_id object_type_cd comment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=comments_to_delete_cas,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_comment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=comment_id,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if &use_saved_comment_cas_keys eq 1 %then
  %do;
     data comments_to_delete_cas;
      set purgekey.comments_to_delete_cas(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_cas));
      run;
  %end;

  /*-----------------------------------
   * Delete from FSK_COMMENT
   * Report (RPT)
   *-----------------------------------*/
  %let use_saved_comment_rpt_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.comments_to_delete_rpt)) %then
  %do;
     %let use_saved_comment_rpt_keys = 1;
     %goto BEGIN_COMMENT_RPT_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * comments_to_delete_rpt fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned comments (on a restart)
      *------------------------------------------------------------------------------*/
     data comments_to_delete_rpt(keep=object_id object_type_cd comment_id);
       if 0 then set &db_lib_kc..fsk_comment(keep=object_type_cd);
       set rpt_to_delete(keep=report_key_char rename=(report_key_char=object_id));
       object_type_cd = "RPT";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_comment(keep=object_id object_type_cd comment_id
                                      dbkey=(object_type_cd object_id)
                                      dbsastype=(object_type_cd = 'char(3)'))
                                     key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set comments_to_delete_rpt.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.comments_to_delete_rpt(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_rpt, output_ds=Y));
      set comments_to_delete_rpt;
      run;
  %end;

  %BEGIN_COMMENT_RPT_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_comment,
                        entities_ds=rpt_to_delete,
                        key_vars=report_key_char,
                        one_to_many_ind=Y,
                        rename_var_from=report_key_char,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=RPT,
                        other_output_ds=comments_to_delete_rpt,
                        other_output_ds_vars=object_id object_type_cd comment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=comments_to_delete_rpt,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_comment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=comment_id,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if &use_saved_comment_rpt_keys eq 1 %then
  %do;
     data comments_to_delete_rpt;
      set purgekey.comments_to_delete_rpt(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_rpt));
      run;
  %end;

  /*-----------------------------------
   * Delete from FSK_COMMENT
   * EFile (EFL)
   *-----------------------------------*/
  %let use_saved_comment_efl_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.comments_to_delete_efl)) %then
  %do;
     %let use_saved_comment_efl_keys = 1;
     %goto BEGIN_COMMENT_EFL_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * comments_to_delete_efl fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned comments (on a restart)
      *------------------------------------------------------------------------------*/
     data comments_to_delete_efl(keep=object_id object_type_cd comment_id);
       if 0 then set &db_lib_kc..fsk_comment(keep=object_type_cd);
       set efl_to_delete(keep=efile_key_char rename=(efile_key_char=object_id));
       object_type_cd = "EFL";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_comment(keep=object_id object_type_cd comment_id
                                      dbkey=(object_type_cd object_id)
                                      dbsastype=(object_type_cd = 'char(3)'))
                                     key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set comments_to_delete_efl.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.comments_to_delete_efl(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_efl, output_ds=Y));
      set comments_to_delete_efl;
      run;
  %end;

  %BEGIN_COMMENT_EFL_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_comment,
                        entities_ds=efl_to_delete,
                        key_vars=efile_key_char,
                        one_to_many_ind=Y,
                        rename_var_from=efile_key_char,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=EFL,
                        other_output_ds=comments_to_delete_efl,
                        other_output_ds_vars=object_id object_type_cd comment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=comments_to_delete_efl,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_comment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=comment_id,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if &use_saved_comment_efl_keys eq 1 %then
  %do;
     data comments_to_delete_efl;
      set purgekey.comments_to_delete_efl(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_efl));
      run;
  %end;

  /*-----------------------------------
   * Delete from FSK_COMMENT
   * CDD Review (CDR)
   *-----------------------------------*/
  %let use_saved_comment_cdr_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.comments_to_delete_cdr)) %then
  %do;
     %let use_saved_comment_cdr_keys = 1;
     %goto BEGIN_COMMENT_CDR_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * comments_to_delete_cdr fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned comments (on a restart)
      *------------------------------------------------------------------------------*/
     data comments_to_delete_cdr(keep=object_id object_type_cd comment_id);
       if 0 then set &db_lib_kc..fsk_comment(keep=object_type_cd);
       set cdr_to_delete(keep=review_key_char rename=(review_key_char=object_id));
       object_type_cd = "CDR";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_comment(keep=object_id object_type_cd comment_id
                                      dbkey=(object_type_cd object_id)
                                      dbsastype=(object_type_cd = 'char(3)'))
                                     key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set comments_to_delete_cdr.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.comments_to_delete_cdr(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_cdr, output_ds=Y));
      set comments_to_delete_cdr;
      run;
  %end;

  %BEGIN_COMMENT_CDR_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_comment,
                        entities_ds=cdr_to_delete,
                        key_vars=review_key_char,
                        one_to_many_ind=Y,
                        rename_var_from=review_key_char,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=CDR,
                        other_output_ds=comments_to_delete_cdr,
                        other_output_ds_vars=object_id object_type_cd comment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=comments_to_delete_cdr,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_comment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=comment_id,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if &use_saved_comment_cdr_keys eq 1 %then
  %do;
     data comments_to_delete_cdr;
      set purgekey.comments_to_delete_cdr(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_cdr));
      run;
  %end;

  /*-----------------------------------
   * Delete from FSK_COMMENT
   * Alert (ALT)
   *-----------------------------------*/
  %let use_saved_comment_alt_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.comments_to_delete_alt)) %then
  %do;
     %let use_saved_comment_alt_keys = 1;
     %goto BEGIN_COMMENT_ALT_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * comments_to_delete_alt fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned comments (on a restart)
      *------------------------------------------------------------------------------*/
     data comments_to_delete_alt(keep=object_id object_type_cd comment_id);
       if 0 then set &db_lib_kc..fsk_comment(keep=object_type_cd);
       set alt_to_delete(keep=alert_id_char rename=(alert_id_char=object_id));
       object_type_cd = "ALT";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_comment(keep=object_id object_type_cd comment_id
                                      dbkey=(object_type_cd object_id)
                                      dbsastype=(object_type_cd = 'char(3)'))
                                     key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set comments_to_delete_alt.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.comments_to_delete_alt(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_alt, output_ds=Y));
      set comments_to_delete_alt;
      run;
  %end;

  %BEGIN_COMMENT_ALT_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_comment,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id_char,
                        one_to_many_ind=Y,
                        rename_var_from=alert_id_char,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=ALT,
                        other_output_ds=comments_to_delete_alt,
                        other_output_ds_vars=object_id object_type_cd comment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=comments_to_delete_alt,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_comment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=comment_id,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if &use_saved_comment_alt_keys eq 1 %then
  %do;
     data comments_to_delete_alt;
      set purgekey.comments_to_delete_alt(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_alt));
      run;
  %end;

  /*-----------------------------------
   * Delete from FSK_COMMENT
   * Transaction (TRN)
   *-----------------------------------*/
  %let use_saved_comment_trn_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.comments_to_delete_trn)) %then
  %do;
     %let use_saved_comment_trn_keys = 1;
     %goto BEGIN_COMMENT_TRN_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * comments_to_delete_trn fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned comments (on a restart)
      *------------------------------------------------------------------------------*/
     data comments_to_delete_trn(keep=object_id object_type_cd comment_id);
       if 0 then set &db_lib_kc..fsk_comment(keep=object_type_cd);
       set trn_to_delete_num(keep=transaction_reference_number rename=(transaction_reference_number=object_id));
       object_type_cd = "TRN";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_comment(keep=object_id object_type_cd comment_id
                                      dbkey=(object_type_cd object_id)
                                      dbsastype=(object_type_cd = 'char(3)'))
                                     key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set comments_to_delete_trn.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.comments_to_delete_trn(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_trn, output_ds=Y));
      set comments_to_delete_trn;
      run;
  %end;

  %BEGIN_COMMENT_TRN_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_comment,
                        entities_ds=trn_to_delete_num,
                        key_vars=transaction_reference_number,
                        one_to_many_ind=Y,
                        rename_var_from=transaction_reference_number,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=TRN,
                        other_output_ds=comments_to_delete_trn,
                        other_output_ds_vars=object_id object_type_cd comment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=comments_to_delete_trn,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_comment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=comment_id,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if &use_saved_comment_trn_keys eq 1 %then
  %do;
     data comments_to_delete_trn;
      set purgekey.comments_to_delete_trn(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_trn));
      run;
  %end;

  /*----------------------------
   * Delete from FSK_ATTACHMENT
   * Party (PTY)
   *----------------------------*/
  %let use_saved_attachment_pty_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.attachments_to_delete_pty)) %then
  %do;
     %let use_saved_attachment_pty_keys = 1;
     %goto BEGIN_ATTACHMENT_PTY_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*----------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * attachments_to_delete_pty fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned attachments (on a restart)
      *----------------------------------------------------------------------------------*/
     data attachments_to_delete_pty(keep=object_id object_type_cd attachment_path attachment_name attachment_id);
       if 0 then set &db_lib_kc..fsk_attachment(keep=object_type_cd);
       set pty_to_delete_num(keep=party_number rename=(party_number=object_id));
       object_type_cd = "PTY";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_attachment(keep=object_id object_type_cd attachment_path attachment_name attachment_id
                                         dbkey=(object_type_cd object_id)
                                         dbsastype=(object_type_cd = 'char(3)'))
                                        key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set attachments_to_delete_pty.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.attachments_to_delete_pty(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_pty, output_ds=Y));
      set attachments_to_delete_pty;
      run;
  %end;

  %BEGIN_ATTACHMENT_PTY_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_attachment,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        rename_var_from=party_number,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=PTY,
                        other_output_ds=attachments_to_delete_pty,
                        other_output_ds_vars=object_id object_type_cd attachment_path attachment_name attachment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-------------------------------------------------------------------
   * Delete the files referenced in the purged FSK_ATTACHMENT records.
   *-------------------------------------------------------------------*/
  %if use_saved_attachment_pty_keys eq 1 %then
  %do;
     data attachments_to_delete_pty;
      set purgekey.attachments_to_delete_pty(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_pty));
      run;
  %end;

  %fcf_purge_attachments(in_ds=attachments_to_delete_pty);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=attachments_to_delete_pty,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_attachment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=attachment_path,
                           key_3_type=C,
                           key_4=attachment_name,
                           key_4_type=C,
                           key_5=attachment_deleted,
                           key_5_type=C,
                           key_6=reason,
                           key_6_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if use_saved_attachment_pty_keys eq 1 %then
  %do;
     data attachments_to_delete_pty;
      set purgekey.attachments_to_delete_pty(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_pty));
      run;
  %end;

  /*----------------------------
   * Delete from FSK_ATTACHMENT
   * Account (ACC)
   *----------------------------*/
  %let use_saved_attachment_acc_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.attachments_to_delete_acc)) %then
  %do;
     %let use_saved_attachment_acc_keys = 1;
     %goto BEGIN_ATTACHMENT_ACC_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*----------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * attachments_to_delete_acc fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned attachments (on a restart)
      *----------------------------------------------------------------------------------*/
     data attachments_to_delete_acc(keep=object_id object_type_cd attachment_path attachment_name attachment_id);
       if 0 then set &db_lib_kc..fsk_attachment(keep=object_type_cd);
       set acc_to_delete_num(keep=account_number rename=(account_number=object_id));
       object_type_cd = "ACC";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_attachment(keep=object_id object_type_cd attachment_path attachment_name attachment_id
                                         dbkey=(object_type_cd object_id)
                                         dbsastype=(object_type_cd = 'char(3)'))
                                        key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set attachments_to_delete_acc.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.attachments_to_delete_acc(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_acc, output_ds=Y));
      set attachments_to_delete_acc;
      run;
  %end;

  %BEGIN_ATTACHMENT_ACC_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_attachment,
                        entities_ds=acc_to_delete_num,
                        key_vars=account_number,
                        one_to_many_ind=Y,
                        rename_var_from=account_number,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=ACC,
                        other_output_ds=attachments_to_delete_acc,
                        other_output_ds_vars=object_id object_type_cd attachment_path attachment_name attachment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-------------------------------------------------------------------
   * Delete the files referenced in the purged FSK_ATTACHMENT records.
   *-------------------------------------------------------------------*/
  %if use_saved_attachment_acc_keys eq 1 %then
  %do;
     data attachments_to_delete_acc;
      set purgekey.attachments_to_delete_acc(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_acc));
      run;
  %end;

  %fcf_purge_attachments(in_ds=attachments_to_delete_acc);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=attachments_to_delete_acc,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_attachment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=attachment_path,
                           key_3_type=C,
                           key_4=attachment_name,
                           key_4_type=C,
                           key_5=attachment_deleted,
                           key_5_type=C,
                           key_6=reason,
                           key_6_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if use_saved_attachment_acc_keys eq 1 %then
  %do;
     data attachments_to_delete_acc;
      set purgekey.attachments_to_delete_acc(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_acc));
      run;
  %end;

  /*----------------------------
   * Delete from FSK_ATTACHMENT
   * Household (HHD)
   *----------------------------*/
  %let use_saved_attachment_hhd_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.attachments_to_delete_hhd)) %then
  %do;
     %let use_saved_attachment_hhd_keys = 1;
     %goto BEGIN_ATTACHMENT_HHD_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*----------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * attachments_to_delete_hhd fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned attachments (on a restart)
      *----------------------------------------------------------------------------------*/
     data attachments_to_delete_hhd(keep=object_id object_type_cd attachment_path attachment_name attachment_id);
       if 0 then set &db_lib_kc..fsk_attachment(keep=object_type_cd);
       set hhd_to_delete_num(keep=household_number rename=(household_number=object_id));
       object_type_cd = "HHD";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_attachment(keep=object_id object_type_cd attachment_path attachment_name attachment_id
                                         dbkey=(object_type_cd object_id)
                                         dbsastype=(object_type_cd = 'char(3)'))
                                        key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set attachments_to_delete_hhd.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.attachments_to_delete_hhd(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_hhd, output_ds=Y));
      set attachments_to_delete_hhd;
      run;
  %end;

  %BEGIN_ATTACHMENT_HHD_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_attachment,
                        entities_ds=hhd_to_delete_num,
                        key_vars=household_number,
                        one_to_many_ind=Y,
                        rename_var_from=household_number,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=HHD,
                        other_output_ds=attachments_to_delete_hhd,
                        other_output_ds_vars=object_id object_type_cd attachment_path attachment_name attachment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-------------------------------------------------------------------
   * Delete the files referenced in the purged FSK_ATTACHMENT records.
   *-------------------------------------------------------------------*/
  %if use_saved_attachment_hhd_keys eq 1 %then
  %do;
     data attachments_to_delete_hhd;
      set purgekey.attachments_to_delete_hhd(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_hhd));
      run;
  %end;

  %fcf_purge_attachments(in_ds=attachments_to_delete_hhd);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=attachments_to_delete_hhd,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_attachment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=attachment_path,
                           key_3_type=C,
                           key_4=attachment_name,
                           key_4_type=C,
                           key_5=attachment_deleted,
                           key_5_type=C,
                           key_6=reason,
                           key_6_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if use_saved_attachment_hhd_keys eq 1 %then
  %do;
     data attachments_to_delete_hhd;
      set purgekey.attachments_to_delete_hhd(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_hhd));
      run;
  %end;

  /*----------------------------
   * Delete from FSK_ATTACHMENT
   * Case (CAS)
   *----------------------------*/
  %let use_saved_attachment_cas_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.attachments_to_delete_cas)) %then
  %do;
     %let use_saved_attachment_cas_keys = 1;
     %goto BEGIN_ATTACHMENT_CAS_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*----------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * attachments_to_delete_cas fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned attachments (on a restart)
      *----------------------------------------------------------------------------------*/
     data attachments_to_delete_cas(keep=object_id object_type_cd attachment_path attachment_name attachment_id);
       if 0 then set &db_lib_kc..fsk_attachment(keep=object_type_cd);
       set cas_to_delete(keep=case_id_char rename=(case_id_char=object_id));
       object_type_cd = "CAS";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_attachment(keep=object_id object_type_cd attachment_path attachment_name attachment_id
                                         dbkey=(object_type_cd object_id)
                                         dbsastype=(object_type_cd = 'char(3)'))
                                        key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set attachments_to_delete_cas.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.attachments_to_delete_cas(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_cas, output_ds=Y));
      set attachments_to_delete_cas;
      run;
  %end;

  %BEGIN_ATTACHMENT_CAS_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_attachment,
                        entities_ds=cas_to_delete,
                        key_vars=case_id_char,
                        one_to_many_ind=Y,
                        rename_var_from=case_id_char,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=CAS,
                        other_output_ds=attachments_to_delete_cas,
                        other_output_ds_vars=object_id object_type_cd attachment_path attachment_name attachment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-------------------------------------------------------------------
   * Delete the files referenced in the purged FSK_ATTACHMENT records.
   *-------------------------------------------------------------------*/
  %if use_saved_attachment_cas_keys eq 1 %then
  %do;
     data attachments_to_delete_cas;
      set purgekey.attachments_to_delete_cas(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_cas));
      run;
  %end;

  %fcf_purge_attachments(in_ds=attachments_to_delete_cas);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=attachments_to_delete_cas,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_attachment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=attachment_path,
                           key_3_type=C,
                           key_4=attachment_name,
                           key_4_type=C,
                           key_5=attachment_deleted,
                           key_5_type=C,
                           key_6=reason,
                           key_6_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if use_saved_attachment_cas_keys eq 1 %then
  %do;
     data attachments_to_delete_cas;
      set purgekey.attachments_to_delete_cas(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_cas));
      run;
  %end;

  /*----------------------------
   * Delete from FSK_ATTACHMENT
   * Report (RPT)
   *----------------------------*/
  %let use_saved_attachment_rpt_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.attachments_to_delete_rpt)) %then
  %do;
     %let use_saved_attachment_rpt_keys = 1;
     %goto BEGIN_ATTACHMENT_RPT_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*----------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * attachments_to_delete_rpt fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned attachments (on a restart)
      *----------------------------------------------------------------------------------*/
     data attachments_to_delete_rpt(keep=object_id object_type_cd attachment_path attachment_name attachment_id);
       if 0 then set &db_lib_kc..fsk_attachment(keep=object_type_cd);
       set rpt_to_delete(keep=report_key_char rename=(report_key_char=object_id));
       object_type_cd = "RPT";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_attachment(keep=object_id object_type_cd attachment_path attachment_name attachment_id
                                         dbkey=(object_type_cd object_id)
                                         dbsastype=(object_type_cd = 'char(3)'))
                                        key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set attachments_to_delete_rpt.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.attachments_to_delete_rpt(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_rpt, output_ds=Y));
      set attachments_to_delete_rpt;
      run;
  %end;

  %BEGIN_ATTACHMENT_RPT_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_attachment,
                        entities_ds=rpt_to_delete,
                        key_vars=report_key_char,
                        one_to_many_ind=Y,
                        rename_var_from=report_key_char,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=RPT,
                        other_output_ds=attachments_to_delete_rpt,
                        other_output_ds_vars=object_id object_type_cd attachment_path attachment_name attachment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-------------------------------------------------------------------
   * Delete the files referenced in the purged FSK_ATTACHMENT records.
   *-------------------------------------------------------------------*/
  %if use_saved_attachment_rpt_keys eq 1 %then
  %do;
     data attachments_to_delete_rpt;
      set purgekey.attachments_to_delete_rpt(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_rpt));
      run;
  %end;

  %fcf_purge_attachments(in_ds=attachments_to_delete_rpt);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=attachments_to_delete_rpt,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_attachment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=attachment_path,
                           key_3_type=C,
                           key_4=attachment_name,
                           key_4_type=C,
                           key_5=attachment_deleted,
                           key_5_type=C,
                           key_6=reason,
                           key_6_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if use_saved_attachment_rpt_keys eq 1 %then
  %do;
     data attachments_to_delete_rpt;
      set purgekey.attachments_to_delete_rpt(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_rpt));
      run;
  %end;

  /*----------------------------
   * Delete from FSK_ATTACHMENT
   * EFile (EFL)
   *----------------------------*/
  %let use_saved_attachment_efl_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.attachments_to_delete_efl)) %then
  %do;
     %let use_saved_attachment_efl_keys = 1;
     %goto BEGIN_ATTACHMENT_EFL_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*----------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * attachments_to_delete_efl fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned attachments (on a restart)
      *----------------------------------------------------------------------------------*/
     data attachments_to_delete_efl(keep=object_id object_type_cd attachment_path attachment_name attachment_id);
       if 0 then set &db_lib_kc..fsk_attachment(keep=object_type_cd);
       set efl_to_delete(keep=efile_key_char rename=(efile_key_char=object_id));
       object_type_cd = "EFL";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_attachment(keep=object_id object_type_cd attachment_path attachment_name attachment_id
                                         dbkey=(object_type_cd object_id)
                                         dbsastype=(object_type_cd = 'char(3)'))
                                        key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set attachments_to_delete_efl.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.attachments_to_delete_efl(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_efl, output_ds=Y));
      set attachments_to_delete_efl;
      run;
  %end;

  %BEGIN_ATTACHMENT_EFL_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_attachment,
                        entities_ds=efl_to_delete,
                        key_vars=efile_key_char,
                        one_to_many_ind=Y,
                        rename_var_from=efile_key_char,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=EFL,
                        other_output_ds=attachments_to_delete_efl,
                        other_output_ds_vars=object_id object_type_cd attachment_path attachment_name attachment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-------------------------------------------------------------------
   * Delete the files referenced in the purged FSK_ATTACHMENT records.
   *-------------------------------------------------------------------*/
  %if use_saved_attachment_efl_keys eq 1 %then
  %do;
     data attachments_to_delete_efl;
      set purgekey.attachments_to_delete_efl(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_efl));
      run;
  %end;

  %fcf_purge_attachments(in_ds=attachments_to_delete_efl);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=attachments_to_delete_efl,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_attachment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=attachment_path,
                           key_3_type=C,
                           key_4=attachment_name,
                           key_4_type=C,
                           key_5=attachment_deleted,
                           key_5_type=C,
                           key_6=reason,
                           key_6_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if use_saved_attachment_efl_keys eq 1 %then
  %do;
     data attachments_to_delete_efl;
      set purgekey.attachments_to_delete_efl(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_efl));
      run;
  %end;

  /*----------------------------
   * Delete from FSK_ATTACHMENT
   * CDD Review (CDR)
   *----------------------------*/
  %let use_saved_attachment_cdr_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.attachments_to_delete_cdr)) %then
  %do;
     %let use_saved_attachment_cdr_keys = 1;
     %goto BEGIN_ATTACHMENT_CDR_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*----------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * attachments_to_delete_cdr fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned attachments (on a restart)
      *----------------------------------------------------------------------------------*/
     data attachments_to_delete_cdr(keep=object_id object_type_cd attachment_path attachment_name attachment_id);
       if 0 then set &db_lib_kc..fsk_attachment(keep=object_type_cd);
       set cdr_to_delete(keep=review_key_char rename=(review_key_char=object_id));
       object_type_cd = "CDR";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_attachment(keep=object_id object_type_cd attachment_path attachment_name attachment_id
                                         dbkey=(object_type_cd object_id)
                                         dbsastype=(object_type_cd = 'char(3)'))
                                        key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set attachments_to_delete_cdr.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.attachments_to_delete_cdr(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_cdr, output_ds=Y));
      set attachments_to_delete_cdr;
      run;
  %end;

  %BEGIN_ATTACHMENT_CDR_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_attachment,
                        entities_ds=cdr_to_delete,
                        key_vars=review_key_char,
                        one_to_many_ind=Y,
                        rename_var_from=review_key_char,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=CDR,
                        other_output_ds=attachments_to_delete_cdr,
                        other_output_ds_vars=object_id object_type_cd attachment_path attachment_name attachment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-------------------------------------------------------------------
   * Delete the files referenced in the purged FSK_ATTACHMENT records.
   *-------------------------------------------------------------------*/
  %if use_saved_attachment_cdr_keys eq 1 %then
  %do;
     data attachments_to_delete_cdr;
      set purgekey.attachments_to_delete_cdr(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_cdr));
      run;
  %end;

  %fcf_purge_attachments(in_ds=attachments_to_delete_cdr);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=attachments_to_delete_cdr,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_attachment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=attachment_path,
                           key_3_type=C,
                           key_4=attachment_name,
                           key_4_type=C,
                           key_5=attachment_deleted,
                           key_5_type=C,
                           key_6=reason,
                           key_6_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if use_saved_attachment_cdr_keys eq 1 %then
  %do;
     data attachments_to_delete_cdr;
      set purgekey.attachments_to_delete_cdr(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_cdr));
      run;
  %end;

  /*----------------------------
   * Delete from FSK_ATTACHMENT
   * Alert (ALT)
   *----------------------------*/
  %let use_saved_attachment_alt_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.attachments_to_delete_alt)) %then
  %do;
     %let use_saved_attachment_alt_keys = 1;
     %goto BEGIN_ATTACHMENT_ALT_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*----------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * attachments_to_delete_alt fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned attachments (on a restart)
      *----------------------------------------------------------------------------------*/
     data attachments_to_delete_alt(keep=object_id object_type_cd attachment_path attachment_name attachment_id);
       if 0 then set &db_lib_kc..fsk_attachment(keep=object_type_cd);
       set alt_to_delete(keep=alert_id_char rename=(alert_id_char=object_id));
       object_type_cd = "ALT";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_attachment(keep=object_id object_type_cd attachment_path attachment_name attachment_id
                                         dbkey=(object_type_cd object_id)
                                         dbsastype=(object_type_cd = 'char(3)'))
                                        key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set attachments_to_delete_alt.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.attachments_to_delete_alt(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_alt, output_ds=Y));
      set attachments_to_delete_alt;
      run;
  %end;

  %BEGIN_ATTACHMENT_ALT_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_attachment,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id_char,
                        one_to_many_ind=Y,
                        rename_var_from=alert_id_char,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=ALT,
                        other_output_ds=attachments_to_delete_alt,
                        other_output_ds_vars=object_id object_type_cd attachment_path attachment_name attachment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-------------------------------------------------------------------
   * Delete the files referenced in the purged FSK_ATTACHMENT records.
   *-------------------------------------------------------------------*/
  %if use_saved_attachment_alt_keys eq 1 %then
  %do;
     data attachments_to_delete_alt;
      set purgekey.attachments_to_delete_alt(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_alt));
      run;
  %end;

  %fcf_purge_attachments(in_ds=attachments_to_delete_alt);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=attachments_to_delete_alt,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_attachment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=attachment_path,
                           key_3_type=C,
                           key_4=attachment_name,
                           key_4_type=C,
                           key_5=attachment_deleted,
                           key_5_type=C,
                           key_6=reason,
                           key_6_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if use_saved_attachment_alt_keys eq 1 %then
  %do;
     data attachments_to_delete_alt;
      set purgekey.attachments_to_delete_alt(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_alt));
      run;
  %end;

  /*----------------------------
   * Delete from FSK_ATTACHMENT
   * Transaction (TRN)
   *----------------------------*/
  %let use_saved_attachment_trn_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.attachments_to_delete_trn)) %then
  %do;
     %let use_saved_attachment_trn_keys = 1;
     %goto BEGIN_ATTACHMENT_TRN_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*----------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * attachments_to_delete_trn fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned attachments (on a restart)
      *----------------------------------------------------------------------------------*/
     data attachments_to_delete_trn(keep=object_id object_type_cd attachment_path attachment_name attachment_id);
       if 0 then set &db_lib_kc..fsk_attachment(keep=object_type_cd);
       set trn_to_delete_num(keep=transaction_reference_number rename=(transaction_reference_number=object_id));
       object_type_cd = "TRN";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_attachment(keep=object_id object_type_cd attachment_path attachment_name attachment_id
                                         dbkey=(object_type_cd object_id)
                                         dbsastype=(object_type_cd = 'char(3)'))
                                        key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set attachments_to_delete_trn.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.attachments_to_delete_trn(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_trn, output_ds=Y));
      set attachments_to_delete_trn;
      run;
  %end;

  %BEGIN_ATTACHMENT_TRN_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_attachment,
                        entities_ds=trn_to_delete_num,
                        key_vars=transaction_reference_number,
                        one_to_many_ind=Y,
                        rename_var_from=transaction_reference_number,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=TRN,
                        other_output_ds=attachments_to_delete_trn,
                        other_output_ds_vars=object_id object_type_cd attachment_path attachment_name attachment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-------------------------------------------------------------------
   * Delete the files referenced in the purged FSK_ATTACHMENT records.
   *-------------------------------------------------------------------*/
  %if use_saved_attachment_trn_keys eq 1 %then
  %do;
     data attachments_to_delete_trn;
      set purgekey.attachments_to_delete_trn(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_trn));
      run;
  %end;

  %fcf_purge_attachments(in_ds=attachments_to_delete_trn);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=attachments_to_delete_trn,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_attachment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=attachment_path,
                           key_3_type=C,
                           key_4=attachment_name,
                           key_4_type=C,
                           key_5=attachment_deleted,
                           key_5_type=C,
                           key_6=reason,
                           key_6_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if use_saved_attachment_trn_keys eq 1 %then
  %do;
     data attachments_to_delete_trn;
      set purgekey.attachments_to_delete_trn(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_trn));
      run;
  %end;

  /*---------------------------------------
   * Delete from FSK_ACCOUNT_PROFILE_ALERT
   *---------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_account_profile_alert,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=account_profile_alert_purged,
                        other_output_ds_vars=alert_id account_number month_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=account_profile_alert_purged,
                           libname=&db_lib_kc,
                           table=fsk_account_profile_alert,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=account_number,
                           key_2_type=C,
                           key_3=month_key,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*---------------------------------------
   * Delete from FSK_PARTY_PROFILE_ALERT
   *---------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_party_profile_alert,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=party_profile_alert_purged,
                        other_output_ds_vars=alert_id party_number month_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=party_profile_alert_purged,
                           libname=&db_lib_kc,
                           table=fsk_party_profile_alert,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=party_number,
                           key_2_type=C,
                           key_3=month_key,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*--------------------------------
   * Delete from FSK_ALERT_NEIGHBOR
   *--------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_alert_neighbor,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=alert_neighbor_purged,
                        other_output_ds_vars=alert_id target_account_number neighbor_account_number);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=alert_neighbor_purged,
                           libname=&db_lib_kc,
                           table=fsk_alert_neighbor,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=target_account_number,
                           key_2_type=C,
                           key_3=neighbor_account_number,
                           key_3_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*--------------------------------
   * Delete from FSK_ENHANCED_ALERT
   *--------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_enhanced_alert,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=enhanced_alert_purged,
                        other_output_ds_vars=alert_id column_name);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=enhanced_alert_purged,
                           libname=&db_lib_kc,
                           table=fsk_enhanced_alert,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=column_name,
                           key_2_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*--------------------------------
   * Delete from FSK_ALERT_REMINDER
   *--------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_alert_reminder,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=alert_reminder_purged,
                        other_output_ds_vars=alert_id reminder_date user_long_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=alert_reminder_purged,
                           libname=&db_lib_kc,
                           table=fsk_alert_reminder,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=reminder_date,
                           key_2_type=N,
                           key_3=user_long_id,
                           key_3_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-----------------------------
   * Delete from FSK_ALERT_EMAIL
   *-----------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_alert_email,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=alert_email_purged,
                        other_output_ds_vars=alert_id email_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=alert_email_purged,
                           libname=&db_lib_kc,
                           table=fsk_alert_email,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=email_id,
                           key_2_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-----------------------------
   * Delete from FSK_ALERT_EVENT
   *-----------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_alert_event,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=alert_event_purged,
                        other_output_ds_vars=alert_id event_id event_type_code);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=alert_event_purged,
                           libname=&db_lib_kc,
                           table=fsk_alert_email,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=event_id,
                           key_2_type=N,
                           key_3=event_type_code,
                           key_3_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*--------------------------------------------
   * Delete from FSK_ENHANCED_ALERT_RISK_FACTOR
   *--------------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_enhanced_alert_risk_factor,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=enhanced_alert_rf_purged,
                        other_output_ds_vars=alert_id scenario_id column_name entity_number);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=enhanced_alert_rf_purged,
                           libname=&db_lib_kc,
                           table=fsk_enhanced_alert_risk_factor,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=scenario_id,
                           key_2_type=N,
                           key_3=column_name,
                           key_3_type=C,
                           key_4=entity_number,
                           key_4_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*--------------------------------------------
   * Delete from FSK_ALERT_RISK_FACTOR
   *--------------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_alert_risk_factor,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=alert_rf_purged,
                        other_output_ds_vars=alert_id scenario_id entity_number entity_level_code);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=alert_rf_purged,
                           libname=&db_lib_kc,
                           table=fsk_alert_risk_factor,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=scenario_id,
                           key_2_type=N,
                           key_3=entity_number,
                           key_3_type=C,
                           key_4=entity_level_code,
                           key_4_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-----------------------------------
   * Delete from FSK_ALERT_TRANSACTION
   *-----------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_alert_transaction,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=alert_transaction_purged,
                        other_output_ds_vars=alert_id alerted_entity_number alerted_entity_level_code fsk_alert_transaction_pk);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=alert_transaction_purged,
                           libname=&db_lib_kc,
                           table=fsk_alert_transaction,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=alerted_entity_number,
                           key_2_type=C,
                           key_3=alerted_entity_level_code,
                           key_3_type=C,
                           key_4=fsk_alert_transaction_pk,
                           key_4_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*------------------------------
   * Delete from FSK_ALERT_TX_AGG
   *------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_alert_tx_agg,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=alert_tx_agg_purged,
                        other_output_ds_vars=alert_id aggregate_type_code fsk_alert_tx_agg_pk);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=alert_tx_agg_purged,
                           libname=&db_lib_kc,
                           table=fsk_alert_tx_agg,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=aggregate_type_code,
                           key_2_type=C,
                           key_3=fsk_alert_tx_agg_pk,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*---------------------------------
   * Delete from FSK_CASH_FLOW_ALERT
   *---------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_cash_flow_alert,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=cash_flow_alert_purged,
                        other_output_ds_vars=alert_id transaction_key account_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=cash_flow_alert_purged,
                           libname=&db_lib_kc,
                           table=fsk_cash_flow_alert,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=transaction_key,
                           key_2_type=N,
                           key_3=account_key,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*--------------------------------------
   * Delete from FSK_CASH_FLOW_BANK_ALERT
   *--------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_cash_flow_bank_alert,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=cash_flow_bank_alert_purged,
                        other_output_ds_vars=alert_id bank_key transaction_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=cash_flow_bank_alert_purged,
                           libname=&db_lib_kc,
                           table=fsk_cash_flow_bank_alert,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=bank_key,
                           key_2_type=N,
                           key_3=transaction_key,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-------------------------------------
   * Delete from FSK_ACCOUNT_EVENT_ALERT
   *-------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_account_event_alert,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=account_event_alert_purged,
                        other_output_ds_vars=alert_id transaction_key account_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=account_event_alert_purged,
                           libname=&db_lib_kc,
                           table=fsk_account_event_alert,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=transaction_key,
                           key_2_type=N,
                           key_3=account_key,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*----------------------------------
   * Delete from FSK_ACCOUNT_KEYS_ACC
   *----------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_account_keys_acc,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=account_keys_acc_purged,
                        other_output_ds_vars=alert_id account_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=account_keys_acc_purged,
                           libname=&db_lib_kc,
                           table=fsk_account_keys_acc,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=account_key,
                           key_2_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*----------------------------------
   * Delete from FSK_ACCOUNT_KEYS_ASC
   *----------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_account_keys_asc,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=account_keys_asc_purged,
                        other_output_ds_vars=alert_id account_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=account_keys_asc_purged,
                           libname=&db_lib_kc,
                           table=fsk_account_keys_asc,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=account_key,
                           key_2_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*----------------------------------
   * Delete from FSK_ACCOUNT_KEYS_HHD
   *----------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_account_keys_hhd,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=account_keys_hhd_purged,
                        other_output_ds_vars=alert_id account_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=account_keys_hhd_purged,
                           libname=&db_lib_kc,
                           table=fsk_account_keys_hhd,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=account_key,
                           key_2_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*----------------------------------
   * Delete from FSK_ACCOUNT_KEYS_PTY
   *----------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_account_keys_pty,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=account_keys_pty_purged,
                        other_output_ds_vars=alert_id account_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=account_keys_pty_purged,
                           libname=&db_lib_kc,
                           table=fsk_account_keys_pty,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=account_key,
                           key_2_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-------------------------------------
   * Delete from FSK_ACCOUNT_TRADE_ALERT
   *-------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_account_trade_alert,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=account_trade_alert_purged,
                        other_output_ds_vars=alert_id transaction_key account_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=account_trade_alert_purged,
                           libname=&db_lib_kc,
                           table=fsk_account_trade_alert,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=transaction_key,
                           key_2_type=N,
                           key_3=account_key,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-----------------------------------
   * Delete from FSK_REPLICATION_DATES
   *-----------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_replication_dates,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=replication_dates_purged,
                        other_output_ds_vars=alert_id start_date_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=replication_dates_purged,
                           libname=&db_lib_kc,
                           table=fsk_replication_dates,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=start_date_key,
                           key_2_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-----------------------------------
   * Delete from FSK_TRANSACTION_ALERT
   *-----------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_transaction_alert,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=transaction_alert_purged,
                        other_output_ds_vars=alert_id transaction_key transaction_reference_number);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=transaction_alert_purged,
                           libname=&db_lib_kc,
                           table=fsk_transaction_alert,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=transaction_key,
                           key_2_type=N,
                           key_3=transaction_reference_number,
                           key_3_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*--------------------------
   * Delete from FSK_NN_PARTY
   *--------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_nn_party,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=nn_party_purged,
                        other_output_ds_vars=alert_id party_number);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=nn_party_purged,
                           libname=&db_lib_kc,
                           table=fsk_nn_party,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=party_number,
                           key_2_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*---------------------------
   * Delete from FSK_NN_ENTITY
   *---------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_nn_entity,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=Y,
                        other_output_ds=nn_entity_purged,
                        other_output_ds_vars=alert_id primary_entity_number primary_entity_level_code);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=nn_entity_purged,
                           libname=&db_lib_kc,
                           table=fsk_nn_entity,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=primary_entity_number,
                           key_2_type=C,
                           key_3=primary_entity_level_code,
                           key_3_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-----------------------
   * Delete from FSK_ALERT
   *-----------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_alert,
                        entities_ds=alt_to_delete,
                        key_vars=alert_id,
                        one_to_many_ind=N,
                        other_output_ds=alert_purged,
                        other_output_ds_vars=alert_id primary_entity_number primary_entity_level_code scenario_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=alert_purged,
                           libname=&db_lib_kc,
                           table=fsk_alert,
                           key_1=alert_id,
                           key_1_type=N,
                           key_2=primary_entity_number,
                           key_2_type=C,
                           key_3=primary_entity_level_code,
                           key_3_type=C,
                           key_4=scenario_id,
                           key_4_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*------------------------------------------
   * Delete from FSK_RISK_ASSESSMENT
   * But first from these due to constraints:
   * FSK_RISK_ASSESSMENT_EMAIL
   * FSK_RISK_ASSESSMENT_EVENT
   * FSK_RISK_ASSESSMENT_CLASSIFIER
   *------------------------------------------*/
  %let use_saved_ras_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.ras_to_delete)) %then
  %do;
     data ras_to_delete;
      set purgekey.ras_to_delete(%fcf_get_ds_opts(lib_name=purgekey, ds_name=ras_to_delete));
      run;

     %let use_saved_ras_keys = 1;

     %goto BEGIN_RAS_PURGE;
  %end;

  /*---------------------------------------------------------------------------
   * This needs to be in a separate step in case it fails.  If the creation of
   * ras_to_delete fails during the purge we would potentially have
   * an incomplete key data set which might leave orphaned comments and 
   * attachments related to risk assessments. (on a restart)
   * Also...
   * We need to first purge from other tables due to constraints.
   *---------------------------------------------------------------------------*/
  data ras_to_delete(keep=party_number risk_assessment_id);
    set pty_to_delete_num(keep=party_number);
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_kc..fsk_risk_assessment(keep=party_number risk_assessment_id
                                             dbkey=(party_number))
                                            key=dbkey;
        if _iorc_ = %sysrc(_sok) then
           output;
        else
           _error_ = 0;
    end;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %let _fcfmsg_=ERROR: FCF: Unable to create key data set ras_to_delete.;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     data purgekey.ras_to_delete(%fcf_get_ds_opts(lib_name=purgekey, ds_name=ras_to_delete, output_ds=Y));
      set ras_to_delete;
      run;
  %end;

  %BEGIN_RAS_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_risk_assessment_email,
                        entities_ds=ras_to_delete,
                        key_vars=risk_assessment_id,
                        one_to_many_ind=Y,
                        other_output_ds=risk_assessment_email_purged,
                        other_output_ds_vars=risk_assessment_id email_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=risk_assessment_email_purged,
                           libname=&db_lib_kc,
                           table=fsk_risk_assessment_email,
                           key_1=risk_assessment_id,
                           key_1_type=N,
                           key_2=email_id,
                           key_2_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_from_table(table=&db_lib_kc..fsk_risk_assessment_event,
                        entities_ds=ras_to_delete,
                        key_vars=risk_assessment_id,
                        one_to_many_ind=Y,
                        other_output_ds=risk_assessment_event_purged,
                        other_output_ds_vars=risk_assessment_id event_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=risk_assessment_event_purged,
                           libname=&db_lib_kc,
                           table=fsk_risk_assessment_event,
                           key_1=risk_assessment_id,
                           key_1_type=N,
                           key_2=event_id,
                           key_2_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_from_table(table=&db_lib_kc..fsk_risk_assessment_classifier,
                        entities_ds=ras_to_delete,
                        key_vars=risk_assessment_id,
                        one_to_many_ind=Y,
                        other_output_ds=risk_assmnt_classifier_purged,
                        other_output_ds_vars=risk_assessment_id risk_classifier_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=risk_assmnt_classifier_purged,
                           libname=&db_lib_kc,
                           table=fsk_risk_assessment_classifier,
                           key_1=risk_assessment_id,
                           key_1_type=N,
                           key_2=risk_classifier_id,
                           key_2_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_from_table(table=&db_lib_kc..fsk_risk_assessment,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        other_output_ds=ras_to_delete,
                        other_output_ds_vars=party_number risk_assessment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=ras_to_delete,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_risk_assessment,
                           key_1=party_number,
                           key_1_type=C,
                           key_2=risk_assessment_id,
                           key_2_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if &use_saved_ras_keys eq 1 %then
  %do;
     data ras_to_delete;
      set purgekey.ras_to_delete(%fcf_get_ds_opts(lib_name=purgekey, ds_name=ras_to_delete));
      run;
  %end;

  data ras_to_delete;
    if 0 then set &db_lib_kc..fsk_comment(keep=object_id rename=(object_id = risk_assessment_id_char));
    label risk_assessment_id_char = "risk_assessment_id_char";
    set ras_to_delete(keep=risk_assessment_id);
    risk_assessment_id_char = strip(put(risk_assessment_id, best.));
   run;

  /*-----------------------------------
   * Delete from FSK_COMMENT
   * Risk Assessment (RAS)
   *-----------------------------------*/
  %let use_saved_comment_ras_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.comments_to_delete_ras)) %then
  %do;
     %let use_saved_comment_ras_keys = 1;
     %goto BEGIN_COMMENT_RAS_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * comments_to_delete_ras fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned comments (on a restart)
      *------------------------------------------------------------------------------*/
     data comments_to_delete_ras(keep=object_id object_type_cd comment_id);
       if 0 then set &db_lib_kc..fsk_comment(keep=object_type_cd);
       set ras_to_delete(keep=risk_assessment_id_char rename=(risk_assessment_id_char=object_id));
       object_type_cd = "RAS";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_comment(keep=object_id object_type_cd comment_id
                                      dbkey=(object_type_cd object_id)
                                      dbsastype=(object_type_cd = 'char(3)'))
                                     key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set comments_to_delete_ras.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.comments_to_delete_ras(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_ras, output_ds=Y));
      set comments_to_delete_ras;
      run;
  %end;

  %BEGIN_COMMENT_RAS_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_comment,
                        entities_ds=ras_to_delete,
                        key_vars=risk_assessment_id_char,
                        one_to_many_ind=Y,
                        rename_var_from=risk_assessment_id_char,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=RAS,
                        other_output_ds=comments_to_delete_ras,
                        other_output_ds_vars=object_id object_type_cd comment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=comments_to_delete_ras,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_comment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=comment_id,
                           key_3_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if &use_saved_comment_trn_keys eq 1 %then
  %do;
     data comments_to_delete_ras;
      set purgekey.comments_to_delete_ras(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_ras));
      run;
  %end;

  /*----------------------------
   * Delete from FSK_ATTACHMENT
   * Risk Assessment (RAS)
   *----------------------------*/
  %let use_saved_attachment_ras_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.attachments_to_delete_ras)) %then
  %do;
     %let use_saved_attachment_ras_keys = 1;
     %goto BEGIN_ATTACHMENT_RAS_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*----------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * attachments_to_delete_ras fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned attachments (on a restart)
      *----------------------------------------------------------------------------------*/
     data attachments_to_delete_ras(keep=object_id object_type_cd attachment_path attachment_name attachment_id);
       if 0 then set &db_lib_kc..fsk_attachment(keep=object_type_cd);
       set ras_to_delete(keep=risk_assessment_id_char rename=(risk_assessment_id_char=object_id));
       object_type_cd = "RAS";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_attachment(keep=object_id object_type_cd attachment_path attachment_name attachment_id
                                         dbkey=(object_type_cd object_id)
                                         dbsastype=(object_type_cd = 'char(3)'))
                                        key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set attachments_to_delete_ras.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.attachments_to_delete_ras(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_ras, output_ds=Y));
      set attachments_to_delete_ras;
      run;
  %end;

  %BEGIN_ATTACHMENT_RAS_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_attachment,
                        entities_ds=ras_to_delete,
                        key_vars=risk_assessment_id_char,
                        one_to_many_ind=Y,
                        rename_var_from=risk_assessment_id_char,
                        rename_var_to=object_id,
                        db_key_vars=object_type_cd object_id,
                        db_key_elc_var=object_type_cd,
                        db_key_elc_value=RAS,
                        other_output_ds=attachments_to_delete_ras,
                        other_output_ds_vars=object_id object_type_cd attachment_path attachment_name attachment_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-------------------------------------------------------------------
   * Delete the files referenced in the purged FSK_ATTACHMENT records.
   *-------------------------------------------------------------------*/
  %if use_saved_attachment_ras_keys eq 1 %then
  %do;
     data attachments_to_delete_ras;
      set purgekey.attachments_to_delete_ras(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_ras));
      run;
  %end;

  %fcf_purge_attachments(in_ds=attachments_to_delete_ras);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=attachments_to_delete_ras,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_attachment,
                           key_1=object_id,
                           key_1_type=C,
                           key_2=object_type_cd,
                           key_2_type=C,
                           key_3=attachment_path,
                           key_3_type=C,
                           key_4=attachment_name,
                           key_4_type=C,
                           key_5=attachment_deleted,
                           key_5_type=C,
                           key_6=reason,
                           key_6_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if use_saved_attachment_ras_keys eq 1 %then
  %do;
     data attachments_to_delete_ras;
      set purgekey.attachments_to_delete_ras(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_ras));
      run;
  %end;

  /*-----------------------------------
   * Delete from FSK_CDD_SCORING_EVENT
   * Party (PTY)
   * CDD scoring is only done for PTY.
   *-----------------------------------*/
  %let use_saved_cdd_keys = 0;

  %if %upcase(&purge_restart) eq Y and
      %sysfunc(exist(purgekey.cdd_scoring_events_to_delete)) %then
  %do;
     %let use_saved_cdd_keys = 1;
     %goto BEGIN_CDD_SCORING_EVENT_PURGE;
  %end;

  %if &purgekey_lib_assigned eq 1 %then
  %do;
     /*-------------------------------------------------------------------------------
      * This needs to be in a separate step in case it fails.  If the creation of
      * cdd_scoring_events_to_delete fails during the purge we would potentially have
      * an incomplete key data set which might leave orphaned cdd triggering values.
      * (on a restart)
      *-------------------------------------------------------------------------------*/
     data cdd_scoring_events_to_delete(keep=cdd_scoring_event_key primary_entity_number primary_entity_level_code cdd_rule_id);
       if 0 then set &db_lib_kc..fsk_cdd_scoring_event(keep=primary_entity_level_code);
       set pty_to_delete_num(keep=party_number rename=(party_number=primary_entity_number));
       primary_entity_level_code = "PTY";
       do until (_iorc_ ne %sysrc(_sok));
          set &db_lib_kc..fsk_cdd_scoring_event(keep=cdd_scoring_event_key primary_entity_number primary_entity_level_code cdd_rule_id
                                                dbkey=(primary_entity_number primary_entity_level_code)
                                                dbsastype=(primary_entity_level_code = 'char(3)'))
                                               key=dbkey;
           if _iorc_ = %sysrc(_sok) then
              output;
           else
              _error_ = 0;
       end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to create key data set cdd_scoring_events_to_delete.;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     data purgekey.cdd_scoring_events_to_delete(%fcf_get_ds_opts(lib_name=purgekey, ds_name=cdd_scoring_events_to_delete, output_ds=Y));
      set cdd_scoring_events_to_delete;
      run;
  %end;

  %BEGIN_CDD_SCORING_EVENT_PURGE:

  %fcf_purge_from_table(table=&db_lib_kc..fsk_cdd_scoring_event,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        rename_var_from=party_number,
                        rename_var_to=primary_entity_number,
                        db_key_vars=primary_entity_number primary_entity_level_code,
                        db_key_elc_var=primary_entity_level_code,
                        db_key_elc_value=PTY,
                        other_output_ds=cdd_scoring_events_to_delete,
                        other_output_ds_vars=cdd_scoring_event_key primary_entity_number primary_entity_level_code cdd_rule_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=cdd_scoring_events_to_delete,
                           delete_in_ds_when_done=N,
                           libname=&db_lib_kc,
                           table=fsk_cdd_scoring_event,
                           key_1=cdd_scoring_event_key,
                           key_1_type=N,
                           key_2=primary_entity_number,
                           key_2_type=C,
                           key_3=primary_entity_level_code,
                           key_3_type=C,
                           key_4=cdd_rule_id,
                           key_4_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %if &use_saved_cdd_keys eq 1 %then
  %do;
     data cdd_scoring_events_to_delete;
      set purgekey.cdd_scoring_events_to_delete(%fcf_get_ds_opts(lib_name=purgekey, ds_name=cdd_scoring_events_to_delete));
      run;
  %end;

  /*---------------------------------------
   * Delete from FSK_CDD_TRIGGERING_VALUES 
   *---------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_cdd_triggering_values,
                        entities_ds=cdd_scoring_events_to_delete,
                        key_vars=cdd_scoring_event_key,
                        one_to_many_ind=Y,
                        other_output_ds=cdd_triggering_values_purged,
                        other_output_ds_vars=cdd_scoring_event_key cdd_triggering_value_key);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=cdd_triggering_values_purged,
                           libname=&db_lib_kc,
                           table=fsk_cdd_triggering_values,
                           key_1=cdd_scoring_event_key,
                           key_1_type=N,
                           key_2=cdd_triggering_value_key,
                           key_2_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /* delete this now since we had to keep it around after logging */
  proc datasets lib=work nowarn nolist;
    delete cdd_scoring_events_to_delete;
  quit;

  /*---------------------------------
   * Delete from FSK_CDD_ENTITY_FACT
   * Party (PTY)
   * CDD scoring is only done for PTY.
   *---------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_cdd_entity_fact,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        rename_var_from=party_number,
                        rename_var_to=primary_entity_number,
                        db_key_vars=primary_entity_number primary_entity_level_code,
                        db_key_elc_var=primary_entity_level_code,
                        db_key_elc_value=PTY,
                        other_output_ds=cdd_entity_fact_purged,
                        other_output_ds_vars=primary_entity_number primary_entity_level_code);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=cdd_entity_fact_purged,
                           libname=&db_lib_kc,
                           table=fsk_cdd_entity_fact,
                           key_1=primary_entity_number,
                           key_1_type=C,
                           key_2=primary_entity_level_code,
                           key_2_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*------------------------------
   * Delete from FSK_ENTITY_EVENT
   * Party (PTY)
   *------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_entity_event,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        rename_var_from=party_number,
                        rename_var_to=entity_number,
                        db_key_vars=entity_number entity_level_code,
                        db_key_elc_var=entity_level_code,
                        db_key_elc_value=PTY,
                        other_output_ds=entity_event_purged,
                        other_output_ds_vars=entity_number entity_level_code event_id case_id);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=entity_event_purged,
                           libname=&db_lib_kc,
                           table=fsk_entity_event,
                           key_1=entity_number,
                           key_1_type=C,
                           key_2=entity_level_code,
                           key_2_type=C,
                           key_3=event_id,
                           key_3_type=N,
                           key_4=case_id,
                           key_4_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*------------------------------------
   * Delete from FSK_ENTITY_TRANSACTION
   * Party (PTY)
   *------------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_entity_transaction,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        rename_var_from=party_number,
                        rename_var_to=alerted_entity_number,
                        db_key_vars=alerted_entity_number alerted_entity_level_code,
                        db_key_elc_var=alerted_entity_level_code,
                        db_key_elc_value=PTY,
                        other_output_ds=entity_transaction_purged,
                        other_output_ds_vars=alerted_entity_number alerted_entity_level_code transaction_id fsk_entity_transaction_pk);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=entity_transaction_purged,
                           libname=&db_lib_kc,
                           table=fsk_entity_transaction,
                           key_1=alerted_entity_number,
                           key_1_type=C,
                           key_2=alerted_entity_level_code,
                           key_2_type=C,
                           key_3=transaction_id,
                           key_3_type=C,
                           key_4=fsk_entity_transaction_pk,
                           key_4_type=N);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*-------------------------------
   * Delete from FSK_ENTITY_TX_AGG
   * Party (PTY)
   *-------------------------------*/
  /* no ACC since alerted can't be ACC? */
  %fcf_purge_from_table(table=&db_lib_kc..fsk_entity_tx_agg,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        rename_var_from=party_number,
                        rename_var_to=alerted_entity_number,
                        db_key_vars=alerted_entity_number alerted_entity_level_code,
                        db_key_elc_var=alerted_entity_level_code,
                        db_key_elc_value=PTY,
                        other_output_ds=entity_tx_agg_purged,
                        other_output_ds_vars=alerted_entity_number alerted_entity_level_code fsk_entity_tx_agg_pk aggregate_type_code);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=entity_tx_agg_purged,
                           libname=&db_lib_kc,
                           table=fsk_entity_tx_agg,
                           key_1=alerted_entity_number,
                           key_1_type=C,
                           key_2=alerted_entity_level_code,
                           key_2_type=C,
                           key_3=fsk_entity_tx_agg_pk,
                           key_3_type=N,
                           key_4=aggregate_type_code,
                           key_4_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*--------------------------------
   * Delete from FSK_ALERTED_ENTITY
   * Party (PTY)
   *--------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_alerted_entity,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        rename_var_from=party_number,
                        rename_var_to=alerted_entity_number,
                        db_key_vars=alerted_entity_number alerted_entity_level_code,
                        db_key_elc_var=alerted_entity_level_code,
                        db_key_elc_value=PTY,
                        other_output_ds=alerted_entity_purged,
                        other_output_ds_vars=alerted_entity_number alerted_entity_level_code);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=alerted_entity_purged,
                           libname=&db_lib_kc,
                           table=fsk_alerted_entity,
                           key_1=alerted_entity_number,
                           key_1_type=C,
                           key_2=alerted_entity_level_code,
                           key_2_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*------------------------------
   * Delete from FSK_ENTITY_QUEUE
   * Party (PTY)
   *------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_entity_queue,
                        entities_ds=pty_to_delete_num,
                        key_vars=party_number,
                        one_to_many_ind=Y,
                        rename_var_from=party_number,
                        rename_var_to=alerted_entity_number,
                        db_key_vars=alerted_entity_number alerted_entity_level_code,
                        db_key_elc_var=alerted_entity_level_code,
                        db_key_elc_value=PTY,
                        other_output_ds=entity_queue_purged,
                        other_output_ds_vars=alerted_entity_number alerted_entity_level_code queue_code);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=entity_queue_purged,
                           libname=&db_lib_kc,
                           table=fsk_entity_queue,
                           key_1=alerted_entity_number,
                           key_1_type=C,
                           key_2=alerted_entity_level_code,
                           key_2_type=C,
                           key_3=queue_code,
                           key_3_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*----------------------------------
   * Delete from FSK_CDD_REVIEW_EVENT
   *----------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_cdd_review_event,
                        entities_ds=cdr_to_delete,
                        key_vars=review_key,
                        one_to_many_ind=Y,
                        other_output_ds=cdd_review_event_purged,
                        other_output_ds_vars=review_key event_id event_type_code);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=cdd_review_event_purged,
                           libname=&db_lib_kc,
                           table=fsk_cdd_review_event,
                           key_1=review_key,
                           key_1_type=N,
                           key_2=event_id,
                           key_2_type=N,
                           key_3=event_type_code,
                           key_3_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*--------------------------------
   * Delete from FSK_CDD_EDD_REVIEW
   *--------------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_cdd_edd_review,
                        entities_ds=cdr_to_delete,
                        key_vars=review_key,
                        one_to_many_ind=Y,
                        other_output_ds=cdd_edd_review_purged,
                        other_output_ds_vars=review_key edd_step_code);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=cdd_edd_review_purged,
                           libname=&db_lib_kc,
                           table=fsk_cdd_edd_review,
                           key_1=review_key,
                           key_1_type=N,
                           key_2=edd_step_code,
                           key_2_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  /*----------------------------
   * Delete from FSK_CDD_REVIEW
   *----------------------------*/
  %fcf_purge_from_table(table=&db_lib_kc..fsk_cdd_review,
                        entities_ds=cdr_to_delete,
                        key_vars=review_key,
                        one_to_many_ind=N,
                        other_output_ds=cdd_review_purged,
                        other_output_ds_vars=review_key primary_entity_number primary_entity_level_code);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;

  %fcf_purge_add_to_log_ds(in_ds=cdd_review_purged,
                           libname=&db_lib_kc,
                           table=fsk_cdd_review,
                           key_1=review_key,
                           key_1_type=N,
                           key_2=primary_entity_number,
                           key_2_type=C,
                           key_3=primary_entity_level_code,
                           key_3_type=C);

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
  %do;
      %goto MACRO_END;
  %end;


  %MACRO_END:

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
     %fcf_execute_macro(fcf_error);
  %else %do;
     %fcf_execute_macro(post&_fcfmodule_);
     %fcf_execute_macro(fcf_success);
  %end;

%mend fcf_purge_from_kc;

