/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    fcf_purge_from_solr.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
| DESC:    Purge entities from SOLR 
+------------------------------------------------------------------------------+
| USAGE: %fcf_purge_from_solr;
+------------------------------------------------------------------------------+
| COMMENTS: 
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2019 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_purge_from_solr;

  /*------------
   * Set Module
   *------------*/
  %local _fcfmodule_;
  %let _fcfmodule_=FCF_PURGE_FROM_SOLR;

  /*-----------------------------------------
   * Call prefcf_purge_from_solr stub macro.
   *-----------------------------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*-------------------------------------------
   * Set error code to 0 and message to blank.
   *-------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;

  /*-----------------------
   * Begin purge from SOLR
   *-----------------------*/

  /*------
   * Case
   *------*/
  %fcf_solr_index_delete(entity_type=case,
                         id_dataset=cas_to_delete,
                         id_variable=case_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting cases from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  /*-------
   * Alert
   *-------*/
  %fcf_solr_index_delete(entity_type=alert,
                         id_dataset=alt_to_delete,
                         id_variable=alert_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting alerts from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  /*--------
   * Report
   *--------*/
  %fcf_solr_index_delete(entity_type=report,
                         id_dataset=rpt_to_delete,
                         id_variable=report_key,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting reports from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  /*----------
   * Customer
   *----------*/
  %fcf_solr_index_delete(entity_type=customer,
                         id_dataset=pty_to_delete_num,
                         id_variable=party_number,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting customers from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  /*---------
   * Account
   *---------*/
  %fcf_solr_index_delete(entity_type=account,
                         id_dataset=acc_to_delete_num,
                         id_variable=account_number,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting accounts from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  /*-----------
   * Household
   *-----------*/
  %fcf_solr_index_delete(entity_type=hhd,
                         id_dataset=hhd_to_delete_num,
                         id_variable=household_number,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting households from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  /*-------------
   * CDD Reviews
   *-------------*/
  %fcf_solr_index_delete(entity_type=cddreview,
                         id_dataset=cdr_to_delete,
                         id_variable=review_key,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting CDD reviews from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  /*------------------
   * Risk Assessments
   *------------------*/
  %fcf_solr_index_delete(entity_type=risk,
                         id_dataset=ras_to_delete,
                         id_variable=risk_assessment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting risk assessments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  /*----------
   * Comments
   *----------*/

  %put NOTE: FCF: Purge party comments from SOLR.;

  %fcf_solr_index_delete(entity_type=comment,
                         id_dataset=comments_to_delete_pty,
                         id_variable=comment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting party comments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %put NOTE: FCF: Purge account comments from SOLR.;

  %fcf_solr_index_delete(entity_type=comment,
                         id_dataset=comments_to_delete_acc,
                         id_variable=comment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting account comments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %put NOTE: FCF: Purge household comments from SOLR.;

  %fcf_solr_index_delete(entity_type=comment,
                         id_dataset=comments_to_delete_hhd,
                         id_variable=comment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting household comments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %put NOTE: FCF: Purge case comments from SOLR.;

  %fcf_solr_index_delete(entity_type=comment,
                         id_dataset=comments_to_delete_cas,
                         id_variable=comment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting case comments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %put NOTE: FCF: Purge report comments from SOLR.;

  %fcf_solr_index_delete(entity_type=comment,
                         id_dataset=comments_to_delete_rpt,
                         id_variable=comment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting report comments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %put NOTE: FCF: Purge efile comments from SOLR.;

  %fcf_solr_index_delete(entity_type=comment,
                         id_dataset=comments_to_delete_efl,
                         id_variable=comment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting efile comments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %put NOTE: FCF: Purge cdd review comments from SOLR.;

  %fcf_solr_index_delete(entity_type=comment,
                         id_dataset=comments_to_delete_cdr,
                         id_variable=comment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting cdd review comments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %put NOTE: FCF: Purge alert comments from SOLR.;

  %fcf_solr_index_delete(entity_type=comment,
                         id_dataset=comments_to_delete_alt,
                         id_variable=comment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting alert comments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %put NOTE: FCF: Purge transaction comments from SOLR.;

  %fcf_solr_index_delete(entity_type=comment,
                         id_dataset=comments_to_delete_trn,
                         id_variable=comment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting transaction comments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %put NOTE: FCF: Purge risk assessment comments from SOLR.;

  %fcf_solr_index_delete(entity_type=comment,
                         id_dataset=comments_to_delete_ras,
                         id_variable=comment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting risk assessment comments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  /*-------------
   * Attachments
   *-------------*/

  %put NOTE: FCF: Purge party attachments from SOLR.;

  %fcf_solr_index_delete(entity_type=attachment,
                         id_dataset=attachments_to_delete_pty,
                         id_variable=attachment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting party attachments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %put NOTE: FCF: Purge account attachments from SOLR.;

  %fcf_solr_index_delete(entity_type=attachment,
                         id_dataset=attachments_to_delete_acc,
                         id_variable=attachment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting account attachments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %put NOTE: FCF: Purge household attachments from SOLR.;

  %fcf_solr_index_delete(entity_type=attachment,
                         id_dataset=attachments_to_delete_hhd,
                         id_variable=attachment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting household attachments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %put NOTE: FCF: Purge case attachments from SOLR.;

  %fcf_solr_index_delete(entity_type=attachment,
                         id_dataset=attachments_to_delete_cas,
                         id_variable=attachment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting case attachments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %put NOTE: FCF: Purge report attachments from SOLR.;

  %fcf_solr_index_delete(entity_type=attachment,
                         id_dataset=attachments_to_delete_rpt,
                         id_variable=attachment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting report attachments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %put NOTE: FCF: Purge efile attachments from SOLR.;

  %fcf_solr_index_delete(entity_type=attachment,
                         id_dataset=attachments_to_delete_efl,
                         id_variable=attachment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting efile attachments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %put NOTE: FCF: Purge cdd review attachments from SOLR.;

  %fcf_solr_index_delete(entity_type=attachment,
                         id_dataset=attachments_to_delete_cdr,
                         id_variable=attachment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting cdd review attachments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %put NOTE: FCF: Purge alert attachments from SOLR.;

  %fcf_solr_index_delete(entity_type=attachment,
                         id_dataset=attachments_to_delete_alt,
                         id_variable=attachment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting alert attachments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %put NOTE: FCF: Purge transaction attachments from SOLR.;

  %fcf_solr_index_delete(entity_type=attachment,
                         id_dataset=attachments_to_delete_trn,
                         id_variable=attachment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting transaction attachments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %put NOTE: FCF: Purge risk assessment attachments from SOLR.;

  %fcf_solr_index_delete(entity_type=attachment,
                         id_dataset=attachments_to_delete_ras,
                         id_variable=attachment_id,
                         cert_file=&cert_file,
                         curl_command=&curl_command,
                         work_location=&purge_log_dir
                        );

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting risk assessment attachments from SOLR;
      %fcf_put_error;
      %goto MACRO_END;
  %end;


  %MACRO_END:

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
     %fcf_execute_macro(fcf_error);
  %else %do;
     %fcf_execute_macro(post&_fcfmodule_);
     %fcf_execute_macro(fcf_success);
  %end;

%mend fcf_purge_from_solr;

