/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    fcf_wl_build_match_codes.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
+------------------------------------------------------------------------------+
| USAGE:   %fcf_wl_build_match_codes
|          (
|              watch_list=watch_list_code,
|              inputds=,
|              outputds=
|          )
+------------------------------------------------------------------------------+
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_wl_build_match_codes_loc(watch_list=, inputds=, outputds=);

   /* Set module */
   %let _fcfmodule_=WL_BUILD_MATCH_CODES_LOC;

   /* Call pre macro stub */
   %fcf_execute_macro(pre&_fcfmodule_);

   /* Set error code to 0 and message to blank */
   %let trans_rc =0;
   %let _fcfmsg_=;

   /* Set default input and output locations if not specified */
   %if &inputds eq %then %do;
       %put WARNING: &_fcfmodule_: Input data set not specified.  Match codes will not be generated.;
       %let trans_rc=3;
       %goto MACRO_END;
   %end;
   %if &outputds eq %then %do;
       %put WARNING: &_fcfmodule_: Output data set not specified.  Match codes will not be generated.;
       %let trans_rc=3;
       %goto MACRO_END;
   %end;

   /* Make sure input data set exists */
   %if not %sysfunc(exist(&inputds)) %then %do;
       %put ERROR: FCF: Input data set does not exist: &inputds;
       %let trans_rc=3;
       %goto MACRO_END;
   %end;
   
   /* Set default sensitivity */
   %let MATCH_CODE_COUNTRY_SENSITIVITY = 85;

   /* Load the QKB */
   %fcf_wl_load_qkb(info=1);
   
   /* Make sure a locale was actually loaded */
   %let locale = %sysfunc(getoption(DQLOCALE));
   %if &locale = %then %do;
     %put _fcfmsg_=ERROR: No locales are specified.  The QKB was not loaded.;
     %fcf_put_error;
     %let trans_rc = 999999;
     %goto MACRO_END;
   %end;

   /*
      QKB Locale ISO Codes for 2012A CI QKB
      
      Locale Name                    Locale ISO Code
      ----------------------------------------------
      Afrikaans, South Africa        AFZAF
      Arabic, Egypt                  AREGY
      Chinese, China                 ZHCHN
      Czech, Czech Republic          CSCZE
      Danish, Denmark                DADNK
      Dutch, Belgium                 NLBEL
      Dutch, Netherlands             NLNLD
      English, Australia             ENAUS
      English, Canada                ENCAN
      English, Hong Kong             ENHKG
      English, India                 ENIND
      English, New Zealand           ENNZL
      English, South Africa          ENZAF
      English, United Kingdom        ENGBR
      English, United States         ENUSA
      Finnish, Finland               FIFIN
      French, Belgium                FRBEL
      French, Canada                 FRCAN
      French, France                 FRFRA
      German, Germany                DEDEU
      Greek, Greece                  ELGRC
      Hungarian, Hungary             HUHUN
      Italian, Italy                 ITITA
      Japanese, Japan                JAJPN
      Korean, South Korea            KOKOR
      Malay, Malaysia                MSMYS
      Norwegian, Norway              NONOR
      Polish, Poland                 PLPOL
      Portuguese, Brazil             PTBRA
      Portuguese, Portugal           PTPRT
      Russian, Russia                RURUS
      Slovak, Slovakia               SKSVK
      Spanish, Mexico                ESMEX
      Spanish, Spain                 ESESP
      Swedish, Sweden                SVSWE
      Thai, Thailand                 THTHA
      Turkish, Turkey                TRTUR
   */

   %local FCF_MC_NAME_DEFINITIONS
          FCF_MC_ORG_DEFINITIONS
          FCF_MC_ADDRESS_DEFINITIONS
          FCF_MC_CITY_DEFINITIONS
          FCF_MC_STATE_DEFINITIONS
          FCF_MC_COUNTRY_DEFINITIONS
          FCF_MC_CSP_DEFINITIONS
          ;
          
   /* NAME: All locales */
   %let FCF_MC_NAME_DEFINITIONS="AFZAF", "AREGY", "ZHCHN", "CSCZE", "DADNK", "NLBEL", "NLNLD",
                                "ENAUS", "ENCAN", "ENHKG", "ENIND", "ENNZL", "ENZAF", "ENGBR",
                                "ENUSA", "FIFIN", "FRBEL", "FRCAN", "FRFRA", "DEDEU", "ELGRC",
                                "HUHUN", "ITITA", "JAJPN", "KOKOR", "MSMYS", "NONOR", "PLPOL",
                                "PTBRA", "PTPRT", "RURUS", "SKSVK", "ESMEX", "ESESP", "SVSWE",
                                "THTHA", "TRTUR";
   /* ORG: All locales except AREGY */
   %let FCF_MC_ORG_DEFINITIONS="AFZAF",          "ZHCHN", "CSCZE", "DADNK", "NLBEL", "NLNLD",
                               "ENAUS", "ENCAN", "ENHKG", "ENIND", "ENNZL", "ENZAF", "ENGBR",
                               "ENUSA", "FIFIN", "FRBEL", "FRCAN", "FRFRA", "DEDEU", "ELGRC",
                               "HUHUN", "ITITA", "JAJPN", "KOKOR", "MSMYS", "NONOR", "PLPOL",
                               "PTBRA", "PTPRT", "RURUS", "SKSVK", "ESMEX", "ESESP", "SVSWE",
                               "THTHA", "TRTUR";
   /* City-State-Postal: All locales except AREGY, ENHKG */
   %let FCF_MC_CSP_DEFINITIONS="AFZAF",          "ZHCHN", "CSCZE", "DADNK", "NLBEL", "NLNLD",
                               "ENAUS", "ENCAN",          "ENIND", "ENNZL", "ENZAF", "ENGBR",
                               "ENUSA", "FIFIN", "FRBEL", "FRCAN", "FRFRA", "DEDEU", "ELGRC",
                               "HUHUN", "ITITA", "JAJPN", "KOKOR", "MSMYS", "NONOR", "PLPOL",
                               "PTBRA", "PTPRT", "RURUS", "SKSVK", "ESMEX", "ESESP", "SVSWE",
                               "THTHA", "TRTUR";
   /* ADDRESS: All locales except AREGY, ENHKG */
   %let FCF_MC_ADDRESS_DEFINITIONS="AFZAF",          "ZHCHN", "CSCZE", "DADNK", "NLBEL", "NLNLD",
                                   "ENAUS", "ENCAN",          "ENIND", "ENNZL", "ENZAF", "ENGBR",
                                   "ENUSA", "FIFIN", "FRBEL", "FRCAN", "FRFRA", "DEDEU", "ELGRC",
                                   "HUHUN", "ITITA", "JAJPN", "KOKOR", "MSMYS", "NONOR", "PLPOL",
                                   "PTBRA", "PTPRT", "RURUS", "SKSVK", "ESMEX", "ESESP", "SVSWE",
                                   "THTHA", "TRTUR";
   /* CITY: All locales except AREGY, ENHKG */
   %let FCF_MC_CITY_DEFINITIONS="AFZAF",          "ZHCHN", "CSCZE", "DADNK", "NLBEL", "NLNLD",
                                "ENAUS", "ENCAN",          "ENIND", "ENNZL", "ENZAF", "ENGBR",
                                "ENUSA", "FIFIN", "FRBEL", "FRCAN", "FRFRA", "DEDEU", "ELGRC",
                                "HUHUN", "ITITA", "JAJPN", "KOKOR", "MSMYS", "NONOR", "PLPOL",
                                "PTBRA", "PTPRT", "RURUS", "SKSVK", "ESMEX", "ESESP", "SVSWE",
                                "THTHA", "TRTUR";

   %let FCF_MC_COUNTRY_DEFINITIONS="AFZAF", "ENAUS", "ENCAN", "ENHKG", "ENNZL", "ENZAF", "ENUSA", "FRCAN";
   %let FCF_MC_STATE_DEFINITIONS="ZHCHN", "NLNLD", "ENAUS", "ENCAN", "ENIND", "ENUSA", "FRCAN", "ELGRC", "ITITA";

   /***************************************************************************/
   /* BEGIN: Generate match codes                                             */
   /***************************************************************************/
   data &outputds._tmp;

      /* FSC_ENTITY_WATCH_LIST_DIM */
      /* Sets variable attribs to match variables in DBMS */
      if 1 eq 0 then
         set seg_kc.FSC_LOCATION_WATCH_LIST_DIM;

	 length default_locale $10 loaded_locales $1000;

         drop default_locale
              loaded_locales
              locale_delim_pos
              len_mc_country      ;

         retain len_mc_country      ;

      /* Get default LOCALE setting
         The first locale specified is the default.  For example, if the locale
         is ENUSA, ENGBR then ENUSA would be the default
      */
      if _N_ = 1 then do;
      
        /* Determine default locale */
        retain default_locale;
        loaded_locales=dqLocaleInfoGet('loaded');
        locale_delim_pos=indexc(loaded_locales, ',');
        if locale_delim_pos then
          default_locale=substr(loaded_locales, 1, locale_delim_pos - 1);
        else
          default_locale=loaded_locales;
        put "NOTE: FCF: Default locale for determining match codes: " default_locale;
        
        /* Set lengths of match code columns */
         len_mc_country      = 14;
      end;
      
      /* Set default values for match codes */
      match_code_country_name     =repeat('$',len_mc_country);

      set &inputds(%fcf_get_ds_opts(ds_name=&inputds));

      if default_locale in (&FCF_MC_COUNTRY_DEFINITIONS) then
        match_code_country_name=dqmatch(country_name, 'Country', &MATCH_CODE_COUNTRY_SENSITIVITY, default_locale);

     run;

     data &outputds(%fcf_get_ds_opts(ds_name=&outputds, output_ds=Y));
         set &outputds._tmp;
         /* COUNTRY_CODE */
         if missing(country_code) and not missing(country_name) then do;
            country_code = put(country_name, $country_code.);
         end;

      run;
   /***************************************************************************/
   /* END: Generate Match Codes                                               */
   /***************************************************************************/

   /* Unload the QKB */
   %dqunload;

   %MACRO_END:

   %if &trans_rc eq 3 or &trans_rc ge 5 %then
      %fcf_execute_macro(fcf_error);
   %else %do;
      %fcf_execute_macro(post&_fcfmodule_);
      %fcf_execute_macro(fcf_success);
   %end;

%mend fcf_wl_build_match_codes_loc;
