/*==============================================================================
| NAME:    fcf_wl_dfat_extract
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================

WATCH LIST PROVIDER - Australian Department of Foreign Affairs and Trade
WATCH LIST NAME     - Consolidated List
WATCH LIST CODE     - DFAT
WEB LINK            - http://www.dfat.gov.au/icat/UNSC_financial_sanctions.html

MODULE TYPE         - EXTRACT
MODULE PURPOSE      - Read extract file(s) and output to SAS data set(s).

MODULE NOTES
------------
None

==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_wl_dfat_extract(dfat_file=,
                           excel_sheet=,
                           engine=xls);

  /*------------
   * Set module
   *------------*/
  %let _fcfmodule_=FCF_WL_DFAT_EXTRACT;

  /*---------------------
   * Call pre macro stub
   *---------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*------------------------------------------
   * Set error code to 0 and message to blank
   *------------------------------------------*/
  %let trans_rc =0;
  %let _fcfmsg_=;

  %let engine=%upcase(&engine);

  /******************************************************************************/
  /* BEGIN: STG_WTCH.wl_dfat_extract                                            */
  /* DESCRIPTION: Input Consolidated List -  Microsoft Excel                    */
  /******************************************************************************/

  %if not %sysfunc(fileexist(&dfat_file)) %then %do;

     /* Use this block to copy the Watch List data file from the Internet to the local disk */
     %put NOTE: FCF: Downloading watch list data from Internet to local disk;
     filename web_dfat url "http://www.dfat.gov.au/icat/regulation8_consolidated.xls" recfm=s debug;
     filename out_dfat "&dfat_file" recfm=f;
     data _NULL_;
       infile web_dfat;
       file  out_dfat;
       input;
       put _infile_;
      run;
     /* Make sure file exists after downloading */
     %if not %sysfunc(fileexist(&dfat_file)) %then %do;
        %let _fcfmsg_=ERROR: SAS Financial Crimes Foundation is unable to process the specified Watch List file: &dfat_file;
        %put &_fcfmsg_;
        %let trans_rc=99999;
        %goto MACRO_END;
     %end;
  %end;
  %else %do;
     %put NOTE: FCF: Extracting data from Watch List file: &dfat_file;
  %end;

  %put NOTE: FCF: Using &engine engine to import watch list data.;
  %if &engine eq XLS %then %do;
     proc import datafile="&dfat_file"
                 out=stg_wtch.wl_dfat_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dfat_extract, output_ds=Y))
                 dbms=xls
                 replace;
                 sheet="&excel_sheet";
				 getnames=yes;
                 textsize=10000;
     run;
  %end;
  %else %if &engine eq EXCEL %then %do;
     filename in_dfat "&dfat_file";
     proc import datafile=in_dfat
                 out=stg_wtch.wl_dfat_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dfat_extract, output_ds=Y))
                 dbms=excel
                 replace;
                 sheet="&excel_sheet";
                 getnames=yes;
                 mixed=yes;
                 scantext=yes;
                 usedate=no;
                 scantime=no;
                 textsize=10000;
     run;
  %end;
  %else %if &engine eq EXCELCS %then %do;
     proc import datafile="&dfat_file"
                 out=stg_wtch.wl_dfat_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dfat_extract, output_ds=Y))
                 dbms=excelcs
                 replace;
                 sheet="&excel_sheet";
                 scantext=yes;
                 usedate=no;
                 scantime=no;
                 textsize=10000;
     run;
  %end;
  %else %do;
     %let _fcfmsg_=ERROR: FCF: Engine &engine is not supported.  Supported values are: XLS, EXCEL, EXCELCS;
     %fcf_put_error;
     %goto MACRO_END;
  %end;
  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %let _fcfmsg_=ERROR: FCF: &_fcfmodule_: Unable to extract the watch list file into FCF data sets.;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  /******************************************************************************/
  /* END: STG_WTCH.wl_dfat_extract                                              */
  /******************************************************************************/


  %MACRO_END:

   %if &trans_rc eq 3 or &trans_rc ge 5 %then
      %fcf_execute_macro(fcf_error);
   %else %do;
      %fcf_execute_macro(post&_fcfmodule_);
      %fcf_execute_macro(fcf_success);
   %end;

%mend fcf_wl_dfat_extract;
