/*==============================================================================
| NAME:    fcf_wl_dwjn_transform
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================

WATCH LIST PROVIDER - Dow Jones
WATCH LIST NAME     - Watchlist
WATCH LIST CODE     - DWJN
WEB LINK            - http://fis.dowjones.com/products/watchlist.html

MODULE TYPE         - TRANSFORM
MODULE PURPOSE      - Transform data in preparation for data load.

MODULE NOTES
------------
None

==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_wl_dwjn_transform;

  /*------------
   * Set module
   *------------*/
  %local _fcfmodule_;
  %let _fcfmodule_=fcf_WL_DWJN_TRANSFORM;

  /*---------------------
   * Call pre macro stub
   *---------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*------------------------------------------
   * Set error code to 0 and message to blank
   *------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;

  /*------------------------------------------
   * get column names for watch_list_dim
   *------------------------------------------*/
  %fcf_get_column_names(table=seg_kc.fsc_entity_watch_list_dim);

  /****************************************************************************/
  /* STEP 1                                                                   */
  /*                                                                          */
  /* DESCRIPTION:                                                             */
  /* Process wl_dwjn_extract                                                  */
  /*                                                                          */
  /* NOTES:                                                                   */
  /*                                                                          */
  /* INPUTS(S);                                                               */
  /* stg_wtch.wl_dwjn_extract                                                 */
  /*                                                                          */
  /* OUTPUT(S):                                                               */
  /* stg_wtch.wl_dwjn_transform_01 (primary entity records)                   */
  /* stg_wtch.wl_dwjn_transform_02 (programs)                                 */
  /* stg_wtch.wl_dwjn_transform_03 (date_of_birth, year_of_birth)             */
  /* stg_wtch.wl_dwjn_transform_04 (entity name)                              */
  /* stg_wtch.wl_dwjn_transform_05 (entity address)                           */
  /* stg_wtch.wl_dwjn_transform_06 (citizenship/country of business)          */
  /* stg_wtch.wl_dwjn_delete       (record deletes)                           */
  /* stg_err.wl_dwjn_errors_01     (data errors                               */
  /****************************************************************************/
  data 
   stg_wtch.wl_dwjn_transform_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_01, output_ds=Y) keep=
      name_type
      entity_watch_list_number
      watch_list_name
      category_desc
      type_desc
      identification_id
      identification_type_desc
      place_of_birth
      deceased_ind
      occupation_desc
      politically_exposed_person_ind
      create_date
      update_date
      exclude_ind
      nationality_country_name
   )

   stg_wtch.wl_dwjn_transform_02(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_02, output_ds=Y) keep=
      entity_watch_list_number
      sanctions_list_reference
   )

   stg_wtch.wl_dwjn_transform_03(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_03, output_ds=Y) keep=
      entity_watch_list_number
      type_desc
      date_type
      date
      month
      year
   )

   stg_wtch.wl_dwjn_transform_04(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_04, output_ds=Y) keep=
      entity_watch_list_number
      type_desc
      name_type
      name_sub_type
      surname
      firstname
      middlename
      title_honorific
   )

   stg_wtch.wl_dwjn_transform_05(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_05, output_ds=Y) keep=
      entity_watch_list_number
      address_line
      address_city
      address_country
   )

   stg_wtch.wl_dwjn_transform_06(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_06, output_ds=Y) keep=
      entity_watch_list_number
      type_desc
      country_type
      country
   )

   stg_wtch.wl_dwjn_delete(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_delete, output_ds=Y) keep=
      entity_watch_list_number
   )

   stg_err.wl_dwjn_errors_01(%fcf_get_ds_opts(lib_name=stg_err, ds_name=wl_dwjn_errors_01, output_ds=Y) keep=
      entity_watch_list_number
      watch_list_name
      error_file
      error_record_number
      error_field
      error_value
      error_message
      error_datetime
   );

   length
      person_entity_id_lag 8
      action_lag $ 3
      type_desc_lag $ 20
      description_3_lag $ 20
   ;

   retain
      person_entity_id_lag
      action_lag
      type_desc_lag
      description_3_lag
   ;
   retain error_flag 0;

   attrib
   /* ERROR FIELDS */
      error_file          length=$200
                          informat=$200.
                          format=$200.
                          label='Error File'

      error_record_number length=8
                          informat=best32.
                          format=best32.
                          label='Error Record Number'

      error_field         length=$32
                          informat=$32.
                          format=$32.
                          label='Error Field'

      error_value         length=$1000
                          informat=$1000.
                          format=$1000.
                          label='Error Value'

      error_message       length=$200
                          informat=$200.
                          format=$200.
                          label='Error Message'

      error_datetime      length=8
                          informat=nldatm.
                          format=nldatm.
                          label='Error Datetime'
   ;

   /* FSC_ENTITY_WATCH_LIST_DIM */
   /* Sets variable attribs to match variables in DBMS */
   if 1 eq 0 then
      set seg_kc.FSC_ENTITY_WATCH_LIST_DIM;

   set stg_wtch.wl_dwjn_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_extract) keep=
      person_entity_id
      action
      deceased
      name_type
      name_sub_type
      title_honorific
      surname
      firstname
      middlename
      suffix
      description_1
      description_2
	  description_3
      title
      date_type
      date
      month
      year
      place_of_birth
      sanctions_list_reference
      address_line
      address_city
      address_country
      country_type
      country
      identification_type
      identification_number
      related_person_entity_id
      addition_date
      last_reviewed_date
      place_of_birth
   ) end=eof;

   /* ENTITY_WATCH_LIST_NUMBER */
   if not missing(person_entity_id) then do;
      person_entity_id_lag=person_entity_id;
      description_3_lag=description_3;
   end;
   else if missing(person_entity_id) then do;
      person_entity_id=person_entity_id_lag;
      description_3=description_3_lag;
   end;

   /* Filter out Ships and Aircrafts */
   if kstrip(upcase(description_3)) ne "SHIP"
     and kstrip(upcase(description_3)) ne "AIRCRAFT";

   entity_watch_list_number=kstrip(put(person_entity_id,best32.));

   if not missing(action) then
      action_lag=action;
   else if missing(action) then
      action=action_lag;

   if upcase(action) eq 'DEL' then
      output stg_wtch.wl_dwjn_delete;

   else if upcase(action) in ('ADD','CHG') then do;

      /* WATCH_LIST_NAME */
      watch_list_name='DWJN';

      /* CATEGORY_DESC */
      if upcase(description_2) eq 'TERROR' then
         category_desc='TERRORISM';
      else
         category_desc=upcase(compbl(kstrip(description_2)));

      /* TYPE_DESC */
      if upcase(compbl(kstrip(description_1))) eq 'POLITICALLY EXPOSED PERSON (PEP)' or
         index(upcase(description_1),'(PEP)') gt 0 then do;
         type_desc='INDIVIDUAL';

         /* POLITICALLY_EXPOSED_PERSON_IND */
         politically_exposed_person_ind='Y';
      end;

      else if upcase(compbl(kstrip(description_1))) eq 'RELATIVE OR CLOSE ASSOCIATE (RCA)' or
         index(upcase(description_1),'(RCA)') gt 0 then
         type_desc='INDIVIDUAL';

      else if upcase(compbl(kstrip(description_1))) eq 'SPECIAL INTEREST PERSON (SIP)' or
         index(upcase(description_1),'(SIP)') gt 0 then
         type_desc='INDIVIDUAL';

      else if upcase(compbl(kstrip(description_1))) eq 'SPECIAL INTEREST ENTITY (SIE)' or
         index(upcase(description_1),'(SIE)') gt 0 then
         type_desc='ORGANIZATION';

      /* IDENTIFICATION_ID */
      identification_id=kstrip(identification_number);

      /* IDENTIFICATION_TYPE_DESC */
      identification_type_desc=upcase(compbl(kstrip(identification_type)));

      /* PLACE_OF_BIRTH */
      place_of_birth=compbl(kstrip(place_of_birth));

      /* DECEASED_IND */
      if upcase(deceased) eq 'YES' then
         deceased_ind='Y';
      else
         deceased_ind='N';

      /* OCCUPATION_DESC */
      occupation_desc=compbl(kstrip(title));

      /* CREATE_DATE */
      if not missing(addition_date) then do;
         create_date=input(addition_date,??anydtdte32.);
         if not missing(create_date) then
            create_date=dhms(create_date,00,00,00);
      end;
      if not missing(last_reviewed_date) then do;
          update_date=input(last_reviewed_date,??anydtdte32.);
          if not missing(update_date) then
             update_date=dhms(update_date,00,00,00);
      end;

      /* EXCLUDE_IND */
      exclude_ind='N';

      /* NATIONALITY_COUNTRY_NAME */
      nationality_country_name='';

      if not missing(type_desc) then
         type_desc_lag=type_desc;
      else if missing(type_desc) then
         type_desc=type_desc_lag;

      if politically_exposed_person_ind ne 'Y' then
         politically_exposed_person_ind='N';

      /* ERROR: Unknown description_1 - cannot determine type_desc */
      if missing(type_desc) and not missing(description_1) then do;

         entity_watch_list_number=kstrip(put(person_entity_id,best32.));
         watch_list_name='DWJN';
         error_file="&dwjn_file";
         error_record_number=_N_;
         error_field='DESCRIPTION_1';
         error_value=kstrip(description_1);
         error_message='ERROR: Unknown DESCRIPTION_1.';
         error_datetime=datetime();

         putlog 'ERROR: FCF: Cannot determine type based on DESCRIPTION_1. '
                entity_watch_list_number= description_1=;
                
         error_flag=1;
         output stg_err.wl_dwjn_errors_01;
      end;

      /* WARNING:  related_person_entity_id is not numeric.  This    */
      /*         occurs when IDENTIFICATION_NOTES or PROFILE_NOTES */
      /*         exceeds the SAS max  character length of 32767    */
      /*          or contains double quotes within the text        */


      if not missing(related_person_entity_id) and notdigit(strip(related_person_entity_id)) ge 1 then do;

         entity_watch_list_number=kstrip(put(person_entity_id,best32.));
         watch_list_name='DWJN';
         error_file="&dwjn_file";
         error_record_number=_N_;
         error_field='related_person_entity_id';
         error_value=kstrip(related_person_entity_id);
         error_message='WARNING: One of the Notes fields is too long or contains invalid characters';
         error_datetime=datetime();

         putlog 'WARNING: FCF: One of the Notes fields is too long or contains invalid characters';
                
         error_flag=1;
         output stg_err.wl_dwjn_errors_01;
      end;
   
      drop related_person_entity_id;

      output
         stg_wtch.wl_dwjn_transform_01
         stg_wtch.wl_dwjn_transform_02
         stg_wtch.wl_dwjn_transform_03
         stg_wtch.wl_dwjn_transform_04
         stg_wtch.wl_dwjn_transform_05
         stg_wtch.wl_dwjn_transform_06
      ;

   end;

   /* Set all columns in if set 1=0 column to missing */
   call missing(&col_name_list);

   if (eof) and (error_flag) then do;
      putlog ' ';
      putlog 'WARNING: FCF: Invalid values were encountered processing the watch list data';
      putlog 'WARNING: FCF: Data values were written to the STG_ERR.WL_DWJN_ERRORS table.';
   end;

  run;

  /****************************************************************************/
  /* STEP 2                                                                   */
  /*                                                                          */
  /* DESCRIPTION:                                                             */
  /* Process sanctions_list_reference.                                        */
  /*                                                                          */
  /* NOTES:                                                                   */
  /* Each entity can have multiple sanctions_list_reference values.  Because  */
  /* some entities are in so many lists that concatenating the values of the  */
  /* lists exceed the length of programs in the database, the following rules */
  /* are applied in building the programs list:                               */
  /* 1)  The sanction_list_reference is checked agains the most important     */
  /*     lists based on current customer base.                                */
  /*          Text Checked             Special List Value                     */
  /*          ------------             ------------------                     */
  /*          OFAC                     OFAC                                   */
  /*          DFAT                     DFAT                                   */
  /*          begins with EC           EUFS                                   */
  /*          HM Treasury              HMT                                    */
  /*          New Zealand Police       NCBI                                   */
  /*          UN Security Council      UNSC                                   */
  /* 2) If the entity is one or more special lists, the Special List Values   */
  /*    are included in the programs field.   If the entity is also on        */
  /*    other lists, the count of other lists is included in the programs     */
  /* 3) If the entity is not on any special list, the programs field contains */
  /*    a concatentated list of all the reference lists providing the number  */
  /*    of distinct lists is <= 5 and the length of the concatenated list     */
  /*    is less than 250.                                                     */
  /* 4) If the number of lists constraint or the length constraint is violated*/
  /*    only a count is provided.                                             */
  /*                                                                          */
  /*                                                                          */
  /*                                                                          */
  /* INPUTS(S);                                                               */
  /* stg_wtch.wl_dwjn_transform_02                                            */
  /*                                                                          */
  /* OUTPUT(S):                                                               */
  /* stg_wtch.wl_dwjn_transform_07                                            */
  /****************************************************************************/
  proc sort data=stg_wtch.wl_dwjn_transform_02(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_02)
                                               where=(sanctions_list_reference ne ''))
            out=stg_wtch.wl_dwjn_transform_02(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_02, output_ds=Y))
            nodupkey;
    by entity_watch_list_number sanctions_list_reference;
   run;



  data stg_wtch.wl_dwjn_transform_07(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_07, output_ds=Y)
                                     keep=entity_watch_list_number programs);

   /* FSC_ENTITY_WATCH_LIST_DIM */
   /* Sets variable attribs to match variables in DBMS */
   if 1 eq 0 then
      set seg_kc.FSC_ENTITY_WATCH_LIST_DIM;

   set stg_wtch.wl_dwjn_transform_02(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_02));
   by entity_watch_list_number sanctions_list_reference;

   retain programs special_programs  count special_prog_count;
   length special_programs $250 current_program $10;

   sanctions_list_reference=upcase(sanctions_list_reference);

   /* if this is the first record for an entity, reset the counters and   */
   /* the text fields used to capture the sanctions lists                 */
   if first.entity_watch_list_number then do; 
      count = 0;
	   special_prog_count=0;
	   programs="";
	   special_programs="";
	end;

    if not missing(sanctions_list_reference) and  first.sanctions_list_reference then do;
	     count+1;
         if kindex(sanctions_list_reference,"OFAC") > 0 then do;
		    special_prog_count+1;
		    current_program="OFAC ";
	     end;
		 else if kindex(sanctions_list_reference,"DFAT") > 0 then do;
		    special_prog_count+1;
		    current_program="DFAT ";
	     end;
		 else if ksubstr(kleft(sanctions_list_reference), 1, 2)="EC" then do;
		    special_prog_count+1;
		    current_program="EUFS ";
	     end;
		 else if kindex(sanctions_list_reference,"HM TREASURY") > 0 then do;
		    special_prog_count+1;
		    current_program="HMT ";
	     end;
		 else if kindex(sanctions_list_reference,"NEW ZEALAND POLICE") > 0 then do;
		    special_prog_count+1;
		    current_program="NCBI ";
	     end;
         else if kindex(sanctions_list_reference,"UN SECURITY COUNCIL") > 0 then do;
		    special_prog_count+1;
		    current_program="UNSC ";
	     end;
		 else if kindex(sanctions_list_reference,"OSFI") > 0 then do;
		    special_prog_count+1;
		    current_program="OSFI ";
	     end;
	     else if missing(programs) then programs=compbl(kstrip(sanctions_list_reference));
		      else programs=kstrip(programs) || ';' || compbl(kstrip(sanctions_list_reference));


		 if missing(special_programs) then special_programs=compbl(kstrip(current_program));
		 else if kindex(special_programs,current_program)=0 then
                 special_programs=kstrip(special_programs) || ';' || compbl(kstrip(current_program));
		  
      end;

   /* if this is the last record for an entity, determine the text to be stored */
   if last.entity_watch_list_number then do;
      if special_prog_count then do;
           programs=special_programs;
           if (count - special_prog_count) > 0 then programs=kstrip(special_programs)||";"||kstrip(put(count - special_prog_count,best32.))||" additional lists";
	  end;
	  else if count > 5 or length(programs) > 250 then programs="Entity on "||kstrip(put(count, best32.))||" sanctions lists";
      output;
   end;

  run;
  /****************************************************************************/
  /* STEP 3                                                                   */
  /*                                                                          */
  /* DESCRIPTION:                                                             */
  /* Process date_of_birth, year_of_birth                                     */
  /*                                                                          */
  /* NOTES:                                                                   */
  /*                                                                          */
  /* INPUTS(S);                                                               */
  /*  stg_wtch.wl_dwjn_transform_03                                           */
  /*                                                                          */
  /* OUTPUT(S):                                                               */
  /* stg_wtch.wl_dwjn_transform_08                                            */
  /* stg_err.wl_dwjn_errors_02     (date_of_birth errors)                     */
  /****************************************************************************/
  data

   stg_wtch.wl_dwjn_transform_08(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_08, output_ds=Y) keep=
      entity_watch_list_number
      date_of_birth
      year_of_birth
      )

   stg_err.wl_dwjn_errors_02(%fcf_get_ds_opts(lib_name=stg_err, ds_name=wl_dwjn_errors_02, output_ds=Y) keep=
      entity_watch_list_number
      watch_list_name
      error_file
      error_record_number
      error_field
      error_value
      error_message
      error_datetime
      );


   length
      date_type_lag $ 255
      _date_of_birth $ 11
   ;

   retain
      date_type_lag
   ;
   retain error_flag 0;

   attrib
   /* ERROR FIELDS */
      error_file          length=$200
                          informat=$200.
                          format=$200.
                          label='Error File'

      error_record_number length=8
                          informat=best32.
                          format=best32.
                          label='Error Record Number'

      error_field         length=$32
                          informat=$32.
                          format=$32.
                          label='Error Field'

      error_value         length=$1000
                          informat=$1000.
                          format=$1000.
                          label='Error Value'

      error_message       length=$200
                          informat=$200.
                          format=$200.
                          label='Error Message'

      error_datetime      length=8
                          informat=nldatm.
                          format=nldatm.
                          label='Error Datetime'
   ;

   /* FSC_ENTITY_WATCH_LIST_DIM */
   /* Sets variable attribs to match variables in DBMS */
   if 1 eq 0 then
      set seg_kc.FSC_ENTITY_WATCH_LIST_DIM;

   set stg_wtch.wl_dwjn_transform_03(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_03)) end=eof;

   if not missing(date_type) then
      date_type_lag=date_type;
   if missing(date_type) then
      date_type=date_type_lag;

   if upcase(type_desc) eq 'INDIVIDUAL' and
      upcase(date_type) eq 'DATE OF BIRTH' then do;

      if not missing(date) and
         not missing(month) and
         not missing(year) then do;

         _date_of_birth=catx('-',date,month,year);
         date_of_birth=input(_date_of_birth,??anydtdte32.);
         if not missing(date_of_birth) then do;
            date_of_birth=dhms(date_of_birth,00,00,00);
            year_of_birth=year(datepart(date_of_birth));
            output stg_wtch.wl_dwjn_transform_08;
         end;
         else if missing(date_of_birth) then do;
            year_of_birth=.;
            watch_list_name='DWJN';
            error_file="&dwjn_file";
            error_record_number=_N_;
            error_field='DATE_OF_BIRTH';
            error_value=kstrip(_date_of_birth);
            error_message='WARNING: Invalid date of birth.';
            error_datetime=datetime();

            output stg_err.wl_dwjn_errors_02;

            putlog 'WARNING: FCF: Invalid date of birth. '
                   entity_watch_list_number= date= month= year=;

            error_flag = 1;

         end;
      end;
      else if not missing(year) then do;
         year_of_birth=input(year,??best32.);
         if not missing(year_of_birth) then do;
            date_of_birth=.;
            output stg_wtch.wl_dwjn_transform_08;
         end;
         else if missing(year_of_birth) then do;
            date_of_birth=.;

            watch_list_name='DWJN';
            error_file="&dwjn_file";
            error_record_number=_N_;
            error_field='DATE_OF_BIRTH';
            error_value=kstrip(year);
            error_message='WARNING: Invalid year of birth.';
            error_datetime=datetime();

            output stg_err.wl_dwjn_errors_02;

            putlog 'WARNING: FCF: Invalid date of birth. ' entity_watch_list_number= date= month= year=;
            error_flag = 1;

         end;
      end;
   end;

   if (eof) and (error_flag) then do;
      putlog ' ';
      putlog 'WARNING: FCF: Invalid values were encountered processing the watch list data';
      putlog 'WARNING: FCF: Data values were written to the STG_ERR.WL_DWJN_ERRORS table.';
   end;

  run;

  proc sort data=stg_wtch.wl_dwjn_transform_08(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_08))
            out=stg_wtch.wl_dwjn_transform_08(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_08, output_ds=Y))
            nodupkey;
    by entity_watch_list_number
       date_of_birth
       year_of_birth
       ;
  run;

  /****************************************************************************/
  /* STEP 4                                                                   */
  /*                                                                          */
  /* DESCRIPTION:                                                             */
  /* Process first_name, middle_name, last_name and entity_name               */
  /*                                                                          */
  /* NOTES:                                                                   */
  /*                                                                          */
  /* INPUTS(S);                                                               */
  /* stg_wtch.wl_dwjn_transform_04                                            */
  /*                                                                          */
  /* OUTPUT(S):                                                               */
  /* stg_wtch.wl_dwjn_transform_09                                            */
  /****************************************************************************/
  data stg_wtch.wl_dwjn_transform_09(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_09, output_ds=Y)
                                     keep=
   entity_watch_list_number
   first_name
   middle_name
   last_name
   entity_name
   entity_title
   );


   /* FSC_ENTITY_WATCH_LIST_DIM */
   /* Sets variable attribs to match variables in DBMS */
   if 1 eq 0 then
      set seg_kc.FSC_ENTITY_WATCH_LIST_DIM;

   set stg_wtch.wl_dwjn_transform_04 (%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_04)
                                      rename=(firstname=first_name
                                              middlename=middle_name
                                              surname=last_name))
   ;

   retain osn_flag 0;
   
   /* Set OSN flag until new name_type encountered.
      Multiple OSN's for an entry will only indicate OSN on the first record.
      Must check for a new (non-missing) name_type to indicate that OSN's
      are complete.
   */
   if upcase(name_sub_type) eq 'OSN' then osn_flag=1;
   if osn_flag=1 and not missing(name_type) then osn_flag=0;
   if osn_flag then
      delete;
      
   if upcase(type_desc) eq 'ORGANIZATION' then do;
      entity_name=upcase(compbl(kstrip(first_name)));
      entity_title='';
   end;

   else if upcase(type_desc) eq 'INDIVIDUAL' then do;

      last_name=kcompress(last_name,'?');

      if missing(last_name) then
         delete;

      /* FIRST_NAME */
      first_name=upcase(compbl(kstrip(first_name)));

      /* MIDDLE_NAME */
      middle_name=upcase(compbl(kstrip(middle_name)));

      /* LAST_NAME */
      last_name=upcase(compbl(kstrip(last_name)));

      /* ENTITY_NAME */
      entity_name=catx(' ',first_name,middle_name,last_name);

      /* ENTITY_TITLE */
      entity_title=upcase(compbl(kstrip(title_honorific)));

   end;

   if not missing(entity_name) then
      output stg_wtch.wl_dwjn_transform_09;

  run;

  proc sort data=stg_wtch.wl_dwjn_transform_09(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_09))
            out=stg_wtch.wl_dwjn_transform_09(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_09, output_ds=Y))
            nodupkey;
   by entity_watch_list_number
      entity_name;
  run;

  /****************************************************************************/
  /* STEP 5                                                                   */
  /*                                                                          */
  /* DESCRIPTION:                                                             */
  /* Process address, city_name, state_name, postal_code, country_name and    */
  /* full_address.                                                            */
  /*                                                                          */
  /* NOTES:                                                                   */
  /*                                                                          */
  /* INPUTS(S);                                                               */
  /* stg_wtch.wl_dwjn_transform_05                                            */
  /*                                                                          */
  /* OUTPUT(S):                                                               */
  /* stg_wtch.wl_dwjn_transform_10                                            */
  /*                                                                          */
  /****************************************************************************/
  data stg_wtch.wl_dwjn_transform_10(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_10, output_ds=Y)
                                     keep=
   entity_watch_list_number
   address
   city_name
   state_name
   postal_code
   country_name
   full_address
   );

    /* FSC_ENTITY_WATCH_LIST_DIM */
    /* Sets variable attribs to match variables in DBMS */
    if 1 eq 0 then
      set seg_kc.FSC_ENTITY_WATCH_LIST_DIM;

    set stg_wtch.wl_dwjn_transform_05(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_05));

    if upcase(address_country) eq 'NOT KNOWN' then
      address_country='';

    if missing(address_line) and
       missing(address_city) and
       missing(address_country) then
      delete;

    address=upcase(compbl(kstrip(address_line)));
    city_name=upcase(compbl(kstrip(address_city)));
    country_name=upcase(compbl(kstrip(address_country)));
    state_name='';
    postal_code='';

    /* Attempt to parse state/province name from city_name */
    pos = findc(city_name, ',', 'b');
    if pos > 0 then do;
       state_name=substr(city_name,pos+1);
       city_name=substr(city_name,1,pos-1);
    end;

    full_address=catx(';', address, city_name, state_name, postal_code, country_name);

    if not missing(full_address) then
      output stg_wtch.wl_dwjn_transform_10;

  run;

  proc sort data=stg_wtch.wl_dwjn_transform_10(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_10))
            out=stg_wtch.wl_dwjn_transform_10(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_10, output_ds=Y))
            nodupkey;
    by entity_watch_list_number
       full_address
       ;
   run;

  /****************************************************************************/
  /* STEP 6                                                                   */
  /*                                                                          */
  /* DESCRIPTION:                                                             */
  /* Process citizenship_country_name and org_country_of_business_name        */
  /*                                                                          */
  /* NOTES:                                                                   */
  /*                                                                          */
  /* INPUTS(S);                                                               */
  /* stg_wtch.wl_dwjn_transform_06                                            */
  /*                                                                          */
  /* OUTPUT(S):                                                               */
  /* stg_wtch.wl_dwjn_transform_11                                            */
  /****************************************************************************/
  data stg_wtch.wl_dwjn_transform_11(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_11, output_ds=Y)
                                     keep=
   entity_watch_list_number
   citizenship_country_name
   org_country_of_business_name
   );

   /* FSC_ENTITY_WATCH_LIST_DIM */
   /* Sets variable attribs to match variables in DBMS */
   if 1 eq 0 then
      set seg_kc.FSC_ENTITY_WATCH_LIST_DIM;

   set stg_wtch.wl_dwjn_transform_06(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_06));

   if upcase(country) eq 'NOT KNOWN' then
      country='';

   if missing(country) then
      delete;

   if upcase(compbl(kstrip(country_type))) eq 'RESIDENT OF' then
      delete;

   if upcase(type_desc) eq 'INDIVIDUAL' then do;
      citizenship_country_name=upcase(compbl(kstrip(country)));
      org_country_of_business_name='';
      output stg_wtch.wl_dwjn_transform_11;
   end;
   else if upcase(type_desc) eq 'ORGANIZATION' then do;
      org_country_of_business_name=upcase(compbl(kstrip(country)));
      citizenship_country_name='';
      output stg_wtch.wl_dwjn_transform_11;
   end;

  run;

  proc sort data=stg_wtch.wl_dwjn_transform_11(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_11))
            out=stg_wtch.wl_dwjn_transform_11(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_11, output_ds=Y))
           nodupkey;
    by entity_watch_list_number
       citizenship_country_name
       org_country_of_business_name
       ;
   run;

  /****************************************************************************/
  /* STEP 7                                                                   */
  /*                                                                          */
  /* DESCRIPTION:                                                             */
  /* Output primary entities                                                  */
  /*                                                                          */
  /* NOTES:                                                                   */
  /*                                                                          */
  /* INPUTS(S):                                                               */
  /* stg_wtch.wl_dwjn_transform_01                                            */
  /*                                                                          */
  /* OUTPUT(S):                                                               */
  /* set stg_wtch.wl_dwjn_transform_12                                        */
  /****************************************************************************/
  data stg_wtch.wl_dwjn_transform_12(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_12, output_ds=Y) drop=name_type);
   set stg_wtch.wl_dwjn_transform_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_01));
    if upcase(compbl(kstrip(name_type))) eq 'PRIMARY NAME' then
       output stg_wtch.wl_dwjn_transform_12;
  run;

  /****************************************************************************/
  /* STEP 8                                                                   */
  /*                                                                          */
  /* DESCRIPTION:                                                             */
  /*                                                                          */
  /* Generate all data permutations for each distinct primary entity          */
  /*                                                                          */
  /* NOTES:                                                                   */
  /*                                                                          */
  /*                                                                          */
  /* INPUTS(S);                                                               */
  /*                                                                          */
  /* stg_wtch.wl_dwjn_transform_07                                            */
  /* stg_wtch.wl_dwjn_transform_08                                            */
  /* stg_wtch.wl_dwjn_transform_09                                            */
  /* stg_wtch.wl_dwjn_transform_10                                            */
  /* stg_wtch.wl_dwjn_transform_11                                            */
  /* stg_wtch.wl_dwjn_transform_12                                            */
  /*                                                                          */
  /* OUTPUT(S):                                                               */
  /*                                                                          */
  /* set stg_wtch.wl_dwjn_transform_13                                        */
  /* set stg_wtch.wl_dwjn_transform_14                                        */
  /* set stg_wtch.wl_dwjn_transform_15                                        */
  /* set stg_wtch.wl_dwjn_transform_16                                        */
  /* set stg_wtch.wl_dwjn_transform    (final transform)                      */
  /****************************************************************************/
  proc sql noprint;

   create table stg_wtch.wl_dwjn_transform_13 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_13, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.programs
        from stg_wtch.wl_dwjn_transform_12(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_12)) as a full join
             stg_wtch.wl_dwjn_transform_07(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_07)) as b
             on a.entity_watch_list_number=b.entity_watch_list_number;

   create table stg_wtch.wl_dwjn_transform_14 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_14, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.date_of_birth,
             b.year_of_birth
        from stg_wtch.wl_dwjn_transform_13(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_13)) as a full join
             stg_wtch.wl_dwjn_transform_08(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_08)) as b
             on a.entity_watch_list_number=b.entity_watch_list_number;

   create table stg_wtch.wl_dwjn_transform_15 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_15, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.first_name,
             b.middle_name,
             b.last_name,
             b.entity_name,
             b.entity_title
        from stg_wtch.wl_dwjn_transform_14(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_14)) as a full join
             stg_wtch.wl_dwjn_transform_09(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_09)) as b
             on a.entity_watch_list_number=b.entity_watch_list_number;

   create table stg_wtch.wl_dwjn_transform_16 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_16, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.address,
             b.city_name,
             b.state_name,
             b.postal_code,
             b.country_name,
             b.full_address
        from stg_wtch.wl_dwjn_transform_15(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_15)) as a full join
             stg_wtch.wl_dwjn_transform_10(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_10)) as b
             on a.entity_watch_list_number=b.entity_watch_list_number;

   create table stg_wtch.wl_dwjn_transform %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.citizenship_country_name,
             b.org_country_of_business_name
        from stg_wtch.wl_dwjn_transform_16(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_16)) as a full join
             stg_wtch.wl_dwjn_transform_11(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transform_11)) as b
             on a.entity_watch_list_number=b.entity_watch_list_number
       order by entity_watch_list_number, entity_name;

quit;

  /****************************************************************************/
  /* STEP 9                                                                   */
  /*                                                                          */
  /* DESCRIPTION:                                                             */
  /* Create final delete file                                                 */
  /*                                                                          */
  /* NOTES:                                                                   */
  /*                                                                          */
  /* INPUTS(S);                                                               */
  /* stg_wtch.wl_dwjn_delete                                                  */
  /*                                                                          */
  /* OUTPUT(S):                                                               */
  /* stg_wtch.wl_dwjn_delete                                                  */
  /****************************************************************************/
  proc sort data=stg_wtch.wl_dwjn_delete(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_delete))
            out=stg_wtch.wl_dwjn_delete(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_delete, output_ds=Y))
            nodupkey;
    by entity_watch_list_number;
   run;

  /****************************************************************************/
  /* STEP 10                                                                  */
  /*                                                                          */
  /* DESCRIPTION:                                                             */
  /* Create final errors file                                                 */
  /*                                                                          */
  /* NOTES:                                                                   */
  /*                                                                          */
  /* INPUTS(S);                                                               */
  /* stg_err.wl_dwjn_errors_01                                                */
  /* stg_err.wl_dwjn_errors_02                                                */
  /*                                                                          */
  /* OUTPUT(S):                                                               */
  /* stg_err.wl_dwjn_errors                                                   */
  /****************************************************************************/
  proc append base=stg_err.wl_dwjn_errors(%fcf_get_ds_opts(lib_name=stg_err, ds_name=wl_dwjn_errors, output_ds=Y))
              data=stg_err.wl_dwjn_errors_01(%fcf_get_ds_opts(lib_name=stg_err, ds_name=wl_dwjn_errors_01))
              force;
   run;

  proc append base=stg_err.wl_dwjn_errors(%fcf_get_ds_opts(lib_name=stg_err, ds_name=wl_dwjn_errors, output_ds=Y))
              data=stg_err.wl_dwjn_errors_02(%fcf_get_ds_opts(lib_name=stg_err, ds_name=wl_dwjn_errors_02))
              force;
   run;

  proc sort data=stg_err.wl_dwjn_errors(%fcf_get_ds_opts(lib_name=stg_err, ds_name=wl_dwjn_errors))
            out=stg_err.wl_dwjn_errors(%fcf_get_ds_opts(lib_name=stg_err, ds_name=wl_dwjn_errors, output_ds=Y))
            nodupkey;
    by entity_watch_list_number
       error_value;
   run;


  %MACRO_END:

   %if &trans_rc eq 3 or &trans_rc ge 5 %then
      %fcf_execute_macro(fcf_error);
   %else %do;
      %fcf_execute_macro(post&_fcfmodule_);
      %fcf_execute_macro(fcf_success);
   %end;

%mend fcf_wl_dwjn_transform;
