/*==============================================================================
| NAME:    fcf_wl_osfi_extract
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================

WATCH LIST PROVIDER - Office of the Superintendent of Financial Institutions Canada
WATCH LIST NAME     - Terrorism Financing (Lists of Names)
WATCH LIST CODE     - OSFI
WEB LINK            - http://www.osfi-bsif.gc.ca/osfi/index_e.aspx?DetailID=525

MODULE TYPE         - EXTRACT
MODULE PURPOSE      - Read extract file(s) and output to SAS data set(s).

MODULE NOTES
------------
None

==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_wl_osfi_extract;

  /*------------
   * Set module
   *------------*/
  %let _fcfmodule_=fcf_WL_OSFI_EXTRACT;

  /*---------------------
   * Call pre macro stub
   *---------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*------------------------------------------
   * Set error code to 0 and message to blank
   *------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;

/******************************************************************************/
/* BEGIN: STG_WTCH.wl_osfi_indstld_extract_01                                 */
/*                                                                            */
/* DESCRIPTION: Obtain maximum field lengths - (Part A - Individuals extract) */
/******************************************************************************/
   filename file_1 "&osfi_indstld_file";

   data STG_WTCH.wl_osfi_indstld_extract_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_osfi_indstld_extract_01, output_ds=Y)
                                            keep=
      id_L
      last_name_L
      first_name_L
      second_name_L
      third_name_L
      fourth_name_L
      pob_L
      alt_pob_L
      dob_L
      alt_dob_1_L
      alt_dob_2_L
      alt_dob_3_L
      nationality_L
      alt_nationality_1_L
      alt_nationality_2_L
      other_info_L
      basis_L
   );

      attrib
         id                informat=$&textsize..
         last_name         informat=$&textsize..
         first_name        informat=$&textsize..
         second_name       informat=$&textsize..
         third_name        informat=$&textsize..
         fourth_name       informat=$&textsize..
         pob               informat=$&textsize..
         alt_pob           informat=$&textsize..
         dob               informat=$&textsize..
         alt_dob_1         informat=$&textsize..
         alt_dob_2         informat=$&textsize..
         alt_dob_3         informat=$&textsize..
         nationality       informat=$&textsize..
         alt_nationality_1 informat=$&textsize..
         alt_nationality_2 informat=$&textsize..
         other_info        informat=$&textsize..
         basis             informat=$&textsize..
      ;

      infile file_1 delimiter='09'x dsd missover lrecl=32767 firstobs=7;

      input
         id                 $
         last_name          $
         first_name         $
         second_name        $
         third_name         $
         fourth_name        $
         pob                $
         alt_pob            $
         dob                $
         alt_dob_1          $
         alt_dob_2          $
         alt_dob_3          $
         nationality        $
         alt_nationality_1  $
         alt_nationality_2  $
         other_info         $
         basis              $
      ;

      if missing(id) then
         stop;

      id_L=length(id);
      last_name_L=length(last_name);
      first_name_L=length(first_name);
      second_name_L=length(second_name);
      third_name_L=length(third_name);
      fourth_name_L=length(fourth_name);
      pob_L=length(pob);
      alt_pob_L=length(alt_pob);
      dob_L=length(dob);
      alt_dob_1_L=length(alt_dob_1);
      alt_dob_2_L=length(alt_dob_2);
      alt_dob_3_L=length(alt_dob_3);
      nationality_L=length(nationality);
      alt_nationality_1_L=length(alt_nationality_1);
      alt_nationality_2_L=length(alt_nationality_2);
      other_info_L=length(other_info);
      basis_L=length(basis);
   run;
   %fcf_rcset(&syserr);
   %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_= ERROR: FCF: An error occurred reading the OSFI data file.;
      %put &_fcfmsg_;
      %let _fcfmsg_= ERROR: FCF: OSFI input file specified as: &osfi_indstld_file.;
      %put &_fcfmsg_;
      %goto MACRO_END;
   %end;

proc sql noprint;
   select max(id_L),
          max(last_name_L),
          max(first_name_L),
          max(second_name_L),
          max(third_name_L),
          max(fourth_name_L),
          max(pob_L),
          max(alt_pob_L),
          max(dob_L),
          max(alt_dob_1_L),
          max(alt_dob_2_L),
          max(alt_dob_3_L),
          max(nationality_L),
          max(alt_nationality_1_L),
          max(alt_nationality_2_L),
          max(other_info_L),
          max(basis_L)
   into   :L1,
          :L2,
          :L3,
          :L4,
          :L5,
          :L6,
          :L7,
          :L8,
          :L9,
          :L10,
          :L11,
          :L12,
          :L13,
          :L14,
          :L15,
          :L16,
          :L17
   from STG_WTCH.wl_osfi_indstld_extract_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_osfi_indstld_extract_01));
quit;

/* Make sure all columns have positive lengths, default of 200 */
%macro fcf_check_length;
   %do i = 1 %to 17;
      %if &&L&i eq 0 %then
         %let L&i=200;
         /* DEBUG */
         /*
         %put L&i: &&L&i;
         */
   %end;
%mend fcf_check_length;
%fcf_check_length;

/******************************************************************************/
/* END: STG_WTCH.wl_osfi_indstld_extract_01                                   */
/******************************************************************************/

/******************************************************************************/
/* BEGIN: STG_WTCH.wl_osfi_indstld_extract                                    */
/*                                                                            */
/* DESCRIPTION: Input(Part A - Individuals extract)                           */
/******************************************************************************/
data STG_WTCH.wl_osfi_indstld_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_osfi_indstld_extract, output_ds=Y));

   attrib
      id                length=$&L1
                        informat=$&L1..
                        format=$&L1..
                        label='ID'

      last_name         length=$&L2
                        informat=$&L2..
                        format=$&L2..
                        label='Last Name'

      first_name        length=$&L3
                        informat=$&L3..
                        format=$&L3..
                        label='First Name'

      second_name       length=$&L4
                        informat=$&L4..
                        format=$&L4..
                        label='Second Name'

      third_name        length=$&L5
                        informat=$&L5..
                        format=$&L5..
                        label='Third Name'

      fourth_name       length=$&L6
                        informat=$&L6..
                        format=$&L6..
                        label='Fourth Name'

      pob               length=$&L7
                        informat=$&L7..
                        format=$&L7..
                        label='Place of Birth'

      alt_pob           length=$&L8
                        informat=$&L8..
                        format=$&L8..
                        label='Alternate Place of Birth'

      dob               length=$&L9
                        informat=$&L9..
                        format=$&L9..
                        label='Date Of Birth'

      alt_dob_1         length=$&L10
                        informat=$&L10..
                        format=$&L10..
                        label='Alternate Date of Birth 1'

      alt_dob_2         length=$&L11
                        informat=$&L11..
                        format=$&L11..
                        label='Alternate Date of Birth 2'

      alt_dob_3         length=$&L12
                        informat=$&L12..
                        format=$&L12..
                        label='Alternate Date of Birth 3'

      nationality       length=$&L13
                        informat=$&L13..
                        format=$&L13..
                        label='Nationality'

      alt_nationality_1 length=$&L14
                        informat=$&L14..
                        format=$&L14..
                        label='Alternate Nationality 1'

      alt_nationality_2 length=$&L15
                        informat=$&L15..
                        format=$&L15..
                        label='Alternate Nationality 2'

      other_info        length=$&L16
                        informat=$&L16..
                        format=$&L16..
                        label='Other Info'

      basis             length=$&L17
                        informat=$&L17..
                        format=$&L17..
                        label='Basis'
   ;

  infile file_1 delimiter='09'x dsd missover lrecl=32767 firstobs=7 end=eof;

   input
      id                 $
      last_name          $
      first_name         $
      second_name        $
      third_name         $
      fourth_name        $
      pob                $
      alt_pob            $
      dob                $
      alt_dob_1          $
      alt_dob_2          $
      alt_dob_3          $
      nationality        $
      alt_nationality_1  $
      alt_nationality_2  $
      other_info         $
      basis              $
   ;

   if missing(id) then
      stop;

   if upcase("&allow_invalid") eq "N" then
      if _error_ ne 0 then do;
         call symputx('trans_rc', 999999);
         stop;
      end;

   if eof then
      call symputx('num_recs', _N_ );

run;
/******************************************************************************/
/* END: STG_WTCH.wl_osfi_indstld_extract                                      */
/******************************************************************************/

/******************************************************************************/
/* BEGIN: STG_WTCH.wl_osfi_entstld_extract_01                                 */
/*                                                                            */
/* DESCRIPTION: Obtain maximum field lengths - (Part B - Entities extract)    */
/******************************************************************************/
filename file_2 "&osfi_entstld_file";

data STG_WTCH.wl_osfi_entstld_extract_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_osfi_entstld_extract_01, output_ds=Y)
                                         keep=
   id_L
   entity_L
   address_L
   basis_L
);

   attrib
      id      informat=$&textsize..
      entity  informat=$&textsize..
      address informat=$&textsize..
      basis   informat=$&textsize..
   ;

   infile file_2 delimiter='09'x dsd missover lrecl=32767 firstobs=6;

   input
      id      $
      entity  $
      address $
      basis   $
   ;

   if missing(id) then
      stop;

   id_L=length(id);
   entity_L=length(entity);
   address_L=length(address);
   basis_L=length(basis);

run;

proc sql noprint;
   select max(id_L),
          max(entity_L),
          max(address_L),
          max(basis_L)
   into   :L1,
          :L2,
          :L3,
          :L4
   from STG_WTCH.wl_osfi_entstld_extract_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_osfi_entstld_extract_01));
quit;
/* Make sure all columns have positive lengths, default of 200 */
%macro fcf_check_length;
   %do i = 1 %to 4;
      %if &&L&i eq 0 %then
         %let L&i=200;
         /* DEBUG */
         /*
         %put L&i: &&L&i;
         */
   %end;
%mend fcf_check_length;
%fcf_check_length;
/******************************************************************************/
/* END: STG_WTCH.wl_osfi_entstld_extract_01                                   */
/******************************************************************************/

/******************************************************************************/
/* BEGIN: STG_WTCH.wl_osfi_entstld_extract                                    */
/*                                                                            */
/* DESCRIPTION: Input(Part B - Entities extract)                              */
/******************************************************************************/
data STG_WTCH.wl_osfi_entstld_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_osfi_entstld_extract, output_ds=Y));

   attrib
      id      length=$&L1
              informat=$&L1..
              format=$&L1..
              label='ID'

      entity  length=$&L2
              informat=$&L2..
              format=$&L2..
              label='Entity'

      address length=$&L3
              informat=$&L3..
              format=$&L3..
              label='Address'

      basis   length=$&L4
              informat=$&L4..
              format=$&L4..
              label='Basis'
   ;

   infile file_2 delimiter='09'x dsd missover lrecl=32767 firstobs=6 end=eof;

   input
      id      $
      entity  $
      address $
      basis   $
   ;

   if missing(id) then
      stop;

  if upcase("&allow_invalid") eq "N" then
      if _error_ ne 0 then do;
         call symputx('trans_rc', 999999);
         stop;
      end;

   if eof then
      call symputx('num_recs', _N_ );

run;
/******************************************************************************/
/* END: STG_WTCH.wl_osfi_entstld_extract                                      */
/******************************************************************************/


  %MACRO_END:
   
   %if &trans_rc eq 3 or &trans_rc ge 5 %then
      %fcf_execute_macro(fcf_error);
   %else %do;
      %fcf_execute_macro(post&_fcfmodule_);
      %fcf_execute_macro(fcf_success);
   %end;

%mend fcf_wl_osfi_extract;
