/*==============================================================================
| NAME:    fcf_wl_unsc_extract
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================

WATCH LIST PROVIDER - United Nations Security Council
WATCH LIST NAME     - The Consolidated List
WATCH LIST CODE     - UNSC
WEB LINK            - http://www.un.org/sc/committees/1267/consolist.shtml

MODULE TYPE         - EXTRACT
MODULE PURPOSE      - Read extract file(s) and output to SAS data set(s).

MODULE NOTES
------------
None

==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_wl_unsc_extract;

  /*------------
   * Set module
   *------------*/
  %let _fcfmodule_=fcf_WL_UNSC_EXTRACT;

  /*---------------------
   * Call pre macro stub
   *---------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*------------------------------------------
   * Set error code to 0 and message to blank
   *------------------------------------------*/
  %let trans_rc =0;
  %let _fcfmsg_=;

  /****************************************************************************/
  /* STEP 1                                                                   */
  /*                                                                          */
  /* DESCRIPTION:                                                             */
  /*                                                                          */
  /* Extract individual and entity data from xml file.                        */
  /*                                                                          */
  /* NOTES:                                                                   */
  /*                                                                          */
  /*                                                                          */
  /* INPUTS(S);                                                               */
  /*                                                                          */
  /* consolidatedlist.xml - UNSC current consolidated list (xml)              */
  /*                                                                          */
  /* OUTPUT(S):                                                               */
  /*                                                                          */
  /* stg_wtch.wl_unsc_extract_i                - Individual                   */
  /* stg_wtch.wl_unsc_extract_i_address        - Individual (Address)         */
  /* stg_wtch.wl_unsc_extract_i_alias          - Individual (Alias)           */
  /* stg_wtch.wl_unsc_extract_i_date_of_birth  - Individual (Date of Birth)   */
  /* stg_wtch.wl_unsc_extract_i_designation    - Individual (Designation)     */
  /* stg_wtch.wl_unsc_extract_i_document       - Individual (Document)        */
  /* stg_wtch.wl_unsc_extract_i_updated        - Individual (Updated)         */
  /* stg_wtch.wl_unsc_extract_i_nationality    - Individual (Nationality)     */
  /* stg_wtch.wl_unsc_extract_i_place_of_birth - Individual (Place of Birth)  */
  /* stg_wtch.wl_unsc_extract_i_title          - Individual (Title)           */
  /* stg_wtch.wl_unsc_extract_e                - Entity                       */
  /* stg_wtch.wl_unsc_extract_e                - Entity (Address)             */
  /* stg_wtch.wl_unsc_extract_e                - Entity (Alias)               */
  /* stg_wtch.wl_unsc_extract_e                - Entity (Updated)             */
  /****************************************************************************/
  filename in_unsc "&unsc_file";
  filename unsc_map "&unsc_map";
  libname  in_unsc xml xmlmap=unsc_map access=readonly;

  data stg_wtch.wl_unsc_extract_i(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i, output_ds=Y));
   set in_unsc.individual;
   run;

  data stg_wtch.wl_unsc_extract_i_address(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_address, output_ds=Y));
   set in_unsc.individual_address;
   run;

  data stg_wtch.wl_unsc_extract_i_alias(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_alias, output_ds=Y));
   set in_unsc.individual_alias;
   run;

  data stg_wtch.wl_unsc_extract_i_date_of_birth(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_date_of_birth, output_ds=Y));
   set in_unsc.individual_date_of_birth;
   run;

  data stg_wtch.wl_unsc_extract_i_designation(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_designation, output_ds=Y));
   set in_unsc.individual_designation;
   run;

  data stg_wtch.wl_unsc_extract_i_document(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_document, output_ds=Y));
   set in_unsc.individual_document;
   run;

  data stg_wtch.wl_unsc_extract_i_updated(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_updated, output_ds=Y));
   set in_unsc.individual_last_day_updated;
   run;

  data stg_wtch.wl_unsc_extract_i_nationality(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_nationality, output_ds=Y));
   set in_unsc.individual_nationality;
   run;

  data stg_wtch.wl_unsc_extract_i_place_of_birth(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_place_of_birth, output_ds=Y));
   set in_unsc.individual_place_of_birth;
   run;

  data stg_wtch.wl_unsc_extract_i_title(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_title, output_ds=Y));
   set in_unsc.individual_title;
   run;

  data stg_wtch.wl_unsc_extract_e(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_e, output_ds=Y));
   set in_unsc.entity;
   run;

  data stg_wtch.wl_unsc_extract_e_address(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_e_address, output_ds=Y));
   set in_unsc.entity_address;
   run;

  data stg_wtch.wl_unsc_extract_e_alias(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_e_alias, output_ds=Y));
   set in_unsc.entity_alias;
   run;

  data stg_wtch.wl_unsc_extract_e_updated(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_e_updated, output_ds=Y));
   set in_unsc.entity_last_day_updated;
   run;

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
     %fcf_execute_macro(fcf_error);
  %else %do;
     %fcf_execute_macro(post&_fcfmodule_);
     %fcf_execute_macro(fcf_success);
  %end;

%mend fcf_wl_unsc_extract;
