/*==============================================================================
| NAME:    fcf_wl_wchk_extract
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================

WATCH LIST PROVIDER - World-Check
WATCH LIST NAME     - Data File
WATCH LIST CODE     - WCHK
WEB LINK            - https://www.world-check.com/login/

MODULE TYPE         - EXTRACT
MODULE PURPOSE      - Read extract file(s) and output to SAS data set(s).

MODULE NOTES
------------
None

==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_wl_wchk_extract;

  /*------------
   * Set module
   *------------*/
  %let _fcfmodule_=fcf_WL_WCHK_EXTRACT;

  /*---------------------
   * Call pre macro stub
   *---------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*------------------------------------------
   * Set error code to 0 and message to blank
   *------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;

/******************************************************************************/
/* BEGIN: Determine World-Check file format                                   */
/*                                                                            */
/* DESCRIPTION: Read the first line of the input file, which will contain     */
/* the field names, to determine the file format, standard, or premium.       */
/******************************************************************************/
   filename in_wl "&wchk_file";

   %let fcf_wchk_file_format=STANDARD;   * Default value to make sure variable is set ;
   data _null_;

	  infile in_wl encoding="latin9"  /* delimiter='09'x dsd missover */ obs=1 ; *lrecl=32767;
      input field_names $200.;
	  if index(field_names,'LOW QUALITY ALIASES') > 0 then do;
	  	put "NOTE: FCF: Processing input as World-Check PREMIUM file format.";
		call symput('fcf_wchk_file_format', 'PREMIUM');
  	   end;
  	   else do;
	  	put "NOTE: FCF: Processing input as World-Check STANDARD file format.";
		call symput('fcf_wchk_file_format', 'STANDARD');
  	   end;
   run;

/******************************************************************************/
/* BEGIN: STG_WTCH.wl_wchk_extract_01                                         */
/*                                                                            */
/* DESCRIPTION: Evaluate the actual maximum observed length of those fields   */
/* which the World-Check file layout description does not provide specific    */
/* lengths for.                                                               */
/*                                                                            */
/* NOTE: For PREMIUM file format, only need the length of the                 */
/*       low_quality_aliases.  The update_category has a fixed length.        */
/******************************************************************************/
   filename in_wl "&wchk_file";

   /* Obtain maximum field length values for each input field. */
   data STG_WTCH.wl_wchk_extract_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_extract_01, output_ds=Y)
                                    keep=
      aliases_L

     %if &fcf_wchk_file_format eq PREMIUM %then %do;
      low_quality_aliases_L
      dobs_L
      id_numbers_L
      citizenship_L
     %end;

      passports_L
      locations_L
      countries_L
      companies_L
      linked_to_L
      further_information_L
      keywords_L
      external_sources_L
      editor_L
   );

      infile in_wl delimiter='09'x dsd missover lrecl=100000 firstobs=2 encoding="latin9";

      attrib
         uid                  informat=$1.
         last_name            informat=$1.
         first_name           informat=$1.
         aliases              informat=$&textsize..

        %if &fcf_wchk_file_format eq PREMIUM %then %do;
         low_quality_aliases  informat=$&textsize..
        %end;

         alternative_spelling informat=$1.
         category             informat=$1.
         title                informat=$1.
         sub_category         informat=$1.
         position             informat=$1.
         age                  informat=$1.
         dob                  informat=$1.

        %if &fcf_wchk_file_format eq PREMIUM %then %do;
         dobs                 informat=$&textsize..
        %end;

         place_of_birth       informat=$1.
         deceased             informat=$1.
         passports            informat=$&textsize..
         ssn                  informat=$1.

        %if &fcf_wchk_file_format eq PREMIUM %then %do;
         id_numbers           informat=$&textsize..
        %end;

         locations            informat=$&textsize..
         countries            informat=$&textsize..

        %if &fcf_wchk_file_format eq PREMIUM %then %do;
         citizenship          informat=$&textsize..
        %end;

         companies            informat=$&textsize..
         e_i                  informat=$1.
         linked_to            informat=$&textsize..
         further_information  informat=$&textsize..
         keywords             informat=$&textsize..
         external_sources     informat=$&textsize..

        %if &fcf_wchk_file_format eq PREMIUM %then %do;
         update_category      informat=$1.
        %end;

         entered              informat=$1.
         updated              informat=$1.
         editor               informat=$&textsize..
         age_date             informat=$1.
      ;

      input
         uid
         last_name                 $
         first_name                $
         aliases                   $

        %if &fcf_wchk_file_format eq PREMIUM %then %do;
         low_quality_aliases       $
        %end;

         alternative_spelling      $
         category                  $
         title                     $
         sub_category              $
         position                  $
         age
         dob                       $

        %if &fcf_wchk_file_format eq PREMIUM %then %do;
         dobs                      $ 
        %end;

         place_of_birth            $
         deceased                  $
         passports                 $
         ssn                       $

        %if &fcf_wchk_file_format eq PREMIUM %then %do;
         id_numbers                $ 
        %end;

         locations                 $
         countries                 $
         companies                 $

        %if &fcf_wchk_file_format eq PREMIUM %then %do;
         citizenship               $
        %end;

         e_i                       $
         linked_to                 $
         further_information       $
         keywords                  $
         external_sources          $

        %if &fcf_wchk_file_format eq PREMIUM %then %do;
         update_category           $
        %end;

         entered                   $
         updated                   $
         editor                    $
         age_date                  $
      ;

      aliases_L=length(aliases);
      
     %if &fcf_wchk_file_format eq PREMIUM %then %do;
      low_quality_aliases_L=length(low_quality_aliases);
      dobs_L=length(dobs);
     %end;

      passports_L=length(passports);
      
     %if &fcf_wchk_file_format eq PREMIUM %then %do;
      id_numbers_L=length(id_numbers);
     %end;

      locations_L=length(locations);
      countries_L=length(countries);
      
     %if &fcf_wchk_file_format eq PREMIUM %then %do;
      citizenship_L=length(citizenship);
     %end;

      companies_L=length(companies);
      linked_to_L=length(linked_to);
      further_information_L=length(further_information);
      keywords_L=length(keywords);
      external_sources_L=length(external_sources);
      editor_L=length(editor);

   run;
   %fcf_rcset(&syserr);
   %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_= ERROR: FCF: An error occurred reading the WorldCheck data file.;
      %put &_fcfmsg_;
      %let _fcfmsg_= ERROR: FCF: WorldCheck input file specified as: &wchk_file.;
      %put &_fcfmsg_;
      %goto MACRO_END;
   %end;

/* Obtain field lengths for multiple entry and text field formats */
proc sql noprint;
   select max(aliases_L),
          max(passports_L),
          max(locations_L),
          max(countries_L),
          max(companies_L),
          max(linked_to_L),
          max(further_information_L),
          max(keywords_L),
          max(external_sources_L),
          max(editor_L)

         %if &fcf_wchk_file_format eq PREMIUM %then %do;
          , max(low_quality_aliases_L)
          , max(dobs_L)
          , max(id_numbers_L)
          , max(citizenship_L)
         %end;

   into   :L1,
          :L2,
          :L3,
          :L4,
          :L5,
          :L6,
          :L7,
          :L8,
          :L9,
          :L10
         %if &fcf_wchk_file_format eq PREMIUM %then %do;
         ,:L11
         ,:L12
         ,:L13
         ,:L14
         %end;
   from STG_WTCH.wl_wchk_extract_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_extract_01));
quit;

/* Make sure all columns have positive lengths, default of 200 */
%macro fcf_check_length;
   %do i = 1 %to 11;
      %if not %symexist(L&i) %then %do;
         %let L&i=200;
      %end;
      %if &&L&i eq 0 %then
         %let L&i=200;

      /* DEBUG */
      %put L&i: &&L&i;
   %end;
%mend fcf_check_length;
%fcf_check_length;

/******************************************************************************/
/* END: STG_WTCH.wl_wchk_extract_01                                           */
/******************************************************************************/

/******************************************************************************/
/* BEGIN: STG_WTCH.wl_ofac_extract                                            */
/*                                                                            */
/* DESCRIPTION: Input World-Check data file - tab delimited                   */
/******************************************************************************/
data STG_WTCH.wl_wchk_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_extract, output_ds=Y));

   infile in_wl delimiter='09'x dsd missover encoding="latin9" lrecl=100000 firstobs=2 end=eof;

   attrib
      uid                  informat=best32.
                           format=best32.
                           label="UI"

      last_name            informat=$255.
                           format=$255.
                           label="Last Name"

      first_name           informat=$255.
                           format=$255.
                           label="First Name"

      aliases              informat=$&L1..
                           format=$&L1..
                           label="Aliases"

     %if &fcf_wchk_file_format eq PREMIUM %then %do;
      low_quality_aliases  informat=$&L11..
                           format=$&L11..
                           label="Low Quality Aliases"
     %end;

      alternative_spelling informat=$255.
                           format=$255.
                           label="Alternative Spelling"

      category             informat=$255.
                           format=$255.
                           label="Category"

      title                informat=$255.
                           format=$255.
                           label="Title"

      sub_category         informat=$32.
                           format=$32.
                           label="Sub-Category"

      position             informat=$255.
                           format=$255.
                           label="Position"

      age                  informat=best32.
                           format=best32.
                           label="Age"

      dob                  informat=$10.
                           format=$10.
                           label="DOB"

     %if &fcf_wchk_file_format eq PREMIUM %then %do;
      dobs                 informat=$&L12..
                           format=$&L12..
                           label="DOBS"
     %end;

      place_of_birth       informat=$255.
                           format=$255.
                           label="Place of Birth"

      deceased             informat=$10.
                           format=$10.
                           label="Deceased"

      passports            informat=$&L2..
                           format=$&L2..
                           label="Passports"

      ssn                  informat=$255.
                           format=$255.
                           label="SSN"

     %if &fcf_wchk_file_format eq PREMIUM %then %do;
      id_numbers           informat=$&L13..
                           format=$&L13..
                           label="ID Numbers"
     %end;

      locations            informat=$&L3..
                           format=$&L3..
                           label="Locations"

      countries            informat=$&L4..
                           format=$&L4..
                           label="Countries"

     %if &fcf_wchk_file_format eq PREMIUM %then %do;
      citizenshp           informat=$&L14..
                           format=$&L14..
                           label="ID Numbers"
     %end;

      companies            informat=$&L5..
                           format=$&L5..
                           label="Companies"

      e_i                  informat=$1.
                           format=$1.
                           label="E/I"

      linked_to            informat=$&L6..
                           format=$&L6..
                           label="Linked To"

      further_information  informat=$&L7..
                           format=$&L7..
                           label="Further Information"

      keywords             informat=$&L8..
                           format=$&L8..
                           label="Keywords"

      external_sources     informat=$&L9..
                           format=$&L9..
                           label="External Sources"

     %if &fcf_wchk_file_format eq PREMIUM %then %do;
      update_category      informat=$2.
                           format=$2.
                           label="Update Category"
     %end;

      entered              informat=$10.
                           format=$10.
                           label="Entered"

      updated              informat=$10.
                           format=$10.
                           label="Updated"

      editor               informat=$&L10..
                           format=$&L10..
                           label="Editor"

      age_date             informat=$10.
                           format=$10.
                           label="Age Date (as of Date)"
   ;

   input
      uid
      last_name                 $
      first_name                $
      aliases                   $
     %if &fcf_wchk_file_format eq PREMIUM %then %do;
      low_quality_aliases       $
     %end;
      alternative_spelling      $
      category                  $
      title                     $
      sub_category              $
      position                  $
      age
      dob                       $
     %if &fcf_wchk_file_format eq PREMIUM %then %do;
      dobs                      $
     %end;
      place_of_birth            $
      deceased                  $
      passports                 $
      ssn                       $
     %if &fcf_wchk_file_format eq PREMIUM %then %do;
      id_numbers                $
     %end;
      locations                 $
      countries                 $
     %if &fcf_wchk_file_format eq PREMIUM %then %do;
      citizenship               $
     %end;
      companies                 $
      e_i                       $
      linked_to                 $
      further_information       $
      keywords                  $
      external_sources          $
     %if &fcf_wchk_file_format eq PREMIUM %then %do;
      update_category           $
     %end;
      entered                   $
      updated                   $
      editor                    $
      age_date                  $
   ;

   if upcase("&allow_invalid") eq "N" then
      if _error_ ne 0 then do;
         call symputx('trans_rc', 999999);
         stop;
      end;

   if eof then
      call symputx('num_recs', _N_ );

run;
/******************************************************************************/
/* END: STG_WTCH.wl_ofac_extract                                              */
/******************************************************************************/


  %MACRO_END:
   
   %if &trans_rc eq 3 or &trans_rc ge 5 %then
      %fcf_execute_macro(fcf_error);
   %else %do;
      %fcf_execute_macro(post&_fcfmodule_);
      %fcf_execute_macro(fcf_success);
   %end;

%mend fcf_wl_wchk_extract;
