/*==============================================================================
| NAME:    fcf_wl_wchk_transport
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================

WATCH LIST PROVIDER - World-Check
WATCH LIST NAME     - Data File
WATCH LIST CODE     - WCHK
WEB LINK            - https://www.world-check.com/login/

MODULE TYPE         - TRANSFORM
MODULE PURPOSE      - Transform data in prepartion for data load.

MODULE NOTES
------------
None

==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2017 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_wl_wchk_transport;

  /*------------
   * Set module
   *------------*/
  %local _fcfmodule_;
  %let _fcfmodule_=fcf_WL_WCHK_TRANSPORT;

  /*---------------------
   * Call pre macro stub
   *---------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*------------------------------------------
   * Set error code to 0 and message to blank
   *------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;
data 
   stg_wtch.wl_wchk_transport_01
  (%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_transport_01, output_ds=Y)
   keep=
      transport_watch_list_number
      watch_list_name
      type_desc
      entity_name
     entity_model_type
     entity_owner_operator
      create_date
      update_date
      exclude_ind
   ) 

    stg_wtch.wl_wchk_transport_02
  (%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_transport_02, output_ds=Y)
   keep=
      transport_watch_list_number
      identification_id
      identification_type_desc
   ) 

   stg_wtch.wl_wchk_transport_03(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_transport_03, output_ds=Y)
                                 keep=
      transport_watch_list_number
      entity_flag
   )

   stg_wtch.wl_wchk_transport_04(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_transport_04, output_ds=Y)
                                 keep=
      transport_watch_list_number
      address
      city_name
      state_name
      country_name
      country_code
   )

   stg_wtch.wl_wchk_transport_05(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_transport_05, output_ds=Y)
                                 keep=
      transport_watch_list_number
      programs
   )

/*   stg_wtch.wl_wchk_transport_06(keep=*/
/*      transport_watch_list_number*/
/*    entity_owner_operator*/
/*   )*/

   stg_err.wl_wchk_trans_errors_01(%fcf_get_ds_opts(lib_name=stg_err, ds_name=wl_wchk_trans_errors_01, output_ds=Y)
                                   keep=
      transport_watch_list_number
      watch_list_name
      error_file
      error_record_number
      error_field
      error_value
      error_message
      error_datetime
   );

  
   attrib
   /* ERROR FIELDS */
      error_file          length=$200
                          informat=$200.
                          format=$200.
                          label='Error File'

      error_record_number length=8
                          informat=best32.
                          format=best32.
                          label='Error Record Number'

      error_field         length=$32
                          informat=$32.
                          format=$32.
                          label='Error Field'

      error_value         length=$1000
                          informat=$1000.
                          format=$1000.
                          label='Error Value'

      error_message       length=$200
                          informat=$200.
                          format=$200.
                          label='Error Message'

      error_datetime      length=8
                          informat=nldatm.
                          format=nldatm.
                          label='Error Datetime'

      /* TEMP FIELDS */
      location_text                  length=$32767
      aliases_text                   length=$32767
      further_information            length=$32767
      entity_flag_text               length=$32767
      orig_programs                  length= $1000 
      current_program                length=   $10 
      special_programs               length= $1000 
   ;

   /* FSC_TRANSPORT_WATCH_LIST_DIM */
   /* Sets variable attribs to match variables in DBMS */
   if 1 eq 0 then
      set seg_kc.FSC_TRANSPORT_WATCH_LIST_DIM;

   set stg_wtch.wl_wchk_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_extract)
                                where = (upcase(category) contains "VESSEL")
      keep=
         uid
         last_name
         aliases
         alternative_spelling
         category
         locations
         countries
         further_information
         keywords
         entered
         updated
   ) end=eof;

  
   /* Store the Transport Watch List Names in wl_wchk_transport_01 */
   if not missing(last_name) then do;
      transport_watch_list_number=kstrip(put(uid,best32.));
      watch_list_name='WCHK';
      entity_name=last_name;
      type_desc='VESSEL';
      create_date=dhms(input(entered, yymmdd10.),0,0,0); 
      update_date=dhms(input(updated, yymmdd10.),0,0,0);
      exclude_ind='N';
      output stg_wtch.wl_wchk_transport_01;
      if alternative_spelling ne '' then do;
         if aliases ne '' then aliases=kstrip(aliases)||';'||kstrip(alternative_spelling);
         else aliases=alternative_spelling;
      end;
      if kcompress(aliases,',;') ne '' then do;
         num_aliases=countc(aliases,';') + 1;
         do i=1 to num_aliases;
            aliases_text=kscan(aliases,i,';');
            entity_name=upcase(compbl(aliases_text));
            output stg_wtch.wl_wchk_transport_01;
         end;
       end;
   end;

   /* Parse the further_information field for      */
   /*    IDs (IMO Registration) and Flag           */
   /* Store the Vessel IDs in wl_wchk_transport_02 */
   /* and the Vessel Flags in wl_wchk_transport_03 */
    if not missing(further_information) then do;
      transport_watch_list_number=kstrip(put(uid,best32.));
      identification_type_desc=further_information;
      if kcompress(further_information,'.;') ne '' then do;
         num_info=countc(further_information,';') + 1;
         do i=1 to num_info;
            further_information_text=kscan(further_information,i,';');
            further_information_text=upcase(compbl(further_information_text));
            further_information_text=tranwrd(further_information_text,'A.K.A.','AKA');
            further_information_text=tranwrd(further_information_text,'F.K.A.','FKA');
            further_information_text=tranwrd(further_information_text,'N.K.A.','NKA');
            num_detailed_info=countc(further_information_text,'.') + 1;
            do j=1 to num_detailed_info;
               identification_type_desc=kscan(further_information_text,j,'.');
               if kindex(identification_type_desc,'[IMO REGISTRATION]') then do;
                  identification_id=kstrip(tranwrd(identification_type_desc,'[IMO REGISTRATION]',''));
                  identification_type_desc='IMO REGISTRATION';
                  output stg_wtch.wl_wchk_transport_02;
               end;
               else if kindex(identification_type_desc,'FLAG')
                  and not kindex(identification_type_desc,'OFAC CALLS') then do;
                   entity_flag_text=identification_type_desc;
                   entity_flag_text=kstrip(tranwrd(entity_flag_text,'FORMER FLAGS:',''));
                   entity_flag_text=kstrip(tranwrd(entity_flag_text,'FORMER FLAG:',''));
                   entity_flag_text=kstrip(tranwrd(entity_flag_text,'FLAGS:',''));
                   entity_flag_text=kstrip(tranwrd(entity_flag_text,'FLAG:',''));
                   num_flags=countc(entity_flag_text,',') + 1;
                   do k = 1 to num_flags;
                      entity_flag=kstrip(kscan(entity_flag_text,k,','));
                      output stg_wtch.wl_wchk_transport_03;
                   end;
                end;
            end;
         end;
       end;
   end;

   /* Store the address information in wl_wchk_transport_04 */
   address='';
   city_name='';
   state_name='';
   country_name=upcase(kstrip(compbl(countries)));
   country_code = put(country_name, $country_code.);

   if kcompress(locations,'~,;') eq '' then output STG_WTCH.wl_wchk_transport_04;
   else do;
   num_locations=countc(locations,';') + 1;
   do j=1 to num_locations;
      location_text=kscan(locations,j,';');
      /* location_text is not blank - proceed */
      if kcompress(location_text,'~,') ne '' then do;
         /* ERROR: entry does not contain exactly 2 '~' delimiters */
         if countc(location_text,'~') ne 2 then do;

            error_file="&wchk_file";
            error_record_number=_N_;
            error_field='LOCATIONS';
            error_value=kstrip(location_text);
            error_message="WARNING: Incorrect field format. Field requires 2 '~' delimiters.";
            error_datetime=datetime();

            putlog "WARNING: FCF: Incorrect field format Field requires 2 '~' delimiters. "
            transport_watch_list_number= locations=;
       
            error_flag = 1;

            output STG_ERR.wl_wchk_trans_errors_01;
         end;
         else do;
            /* location_text format = ~ location_city, state ~ country */
            /* no Freetext (address) at beginning */
            if kindex(kstrip(location_text),'~') eq 1 then do;
               /* ERROR: entry does not contain exactly 1 ',' delimiter */
               if countc(kscan(location_text,1,'~'),',') ne 1 then do;

                  error_file="&wchk_file";
                  error_record_number=_N_;
                  error_field='LOCATIONS';
                  error_value=kstrip(location_text);
                  error_message="WARNING: Incorrect field format. Field requires 1 ',' delimiter.";
                  error_datetime=datetime();

                  putlog "WARNING: FCF: Incorrect field format. Field requires 1 ',' delimiter. "
                  transport_watch_list_number= locations=;
       
                  error_flag = 1;

                  output STG_ERR.wl_wchk_trans_errors_01;
               end;
               else do;
                  /* set location_address value=blank due to missing freetext */
                  address="";
                  /* city_name */
                  city_name=upcase(compbl(kscan(kscan(location_text,1,'~'),1,',')));
                  /* state_name */
                  state_name=upcase(compbl(kscan(kscan(location_text,1,'~'),2,',')));
               end;
            end; /* end locations format = ~location_city,state,country */

            /* location_text format = freetext~location_city,state~country */
            else if kindex(kstrip(location_text),'~') ne 1 then do;
               /* ERROR: entry does not contain exactly 1 ',' delimiter */
               if countc(kscan(location_text,2,'~'),',') ne 1 then do;

                  error_file="&wchk_file";
                  error_record_number=_N_;
                  error_field='LOCATIONS';
                  error_value=kstrip(location_text);
                  error_message="WARNING: Incorrect field format. Field requires 1 ',' delimiter.";
                  error_datetime=datetime();

                  putlog "WARNING: FCF: Incorrect field format. Field requires 1 ',' delimiter. "
                  transport_watch_list_number= location_text=;
       
                  error_flag = 1;

                  output STG_ERR.wl_wchk_trans_errors_01;
               end;
               else do;
                  /* address */
                  address=upcase(compbl(kscan(location_text,1,'~')));
                  /* city_name */
                  city_name=upcase(compbl(kscan(kscan(location_text,2,'~'),1,',')));
                  /* state_name */
                  state_name=upcase(compbl(kscan(kscan(location_text,2,'~'),2,',')));
               end;
            end; /* end locations format=freetext~location_city,state,country */

            if kindex(kreverse(kstrip(location_text)),'~') ne 1 then do;
                country_name=upcase(kstrip(compbl(kscan(location_text,-1,'~'))));
                country_code = put(country_name, $country_code.);
            end;

            if not missing(error_field) then
               output STG_WTCH.wl_wchk_transport_04
                      STG_ERR.wl_wchk_trans_errors_01;
            else do;
               output STG_WTCH.wl_wchk_transport_04;
               if j=1 and country_name ne upcase(kstrip(compbl(countries))) then do;
                  country_name=upcase(kstrip(compbl(countries)));
                  output STG_WTCH.wl_wchk_transport_04;
               end;
            end;

         end; /* end no format issues */
      end; /* end location_text is not blank */
         
   end; /* end do loop */
end; /* end location is not blank */


/****************************************************************************/
  /* DESCRIPTION:                                                             */
  /* Process sanctions_list_reference.                                        */
  /*                                                                          */
  /* NOTES:                                                                   */
  /* Each entity can have multiple program values.                            */
  /* Some entities are in so many lists that concatenating the values of the  */
  /* lists exceed the length of programs in the database, the following rules */
  /* are applied in building the programs list:                               */
  /* 1)  The programs field is checked agains the most important              */
  /*     lists based on current customer base.                                */
  /*          Text Checked             Special List Value                     */
  /*          ------------             ------------------                     */
  /*          OFAC                     OFAC                                   */
  /*          DFAT                     DFAT                                   */
  /*          begins with EC           EUFS                                   */
  /*          HM Treasury              HMT                                    */
  /*          New Zealand Police       NCBI                                   */
  /*          UN Security Council      UNSC                                   */
  /* 2) If the entity is one or more special lists, the Special List Values   */
  /*    are included in the programs field.   If the entity is also on        */
  /*    other lists, the count of other lists is included in the programs     */
  /* 3) If the entity is not on any special list, the programs field contains */
  /*    a concatentated list of all the reference lists providing the number  */
  /*    of distinct lists is <= 5 and the length of the concatenated list     */
  /*    is less than 250.                                                     */
  /* 4) If the number of lists constraint or the length constraint is violated*/
  /*    only a count is provided.                                             */
  /****************************************************************************/

    orig_programs=keywords;
    
    /* Check Special Programs */
    special_programs='';
    special_prog_count=0;

    if kindex(orig_programs,"OFAC") > 0 then do;
       special_prog_count+1;
       special_programs="OFAC";
    end;
    if kindex(orig_programs,"DFAT") > 0 then do;
       special_prog_count+1;
       special_programs=kstrip(special_programs)||";DFAT ";
    end;
    if ksubstr(kleft(orig_programs), 1, 2)="EU" then do;
       special_prog_count+1;
       special_programs=kstrip(special_programs)||";EUFS ";
    end;
    if kindex(orig_programs,"UKHMT") > 0 then do;
       special_prog_count+1;
       special_programs=kstrip(special_programs)||";UKHMT ";
    end;
    if kindex(orig_programs,"NZ-MFAT") > 0 then do;
       special_prog_count+1;
       special_programs=kstrip(special_programs)||";NCBI ";
    end;
    else if substr(orig_programs,1,2)="UN" then do;
       special_prog_count+1;
       special_programs=kstrip(special_programs)||";UNSC ";
    end;
    else if kindex(orig_programs,"OSFI") > 0 then do;
       special_prog_count+1;
       special_programs=kstrip(special_programs)||";OSFI ";
    end;

    num_programs=countc(orig_programs,'~') + 1;
    if num_programs ge 1 then do;
       programs='';
       do i=1 to num_programs;
          current_program=kscan(orig_programs,i,'~');
          if missing(programs) then programs=compbl(kstrip(current_program));
              else programs=kstrip(programs) || ';' || compbl(kstrip(current_program));
        end; /* do loop */
      end;

      if special_prog_count then do;
           if num_programs > 5  then do;
              programs=special_programs;
              if (num_programs - special_prog_count) > 0 then 
                  programs=kstrip(special_programs)||";"||kstrip(put(num_programs - special_prog_count,best32.))||" additional lists";
           end;
      end;
      else if num_programs > 5 or length(programs) > 250 then programs="Entity on "||kstrip(put(num_programs, best32.))||" sanctions lists";
      if not missing(keywords) then output stg_wtch.wl_wchk_transport_05;
run;

proc sql noprint;

   create table stg_wtch.wl_wchk_transport_06 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_transport_06, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.identification_id,
             b.identification_type_desc
        from stg_wtch.wl_wchk_transport_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_transport_01)) as a full join
             stg_wtch.wl_wchk_transport_02(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_transport_02)) as b
             on a.transport_watch_list_number=b.transport_watch_list_number;

   
   create table stg_wtch.wl_wchk_transport_07 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_transport_07, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.entity_flag
        from stg_wtch.wl_wchk_transport_06(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_transport_06)) as a full join
             stg_wtch.wl_wchk_transport_03(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_transport_03)) as b
             on a.transport_watch_list_number=b.transport_watch_list_number;

   create table stg_wtch.wl_wchk_transport_08 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_transport_08, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.address,
             b.city_name, 
             b.state_name,
             b.country_name,
             b.country_code
        from stg_wtch.wl_wchk_transport_07(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_transport_07)) as a full join
             stg_wtch.wl_wchk_transport_04(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_transport_04)) as b
             on a.transport_watch_list_number=b.transport_watch_list_number;

     create table stg_wtch.wl_wchk_transport %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_transport, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.programs
        from stg_wtch.wl_wchk_transport_08(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_transport_08)) as a full join
             stg_wtch.wl_wchk_transport_05(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_transport_05)) as b
             on a.transport_watch_list_number=b.transport_watch_list_number;
quit;
%mend fcf_wl_wchk_transport;
