/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_efile_assign_efile_key.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Driver program for generating finCEN e-files.   
|          
+-----------------------------------------------------------------------------------------+
| USAGE:   form_config_key = form key
|          form_type_code  = form type (e.g. SAR, CTR)
|          efile_key       = e-file key for regenerating existing e-file  
|                            if this parameter is blank, all reports with READY_CODE='R' 
|                            will be included in the e-file.
|          testYN          = Y to create e-file(s) without updating database data
|                            N to create e-file(s) with database update 
+------------------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

 %macro rc_efile_assign_efile_key(report_list=,
                              form_config_key=,
                              form_type_code=,
                              efile_key=,
                              out_dsn=seq_report
                         );

    %let trans_rc=0;
    %let _fcfmsg_=;

    /*-------------------------------------------------------------------------
     * Get e-file information from configuration files and 
     * derive the new e-file keys based on the max of the existing e-file keys
     *-------------------------------------------------------------------------*/
     
    %let efile_max_report_count=0;
    %let last_efile_key=0;
   
    %if %nrbquote(&efile_key) ne %nrbquote() %then
    %do;
        %let efile_max_report_count=10000;
        %let last_efile_key=%eval(&efile_key-1);
    %end;
    %else 
    %do;

        %let last_efile_key=0;
        %let efile_max_report_count=0;

        proc sql noprint;
             select efile_max_report_count into : efile_max_report_count
             from seg_kc.fsk_rc_form_config
             where form_config_key=&form_config_key;
              %fcf_rcset(&sqlrc);
              %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
                  %goto MACRO_END;
              %end;  

             select max(efile_key) into :last_efile_key
             from seg_kc.fsk_rc_efile;
             %fcf_rcset(&sqlrc);
             %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
                  %goto MACRO_END;
             %end;  
        quit;

    %end;
    quit;

    %if &efile_max_report_count < 1 %then %let efile_max_report_count=100; 
    %if &last_efile_key < 1 %then %let next_efile_key=1;
    %else %let next_efile_key=%eval(&last_efile_key + 1); 
        
     
   data &out_dsn(%fcf_get_ds_opts(ds_name=&out_dsn, output_ds=Y));
         if 0 then set seg_kc.fsk_rc_efile_report;
         set seg_kc.fsk_rc_report (keep=report_key) 
         ;
         where report_key in (&report_list);
         retain report_seq_number 0;
         retain efile_key &next_efile_key ;
         report_seq_number+1;
         if report_seq_number > &efile_max_report_count then
         do;
            efile_key+1;
            report_seq_number=1;
        end;
    run;
         

%MACRO_END:
   
  
  
   %if &trans_rc eq 3 or &trans_rc ge 5 %then
      %fcf_execute_macro(fcf_error);
   %else %do;
      %fcf_execute_macro(fcf_success);
   %end;

 
%mend;

 
