/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_efile_fincen_generate.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    This macro generates the .dat efile(s)   
|          
+-----------------------------------------------------------------------------------------+
| USAGE:   form_config_key = form key
|          form_type_code  = form type (e.g. SAR, CTR)
|          efile_key       = efile key if it is a regeneration of existing efile
|          efile_outdsn    = output table with efile info  
|          efile_report_outdsn = output table with report keys of each efile 
+------------------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro rc_efile_fincen_generate(form_config_key=,
                                form_type_code=,
                                efile_key=,
                                efile_outdsn=rc_efile,
                                efile_report_outdsn=rc_efile_report
                               );
 
    %let trans_rc=0;
    %let _fcfmsg_=;

    %let efile_file_prefix=;
    %let record_id_cnt=0;

    proc sql noprint; 
     
         select trim(efile_file_prefix)
               into :efile_file_prefix
             from seg_kc.fsk_rc_form_config
             where form_config_key=&form_config_key
            ;
         %let efile_file_prefix=%trim(&efile_file_prefix);
          %if %nrbquote(&efile_file_prefix)=%nrbquote() %then %do;
             %let _fcfmsg_=Note: RC: efile prefix is not defined for &form_type_code form in SEG_KC.FSK_RC_FORM_CONFIG.;
             %fcf_put_error;
             %fcf_rcset(3);
             %goto MACRO_END;
          %end;
          
          /* all record lengths are supposed to be the same */ 
           select max(record_length) into :record_length
           from rc_cfg.form_efile_record_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config))
               where form_config_key=&form_config_key
          ;
        
       
         select distinct  form_efile_record_id into :record_id_1 -  
         from rc_cfg.form_efile_record_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config))
         where form_config_key=&form_config_key
          ;
           %let record_id_cnt=&sqlobs;
         quit;

           %if &record_id_cnt=0 %then %do;
                %let _fcfmsg_=Note: RC: No &form_type_code record configuration found.;
                %fcf_put_error;
                %fcf_rcset(3);
                %goto MACRO_END;
            %end;
            %let last_version_number=0;
            %if %nrbquote(&efile_key) ne %nrbquote() %then %do;
                
                proc sql noprint;
                     select put(version_number,best.) into :last_version_number
                     from seg_kc.fsk_rc_efile
                     where efile_key=&efile_key
                ; 
                quit;
                %let last_version_number=%trim(&last_version_number);
            %end;     

           proc sql noprint;
                create table filed_date as 
                select distinct efile_key, filed_date 
                from &form_type_code._3A;

                 
           data &efile_outdsn(%fcf_get_ds_opts(ds_name=&efile_outdsn, output_ds=Y));
             if 0 then set seg_kc.fsk_rc_efile;
                merge &form_type_code._1A (keep=efile_key coverage_beginning_date coverage_ending_date)
                      filed_date
                      &form_type_code._9Z (keep=efile_key report_count 
                       %if &form_type_code=SAR %then
                       %do;
                                                 attachment_count
                       %end; 
                                           )
                     end=eof;                     
                by efile_key;  
             form_config_key=&form_config_key;
             efile_id=strip("&form_type_code")||'-'||strip(put(efile_key,best.));
             output_name=strip("&form_type_code")||'_'||strip(put(efile_key,best.))||'.dat';
             create_date=datetime(); 
             lstupdate_date=create_date;
             output_path_name="&efile_file_prefix";  
             output_report_count=report_count;
             output_create_date=filed_date*3600*24;
             %if &form_type_code=SAR %then
             %do;
             if attachment_count > 0 then 
                output_zip_name=strip("&form_type_code")||'_'||strip(put(efile_key,best.))||'.zip';
             else output_zip_name='';
             %end;
             coverage_begin_date=coverage_beginning_date*3600*24;
             coverage_end_date=coverage_ending_date*3600*24; 
             efile_status_code='G'; 
             %if %nrbquote(&efile_key) = %nrbquote() %then
             %do;
                 efile_desc='Batch Generated.';
             %end; 
             %else
             %do;
                 efile_desc='Batch Re-generated.';
             %end;
             
             call symput('efile_key_'||strip(put(_n_,best.)),strip(put(efile_key,best.)));
             if eof then call symput('efile_count',strip(put(_n_,best.)));
             create_user_id="&sysuserid";
             logical_delete_ind='N';
             version_number=&last_version_number+1;
             drop coverage_beginning_date coverage_ending_date report_count filed_date 
             %if &form_type_code=SAR %then
             %do;
                  attachment_count
             %end;
             ;     
          run;  
                
          %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
               %goto MACRO_END;
           %end; 

         %if not %sysfunc(fileexist(&rc_template_path&slash&form_type_code._macro_wrt_efile.sas))%then %do; 
                     %let _fcfmsg_=Note: RC: &rc_template_path&slash&form_type_code._macro_wrt_efile.sas not found.;
                     %fcf_put_error;
                     %fcf_rcset(3);
                     %goto MACRO_END;
         %end;
        %inc rc_tmplt(%trim(&form_type_code)_macro_wrt_efile.sas);    
        options missing='';

        %do iefile=1 %to &efile_count;

          %let efile_key=%trim(&&&efile_key_&iefile);
         filename efilenm "&rc_efile_path&slash.%trim(&efile_file_prefix)&slash.&form_type_code._&efile_key..dat";
       
         data _null_;
             retain line_count 0;
             set
         %do irecord =1 %to &record_id_cnt;
             %if %sysfunc(exist(&form_type_code._&&&record_id_&irecord)) %then
             %do;
             &form_type_code._&&&record_id_&irecord
             %end;
          %end;
             end=eof
          ;
              by report_seq_number entity_seq_number record_type row_seq_number;
              where efile_key=%trim(&efile_key);
              file efilenm lrecl=&record_length pad termstr=CRLF;
           %do irecord =1 %to &record_id_cnt;
             if record_type = "&&&record_id_&irecord" then
             do;
             %put_&form_type_code._&&&record_id_&irecord;
             line_count+1;
             output;
             end;
          %end;
              if eof then call symput('LINE_COUNT',strip(put(line_count,best.)));
           run;

           data _null_;
                fid=fopen('efilenm');
                call symput('output_file_size',strip(finfo(fid,'File Size (bytes)')));
                rc=fclose (fid);
           run; 
           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
               %goto MACRO_END;
           %end;
 
           
           proc sql noprint;
                
                update &efile_outdsn(%fcf_get_ds_opts(ds_name=&efile_outdsn))
                      set output_file_size=%trim(&output_file_size)
                          , output_line_count=%trim(&line_count)
                          
                      where efile_key=&efile_key
                ;
            quit;
            %fcf_rcset(&sqlrc);
            %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
               %goto MACRO_END;
           %end; 

            data &efile_report_outdsn(%fcf_get_ds_opts(ds_name=&efile_report_outdsn, output_ds=Y));
                 set seq_report (keep=efile_key report_key report_seq_number);
                 file_status_code='G';
            run;
            %fcf_rcset(&syserr);
            %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
               %goto MACRO_END;
           %end; 
        %end;



%MACRO_END:
  

    %if &trans_rc eq 3 or &trans_rc ge 5 %then 
       %fcf_execute_macro(fcf_error);
    %else 
       %fcf_execute_macro(fcf_success);
    
  


 %mend;
 
 
