/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_efile_fincen_generate.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    This macro generates the .xml efile(s)   
|          
+-----------------------------------------------------------------------------------------+
| USAGE:   form_config_key = form key
|          form_type_code  = form type (e.g. SARX, CTRX)
|          efile_key       = efile key if it is a regeneration of existing efile
|          efile_outdsn    = output table with efile info  
|          efile_report_outdsn = output table with report keys of each efile 
+------------------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2018 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro rc_efile_fincen_generate_x(form_config_key=,
                                form_type_code=,
                                efile_key=,                               
                                efile_outdsn=rc_efile,
                                efile_report_outdsn=rc_efile_report
                               );
 
    %let trans_rc=0;
    %let _fcfmsg_=;

    %let efile_file_prefix=;
    %let record_id_cnt=0;

    proc sql noprint; 
     
         select trim(efile_file_prefix)
               into :efile_file_prefix
             from seg_kc.fsk_rc_form_config
             where form_config_key=&form_config_key
            ;
             %fcf_rcset(&sqlrc);
             %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
                 %let _fcfmsg_=ERROR: RC: Failed to extract efile file prefix from fsk_rc_form_config;
                 %fcf_put_error;
                 %goto MACRO_END;
             %end;

          /* check existence of efile directory */
          %let efile_file_prefix=%trim(&efile_file_prefix);
          %if %nrbquote(&efile_file_prefix)=%nrbquote() %then %do;
             %let _fcfmsg_=ERROR: RC: efile prefix is not defined for &form_type_code form in SEG_KC.FSK_RC_FORM_CONFIG.;
             %fcf_put_error;
             %fcf_rcset(3);
             %goto MACRO_END;
          %end;

          proc sql;
               create table efile_summary as
               select efile_key, count(distinct report_key) as output_report_count
               from seq_report
               group by efile_key
               order by efile_key
               ;
          quit; 
             %fcf_rcset(&sqlrc);
             %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
                 %let _fcfmsg_=ERROR: RC: Failed to create efile_summary;
                 %fcf_put_error;
                 %goto MACRO_END;
             %end;
          
          data &efile_outdsn(%fcf_get_ds_opts(ds_name=&efile_outdsn, output_ds=Y));
                if 0 then set seg_kc.fsk_rc_efile;
          %if %str(&efile_key) ne %str() %then
          %do; 
                merge efile_summary 
                      seg_kc.fsk_rc_efile (where=(efile_key=&efile_key) 
                                           keep=efile_key create_date version_number create_user_id
                                           )
                      end=eof;
                by efile_key;  
           %end;
           %else
           %do;
                set efile_summary end=eof;
           %end; 
             form_config_key=&form_config_key;
             efile_id=strip("&form_type_code")||'-'||strip(put(efile_key,best.));
             output_name=strip("&form_type_code")||'_'||strip(put(efile_key,best.))||'.xml';
             output_create_date=today()*24*3600;
             lstupdate_date=datetime();
             output_path_name="&efile_file_prefix"; 
             
             /*
             %if &form_type_code=SARX %then
             %do;
             if attachment_count > 0 then 
                output_zip_name=strip("&form_type_code")||'_'||strip(put(efile_key,best.))||'.zip';
             else output_zip_name='';
             %end;
             */
             coverage_begin_date=.;
             coverage_end_date=.; 
             efile_status_code='G'; 
             logical_delete_ind='N';
                  
             %if %nrbquote(&efile_key) = %nrbquote() %then
             %do;
                 create_date= lstupdate_date; 
                 efile_desc='Batch Generated.';
                 version_number=1;
                 create_user_id="&sysuserid";
             %end; 
             %else
             %do;

                 efile_desc='Batch Re-generated.';
                 version_number=version_number+1;
             %end;
             
             call symput('efile_key_'||strip(put(_n_,best.)),strip(put(efile_key,best.)));
             call symput('output_name_'||strip(put(_n_,best.)),strip(output_name));
             if eof then call symput('efile_count',strip(put(_n_,best.)));
            
             
          run;  
                
          %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
               %let _fcfmsg_=ERROR: RC: failed to create &efile_outdsn;
               %fcf_put_error;
               %goto MACRO_END;
           %end; 

         %if not %sysfunc(fileexist(&rc_template_path&slash.rc_%lowcase(&form_type_code)_efile.xsl))%then %do; 
             %let _fcfmsg_=ERROR: RC: &rc_template_path&slash.rc_%lowcase(&form_type_code)_efile.xsl not found.;
             %fcf_put_error;
             %fcf_rcset(3);
             %goto MACRO_END;
         %end;
   
    /* include the macro for writing RC_CFG.FINCEN_* data */
    %inc rc_tmplt(%upcase(&form_type_code)_macro_wrt_xml.sas);
  
    filename xslt "&rc_template_path&slash.rc_%lowcase(&form_type_code)_efile.xsl";
  
    /* generate xml for each efile key */
    %do iefile=1 %to &efile_count;

         filename rawxml "%sysfunc(pathname(work))&slash.%lowcase(&form_type_code)Raw_&iefile..xml";

        /* transform report data into xml */
        %rc_efile_fincen_gen_rawxml(form_config_key=&form_config_key,
                                    form_type_code=&form_type_code,
                                    efile_key=&&efile_key_&iefile,
                                    in_dsn=rc_report_node_more_x,
                                    outfref=rawxml 
                                   );
      
        filename efilenm "&rc_efile_path&slash.%trim(&efile_file_prefix)&slash%upcase(&form_type_code)_&&efile_key_&iefile...xml";
           
        filename outxml "%sysfunc(pathname(work))&slash%lowcase(&form_type_code)Temp_&iefile..xml";
        
        /* convert report xml into e-file ready xml */
        proc xsl
           in=rawxml
           xsl=xslt
           out=outxml
           ;
        run;

       /*-----------------------------------------------
        * add unique sequence numbers to the xml
        *-----------------------------------------------*/

       %let line_cnt=0;
      
       %rc_efile_xml_seqnum(exclude_dsn=seq_report, 
                            exclude_var=report_key,
                            infname=outxml, 
                            outfname=efilenm, 
                            lineCntVar=line_cnt);
       
         %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
            %goto MACRO_END;
         %end;

         data _null_;
              fid=fopen('efilenm');
              call symput('output_file_size',strip(finfo(fid,'File Size (bytes)')));
              rc=fclose (fid);
         run;
 
         %fcf_rcset(&syserr);
         %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
             %let _fcfmsg_=ERROR: RC: failed to get e-file size;
             %fcf_put_error;
            %goto MACRO_END;
         %end;

        /* Determine the starting coverage begin date and end date */		 
	    %let coverage_begin_date=;
        %let coverage_end_date=;
		%if &form_type_code=CTRX %then
            %do;
            proc sql noprint;
               select min(input(substrn(node_value,1,10),yymmdd10.)) 
                  into :coverage_begin_date            
               from rc_report_node_more_x
                  where entity_level_code='REPORT'
                     and  node_name='transactionDate'			
               ;
               select max(input(substrn(node_value,1,10),yymmdd10.)) 
                  into :coverage_end_date
               from rc_report_node_more_x
                  where entity_level_code='REPORT'
                     and  node_name='transactionDate'			
               ;
	        quit;
			%end;
               
        proc sql noprint;
               
             update &efile_outdsn(%fcf_get_ds_opts(ds_name=&efile_outdsn))
             set output_file_size=%trim(&output_file_size)
                 , output_line_count=%trim(&line_cnt)
				 /* Add in the coverage begin and end dates if they exist */
                 %if %str(&coverage_begin_date) ne %str() %then
                     %do;
                     , coverage_begin_date=&coverage_begin_date*24*3600
                     %end;
                 %if %str(&coverage_end_date) ne %str() %then
                     %do;
                     , coverage_end_date=&coverage_end_date*24*3600
                     %end;				 
                 where efile_key=&&efile_key_&iefile
             ;
        quit;
        %fcf_rcset(&sqlrc);
        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: RC: failed to update &efile_outdsn;
             %fcf_put_error;
            %goto MACRO_END;
        %end; 

%end; /* end loop */

    
    data &efile_report_outdsn(%fcf_get_ds_opts(ds_name=&efile_report_outdsn, output_ds=Y));
          set seq_report (keep=efile_key report_key report_seq_number);
          file_status_code='G';
    run;
    %fcf_rcset(&syserr);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: RC: failed to create &efile_report_outdsn;
         %fcf_put_error;
        %goto MACRO_END;
     %end;

%MACRO_END:

    %if &trans_rc eq 3 or &trans_rc ge 5 %then 
       %fcf_execute_macro(fcf_error);
    %else 
       %fcf_execute_macro(fcf_success);
    

 %mend;
 
 
