/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_efile_fincen_sum_ctr.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    This macro generate the summary records (9<x>) specific to ctr.
 |          
+------------------------------------------------------------------------------+
| USAGE:   form_config_key = form key 
|          form_type_code  = form type code (defined in FSK_RC_FORM_CONFIG)
|
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/
 

%macro rc_efile_fincen_sum_ctr(form_config_key=,
                               form_type_code=
                               );

    /***************************************************************************/
    /* Count number of branches where activity occurred for each report  (9A)  */
    /***************************************************************************/
    %if %sysfunc(exist(&form_type_code._2B)) %then
    %do;
         proc sql;
              create table count_2B as
              select distinct efile_key, report_key, count(*) as BRANCH_COUNT
              from &form_type_code._2B
              group by efile_key, report_key
              order by efile_key, report_key;
         quit;
     %end;
     %else
     %do;
          data count_2B;
               set seq_report;
               branch_count=0;
          run;

     %end;

     
    %fcf_rcset(&syserr);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %goto MACRO_END;
    %end;            
     
    /*************************************************/
    /* Count number of subjects for each report (9A) */
    /*************************************************/

     
    proc freq data=&form_type_code._4A ;
     table efile_key*report_key /out=count_4A (drop=percent rename=(count=subject_count)) noprint;
    run;
     
    %fcf_rcset(&syserr);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %goto MACRO_END;
    %end;
       
      
        proc sql;
            create table count_4A as
            select distinct efile_key, report_key, count(*) as SUBJECT_COUNT
            from &form_type_code._4A
            group by efile_key, report_key
            order by efile_key, report_key; 

             
        quit;
     
    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %goto MACRO_END;
    %end;

    data &form_type_code._9A;
        if 0 then set rc_db.&form_type_code._9A (
                                                 %fcf_get_ds_opts(lib_name=rc_db, ds_name=&form_type_code._9A)
                                                 drop=report_count
                                                ); /* to be fixed later */
        merge &form_type_code._3A (keep=efile_key report_key entity_level_code report_seq_number)  
              count_2B (in=in_branch_cnt)
              count_4A (in=in_subject_cnt)
               
        ;
        by efile_key report_key;
        if not in_subject_cnt then subject_count=0;   
        if not in_branch_cnt then  branch_count=0;
         
        report_count=1;   
        entity_seq_number=99999;
        
        record_type='9A';    
         
    run;
    %fcf_rcset(&syserr);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %goto MACRO_END;
    %end;

    

    proc summary data=&form_type_code._9A nway missing;
              class efile_key ;            
              var report_count branch_count subject_count  ;
              output out=sum_9A (drop=_type_ _freq_) sum=;
    run;
    %fcf_rcset(&syserr);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %goto MACRO_END;
    %end;

    data &form_type_code._9B;
         if 0 then set rc_db.&form_type_code._9B(%fcf_get_ds_opts(lib_name=rc_db, ds_name=&form_type_code._9B));
         set sum_9A  ;
         report_seq_number=99999;
         entity_seq_number=99999;
         record_type='9B';          
    run;

    %fcf_rcset(&syserr);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %goto MACRO_END;
    %end;

    /* 9Z is almost same as 9B because there is only 1 filer. */
    data &form_type_code._9Z;
         if 0 then set rc_db.&form_type_code._9Z(%fcf_get_ds_opts(lib_name=rc_db, ds_name=&form_type_code._9Z));
         set sum_9A;
         report_seq_number=99999;
         entity_seq_number=99999;
         filer_count=1;          
         record_type='9Z';
    run;
    %fcf_rcset(&syserr);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %goto MACRO_END;
    %end;


%MACRO_END:
  

    %if &trans_rc eq 3 or &trans_rc ge 5 %then 
       %fcf_execute_macro(fcf_error);
    %else 
       %fcf_execute_macro(fcf_success);
    
  

%mend;

