/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_efile_gen_json_default.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    This macro generates the default json with null values by report entity.
|          The data is saved in fsk_rc_form_default.
|
+-----------------------------------------------------------------------------------------+
| USAGE:   form_config_key = form key
|          form_type_code  = form type (e.g. SAR, CTR)
 +------------------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/


%macro  rc_efile_gen_json_default(form_config_key=
                          , form_type_code=
               ) /  des='Macro to create default json ';


    proc sql noprint;
        create table rc_field_def as
        select a.form_config_key,
               a.form_efile_record_id,
               a.form_efile_field_seq_number,
               case
               when (index(a.source_field_name,'.') > 0) then scan(a.source_field_name,2,'.') 
               else a.source_field_name
               end as source_field_name length=64,
               a.source_field_type ,
               a.source_field_type_parm_list,
               a.source_field_default_value,
               a.source_field_mapped_flg,
               a.target_field_name,
                
               case
               when (index(a.source_field_name,'.') > 0) then upcase(scan(a.source_field_name,1,'.')) 
               else b.source_entity_level_code
               end as entity_level_code length=32,
                b.source_group_name 
        from rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config)) as a
        left join   rc_cfg.form_efile_record_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config)) as b
        on a.form_config_key=b.form_config_key
           and a.form_efile_record_seq_number=b.form_efile_record_seq_number
         where   a.form_config_key=&form_config_key
                 and source_table_name='RC_REPORT_NODE' and source_field_name ne ''
        order by entity_level_code, source_group_name,  form_efile_field_seq_number
       ;
    quit;
    
    /* create multiple columns for field with 'ARRYCAT' type */
    data rc_field_def_adj;
        set rc_field_def;
        retain row_no 0;
        row_no=1;
        length default_value $ 256;

       if substrn(strip(source_field_default_value),1,1)='[' then
       do;
          /* if the default value is in an array of multiple rows */
          do while (scan(source_field_default_value,row_no,',') > '' );
             if source_field_mapped_flg='1' then

              default_value='"format('||"'"||
                            strip(compress(scan(source_field_default_value,row_no,','),'[]'))||
                            "',"||
                            strip(source_field_name)||
                            ')"';
 
             else
             default_value=compress(scan(source_field_default_value,row_no,','),'[]');
             link wrt_rec;
             row_no+1;
           end;
       end;
       else
       do;
           if source_field_default_value ne '' then
              if source_field_mapped_flg='1' then
              default_value='"format('||"'"||
                            strip(source_field_default_value)||
                            "',"||
                            strip(source_field_name)||
                            ')"';
              else default_value=source_field_default_value;
           else default_value='""';
           link wrt_rec;
       end;
       return;

    wrt_rec:

         if source_field_type='ARRYCAT' then
         do;
             orig_source_field_name=source_field_name;
             do iascii=rank(strip(scan(source_field_type_parm_list,1,','))) to
                        rank(strip(scan(source_field_type_parm_list,2,','))) ;

                 source_field_name=strip(orig_source_field_name)||byte(iascii);
                  type='boolean';
                 output;
             end;
             if index(source_field_type_parm_list,'Z') then
             do;
                source_field_name=strip(orig_source_field_name)||'Z';
                type='boolean';
                output;
             end;
         end;
         else output;
     run;

     proc sort data=rc_field_def_adj ;
          by entity_level_code source_group_name row_no;
     run;

    data default_ui_json (keep=form_config_key entity_level_code default_ui_json);

       length default_ui_json $ 32767;
       length default_value $ 256;
       if 0 then set seg_kc.fsk_rc_form_default;
       set rc_field_def_adj;
       retain default_ui_json;
       by entity_level_code source_group_name row_no;
       if first.entity_level_code then link entity_header;
       if first.source_group_name then link group_header;
       if first.row_no then link row_header;

       if first.row_no then
          default_ui_json=strip(default_ui_json)||'  "'||strip(source_field_name)||'":'||strip(default_value);
        else
          default_ui_json=strip(default_ui_json)||', "'||strip(source_field_name)||'":'||strip(default_value);

       if last.row_no then link row_trailer;
       if last.source_group_name then link group_trailer;
       if last.entity_level_code then link entity_trailer;
       return;

    entity_header:
        default_ui_json='{';
    return;

    entity_trailer:
        default_ui_json=strip(default_ui_json)||'}';
    output;
    return;

    group_header:
    if source_group_name ne '' then
    do;
        default_ui_json=strip(default_ui_json)||', "'||strip(source_group_name)||'":[';
    end;
    return;

    group_trailer:
    if source_group_name ne '' then
    do;
        default_ui_json=strip(default_ui_json)||']';
    end;

    return;

    row_header:

    if source_group_name ne '' then
    do;
        if row_no=1 then
           default_ui_json=strip(default_ui_json)||'{"id":1,';
        else
           default_ui_json=strip(default_ui_json)||', {"id":'||strip(put(row_no,best.)||',');
    end;
    return;

    row_trailer:
    if source_group_name ne '' then
    do;
        default_ui_json=strip(default_ui_json)||'}';
    end;
    return;

    run;

%if &syserr <= 4 and &rc_debug=N %then
%do;
     proc sql noprint;
          delete from seg_kc.fsk_rc_form_default as def
          where form_config_key=&form_config_key
          ;

     quit;
     proc append base=seg_kc.fsk_rc_form_default data=default_ui_json
                     force;
      run;
%end;
%mend;
