/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_efile_gen_macro_wrt_efile.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Generate SAS program for reading or writing e-files   
|          
+------------------------------------------------------------------------------+
| USAGE:   form_config_key = form key
|          form_type_code = form type (e.g. SAR, CTR)
|          input_or_put = PUT for writing efiles, INPUT for reading E-files 
|                         INPUT mode is provided as a tool only. 
|                         It is not used for generating e-files. 
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2015 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro  rc_efile_gen_macro_wrt_efile(   
                            form_config_key=
                          , form_type_code=
                          , input_or_put=PUT                          
               ) /  des='Macro to create sas code for efile formatting';         

       data _null_;                                                                                                                                                                                                                                                  
        
       Set rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config)) end = eof ;
       where form_config_key=&form_config_key
             and target_field_name ne '' and target_field_name ne 'FILLER';
       by form_efile_record_seq_number;
       length stmt $ 4000; 
       efile_field_length=target_field_end_position - target_field_start_position +1;
       %if %upcase(&input_or_put) ="PUT" %then
       %do;
       file  rc_tmplt(&form_type_code._macro_wrt_efile.sas);    
       %end;
       %else
       %do;
       file  rc_tmplt(&form_type_code._macro_wrt_efile_input.sas);    
       %end;

          
       if target_sas_format_name = '' then
       do;
          if target_field_num_flg ne 1 then 
             target_sas_format_name='$'||strip(put(efile_field_length,best.))||'.';
          else     
            target_sas_format_name=strip(put(efile_field_length,best.))||'.';
       end; 
       %if %upcase(&input_or_put) ="INPUT" %then
       %do;
           if upcase(substr(target_sas_format_name,1,1))='Z' then 
              target_sas_format_name=strip(put(efile_field_length,best.))||'.';
           if upcase(substr(target_sas_format_name,1,7))='MMDDYYN' then 
              target_sas_format_name='MMDDYY'||strip(put(efile_field_length,best.))||'.';
       %end;     
      

       If first.form_efile_record_seq_number then 
       do ;                                                                                                                                                                                                                                        
          stmt= '%macro '||strip(&input_or_put)||'_'
                ||strip("&form_type_code")
                ||'_'||strip(form_efile_record_id)
                ||';'; put stmt;
          stmt=&input_or_put;
          put stmt; 
       end ;        
      
       
       stmt='@'
            ||' '|| strip(put(target_field_start_position,best.))||' '
            ||strip(target_field_name) ||' '
            ||target_sas_format_name 
            ;
       put stmt; 
       If last.form_efile_record_seq_number then 
       do;
          stmt=';'; put stmt;
          stmt='%mend;'; put stmt; put; 
       end;
    run; 
   
%MEND;                          

 
