/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_efile_gen_macro_wrt_xml.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Generate SAS program for writing configuration data in RC_CFG
|          into XML for generating FinCEN e-file in XML 
|           
|          
+------------------------------------------------------------------------------+
| USAGE:   form_config_key = form key
|          form_type_code = form type (e.g. SARX, CTRX)
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2018 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro  rc_efile_gen_macro_wrt_xml(   
                            form_config_key=
                          , form_type_code=                                                 
               ) /  des='Macro to create sas code for loading RC_CFG data in xml format';         

       %let trans_rc=0;
       %let _fcfmsg_=;

       data _null_;                                                                                                                                                                                                                                                  
        
       Set rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config)) end = eof ;
       where form_config_key=&form_config_key
             and form_efile_record_id in ('transmitter' 'filer' 'branch' 'institution')
             and target_field_name ne '' and source_field_name = '';
       by form_efile_record_seq_number;
       length stmt $ 4000; 
             
       file  rc_tmplt(%upcase(&form_type_code)_macro_wrt_xml.sas);         
   

       If first.form_efile_record_seq_number then 
       do ;                                                                                                                                                                                                                                        
          stmt= '%macro '
                ||strip("&form_type_code")
                ||'_'||strip(form_efile_record_id)
                ||';'; put stmt;      
           
       end ;  

       stmt='%rc_xml_gen(field_name='||strip(target_field_name)||', field_type='||strip(source_field_type)||');'; 
       
       put stmt; 
       If last.form_efile_record_seq_number then 
       do;
          stmt=';'; put stmt;
          stmt='%mend;'; put stmt; put; 
       end;
    run;
    %fcf_rcset(&syserr);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: RC: Failed to create &form_type_code._macro_wrt_xml.sas;
        %fcf_put_error;
        %goto MACRO_END;
    %end; 
 


%MACRO_END:  

    %if &trans_rc eq 3 or &trans_rc ge 5 %then 
       %fcf_execute_macro(fcf_error);
    %else 
       %fcf_execute_macro(fcf_success);
     
%MEND;                          

 
