/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_efile_transpoes_data.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Generic program to transform report nodes into records based on 
|          the definition in <form_type_code>_macro_xpose_node.sas
|          This program is called by rc_efile_fincen_detail.
|          
+------------------------------------------------------------------------------+
| USAGE:   form_config_key = form key
|          form_type_code  = form type code (defined in FSK_RC_FORM_CONFIG)
|          report_list     = report key list of reports to be processed 
|                            Keys are separated by ' ' 
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

  
%macro rc_efile_transpose_data(
                               form_config_key=,
                               form_type_code=,
                               report_list=
                              );

    %let trans_rc=0;
    %let _fcfmsg_=;

    %rc_rest_get_node(report_list=&report_list);

     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
             %let _fcfmsg_=Error: RC: cannot deleting existing RC_REPORT_NODE.;
             %fcf_put_error;     
             %goto MACRO_END;
     %end;



    /*---------------------------------------------
     * Transpose report node data into records
     *---------------------------------------------*/
    /* get the record ID */
    /* rc_form_code_mapping is used to include external parties to 4A */
    proc sql noprint; 
        create table rc_report_node_more as
        select a.node_name length=32,  
               a.node_value, 
               a.report_key,
               a.entity_key,
               a.entity_level_code length=32,
               a.node_path length=128,  
               b.form_efile_record_id 
        from rc_report_node as a,
             rc_cfg.form_efile_record_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config)) as b,
             seg_kc.fsk_rc_form_code_mapping as c             
        where  b.source_table_name='RC_REPORT_NODE'
        %if %str(&report_list) ne %str() %then
        %do;
           and a.report_key in (&report_list)
        %end; 
           and b.form_config_key=&form_config_key
           and c.form_config_key=&form_config_key
           and a.node_name ne 'id'
           and a.node_value ne 'false'
           and a.entity_level_code=c.input_code
           and c.format_name=b.source_entity_level_code
           and a.group_key_name=b.source_group_name  
        order by form_efile_record_id, report_key,entity_key, node_path        
        ;
        
        quit;
       
        

        %if &form_type_code=DOEP %then
        %do;
          proc sql noprint;
          create table rc_report_node_more_2 as
          select more.*,  d.entity_key
          from 
          (
            select a.node_name length=32,  
                   a.node_value, 
                   a.report_key,              
                   a.entity_level_code length=32,
                   a.node_path length=128,  
                   b.form_efile_record_id 
            from rc_report_node as a,
                 rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config)) as b,
                 seg_kc.fsk_rc_form_code_mapping as c
            where  upcase(scan(b.source_field_name,1,'.'))=a.entity_level_code
                   and  scan(b.source_field_name,2,'.')=a.node_name
                    
            %if %str(&report_list) ne %str() %then
            %do;
                   
               and a.report_key in (&report_list)
               
            %end; 
                
               and b.form_config_key=&form_config_key
               and c.form_config_key=&form_config_key
               and a.node_name ne 'id'
               and a.node_value ne 'false'
               and a.entity_level_code=c.input_code
               and c.format_name=a.entity_level_code
           )  as more
           left join  seg_kc.fsk_rc_report_entity as d   
           on more.report_key=d.report_key                   
        order by form_efile_record_id, report_key,entity_key, node_path        
        ;


        proc append base=rc_report_node_more data=rc_report_node_more_2 force;
        run;
        proc sort data=rc_report_node_more;
        by form_efile_record_id  report_key entity_key node_path;
        run;
        
        %end;

        %if %rc_nobs(rc_report_node_more) =0 %then %do;
                 %let _fcfmsg_=Error: RC: No &form_type_code report nodes found.;
                 %fcf_put_error;
                 %fcf_rcset(3);
                 %put;
                 %goto MACRO_END;
        %end;
 
         
      proc sql noprint;
         select distinct form_efile_record_id into :record_id_1 -  
         from rc_report_node_more
         where form_efile_record_id ne ''
           ;
         %let record_id_cnt=&sqlobs;

      quit;

        

        %if &record_id_cnt=0 %then %do;
                 %let _fcfmsg_=Note: RC: No &form_type_code report nodes found.;
                 %fcf_put_error;
                 %fcf_rcset(3);
                 %goto MACRO_END;
        %end;


        %if not %sysfunc(fileexist(&rc_template_path&slash&form_type_code._macro_xpose_node.sas))%then %do; 
                 %let _fcfmsg_=Note: RC: &rc_template_path&slash&form_type_code._macro_xpose_node.sas not found.;
                 %fcf_put_error;
                 %fcf_rcset(3);
                 %goto MACRO_END;
        %end;

       
        %inc rc_tmplt(%trim(&form_type_code)_macro_xpose_node.sas);
        %inc rc_tmplt(%trim(&form_type_code)_macro_clear_node.sas);

        %do itable=1 %to  &record_id_cnt ;

            data &form_type_code._&&&record_id_&itable (index=(report_key));
                if 0 then set rc_db.&form_type_code._&&&record_id_&itable(%fcf_get_ds_opts(lib_name=rc_db, ds_name=&form_type_code._&&&record_id_&itable));
                set
                    rc_report_node_more  (keep=node_name  
                                          node_value 
                                          report_key entity_key entity_level_code node_path 
                                          form_efile_record_id
                                          rename=(node_name=source_field_name))
                     
                 ;
                where form_efile_record_id="&&&record_id_&itable";
                by  report_key  entity_key node_path                
                ;
                retain entity_seq_number row_seq_number;

                 
                if first.report_key then entity_seq_number=0;
                if first.entity_key then
                do; 
                   link CLEAR_NODE;
                   entity_seq_number+1;
                   row_seq_number=0;
                end;
                         
                %rc_load_&form_type_code._&&&record_id_&itable;
                if last.node_path then
                do;                
                     row_seq_number+1;
                     record_type="&&&record_id_&itable";                
                     output;
                end;
        
                drop source_field_name node_value   ;
                return;
             CLEAR_NODE:
                %rc_clear_&form_type_code._&&&record_id_&itable;
             return;
             run;
             %fcf_rcset(&syserr);
             %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
                %goto MACRO_END;
              %end;

        %end;


        /* Create the tables that do not use json nodes but the entities are saved in RC_REPORT_ENTITY */ 
        proc sql noprint;
         select distinct form_efile_record_id, 
                         source_entity_level_code
                         into 
                         :nojson_record_id_1 -,   
                         :nojson_entity_level_code_1 -  
         from rc_cfg.form_efile_record_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config))
         where source_table_name='RC_REPORT_ENTITY' 
               and form_config_key=&form_config_key
          ;
         %let nojson_record_id_cnt=&sqlobs;
         quit;
         
         %do nojson_itable=1 %to  &nojson_record_id_cnt ;

            data &form_type_code._&&&nojson_record_id_&nojson_itable (index=(report_key));
                if 0 then set rc_db.&form_type_code._&&&nojson_record_id_&nojson_itable(%fcf_get_ds_opts(lib_name=rc_db, ds_name=&form_type_code._&&&nojson_record_id_&nojson_itable));
                set seg_kc.fsk_rc_report_entity (keep=report_key entity_key entity_level_code 
                                          );
                where report_key in (&report_list) 
                      and entity_level_code="&&&nojson_entity_level_code_&nojson_itable"
                 ;
                record_type="&&&nojson_record_id_&nojson_itable";
                entity_seq_number=_n_;
                row_seq_number=_n_;
                entity_level_code="&&&nojson_entity_level_code_&nojson_itable";
            run;
      
         %end;

   


%MACRO_END:
  

    %if &trans_rc eq 3 or &trans_rc ge 5 %then 
       %fcf_execute_macro(fcf_error);
    %else 
       %fcf_execute_macro(fcf_success);
    
    

%mend;

 
