/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_resp_fince_ctr_read
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    read the ctr acknowledgement receipt based on govt spec. 
|          
+------------------------------------------------------------------------------+
| USAGE:    INFREF=fileref pointing to a CTR repsonse file.                  
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/



%macro rc_resp_fincen_ctr_read ( infref=    
                               );
    proc datasets lib=work nowarn nolist;
         delete __1A _2A _2B 
                _3A _3B _3C   
                _4A _4B _4C  
                _9Z 
                _ctr_error_codes
    ;
    quit;

    %let common_fld_list=line_number record_type user_field;
        %let doc_fld_list=trans_seq_number bsa_id;
        data 
             _1A (keep=&common_fld_list coverage_begin_dt coverage_end_dt tcc bsn)
             _2A (keep=&common_fld_list filing_inst_tin)
             _2B (keep=&common_fld_list fin_inst_loc_code)
             _2C (keep=&common_fld_list branch_loc_code)
             _3A (keep=&common_fld_list &doc_fld_list)
             _3B (keep=&common_fld_list &doc_fld_list)
             _3C (keep=&common_fld_list &doc_fld_list)
             _4A (keep=&common_fld_list &doc_fld_list)
             _4B (keep=&common_fld_list &doc_fld_list)
             _4C (keep=&common_fld_list &doc_fld_list)
             _9Z (keep=&common_fld_list)       
             _ctr_error_codes  (keep=&common_fld_list error_seq_number record_type error_code trans_seq_number BSA_ID)
          ;

          infile &infref dsd;
          length ERROR_CODES $ 90 
                 ERROR_CODE  $ 4
                 LINE_NUMBER     8
                 ERROR_SEQ_NUMBER 8

          ; 
                
          input @1 RECORD_TYPE $2. @;
          line_number=_n_;

          /* Acknowledgement Transmitter (1A) Record */
          if RECORD_TYPE = '1A' then do;
            input
              @3   COVERAGE_BEGIN_DT $8.    /* Coverage Begin Date                                                   */
              @11  COVERAGE_END_DT $8.      /* Coverege End Date                                                     */
              @19  TCC $8.                  /* Transmitter Control Code                                              */
              @27  BSN $3.                  /* Batch Sequence Number                                                 */
              @30  ERROR_CODES $90.         /* Error Codes - 3 alphanumeric                                          */
              @120 USER_FIELD $10.          /* Field Positions 1191-1200 of the incoming 1A record                   */
              @130 FILLER $21.;             /* Space Filled                                                          */
            output _1A;
          end;

          /* Acknowledgement Filing Institution Information (2A) Record */
          else if RECORD_TYPE = '2A' then do;
            input
              @3   FILING_INST_TIN $25.     /* Filing Institution TIN                                                */ 
              @28  ERROR_CODES $90.         /* Error Codes - 4 alphanumeric                                          */
              @118 USER_FIELD $10.          /* Field Positions 1041-1050 of the incoming 2A record                   */ 
              @128 FILLER $23.;             /* Space Filled                                                          */
            output _2A;
          end;     
           
          /* Acknowledgement Branch or Office Where Activity Occurred (2C) Record */
          else if RECORD_TYPE = '2B' then do;
            input
              @3   BRANCH_LOC_CODE $10.     /* Branch Location Code                                                  */
              @13  ERROR_CODES $90.         /* Error Codes - 4 alphanumeric                                          */
              @103 USER_FIELD $10.          /* Field Positions 1191-1200 of the incoming 2C record                   */
              @113 FILLER $38.;             /* Space Filled                                                          */
            output _2B;
          end;

          /* Acknowledgement Suspicious Activity (3A) Record */
          else if RECORD_TYPE = '3A' then do;
            input
              @3   TRANS_SEQ_NUMBER  5.     /* Transaction Sequence Number                                           */
              @8   BSA_ID $14.              /* BSA ID                                                                */
              @22  ERROR_CODES $90.         /* Error Codes - 4 alphanumeric                                          */
              @112 USER_FIELD $10.          /* Field Positions 1041-1050 of the incoming 3A record                   */
              @122 FILLER $29.;             /* Space Filled                                                          */
            output _3A;
          end;

          /* Acknowledgement Foreign Cash-in (3B) Record */
          else if RECORD_TYPE = '3B' then do;
            input
              @3   TRANS_SEQ_NUMBER  5      /* Transaction Sequence Number                                           */ 
              @8   BSA_ID $14.              /* BSA ID                                                                */
              @22  ERROR_CODES $90.         /* Error Codes - 4 alphanumeric                                          */
              @112 USER_FIELD $10.          /* Field Positions 1041-1050 of the incoming 3B record                   */
              @122 FILLER $29.;             /* Space Filled                                                          */
            output _3B;
          end;

          /* Acknowledgement Foreign Cash-out (3C) Record */
          else if RECORD_TYPE = '3C' then do;
            input
              @3   TRANS_SEQ_NUMBER  5.     /* Transaction Sequence Number                                           */ 
              @8   BSA_ID $14.              /* BSA ID                                                                */
              @22  ERROR_CODES $90.         /* Error Codes - 4 alphanumeric                                          */
              @112 USER_FIELD $10.          /* Field Positions 1041-1050 of the incoming 3C record                   */
              @122 FILLER $29.;             /* Space Filled                                                          */
            output _3C;
          end;

          /* Acknowledgement Person Involved (4A) Record */
          else if RECORD_TYPE = '4A' then do;
            input
              @3   TRANS_SEQ_NUMBER  5.     /* Transaction Sequence Number                                           */ 
              @8   BSA_ID $14.              /* BSA ID                                                                */
              @22  ERROR_CODES $90.         /* Error Codes - 4 alphanumeric                                          */
              @112 USER_FIELD $10.          /* Field Positions 1041-1050 of the incoming 4A record                   */
              @122 FILLER $29.;             /* Space Filled                                                          */
            output _4A;
          end;

          /* Acknowledgement Account Number (Cash-in)(4B) Record */
          else if RECORD_TYPE = '4B' then do;
            input  
              @3   TRANS_SEQ_NUMBER  5.         /* Transaction Sequence Number                                           */ 
              @8   BSA_ID $14.              /* BSA ID                                                                */
              @22  ERROR_CODES $90.         /* Error Codes - 4 alphanumeric                                          */
              @112 USER_FIELD $10.          /* Field Positions 1041-1050 of the incoming 4B record                   */
              @122 FILLER $29.;             /* Space Filled                                                          */
            output _4B;
          end;

          /* Acknowledgement Account Number (Cash-in)(4C) Record */
          else if RECORD_TYPE = '4C' then do;
            input
              @3   TRANS_SEQ_NUMBER  5.         /* Transaction Sequence Number                                           */ 
              @8   BSA_ID $14.              /* BSA ID                                                                */
              @22  ERROR_CODES $90.         /* Error Codes - 4 alphanumeric                                          */
              @112 USER_FIELD $10.          /* Field Positions 1041-1050 of the incoming 4C record                   */
              @122 FILLER $29.;             /* Space Filled                                                          */
            output _4C;
          end;
           

          /* Acknowledgement Trailer for Transmitter (9Z) Record */
          else if RECORD_TYPE = '9Z' then do;
            input
              @3   NUM_PARENT_RECS $10.     /* Number of Filing Institution Contact Information (2A) Records in File */
              @13  NUM_CTR_RECS $10.        /* Number of Suspicious Activity (3A) Records in File                    */
              @23  ERROR_CODES $90.         /* Error Codes - 3 alphanumeric                                          */
              @112 USER_FIELD $10.          /* Field Positions 1041-1050 of the incoming 9Z record                   */
              @122 FILLER $29.;             /* Space Filled                                                          */
             output _9Z;
          end;
          
          link PARSE_ERROR; 
          return;

    /* parse the error code into 4 character strings. */
    PARSE_ERROR:

        if record_type in ('1A' '9Z') then error_code_len=3;
        else error_code_len=4;
        remaining_codes=error_codes;
        error_seq_number=0;
        /* stop the loop when there are no alphabets in the list */
        do while (indexc(remaining_codes,'ABCDEFGHIJKLMNOPQRSTUXWXYZ') > 0 and error_seq_number < 31);
           error_code=substr(remaining_codes,1,error_code_len);
           error_seq_number+1;
           output _ctr_error_codes;
           remaining_codes=substr(remaining_codes,error_code_len+1);
        end;
    return;
    run;

    %fcf_rcset(&sqlrc);
                        

     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %let _fcfmsg_=ERROR: RC: Unable to read CTR Response file;
         %fcf_put_error;
         %goto MACRO_END;
     %end;
 
%MACRO_END:    

  
    %if &trans_rc eq 3 or &trans_rc ge 5 %then 
      %fcf_execute_macro(fcf_error);
    %else %do;
      %fcf_execute_macro(fcf_success);
    %end;
   
 
%mend;
